
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 2388
 * transforms:
 *    ('fgeu', 'a', 'b') => ('inot', ('flt', 'a', 'b'))
 *    ('fltu', 'a', 'b') => ('inot', ('fge', 'a', 'b'))
 *    ('fneo', 0.0, 'a') => ('flt', 0.0, ('fabs', 'a'))
 *    ('fequ', 0.0, 'a') => ('inot', ('flt', 0.0, ('fabs', 'a')))
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fmul', ('fsign', 'a'), ('ffloor', ('fadd', ('fabs', 'a'), 0.5))) => ('ftrunc', ('fadd', 'a', ('fmul', ('fsign', 'a'), 0.5)))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float,nsz)', 'a', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('iadd_sat', 'a', 0) => a
 *    ('isub_sat', 'a', 0) => a
 *    ('uadd_sat', 'a', 0) => a
 *    ('usub_sat', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a')
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0)
 *    ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0)
 *    ('ieq', ('ushr(is_used_once)', 'a', '#b'), 0) => ('ult', 'a', ('ishl', 1, 'b'))
 *    ('ine', ('ushr(is_used_once)', 'a', '#b'), 0) => ('uge', 'a', ('ishl', 1, 'b'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul(nsz,nnan)', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz(nsz)', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz(nsz)', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma(is_only_used_as_float,nsz,nnan,ninf)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma(nsz)', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz(nsz)', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz(nsz)', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz(nsz)', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'b')))) => ('fmulz', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b')))
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b'))) => ('fmulz', ('fneg', ('fabs', 'a')), ('fabs', 'b'))
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b'))) => ('fmulz', ('fneg', ('fabs', 'a')), ('fneg', 'b'))
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', ('fneg', ('fabs', 'a')), 'b')
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b'))) => ('fmulz', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b'))) => ('fmulz', ('fabs', 'a'), ('fneg', 'b'))
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', ('fabs', 'a'), 'b')
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b'))) => ('fmulz', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', ('fneg', 'a'), 'b')
 *    ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32(nsz)', ('fneg', ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', ('fneg', ('fabs', 'a')), 'b')
 *    ('fmul@32(nsz)', ('fabs', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', ('fabs', 'a'), 'b')
 *    ('fmul@32(nsz)', ('fneg', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', ('fneg', 'a'), 'b')
 *    ('fmul@32(nsz)', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b')), 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b')), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b')), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fneg', 'b'), 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), 'b', 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fneg', 'b'), 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', ('fabs', 'a'), 'b', 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c')
 *    ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32(nsz)', ('fneg', ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), 'b', 'c')
 *    ('ffma@32(nsz)', ('fabs', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', ('fabs', 'a'), 'b', 'c')
 *    ('ffma@32(nsz)', ('fneg', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c')
 *    ('ffma@32(nsz)', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', ('fneg', ('fabs', 'b'))))) => ('fexp2', ('fmulz', 'a', ('fneg', ('fabs', 'b'))))
 *    ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', ('fabs', 'b')))) => ('fexp2', ('fmulz', 'a', ('fabs', 'b')))
 *    ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', ('fneg', 'b')))) => ('fexp2', ('fmulz', 'a', ('fneg', 'b')))
 *    ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b'))
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc@16', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ftrunc@32', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ftrunc@64', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd@16', 'a', ('fadd@16', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@16', 'b', ('ffloor', 'a'))
 *    ('fadd@32', 'a', ('fadd@32', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@32', 'b', ('ffloor', 'a'))
 *    ('fadd@64', 'a', ('fadd@64', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@64', 'b', ('ffloor', 'a'))
 *    ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', 'a', 0.0) => 0.0
 *    ('fdot3', 'a', 0.0) => 0.0
 *    ('fdot2', 'a', 0.0) => 0.0
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a(is_not_const)'), '#b') => ('flt', ('fneg', 'b'), 'a')
 *    ('flt', '#b', ('fneg', 'a(is_not_const)')) => ('flt', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg', 'a(is_not_const)'), '#b') => ('fge', ('fneg', 'b'), 'a')
 *    ('fge', '#b', ('fneg', 'a(is_not_const)')) => ('fge', 'a', ('fneg', 'b'))
 *    ('fneu', ('fneg', 'a(is_not_const)'), '#b') => ('fneu', ('fneg', 'b'), 'a')
 *    ('feq', '#b', ('fneg', 'a(is_not_const)')) => ('feq', 'a', ('fneg', 'b'))
 *    ('flt', 'a', '#b(is_negative_zero)') => ('flt', 'a', 0.0)
 *    ('flt', '#b(is_negative_zero)', 'a') => ('flt', 0.0, 'a')
 *    ('fge', 'a', '#b(is_negative_zero)') => ('fge', 'a', 0.0)
 *    ('fge', '#b(is_negative_zero)', 'a') => ('fge', 0.0, 'a')
 *    ('fneu', 'a', '#b(is_negative_zero)') => ('fneu', 0.0, 'a')
 *    ('feq', '#b(is_negative_zero)', 'a') => ('feq', 'a', 0.0)
 *    ('ieq', ('ineg', 'a'), 0) => ('ieq', 'a', 0)
 *    ('ine', ('ineg', 'a'), 0) => ('ine', 'a', 0)
 *    ('ieq', ('iabs', 'a'), 0) => ('ieq', 'a', 0)
 *    ('ine', ('iabs', 'a'), 0) => ('ine', 'a', 0)
 *    ('fneu', ('fabs', 'a'), 0.0) => ('fneu', 'a', 0.0)
 *    ('feq', ('fabs', 'a'), 0.0) => ('feq', 'a', 0.0)
 *    ('fneu', ('fabs', 'a'), ('fabs', 'a')) => ('fneu', 'a', 'a')
 *    ('feq', ('fabs', 'a'), ('fabs', 'a')) => ('feq', 'a', 'a')
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('ieq', 'a@1', False) => ('inot', 'a')
 *    ('ieq', 'a@1', True) => a
 *    ('ine', 'a@1', False) => a
 *    ('ine', 'a@1', True) => ('inot', 'a')
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat(nsz)', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('fmax', ('fsat(is_used_once)', 'a'), ('fsat(is_used_once)', 'b')) => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('umin', ('iand', 'a', '#b(is_pos_power_of_two)'), ('iand', 'c', 'b')) => ('iand', ('iand', 'a', 'b'), ('iand', 'c', 'b'))
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('feq(is_used_once)', 'a@16', 0.0), ('feq', 'b@16', 0.0)) => ('feq', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('ior', ('fneu(is_used_once)', 'a@16', 0.0), ('fneu', 'b@16', 0.0)) => ('fneu', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('iand', ('feq(is_used_once)', 'a@16', 0.0), ('feq', 'b@16', 0.0)) => ('feq', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('iand', ('fneu(is_used_once)', 'a@16', 0.0), ('fneu', 'b@16', 0.0)) => ('fneu', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('~f2f16', ('f2f', 'a')) => ('f2f16', 'a')
 *    ('~f2f16', ('u2f', 'a')) => ('u2f16', 'a')
 *    ('~f2f16', ('i2f', 'a')) => ('i2f16', 'a')
 *    ('~f2u16', ('f2f', 'a')) => ('f2u16', 'a')
 *    ('~f2i16', ('f2f', 'a')) => ('f2i16', 'a')
 *    ('i2f16', ('f2i', ('fsign', 'a@16'))) => ('fsign', 'a')
 *    ('~f2f16', ('f2f32', 'a@16')) => a
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('~f2f16', ('f2f64', 'a@16')) => a
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('feq(is_used_once)', 'a@32', 0.0), ('feq', 'b@32', 0.0)) => ('feq', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('ior', ('fneu(is_used_once)', 'a@32', 0.0), ('fneu', 'b@32', 0.0)) => ('fneu', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('iand', ('feq(is_used_once)', 'a@32', 0.0), ('feq', 'b@32', 0.0)) => ('feq', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('iand', ('fneu(is_used_once)', 'a@32', 0.0), ('fneu', 'b@32', 0.0)) => ('fneu', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('~f2f32', ('f2f', 'a')) => ('f2f32', 'a')
 *    ('~f2f32', ('u2f', 'a')) => ('u2f32', 'a')
 *    ('~f2f32', ('i2f', 'a')) => ('i2f32', 'a')
 *    ('~f2u32', ('f2f', 'a')) => ('f2u32', 'a')
 *    ('~f2i32', ('f2f', 'a')) => ('f2i32', 'a')
 *    ('i2f32', ('f2i', ('fsign', 'a@32'))) => ('fsign', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('feq(is_used_once)', 'a@64', 0.0), ('feq', 'b@64', 0.0)) => ('feq', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('ior', ('fneu(is_used_once)', 'a@64', 0.0), ('fneu', 'b@64', 0.0)) => ('fneu', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('iand', ('feq(is_used_once)', 'a@64', 0.0), ('feq', 'b@64', 0.0)) => ('feq', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('iand', ('fneu(is_used_once)', 'a@64', 0.0), ('fneu', 'b@64', 0.0)) => ('fneu', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0)
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('~f2f64', ('f2f', 'a')) => ('f2f64', 'a')
 *    ('~f2f64', ('u2f', 'a')) => ('u2f64', 'a')
 *    ('~f2f64', ('i2f', 'a')) => ('i2f64', 'a')
 *    ('~f2u64', ('f2f', 'a')) => ('f2u64', 'a')
 *    ('~f2i64', ('f2f', 'a')) => ('f2i64', 'a')
 *    ('i2f64', ('f2i', ('fsign', 'a@64'))) => ('fsign', 'a')
 *    ('i2i1', ('i2i8', 'a@1')) => a
 *    ('u2u1', ('u2u8', 'a@1')) => a
 *    ('i2i1', ('i2i16', 'a@1')) => a
 *    ('u2u1', ('u2u16', 'a@1')) => a
 *    ('u2f16', ('u2u8', 'a@1')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i8', 'a@1')) => ('i2f16', 'a')
 *    ('u2f16', ('u2u16', 'a@1')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i16', 'a@1')) => ('i2f16', 'a')
 *    ('u2f16', ('u2u32', 'a@1')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i32', 'a@1')) => ('i2f16', 'a')
 *    ('u2f16', ('u2u64', 'a@1')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i64', 'a@1')) => ('i2f16', 'a')
 *    ('i2i1', ('i2i32', 'a@1')) => a
 *    ('u2u1', ('u2u32', 'a@1')) => a
 *    ('u2f32', ('u2u8', 'a@1')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i8', 'a@1')) => ('i2f32', 'a')
 *    ('u2f32', ('u2u16', 'a@1')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i16', 'a@1')) => ('i2f32', 'a')
 *    ('u2f32', ('u2u32', 'a@1')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@1')) => ('i2f32', 'a')
 *    ('u2f32', ('u2u64', 'a@1')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i64', 'a@1')) => ('i2f32', 'a')
 *    ('i2i1', ('i2i64', 'a@1')) => a
 *    ('u2u1', ('u2u64', 'a@1')) => a
 *    ('u2f64', ('u2u8', 'a@1')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i8', 'a@1')) => ('i2f64', 'a')
 *    ('u2f64', ('u2u16', 'a@1')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i16', 'a@1')) => ('i2f64', 'a')
 *    ('u2f64', ('u2u32', 'a@1')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i32', 'a@1')) => ('i2f64', 'a')
 *    ('u2f64', ('u2u64', 'a@1')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@1')) => ('i2f64', 'a')
 *    ('i2i8', ('i2i16', 'a@8')) => a
 *    ('u2u8', ('u2u16', 'a@8')) => a
 *    ('u2f16', ('u2u16', 'a@8')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i16', 'a@8')) => ('i2f16', 'a')
 *    ('u2f16', ('u2u32', 'a@8')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i32', 'a@8')) => ('i2f16', 'a')
 *    ('u2f16', ('u2u64', 'a@8')) => ('u2f16', 'a')
 *    ('i2f16', ('i2i64', 'a@8')) => ('i2f16', 'a')
 *    ('i2i8', ('i2i32', 'a@8')) => a
 *    ('u2u8', ('u2u32', 'a@8')) => a
 *    ('u2f32', ('u2u16', 'a@8')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i16', 'a@8')) => ('i2f32', 'a')
 *    ('u2f32', ('u2u32', 'a@8')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@8')) => ('i2f32', 'a')
 *    ('u2f32', ('u2u64', 'a@8')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i64', 'a@8')) => ('i2f32', 'a')
 *    ('i2i8', ('i2i64', 'a@8')) => a
 *    ('u2u8', ('u2u64', 'a@8')) => a
 *    ('u2f64', ('u2u16', 'a@8')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i16', 'a@8')) => ('i2f64', 'a')
 *    ('u2f64', ('u2u32', 'a@8')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i32', 'a@8')) => ('i2f64', 'a')
 *    ('u2f64', ('u2u64', 'a@8')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@8')) => ('i2f64', 'a')
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('u2f32', ('u2u64', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i64', 'a@16')) => ('i2f32', 'a')
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('u2f64', ('u2u32', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i32', 'a@16')) => ('i2f64', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('bcsel', ('ult', 'b@8', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a@8', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a@8', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b@8', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b@8', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a@8', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a@8', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b@8', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2))
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('bcsel', ('ult', 'b@16', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a@16', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a@16', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b@16', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b@16', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a@16', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a@16', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b@16', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3))
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('bcsel', ('ult', 'b@32', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a@32', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a@32', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b@32', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b@32', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a@32', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a@32', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b@32', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4))
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('bcsel', ('ult', 'b@64', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a@64', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a@64', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b@64', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b@64', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a@64', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a@64', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b@64', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5))
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('ishl', ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)), '#c') => ('bcsel', ('ige', ('iand', 'c', 31), ('find_lsb', 'b')), ('ishl', ('iand', 'a', 'b'), ('iadd', ('iand', 'c', 31), ('ineg', ('find_lsb', 'b')))), ('ushr', ('iand', 'a', 'b'), ('iadd', ('ineg', ('iand', 'c', 31)), ('find_lsb', 'b'))))
 *    ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)) => ('ushr', ('iand', 'a', 'b'), ('find_lsb', 'b'))
 *    ('ior', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('ior', ('b2i', 'a'), 'b'), 1)
 *    ('iand', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('b2i', 'a'), 'b')
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0)
 *    ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z')))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h'))))
 *    ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p')))))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z')))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h'))))
 *    ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p')))))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z')))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h'))))
 *    ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p')))))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z')))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h'))))
 *    ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p')))))
 *    ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', 0) => 0
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', ('inot', 'a')) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', -1) => -1
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('ixor', 'a', ('ixor', 'a', 'b')) => b
 *    ('ixor', 'a', -1) => ('inot', 'a')
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('iand(is_used_once)', 'a', 'b'), ('iand(is_used_once)', 'a', 'c')) => ('iand', 'a', ('iand', 'b', 'c'))
 *    ('iand@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', 0, ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('iand@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), 0)
 *    ('iand@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('iand@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a'))
 *    ('ior@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('ior@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a'))
 *    ('ior@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', -1, ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('ior@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), -1)
 *    ('ixor@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ixor', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('ixor@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ixor', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a'))
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', -1, 'a') => -1
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b')))
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b')))
 *    ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b')))
 *    ('bitfield_select', 4278190080, ('ishl', 'b@32', 24), ('ushr', 'a', 8)) => ('shfr', 'b', 'a', 8)
 *    ('bitfield_select', 4294901760, ('ishl', 'b@32', 16), ('extract_u16', 'a', 1)) => ('shfr', 'b', 'a', 16)
 *    ('bitfield_select', 4294967040, ('ishl', 'b@32', 8), ('extract_u8', 'a', 3)) => ('shfr', 'b', 'a', 24)
 *    ('ior', ('ishl', 'b@32', 24), ('ushr', 'a', 8)) => ('shfr', 'b', 'a', 8)
 *    ('ior', ('ishl', 'b@32', 16), ('extract_u16', 'a', 1)) => ('shfr', 'b', 'a', 16)
 *    ('ior', ('ishl', 'b@32', 8), ('extract_u8', 'a', 3)) => ('shfr', 'b', 'a', 24)
 *    ('ior', ('ishl', 'b@32', ('iadd', 32, ('ineg', 'c'))), ('ushr@32', 'a', 'c')) => ('shfr', 'b', 'a', 'c')
 *    ('bfi', 4294967295, 'a', 'b') => a
 *    ('bfi', 0, 'a', 'b') => b
 *    ('bfi', ('ineg', ('b2i', 'a@1')), 'b', 'c') => ('bcsel', 'a', 'b', 'c')
 *    ('bfi', '#a(is_odd)', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bfi', '#a(is_odd)', 'b', 0) => ('iand', 'a', 'b')
 *    ('u2f32', ('bfi', '#a(is_pos_power_of_two)', 'b', 0)) => ('bcsel', ('ieq', ('iand', 'b', 1), 0), ('iand', 'b', 1), ('u2f', 'a'))
 *    ('u2f', ('bfi', '#a(is_pos_power_of_two)', 'b', 0)) => ('bcsel', ('ieq', ('iand', 'b', 1), 0), 0, ('u2f', 'a'))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 3.0)) => ('fmul', ('fmul', 'a', 'a'), 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 5.0)) => ('fmul', ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')), 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 6.0)) => ('fmul', ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')), ('fmul', 'a', 'a'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 8.0)) => ('fmul', ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')), ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 3.0) => ('fmul', ('fmul', 'a', 'a'), 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('umax', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('umin', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a'), 1) => ('b2i', 'a')
 *    ('ine', ('umin', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('iand', 'a', ('ine', 'b', 0))
 *    ('ine', ('umax', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('ior', 'a', ('ine', 'b', 0))
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('f2i32', ('f2fmp', 'a@32')) => ('f2i32', 'a')
 *    ('f2u32', ('f2fmp', 'a@32')) => ('f2u32', 'a')
 *    ('i2f32', ('i2imp', 'a@32')) => ('i2f32', 'a')
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('fround_even', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y
 *    ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0
 *    ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31)
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('unpack_64_4x16', ('pack_64_4x16', 'a')) => a
 *    ('unpack_64_4x16', ('pack_64_2x32', ('vec2', ('pack_32_2x16_split', 'a', 'b'), ('pack_32_2x16_split', 'c', 'd')))) => ('vec4', 'a', 'b', 'c', 'd')
 *    ('unpack_64_4x16', ('pack_64_2x32_split', ('pack_32_2x16_split', 'a', 'b'), ('pack_32_2x16_split', 'c', 'd'))) => ('vec4', 'a', 'b', 'c', 'd')
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('ishr', ('iand', 'a', 65280), 8) => ('extract_u8', 'a', 1)
 *    ('ishr', ('iand', 'a', 16711680), 16) => ('extract_u8', 'a', 2)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_i8', ('iand', 'a', 65280), 1) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('iand', 'a', 16711680), 2) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('iand', 'a', 4278190080), 3) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('iand', 'a', 65280), 1) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('iand', 'a', 16711680), 2) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('iand', 'a', 4278190080), 3) => ('extract_u8', 'a', 3)
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('unpack_32_4x8', ('pack_32_4x8', 'a')) => a
 *    ('unpack_32_2x16', ('pack_32_2x16', 'a')) => a
 *    ('unpack_64_4x16', ('pack_64_4x16', 'a')) => a
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('pack_32_4x8', ('unpack_32_4x8', 'a')) => a
 *    ('pack_32_2x16', ('unpack_32_2x16', 'a')) => a
 *    ('pack_64_4x16', ('unpack_64_4x16', 'a')) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_i16', ('iand', 'a', 16711680), 1) => ('extract_u8', 'a', 2)
 *    ('extract_u16', ('iand', 'a', 16711680), 1) => ('extract_u8', 'a', 2)
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('pack_half_2x16_split', 'a', 'b') => ('pack_half_2x16_rtz_split', 'a', 'b')
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_64_2x32_split_x', ('ushr', 'a', 32)) => ('unpack_64_2x32_split_y', 'a')
 *    ('u2u32', ('ushr', 'a@64', 32)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('ishl', ('pack_half_2x16_rtz_split', 'a', 0), 16) => ('pack_half_2x16_rtz_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_rtz_split', 0, 'a'), 16) => ('pack_half_2x16_rtz_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_rtz_split', 0, 'a'), 1) => ('pack_half_2x16_rtz_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('iadd', ('pack_half_2x16_rtz_split', 'a', 0), ('pack_half_2x16_rtz_split', 0, 'b')) => ('pack_half_2x16_rtz_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_rtz_split', 'a', 0), ('pack_half_2x16_rtz_split', 0, 'b')) => ('pack_half_2x16_rtz_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('u2u32', ('iadd(is_used_once)', 'a@64', 'b')) => ('iadd', ('u2u32', 'a'), ('u2u32', 'b'))
 *    ('u2u32', ('ushr', ('ior', ('ishl', 'a', 32), ('u2u64', 'b')), 32)) => ('u2u32', 'a')
 *    ('u2u16', ('ushr', ('ior', ('ishl', 'a', 16), ('u2u32', 'b')), 16)) => ('u2u16', 'a')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ieq', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ieq', 'a', 'b')
 *    ('ieq', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ieq', 'a', ('unpack_64_2x32_split_x', 'b'))
 *    ('ieq', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ieq', ('unpack_64_2x32_split_x', 'a'), 'b')
 *    ('ieq', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ieq', 'a', 'b')
 *    ('ieq', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ieq', 'a', ('unpack_64_2x32_split_y', 'b'))
 *    ('ieq', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ieq', ('unpack_64_2x32_split_y', 'a'), 'b')
 *    ('ine', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ine', 'a', 'b')
 *    ('ine', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ine', 'a', ('unpack_64_2x32_split_x', 'b'))
 *    ('ine', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ine', ('unpack_64_2x32_split_x', 'a'), 'b')
 *    ('ine', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ine', 'a', 'b')
 *    ('ine', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ine', 'a', ('unpack_64_2x32_split_y', 'b'))
 *    ('ine', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ine', ('unpack_64_2x32_split_y', 'a'), 'b')
 *    ('ult', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ult', 'a', 'b')
 *    ('ult', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ult', 'a', ('unpack_64_2x32_split_x', 'b'))
 *    ('ult', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ult', ('unpack_64_2x32_split_x', 'a'), 'b')
 *    ('ult', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ult', 'a', 'b')
 *    ('ult', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ult', 'a', ('unpack_64_2x32_split_y', 'b'))
 *    ('ult', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ult', ('unpack_64_2x32_split_y', 'a'), 'b')
 *    ('ilt', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ult', 'a', 'b')
 *    ('ilt', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ult', 'a', ('unpack_64_2x32_split_x', 'b'))
 *    ('ilt', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ult', ('unpack_64_2x32_split_x', 'a'), 'b')
 *    ('ilt', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ilt', 'a', 'b')
 *    ('ilt', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ilt', 'a', ('unpack_64_2x32_split_y', 'b'))
 *    ('ilt', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 'b')
 *    ('uge', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('uge', 'a', 'b')
 *    ('uge', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('uge', 'a', ('unpack_64_2x32_split_x', 'b'))
 *    ('uge', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('uge', ('unpack_64_2x32_split_x', 'a'), 'b')
 *    ('uge', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('uge', 'a', 'b')
 *    ('uge', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('uge', 'a', ('unpack_64_2x32_split_y', 'b'))
 *    ('uge', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('uge', ('unpack_64_2x32_split_y', 'a'), 'b')
 *    ('ige', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('uge', 'a', 'b')
 *    ('ige', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('uge', 'a', ('unpack_64_2x32_split_x', 'b'))
 *    ('ige', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('uge', ('unpack_64_2x32_split_x', 'a'), 'b')
 *    ('ige', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ige', 'a', 'b')
 *    ('ige', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ige', 'a', ('unpack_64_2x32_split_y', 'b'))
 *    ('ige', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ige', ('unpack_64_2x32_split_y', 'a'), 'b')
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('bitz', 'a', 'b') => ('inot', ('bitnz', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat,nsz)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a')
 *    ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a')
 *    ('ifind_msb', ('f2i32(is_used_once)', 'a')) => ('ufind_msb', ('f2i32', ('fabs', 'a')))
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a')
 *    ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a')
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0))
 *    ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False
 *    ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False
 *    ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width')
 *    ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width')
 *    ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset')
 *    ('iadd@32', ('ishl', 1, 'a'), -1) => ('bfm', 'a', 0)
 *    ('ishl', ('bfm', 'a', 0), 'b') => ('bfm', 'a', 'b')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('ine', ('ubfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('ine', ('ibfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ifind_msb', 'value') => ('isub', 31, ('uclz', ('ixor', 'value', ('ishr', 'value', 31))))
 *    ('ufind_msb', 'value@32') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('ufind_msb', 'value@32') => ('isub', 31, ('uclz', 'value'))
 *    ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a'))
 *    ('find_lsb', 'value@64') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('find_lsb', 'value') => ('ufind_msb', ('u2u32', ('iand', 'value', ('ineg', 'value'))))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_32_4x8', ('f2u8', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_32_4x8', ('f2i8', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('fmul', 1.0, ('u2u16', 'a')))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('fmul', 1.0, ('u2u16', ('ushr', 'a', 16))))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('fsign', 'a@64') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('bcsel', ('iand', ('ine', ('fabs', 'x'), 2139095040), ('ieq', ('iand', ('pack_half_2x16_rtz_split', 'x', 0), 32767), 31744)), ('iadd', ('pack_half_2x16_rtz_split', 'x', 0), 4294967295), ('pack_half_2x16_rtz_split', 'x', 0)) => ('pack_half_2x16_rtz_split', 'x', 0)
 *    ('bcsel', ('iand', ('ine', 'x', 2139095040), ('ieq', ('iand', ('pack_half_2x16_rtz_split', 'x(is_not_negative)', 0), 32767), 31744)), ('iadd', ('pack_half_2x16_rtz_split', 'x(is_not_negative)', 0), 4294967295), ('pack_half_2x16_rtz_split', 'x(is_not_negative)', 0)) => ('pack_half_2x16_rtz_split', 'x', 0)
 *    ('bcsel', ('iand', ('ine', ('fabs', 'x'), 2139095040), ('ieq', ('iand', ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0), 32767), 31744)), ('iadd', ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0), 4294967295), ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0)) => ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0)
 *    ('iadd(many-comm-expr)', ('iadd', ('iadd', ('bcsel', ('ieq', ('extract_u8', 'a@32', 0), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 0), ('ineg', ('extract_u8', 'b@32', 0))))), ('bcsel', ('ieq', ('extract_u8', 'a@32', 1), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 1), ('ineg', ('extract_u8', 'b@32', 1)))))), ('bcsel', ('ieq', ('extract_u8', 'a@32', 2), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 2), ('ineg', ('extract_u8', 'b@32', 2)))))), ('bcsel', ('ieq', ('extract_u8', 'a@32', 3), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 3), ('ineg', ('extract_u8', 'b@32', 3)))))) => ('msad_4x8', 'a', 'b', 0)
 *    ('iadd', ('msad_4x8', 'a', 'b', 0), 'c') => ('msad_4x8', 'a', 'b', 'c')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin_mdg(is_used_once)', 'a'), ('fsin_mdg(is_used_once)', 'b')) => ('fsin_mdg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos_mdg(is_used_once)', 'a'), ('fcos_mdg(is_used_once)', 'b')) => ('fcos_mdg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin_agx(is_used_once)', 'a'), ('fsin_agx(is_used_once)', 'b')) => ('fsin_agx', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992))
 *    ('fquantize2f16', 'a@32') => ('bcsel', ('!flt', ('!fabs', 'a'), 6.103515625e-05), ('iand', 'a', 2147483648), ('!f2f32', ('!f2f16_rtne', 'a')))
 *    ('bfi', 4294967295, 'a', '#b') => ('iadd', ('ishl', 'a', 0), ('iand', 'b', -4294967296))
 *    ('bfi', 8589934590, 'a', '#b') => ('iadd', ('ishl', 'a', 1), ('iand', 'b', -8589934591))
 *    ('bfi', 17179869180, 'a', '#b') => ('iadd', ('ishl', 'a', 2), ('iand', 'b', -17179869181))
 *    ('bfi', 34359738360, 'a', '#b') => ('iadd', ('ishl', 'a', 3), ('iand', 'b', -34359738361))
 *    ('bfi', 68719476720, 'a', '#b') => ('iadd', ('ishl', 'a', 4), ('iand', 'b', -68719476721))
 *    ('bfi', 137438953440, 'a', '#b') => ('iadd', ('ishl', 'a', 5), ('iand', 'b', -137438953441))
 *    ('bfi', 274877906880, 'a', '#b') => ('iadd', ('ishl', 'a', 6), ('iand', 'b', -274877906881))
 *    ('bfi', 549755813760, 'a', '#b') => ('iadd', ('ishl', 'a', 7), ('iand', 'b', -549755813761))
 *    ('bfi', 1099511627520, 'a', '#b') => ('iadd', ('ishl', 'a', 8), ('iand', 'b', -1099511627521))
 *    ('bfi', 2199023255040, 'a', '#b') => ('iadd', ('ishl', 'a', 9), ('iand', 'b', -2199023255041))
 *    ('bfi', 4398046510080, 'a', '#b') => ('iadd', ('ishl', 'a', 10), ('iand', 'b', -4398046510081))
 *    ('bfi', 8796093020160, 'a', '#b') => ('iadd', ('ishl', 'a', 11), ('iand', 'b', -8796093020161))
 *    ('bfi', 17592186040320, 'a', '#b') => ('iadd', ('ishl', 'a', 12), ('iand', 'b', -17592186040321))
 *    ('bfi', 35184372080640, 'a', '#b') => ('iadd', ('ishl', 'a', 13), ('iand', 'b', -35184372080641))
 *    ('bfi', 70368744161280, 'a', '#b') => ('iadd', ('ishl', 'a', 14), ('iand', 'b', -70368744161281))
 *    ('bfi', 140737488322560, 'a', '#b') => ('iadd', ('ishl', 'a', 15), ('iand', 'b', -140737488322561))
 *    ('bfi', 281474976645120, 'a', '#b') => ('iadd', ('ishl', 'a', 16), ('iand', 'b', -281474976645121))
 *    ('bfi', 562949953290240, 'a', '#b') => ('iadd', ('ishl', 'a', 17), ('iand', 'b', -562949953290241))
 *    ('bfi', 1125899906580480, 'a', '#b') => ('iadd', ('ishl', 'a', 18), ('iand', 'b', -1125899906580481))
 *    ('bfi', 2251799813160960, 'a', '#b') => ('iadd', ('ishl', 'a', 19), ('iand', 'b', -2251799813160961))
 *    ('bfi', 4503599626321920, 'a', '#b') => ('iadd', ('ishl', 'a', 20), ('iand', 'b', -4503599626321921))
 *    ('bfi', 9007199252643840, 'a', '#b') => ('iadd', ('ishl', 'a', 21), ('iand', 'b', -9007199252643841))
 *    ('bfi', 18014398505287680, 'a', '#b') => ('iadd', ('ishl', 'a', 22), ('iand', 'b', -18014398505287681))
 *    ('bfi', 36028797010575360, 'a', '#b') => ('iadd', ('ishl', 'a', 23), ('iand', 'b', -36028797010575361))
 *    ('bfi', 72057594021150720, 'a', '#b') => ('iadd', ('ishl', 'a', 24), ('iand', 'b', -72057594021150721))
 *    ('bfi', 144115188042301440, 'a', '#b') => ('iadd', ('ishl', 'a', 25), ('iand', 'b', -144115188042301441))
 *    ('bfi', 288230376084602880, 'a', '#b') => ('iadd', ('ishl', 'a', 26), ('iand', 'b', -288230376084602881))
 *    ('bfi', 576460752169205760, 'a', '#b') => ('iadd', ('ishl', 'a', 27), ('iand', 'b', -576460752169205761))
 *    ('bfi', 1152921504338411520, 'a', '#b') => ('iadd', ('ishl', 'a', 28), ('iand', 'b', -1152921504338411521))
 *    ('bfi', 2305843008676823040, 'a', '#b') => ('iadd', ('ishl', 'a', 29), ('iand', 'b', -2305843008676823041))
 *    ('bfi', 4611686017353646080, 'a', '#b') => ('iadd', ('ishl', 'a', 30), ('iand', 'b', -4611686017353646081))
 *    ('fadd', '#a(is_nan)', 'b') => nan
 *    ('fadd', 'a', '#b(is_nan)') => nan
 *    ('fdiv', '#a(is_nan)', 'b') => nan
 *    ('fdiv', 'a', '#b(is_nan)') => nan
 *    ('fmod', '#a(is_nan)', 'b') => nan
 *    ('fmod', 'a', '#b(is_nan)') => nan
 *    ('fmul', '#a(is_nan)', 'b') => nan
 *    ('fmul', 'a', '#b(is_nan)') => nan
 *    ('fpow', '#a(is_nan)', 'b') => nan
 *    ('fpow', 'a', '#b(is_nan)') => nan
 *    ('frem', '#a(is_nan)', 'b') => nan
 *    ('frem', 'a', '#b(is_nan)') => nan
 *    ('fsub', '#a(is_nan)', 'b') => nan
 *    ('fsub', 'a', '#b(is_nan)') => nan
 *    ('ffma', '#a(is_nan)', 'b', 'c') => nan
 *    ('ffma', 'a', '#b(is_nan)', 'c') => nan
 *    ('ffma', 'a', 'b', '#c(is_nan)') => nan
 *    ('flrp', '#a(is_nan)', 'b', 'c') => nan
 *    ('flrp', 'a', '#b(is_nan)', 'c') => nan
 *    ('flrp', 'a', 'b', '#c(is_nan)') => nan
 *    ('fmin', '#a(is_nan)', 'b') => b
 *    ('fmax', '#a(is_nan)', 'b') => b
 *    ('ldexp', '#a(is_nan)', 'b') => nan
 *    ('fdot2', '#a(is_any_comp_nan)', 'b') => nan
 *    ('fdot3', '#a(is_any_comp_nan)', 'b') => nan
 *    ('fdot4', '#a(is_any_comp_nan)', 'b') => nan
 *    ('fdot5', '#a(is_any_comp_nan)', 'b') => nan
 *    ('fdot8', '#a(is_any_comp_nan)', 'b') => nan
 *    ('fdot16', '#a(is_any_comp_nan)', 'b') => nan
 *    ('feq', '#a(is_nan)', 'b') => False
 *    ('feq', 'a', '#b(is_nan)') => False
 *    ('fge', '#a(is_nan)', 'b') => False
 *    ('fge', 'a', '#b(is_nan)') => False
 *    ('flt', '#a(is_nan)', 'b') => False
 *    ('flt', 'a', '#b(is_nan)') => False
 *    ('fneu', '#a(is_nan)', 'b') => True
 *    ('seq', '#a(is_nan)', 'b') => 0.0
 *    ('seq', 'a', '#b(is_nan)') => 0.0
 *    ('sge', '#a(is_nan)', 'b') => 0.0
 *    ('sge', 'a', '#b(is_nan)') => 0.0
 *    ('slt', '#a(is_nan)', 'b') => 0.0
 *    ('slt', 'a', '#b(is_nan)') => 0.0
 *    ('sne', '#a(is_nan)', 'b') => 1.0
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('fgeu', 'a', 'b') => ('inot', ('flt', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fgeu,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace0_0_0 -> 0 in the cache */
   /* replace0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },

   /* ('fltu', 'a', 'b') => ('inot', ('fge', 'a', 'b')) */
   /* search1_0 -> 0 in the cache */
   /* search1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fltu,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1_0_0 -> 0 in the cache */
   /* replace1_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('fneo', 0.0, 'a') => ('flt', 0.0, ('fabs', 'a')) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 8, 9 },
      -1,
   } },

   /* replace2_0 -> 8 in the cache */
   /* replace2_1_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 8, 11 },
      -1,
   } },

   /* ('fequ', 0.0, 'a') => ('inot', ('flt', 0.0, ('fabs', 'a'))) */
   /* search3_0 -> 8 in the cache */
   /* search3_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fequ,
      0, 1,
      { 8, 9 },
      -1,
   } },

   /* replace3_0_0 -> 8 in the cache */
   /* replace3_0_1_0 -> 9 in the cache */
   /* replace3_0_1 -> 11 in the cache */
   /* replace3_0 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 12 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search4_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 15 },
      -1,
   } },

   /* replace4_0 -> 0 in the cache */
   /* replace4_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 17 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80ull /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 19, 20 },
      -1,
   } },

   /* replace5_0 -> 19 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7ull /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 19, 22 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000ull /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 24, 25 },
      -1,
   } },

   /* replace6_0 -> 24 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfull /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 24, 27 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000ull /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 29, 30 },
      -1,
   } },

   /* replace7_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1full /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 32 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000ull /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 34, 35 },
      -1,
   } },

   /* replace8_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3full /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 37 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search9_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 39 },
      -1,
   } },

   /* replace9_0_0 -> 0 in the cache */
   /* replace9_0_1_0_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 43 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   /* search10_0 -> 9 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 9, 45 },
      -1,
   } },

   /* replace10_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 47, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 9, 49 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search11_0 -> 34 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 34, 51 },
      -1,
   } },

   /* replace11_0_0 -> 34 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 54 },
      -1,
   } },
   /* replace11_1_0 -> 34 in the cache */
   /* replace11_1_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 56 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 55, 57 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search12_0_0 -> 29 in the cache */
   /* search12_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 29, 48 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 59 },
      -1,
   } },

   /* replace12_0 -> 29 in the cache */
   /* replace12_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search13_0_0 -> 29 in the cache */
   /* search13_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 29, 48 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 62 },
      -1,
   } },

   /* replace13_0 -> 29 in the cache */
   /* replace13_1 -> 48 in the cache */
   /* replace13 -> 61 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search14_0 -> 29 in the cache */
   /* search14_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace14_0_0 -> 29 in the cache */
   /* replace14_0_1 -> 48 in the cache */
   /* replace14_0 -> 61 in the cache */
   /* replace14_1_0 -> 29 in the cache */
   /* replace14_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 61, 65 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search15_0 -> 29 in the cache */
   /* search15_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace15_0_0 -> 29 in the cache */
   /* replace15_0_1 -> 48 in the cache */
   /* replace15_0 -> 61 in the cache */
   /* replace15_1_0 -> 29 in the cache */
   /* replace15_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 61, 68 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search16_0 -> 9 in the cache */
   /* search16_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   /* replace16 -> 9 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search17_0 -> 9 in the cache */
   /* search17_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   /* replace17 -> 9 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search18_0 -> 9 in the cache */
   /* search18_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search19_0 -> 9 in the cache */
   /* search19_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   /* replace19 -> 73 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search20_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 9, 75 },
      -1,
   } },

   /* replace20 -> 73 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search21_0 -> 9 in the cache */
   /* search21_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   /* replace21 -> 73 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search22_0 -> 9 in the cache */
   /* search22_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 9, 75 },
      -1,
   } },

   /* replace22 -> 73 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 15 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 15 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 1 in the cache */
   /* replace23_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 17 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 15 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 15 },
      -1,
   } },

   /* replace24_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace24_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace24_1_1_0 -> 1 in the cache */
   /* replace24_1_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 83, 17 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 82, 84 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 39 },
      -1,
   } },

   /* replace25_0_0_0 -> 0 in the cache */
   /* replace25_0_0 -> 82 in the cache */
   /* replace25_0_1_0_0 -> 0 in the cache */
   /* replace25_0_1_0 -> 83 in the cache */
   /* replace25_0_1_1_0_0 -> 1 in the cache */
   /* replace25_0_1_1_0 -> 41 in the cache */
   /* replace25_0_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 83, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 82, 87 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 88 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 15 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 15 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 1 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 1, 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 92 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search27_0 -> 0 in the cache */
   /* search27_1 -> 15 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 15 },
      -1,
   } },

   /* replace27_0 -> 0 in the cache */
   /* replace27_1_0 -> 1 in the cache */
   /* replace27_1_1 -> 91 in the cache */
   /* replace27_1 -> 92 in the cache */
   /* replace27 -> 93 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search28_0 -> 0 in the cache */
   /* search28_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 39 },
      -1,
   } },

   /* replace28_0_0_0 -> 0 in the cache */
   /* replace28_0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* replace28_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 96, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   /* replace28_2_0 -> 0 in the cache */
   /* replace28_2_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 97, 98, 99 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search29_0 -> 0 in the cache */
   /* search29_1 -> 15 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 15 },
      -1,
   } },

   /* replace29_0 -> 0 in the cache */
   /* replace29_1_0_0_0 -> 0 in the cache */
   /* replace29_1_0_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 98 },
      -1,
   } },
   /* replace29_1_0_1_0 -> 0 in the cache */
   /* replace29_1_0_1_1_0 -> 1 in the cache */
   /* replace29_1_0_1_1_1 -> 91 in the cache */
   /* replace29_1_0_1_1 -> 92 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 92 },
      -1,
   } },
   /* replace29_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 102, 103, 0 },
      -1,
   } },
   /* replace29_1_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 104, 105 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 106 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search30_0 -> 0 in the cache */
   /* search30_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 39 },
      -1,
   } },

   /* replace30_0 -> 0 in the cache */
   /* replace30_1_0 -> 1 in the cache */
   /* replace30_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 41 },
      -1,
   } },

   /* ('~fmul', ('fsign', 'a'), ('ffloor', ('fadd', ('fabs', 'a'), 0.5))) => ('ftrunc', ('fadd', 'a', ('fmul', ('fsign', 'a'), 0.5))) */
   /* search31_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search31_1_0_0_0 -> 9 in the cache */
   /* search31_1_0_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000ull /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 112 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 110, 113 },
      -1,
   } },

   /* replace31_0_0 -> 9 in the cache */
   /* replace31_0_1_0_0 -> 9 in the cache */
   /* replace31_0_1_0 -> 110 in the cache */
   /* replace31_0_1_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 110, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 9, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 2,
      { 116 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search32_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 118 },
      -1,
   } },

   /* replace32 -> 9 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search33_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 120 },
      -1,
   } },

   /* replace33 -> 9 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search34_0_0 -> 9 in the cache */
   /* search34_0 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 118 },
      -1,
   } },

   /* replace34_0 -> 9 in the cache */
   /* replace34 -> 11 in the cache */

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search35_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 123 },
      -1,
   } },

   /* replace35_0 -> 9 in the cache */
   /* replace35 -> 123 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search36_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 125 },
      -1,
   } },

   /* replace36_0 -> 9 in the cache */
   /* replace36 -> 125 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search37_0_0 -> 9 in the cache */
   /* search37_0 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 120 },
      -1,
   } },

   /* replace37_0 -> 9 in the cache */
   /* replace37 -> 125 in the cache */

   /* ('~fadd', 'a', 0.0) => a */
   /* search38_0 -> 9 in the cache */
   /* search38_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* replace38 -> 9 in the cache */

   /* ('fadd(is_only_used_as_float,nsz)', 'a', 0.0) => a */
   /* search39_0 -> 9 in the cache */
   /* search39_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 9, 8 },
      1,
   } },

   /* replace39 -> 9 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search40_0 -> 9 in the cache */
   /* search40_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace40 -> 9 in the cache */

   /* ('iadd_sat', 'a', 0) => a */
   /* search41_0 -> 9 in the cache */
   /* search41_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace41 -> 9 in the cache */

   /* ('isub_sat', 'a', 0) => a */
   /* search42_0 -> 9 in the cache */
   /* search42_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* replace42 -> 9 in the cache */

   /* ('uadd_sat', 'a', 0) => a */
   /* search43_0 -> 9 in the cache */
   /* search43_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace43 -> 9 in the cache */

   /* ('usub_sat', 'a', 0) => a */
   /* search44_0 -> 9 in the cache */
   /* search44_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* replace44 -> 9 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search45_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 29, 135 },
      -1,
   } },

   /* replace45 -> 29 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search46_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 29, 137 },
      -1,
   } },

   /* replace46 -> 137 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* search47_1_0 -> 139 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 141, 143 },
      -1,
   } },

   /* replace47_0 -> 139 in the cache */
   /* replace47_1_0 -> 140 in the cache */
   /* replace47_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 139, 145 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search48_0_0 -> 29 in the cache */
   /* search48_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* search48_1_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 29, 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 147, 149 },
      -1,
   } },

   /* replace48_0 -> 29 in the cache */
   /* replace48_1_0 -> 48 in the cache */
   /* replace48_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 48, 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 29, 151 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search49_0 -> 0 in the cache */
   /* search49_1 -> 1 in the cache */
   /* search49_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 153, 154 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 1, 155 },
      -1,
   } },

   /* replace49_0 -> 0 in the cache */
   /* replace49_1_0 -> 1 in the cache */
   /* replace49_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1, 153 },
      -1,
   } },
   /* replace49_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 157, 154 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search50_0 -> 0 in the cache */
   /* search50_1 -> 1 in the cache */
   /* search50_2_0 -> 0 in the cache */
   /* search50_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 1, 159 },
      -1,
   } },

   /* replace50_0 -> 0 in the cache */
   /* replace50_1_0 -> 1 in the cache */
   /* replace50_1_1 -> 153 in the cache */
   /* replace50_1 -> 157 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 157 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 162, 163 },
      0,
   } },
   /* search51_1_0 -> 162 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 162, 165, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 164, 167 },
      -1,
   } },

   /* replace51_0 -> 162 in the cache */
   /* replace51_1_0 -> 163 in the cache */
   /* replace51_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 163, 165 },
      -1,
   } },
   /* replace51_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 162, 169, 166 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search52_0 -> 162 in the cache */
   /* search52_1_0 -> 163 in the cache */
   /* search52_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 163, 165 },
      0,
   } },
   /* search52_2_0 -> 163 in the cache */
   /* search52_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 162, 171, 172 },
      -1,
   } },

   /* replace52_0 -> 163 in the cache */
   /* replace52_1_0 -> 162 in the cache */
   /* replace52_1_1 -> 165 in the cache */
   /* replace52_1_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 162, 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 163, 174 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search53_0 -> 29 in the cache */
   /* search53_1 -> 48 in the cache */
   /* search53_2_0 -> 29 in the cache */
   /* search53_2_1 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 29, 148, 176 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 29, 48, 177 },
      -1,
   } },

   /* replace53_0 -> 29 in the cache */
   /* replace53_1_0 -> 48 in the cache */
   /* replace53_1_1 -> 148 in the cache */
   /* replace53_1 -> 151 in the cache */
   /* replace53_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 29, 151, 176 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search54_0 -> 29 in the cache */
   /* search54_1 -> 48 in the cache */
   /* search54_2_0 -> 29 in the cache */
   /* search54_2_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 29, 148 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 29, 48, 180 },
      -1,
   } },

   /* replace54_0 -> 29 in the cache */
   /* replace54_1_0 -> 48 in the cache */
   /* replace54_1_1 -> 148 in the cache */
   /* replace54_1 -> 151 in the cache */
   /* replace54 -> 152 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search55_0_0 -> 29 in the cache */
   /* search55_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 29, 48 },
      0,
   } },
   /* search55_1_0 -> 29 in the cache */
   /* search55_1_1 -> 148 in the cache */
   /* search55_1_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 29, 148, 176 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 182, 183 },
      -1,
   } },

   /* replace55_0 -> 29 in the cache */
   /* replace55_1_0 -> 48 in the cache */
   /* replace55_1_1 -> 148 in the cache */
   /* replace55_1 -> 151 in the cache */
   /* replace55_2 -> 176 in the cache */
   /* replace55 -> 179 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search56_0 -> 29 in the cache */
   /* search56_1_0 -> 48 in the cache */
   /* search56_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 48, 148 },
      0,
   } },
   /* search56_2_0 -> 48 in the cache */
   /* search56_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 48, 176 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 29, 185, 186 },
      -1,
   } },

   /* replace56_0 -> 48 in the cache */
   /* replace56_1_0 -> 29 in the cache */
   /* replace56_1_1 -> 148 in the cache */
   /* replace56_1_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 29, 148, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 48, 188 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search57_0_0 -> 139 in the cache */
   /* search57_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* search57_1_0 -> 139 in the cache */
   /* search57_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 190, 191 },
      -1,
   } },

   /* replace57_0 -> 139 in the cache */
   /* replace57_1_0 -> 140 in the cache */
   /* replace57_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 139, 193 },
      -1,
   } },

   /* ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 195, 196 },
      -1,
   } },
   /* search58_1_0 -> 142 in the cache */
   /* search58_1_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 142, 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 197, 198 },
      -1,
   } },

   /* replace58_0_0 -> 195 in the cache */
   /* replace58_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 195, 142 },
      -1,
   } },
   /* replace58_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 200, 196 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search59_0_0 -> 139 in the cache */
   /* search59_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* search59_1_0 -> 139 in the cache */
   /* search59_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 202, 203 },
      -1,
   } },

   /* replace59_0 -> 139 in the cache */
   /* replace59_1_0 -> 140 in the cache */
   /* replace59_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 139, 205 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search60_0_0 -> 139 in the cache */
   /* search60_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* search60_1_0 -> 139 in the cache */
   /* search60_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 207, 208 },
      -1,
   } },

   /* replace60_0 -> 139 in the cache */
   /* replace60_1_0 -> 140 in the cache */
   /* replace60_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 139, 210 },
      -1,
   } },

   /* ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0) */
   /* search61_0_0 -> 0 in the cache */
   /* search61_0_1 -> 15 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 15 },
      -1,
   } },
   /* search61_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 212, 1 },
      -1,
   } },

   /* replace61_0_0 -> 0 in the cache */
   /* replace61_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* replace61_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 214, 98 },
      -1,
   } },

   /* ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0) */
   /* search62_0_0 -> 0 in the cache */
   /* search62_0_1 -> 15 in the cache */
   /* search62_0 -> 212 in the cache */
   /* search62_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 212, 1 },
      -1,
   } },

   /* replace62_0_0 -> 0 in the cache */
   /* replace62_0_1 -> 1 in the cache */
   /* replace62_0 -> 214 in the cache */
   /* replace62_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 214, 98 },
      -1,
   } },

   /* ('ieq', ('ushr(is_used_once)', 'a', '#b'), 0) => ('ult', 'a', ('ishl', 1, 'b')) */
   /* search63_0_0 -> 9 in the cache */
   /* search63_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 9, 45 },
      0,
   } },
   /* search63_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 218, 73 },
      -1,
   } },

   /* replace63_0 -> 9 in the cache */
   /* replace63_1_0 -> 47 in the cache */
   /* replace63_1_1 -> 48 in the cache */
   /* replace63_1 -> 49 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 9, 49 },
      -1,
   } },

   /* ('ine', ('ushr(is_used_once)', 'a', '#b'), 0) => ('uge', 'a', ('ishl', 1, 'b')) */
   /* search64_0_0 -> 9 in the cache */
   /* search64_0_1 -> 45 in the cache */
   /* search64_0 -> 218 in the cache */
   /* search64_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 218, 73 },
      -1,
   } },

   /* replace64_0 -> 9 in the cache */
   /* replace64_1_0 -> 47 in the cache */
   /* replace64_1_1 -> 48 in the cache */
   /* replace64_1 -> 49 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 9, 49 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search65_0_0 -> 9 in the cache */
   /* search65_0 -> 118 in the cache */
   /* search65_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 118, 9 },
      -1,
   } },

   /* replace65 -> 8 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search66_0_0 -> 9 in the cache */
   /* search66_0 -> 120 in the cache */
   /* search66_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 120, 9 },
      -1,
   } },

   /* replace66 -> 73 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search67_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search67_1_0 -> 0 in the cache */
   /* search67_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 225, 226 },
      -1,
   } },

   /* replace67 -> 1 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search68_0 -> 0 in the cache */
   /* search68_1_0_0 -> 0 in the cache */
   /* search68_1_0 -> 225 in the cache */
   /* search68_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 225, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 228 },
      -1,
   } },

   /* replace68 -> 1 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search69_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search69_1_0 -> 0 in the cache */
   /* search69_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 230, 231 },
      -1,
   } },

   /* replace69 -> 1 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search70_0 -> 0 in the cache */
   /* search70_1_0_0 -> 0 in the cache */
   /* search70_1_0 -> 230 in the cache */
   /* search70_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 230, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 233 },
      -1,
   } },

   /* replace70 -> 1 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search71_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search71_1_0_0 -> 9 in the cache */
   /* search71_1_0 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 118 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 235, 236 },
      -1,
   } },

   /* replace71_0_0 -> 9 in the cache */
   /* replace71_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search72_0 -> 9 in the cache */
   /* search72_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* replace72 -> 8 in the cache */

   /* ('fmul(nsz,nnan)', 'a', 0.0) => 0.0 */
   /* search73_0 -> 9 in the cache */
   /* search73_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      true,
      true,
      false,
      nir_op_fmul,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* replace73 -> 8 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search74_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 29, 241 },
      -1,
   } },

   /* replace74 -> 241 in the cache */

   /* ('fmulz(nsz)', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search75_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 29, 243 },
      -1,
   } },

   /* replace75_0 -> 29 in the cache */
   /* replace75_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 246, 247 },
      -1,
   } },

   /* replace76_0 -> 29 in the cache */
   /* replace76_1 -> 48 in the cache */
   /* replace76 -> 245 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search77_0 -> 29 in the cache */
   /* search77_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 29, 29 },
      -1,
   } },

   /* replace77_0 -> 29 in the cache */
   /* replace77_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 29, 29 },
      -1,
   } },

   /* ('ffmaz(nsz)', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search78_0 -> 29 in the cache */
   /* search78_1 -> 243 in the cache */
   /* search78_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 29, 243, 148 },
      -1,
   } },

   /* replace78_0 -> 29 in the cache */
   /* replace78_1 -> 48 in the cache */
   /* replace78_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search79_0 -> 246 in the cache */
   /* search79_1 -> 247 in the cache */
   /* search79_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 246, 247, 148 },
      -1,
   } },

   /* replace79_0 -> 29 in the cache */
   /* replace79_1 -> 48 in the cache */
   /* replace79_2 -> 148 in the cache */
   /* replace79 -> 252 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search80_0 -> 29 in the cache */
   /* search80_1 -> 29 in the cache */
   /* search80_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 29, 29, 48 },
      -1,
   } },

   /* replace80_0 -> 29 in the cache */
   /* replace80_1 -> 29 in the cache */
   /* replace80_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 29, 29, 48 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search81_0 -> 9 in the cache */
   /* search81_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace81 -> 73 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search82_0 -> 29 in the cache */
   /* search82_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 29, 135 },
      -1,
   } },

   /* replace82 -> 135 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search83_0 -> 29 in the cache */
   /* search83_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 29, 137 },
      -1,
   } },

   /* replace83 -> 29 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search84_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 9, 259 },
      -1,
   } },

   /* replace84 -> 9 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search85_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 29, 261 },
      -1,
   } },

   /* replace85 -> 29 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search86_0 -> 9 in the cache */
   /* search86_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 9, 259 },
      1,
   } },

   /* replace86 -> 9 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search87_0 -> 9 in the cache */
   /* search87_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 9, 47 },
      -1,
   } },

   /* replace87 -> 9 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search88_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 9, 265 },
      -1,
   } },

   /* replace88_0 -> 9 in the cache */
   /* replace88 -> 118 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search89_0 -> 9 in the cache */
   /* search89_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 9, 75 },
      -1,
   } },

   /* replace89_0 -> 9 in the cache */
   /* replace89 -> 120 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search90_0_0 -> 9 in the cache */
   /* search90_0 -> 110 in the cache */
   /* search90_1_0 -> 9 in the cache */
   /* search90_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 9, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 110, 268 },
      -1,
   } },

   /* replace90_0_0 -> 9 in the cache */
   /* replace90_0 -> 11 in the cache */
   /* replace90_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 9 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search91_0_0_0 -> 9 in the cache */
   /* search91_0_0 -> 110 in the cache */
   /* search91_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 110, 9 },
      -1,
   } },
   /* search91_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 271, 9 },
      -1,
   } },

   /* replace91_0_0 -> 9 in the cache */
   /* replace91_0 -> 11 in the cache */
   /* replace91_1 -> 9 in the cache */
   /* replace91 -> 270 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   /* search92_1 -> 0 in the cache */
   /* search92_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 273, 0, 1 },
      -1,
   } },

   /* replace92 -> 1 in the cache */

   /* ('ffma(is_only_used_as_float,nsz,nnan,ninf)', 0.0, 'a', 'b') => b */
   /* search93_0 -> 273 in the cache */
   /* search93_1 -> 0 in the cache */
   /* search93_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      true,
      true,
      true,
      nir_op_ffma,
      0, 1,
      { 273, 0, 1 },
      1,
   } },

   /* replace93 -> 1 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search94_0 -> 241 in the cache */
   /* search94_1 -> 29 in the cache */
   /* search94_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 241, 29, 48 },
      -1,
   } },

   /* replace94_0 -> 241 in the cache */
   /* replace94_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 241, 48 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search95_0 -> 0 in the cache */
   /* search95_1 -> 1 in the cache */
   /* search95_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 1, 273 },
      -1,
   } },

   /* replace95_0 -> 0 in the cache */
   /* replace95_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('ffma(nsz)', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search96_0 -> 0 in the cache */
   /* search96_1 -> 1 in the cache */
   /* search96_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 1, 273 },
      -1,
   } },

   /* replace96_0 -> 0 in the cache */
   /* replace96_1 -> 1 in the cache */
   /* replace96 -> 279 in the cache */

   /* ('ffmaz(nsz)', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search97_0 -> 29 in the cache */
   /* search97_1 -> 48 in the cache */
   /* search97_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 29, 48, 241 },
      -1,
   } },

   /* replace97_0 -> 29 in the cache */
   /* replace97_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   /* search98_1 -> 0 in the cache */
   /* search98_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 283, 0, 1 },
      -1,
   } },

   /* replace98_0 -> 0 in the cache */
   /* replace98_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('ffmaz(nsz)', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search99_0 -> 261 in the cache */
   /* search99_1 -> 29 in the cache */
   /* search99_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 261, 29, 48 },
      -1,
   } },

   /* replace99_0 -> 29 in the cache */
   /* replace99_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   /* search100_1 -> 0 in the cache */
   /* search100_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 288, 0, 1 },
      -1,
   } },

   /* replace100_0_0 -> 0 in the cache */
   /* replace100_0 -> 230 in the cache */
   /* replace100_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 230, 1 },
      -1,
   } },

   /* ('ffmaz(nsz)', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   /* search101_1 -> 29 in the cache */
   /* search101_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 291, 29, 48 },
      -1,
   } },

   /* replace101_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 29 },
      -1,
   } },
   /* replace101_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 293, 48 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search102_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 295, 296, 142 },
      -1,
   } },

   /* replace102_0_0 -> 139 in the cache */
   /* replace102_0_1 -> 140 in the cache */
   /* replace102_0 -> 141 in the cache */
   /* replace102_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 141, 142 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search103_1 -> 45 in the cache */
   /* search103_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 299, 45, 148 },
      -1,
   } },

   /* replace103_0_0 -> 29 in the cache */
   /* replace103_0_1 -> 48 in the cache */
   /* replace103_0 -> 147 in the cache */
   /* replace103_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 147, 148 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search104_0 -> 0 in the cache */
   /* search104_1 -> 1 in the cache */
   /* search104_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 1, 273 },
      -1,
   } },

   /* replace104 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search105_0 -> 0 in the cache */
   /* search105_1 -> 1 in the cache */
   /* search105_2 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 1, 283 },
      -1,
   } },

   /* replace105 -> 1 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search106_0 -> 0 in the cache */
   /* search106_1 -> 0 in the cache */
   /* search106_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 1 },
      -1,
   } },

   /* replace106 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search107_0 -> 273 in the cache */
   /* search107_1 -> 0 in the cache */
   /* search107_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 273, 0, 1 },
      -1,
   } },

   /* replace107_0 -> 0 in the cache */
   /* replace107_1 -> 1 in the cache */
   /* replace107 -> 279 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search108_0 -> 139 in the cache */
   /* search108_1_0 -> 139 in the cache */
   /* search108_1_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 139, 140 },
      0,
   } },
   /* search108_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 139, 306, 142 },
      -1,
   } },

   /* replace108_0_0 -> 140 in the cache */
   /* replace108_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 140, 142 },
      -1,
   } },
   /* replace108_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 308, 139 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search109_0 -> 29 in the cache */
   /* search109_1 -> 135 in the cache */
   /* search109_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace109 -> 48 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search110_0 -> 29 in the cache */
   /* search110_1 -> 135 in the cache */
   /* search110_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace110 -> 48 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search111_0 -> 29 in the cache */
   /* search111_1 -> 135 in the cache */
   /* search111_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace111 -> 48 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search112_0 -> 29 in the cache */
   /* search112_1 -> 135 in the cache */
   /* search112_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace112 -> 48 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search113_0 -> 29 in the cache */
   /* search113_1 -> 135 in the cache */
   /* search113_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace113 -> 48 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search114_0 -> 29 in the cache */
   /* search114_1 -> 135 in the cache */
   /* search114_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace114 -> 48 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search115_0 -> 29 in the cache */
   /* search115_1 -> 135 in the cache */
   /* search115_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace115 -> 48 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search116_0 -> 29 in the cache */
   /* search116_1 -> 135 in the cache */
   /* search116_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 29, 135, 48 },
      -1,
   } },

   /* replace116 -> 48 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search117_0 -> 29 in the cache */
   /* search117_1 -> 135 in the cache */
   /* search117_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 29, 135, 48 },
      -1,
   } },

   /* replace117 -> 48 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search118_0 -> 135 in the cache */
   /* search118_1 -> 29 in the cache */
   /* search118_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 135, 29, 48 },
      -1,
   } },

   /* replace118 -> 48 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search119_0 -> 29 in the cache */
   /* search119_1 -> 135 in the cache */
   /* search119_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 29, 135, 48 },
      -1,
   } },

   /* replace119 -> 48 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search120_0 -> 135 in the cache */
   /* search120_1 -> 29 in the cache */
   /* search120_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 135, 29, 48 },
      -1,
   } },

   /* replace120 -> 48 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search121_0_0 -> 29 in the cache */
   /* search121_0_1 -> 48 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 29, 48, 322 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 323, 324 },
      -1,
   } },

   /* replace121_0 -> 29 in the cache */
   /* replace121_1 -> 48 in the cache */
   /* replace121_2_0 -> 148 in the cache */
   /* replace121_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 29, 48, 326 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search122_0_0 -> 29 in the cache */
   /* search122_0_1 -> 48 in the cache */
   /* search122_0_2 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 29, 48, 322 },
      0,
   } },
   /* search122_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 328, 324 },
      -1,
   } },

   /* replace122_0 -> 29 in the cache */
   /* replace122_1 -> 48 in the cache */
   /* replace122_2_0 -> 148 in the cache */
   /* replace122_2_1 -> 176 in the cache */
   /* replace122_2 -> 326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 29, 48, 326 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search123_0_0 -> 29 in the cache */
   /* search123_0_1 -> 48 in the cache */
   /* search123_0_2 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 29, 48, 322 },
      0,
   } },
   /* search123_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 331, 324 },
      -1,
   } },

   /* replace123_0 -> 29 in the cache */
   /* replace123_1 -> 48 in the cache */
   /* replace123_2_0 -> 148 in the cache */
   /* replace123_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 29, 48, 333 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search124_0_0 -> 29 in the cache */
   /* search124_0_1 -> 48 in the cache */
   /* search124_0_2 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 29, 48, 322 },
      0,
   } },
   /* search124_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 335, 324 },
      -1,
   } },

   /* replace124_0 -> 29 in the cache */
   /* replace124_1 -> 48 in the cache */
   /* replace124_2_0 -> 148 in the cache */
   /* replace124_2_1 -> 176 in the cache */
   /* replace124_2 -> 326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 29, 48, 326 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search125_0_0 -> 29 in the cache */
   /* search125_0_1 -> 48 in the cache */
   /* search125_0_2 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 29, 48, 322 },
      0,
   } },
   /* search125_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 338, 324 },
      -1,
   } },

   /* replace125_0 -> 29 in the cache */
   /* replace125_1 -> 48 in the cache */
   /* replace125_2_0 -> 148 in the cache */
   /* replace125_2_1 -> 176 in the cache */
   /* replace125_2 -> 326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 29, 48, 326 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search126_0_1 -> 48 in the cache */
   /* search126_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 341, 48, 135 },
      -1,
   } },
   /* search126_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 342, 148 },
      -1,
   } },

   /* replace126_0 -> 29 in the cache */
   /* replace126_1 -> 48 in the cache */
   /* replace126_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search127_0_0 -> 341 in the cache */
   /* search127_0_1 -> 48 in the cache */
   /* search127_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 341, 48, 135 },
      -1,
   } },
   /* search127_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 345, 148 },
      -1,
   } },

   /* replace127_0 -> 29 in the cache */
   /* replace127_1 -> 48 in the cache */
   /* replace127_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search128_0_0 -> 341 in the cache */
   /* search128_0_1 -> 48 in the cache */
   /* search128_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 341, 48, 135 },
      -1,
   } },
   /* search128_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 348, 148 },
      -1,
   } },

   /* replace128_0 -> 29 in the cache */
   /* replace128_1 -> 48 in the cache */
   /* replace128_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 29, 48, 148 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search129_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search129_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 29, 351, 135 },
      -1,
   } },
   /* search129_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 352, 148 },
      -1,
   } },

   /* replace129_0 -> 29 in the cache */
   /* replace129_1 -> 48 in the cache */
   /* replace129_2 -> 148 in the cache */
   /* replace129 -> 350 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search130_0_0 -> 341 in the cache */
   /* search130_0_1 -> 48 in the cache */
   /* search130_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 341, 48, 135 },
      -1,
   } },
   /* search130_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 354, 148 },
      -1,
   } },

   /* replace130_0 -> 29 in the cache */
   /* replace130_1 -> 48 in the cache */
   /* replace130_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search131_0_0 -> 341 in the cache */
   /* search131_0_1 -> 48 in the cache */
   /* search131_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 341, 48, 135 },
      -1,
   } },
   /* search131_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 357, 148 },
      -1,
   } },

   /* replace131_0 -> 29 in the cache */
   /* replace131_1 -> 48 in the cache */
   /* replace131_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 299 in the cache */
   /* search132_1 -> 45 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace132_0_0 -> 29 in the cache */
   /* replace132_0_1 -> 48 in the cache */
   /* replace132_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 29, 48, 135 },
      -1,
   } },
   /* replace132_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 362, 148 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 299 in the cache */
   /* search133_1 -> 45 in the cache */
   /* search133_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace133_0_0 -> 29 in the cache */
   /* replace133_0_1 -> 48 in the cache */
   /* replace133_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 29, 48, 135 },
      -1,
   } },
   /* replace133_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 365, 148 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search134_0 -> 299 in the cache */
   /* search134_1 -> 45 in the cache */
   /* search134_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 299, 45, 360 },
      -1,
   } },

   /* replace134_0_0 -> 29 in the cache */
   /* replace134_0_1 -> 48 in the cache */
   /* replace134_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 29, 48, 135 },
      -1,
   } },
   /* replace134_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 368, 148 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search135_0 -> 299 in the cache */
   /* search135_1 -> 45 in the cache */
   /* search135_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace135_0_0 -> 29 in the cache */
   /* replace135_0_1 -> 48 in the cache */
   /* replace135_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 29, 48, 135 },
      -1,
   } },
   /* replace135_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 371, 148 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search136_0 -> 299 in the cache */
   /* search136_1 -> 45 in the cache */
   /* search136_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace136_0_0 -> 29 in the cache */
   /* replace136_0_1 -> 48 in the cache */
   /* replace136_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 29, 48, 135 },
      -1,
   } },
   /* replace136_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 374, 148 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search137_0 -> 299 in the cache */
   /* search137_1 -> 45 in the cache */
   /* search137_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace137_0_0 -> 29 in the cache */
   /* replace137_0_1 -> 48 in the cache */
   /* replace137_0_2 -> 135 in the cache */
   /* replace137_0 -> 362 in the cache */
   /* replace137_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 362, 148 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search138_0 -> 299 in the cache */
   /* search138_1 -> 45 in the cache */
   /* search138_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace138_0_0 -> 29 in the cache */
   /* replace138_0_1 -> 48 in the cache */
   /* replace138_0_2 -> 135 in the cache */
   /* replace138_0 -> 365 in the cache */
   /* replace138_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 365, 148 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search139_0 -> 299 in the cache */
   /* search139_1 -> 45 in the cache */
   /* search139_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 299, 45, 360 },
      -1,
   } },

   /* replace139_0_0 -> 29 in the cache */
   /* replace139_0_1 -> 48 in the cache */
   /* replace139_0_2 -> 135 in the cache */
   /* replace139_0 -> 368 in the cache */
   /* replace139_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 368, 148 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search140_0 -> 299 in the cache */
   /* search140_1 -> 45 in the cache */
   /* search140_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace140_0_0 -> 29 in the cache */
   /* replace140_0_1 -> 48 in the cache */
   /* replace140_0_2 -> 135 in the cache */
   /* replace140_0 -> 371 in the cache */
   /* replace140_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 371, 148 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search141_0 -> 299 in the cache */
   /* search141_1 -> 45 in the cache */
   /* search141_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 299, 45, 360 },
      -1,
   } },

   /* replace141_0_0 -> 29 in the cache */
   /* replace141_0_1 -> 48 in the cache */
   /* replace141_0_2 -> 135 in the cache */
   /* replace141_0 -> 374 in the cache */
   /* replace141_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 374, 148 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'b')))) => ('fmulz', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search142_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 386, 241 },
      -1,
   } },
   /* search142_0_1 -> 241 in the cache */
   /* search142_0_2_0_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 387, 241, 389 },
      -1,
   } },
   /* search142_1_0_0 -> 196 in the cache */
   /* search142_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 196, 241 },
      -1,
   } },
   /* search142_1_1 -> 241 in the cache */
   /* search142_1_2_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 392 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 391, 241, 393 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 390, 394 },
      -1,
   } },

   /* replace142_0_0_0 -> 196 in the cache */
   /* replace142_0_0 -> 388 in the cache */
   /* replace142_0 -> 389 in the cache */
   /* replace142_1_0_0 -> 386 in the cache */
   /* replace142_1_0 -> 392 in the cache */
   /* replace142_1 -> 393 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 389, 393 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b'))) => ('fmulz', ('fneg', ('fabs', 'a')), ('fabs', 'b')) */
   /* search143_0_0_0 -> 386 in the cache */
   /* search143_0_0_1 -> 241 in the cache */
   /* search143_0_0 -> 387 in the cache */
   /* search143_0_1 -> 241 in the cache */
   /* search143_0_2_0_0 -> 196 in the cache */
   /* search143_0_2_0 -> 388 in the cache */
   /* search143_0_2 -> 389 in the cache */
   /* search143_0 -> 390 in the cache */
   /* search143_1_0_0 -> 196 in the cache */
   /* search143_1_0_1 -> 241 in the cache */
   /* search143_1_0 -> 391 in the cache */
   /* search143_1_1 -> 241 in the cache */
   /* search143_1_2_0 -> 386 in the cache */
   /* search143_1_2 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 391, 241, 392 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 390, 397 },
      -1,
   } },

   /* replace143_0_0_0 -> 196 in the cache */
   /* replace143_0_0 -> 388 in the cache */
   /* replace143_0 -> 389 in the cache */
   /* replace143_1_0 -> 386 in the cache */
   /* replace143_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 389, 392 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b'))) => ('fmulz', ('fneg', ('fabs', 'a')), ('fneg', 'b')) */
   /* search144_0_0_0 -> 386 in the cache */
   /* search144_0_0_1 -> 241 in the cache */
   /* search144_0_0 -> 387 in the cache */
   /* search144_0_1 -> 241 in the cache */
   /* search144_0_2_0_0 -> 196 in the cache */
   /* search144_0_2_0 -> 388 in the cache */
   /* search144_0_2 -> 389 in the cache */
   /* search144_0 -> 390 in the cache */
   /* search144_1_0_0 -> 196 in the cache */
   /* search144_1_0_1 -> 241 in the cache */
   /* search144_1_0 -> 391 in the cache */
   /* search144_1_1 -> 241 in the cache */
   /* search144_1_2_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 391, 241, 400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 390, 401 },
      -1,
   } },

   /* replace144_0_0_0 -> 196 in the cache */
   /* replace144_0_0 -> 388 in the cache */
   /* replace144_0 -> 389 in the cache */
   /* replace144_1_0 -> 386 in the cache */
   /* replace144_1 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 389, 400 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', ('fneg', ('fabs', 'a')), 'b') */
   /* search145_0_0_0 -> 386 in the cache */
   /* search145_0_0_1 -> 241 in the cache */
   /* search145_0_0 -> 387 in the cache */
   /* search145_0_1 -> 241 in the cache */
   /* search145_0_2_0_0 -> 196 in the cache */
   /* search145_0_2_0 -> 388 in the cache */
   /* search145_0_2 -> 389 in the cache */
   /* search145_0 -> 390 in the cache */
   /* search145_1_0_0 -> 196 in the cache */
   /* search145_1_0_1 -> 241 in the cache */
   /* search145_1_0 -> 391 in the cache */
   /* search145_1_1 -> 241 in the cache */
   /* search145_1_2 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 391, 241, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 390, 404 },
      -1,
   } },

   /* replace145_0_0_0 -> 196 in the cache */
   /* replace145_0_0 -> 388 in the cache */
   /* replace145_0 -> 389 in the cache */
   /* replace145_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 389, 386 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b'))) => ('fmulz', ('fabs', 'a'), ('fabs', 'b')) */
   /* search146_0_0_0 -> 386 in the cache */
   /* search146_0_0_1 -> 241 in the cache */
   /* search146_0_0 -> 387 in the cache */
   /* search146_0_1 -> 241 in the cache */
   /* search146_0_2_0 -> 196 in the cache */
   /* search146_0_2 -> 388 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 387, 241, 388 },
      -1,
   } },
   /* search146_1_0_0 -> 196 in the cache */
   /* search146_1_0_1 -> 241 in the cache */
   /* search146_1_0 -> 391 in the cache */
   /* search146_1_1 -> 241 in the cache */
   /* search146_1_2_0 -> 386 in the cache */
   /* search146_1_2 -> 392 in the cache */
   /* search146_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 407, 397 },
      -1,
   } },

   /* replace146_0_0 -> 196 in the cache */
   /* replace146_0 -> 388 in the cache */
   /* replace146_1_0 -> 386 in the cache */
   /* replace146_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 388, 392 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b'))) => ('fmulz', ('fabs', 'a'), ('fneg', 'b')) */
   /* search147_0_0_0 -> 386 in the cache */
   /* search147_0_0_1 -> 241 in the cache */
   /* search147_0_0 -> 387 in the cache */
   /* search147_0_1 -> 241 in the cache */
   /* search147_0_2_0 -> 196 in the cache */
   /* search147_0_2 -> 388 in the cache */
   /* search147_0 -> 407 in the cache */
   /* search147_1_0_0 -> 196 in the cache */
   /* search147_1_0_1 -> 241 in the cache */
   /* search147_1_0 -> 391 in the cache */
   /* search147_1_1 -> 241 in the cache */
   /* search147_1_2_0 -> 386 in the cache */
   /* search147_1_2 -> 400 in the cache */
   /* search147_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 407, 401 },
      -1,
   } },

   /* replace147_0_0 -> 196 in the cache */
   /* replace147_0 -> 388 in the cache */
   /* replace147_1_0 -> 386 in the cache */
   /* replace147_1 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 388, 400 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', ('fabs', 'a'), 'b') */
   /* search148_0_0_0 -> 386 in the cache */
   /* search148_0_0_1 -> 241 in the cache */
   /* search148_0_0 -> 387 in the cache */
   /* search148_0_1 -> 241 in the cache */
   /* search148_0_2_0 -> 196 in the cache */
   /* search148_0_2 -> 388 in the cache */
   /* search148_0 -> 407 in the cache */
   /* search148_1_0_0 -> 196 in the cache */
   /* search148_1_0_1 -> 241 in the cache */
   /* search148_1_0 -> 391 in the cache */
   /* search148_1_1 -> 241 in the cache */
   /* search148_1_2 -> 386 in the cache */
   /* search148_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 407, 404 },
      -1,
   } },

   /* replace148_0_0 -> 196 in the cache */
   /* replace148_0 -> 388 in the cache */
   /* replace148_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 388, 386 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b'))) => ('fmulz', ('fneg', 'a'), ('fneg', 'b')) */
   /* search149_0_0_0 -> 386 in the cache */
   /* search149_0_0_1 -> 241 in the cache */
   /* search149_0_0 -> 387 in the cache */
   /* search149_0_1 -> 241 in the cache */
   /* search149_0_2_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 387, 241, 414 },
      -1,
   } },
   /* search149_1_0_0 -> 196 in the cache */
   /* search149_1_0_1 -> 241 in the cache */
   /* search149_1_0 -> 391 in the cache */
   /* search149_1_1 -> 241 in the cache */
   /* search149_1_2_0 -> 386 in the cache */
   /* search149_1_2 -> 400 in the cache */
   /* search149_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 415, 401 },
      -1,
   } },

   /* replace149_0_0 -> 196 in the cache */
   /* replace149_0 -> 414 in the cache */
   /* replace149_1_0 -> 386 in the cache */
   /* replace149_1 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 414, 400 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', ('fneg', 'a'), 'b') */
   /* search150_0_0_0 -> 386 in the cache */
   /* search150_0_0_1 -> 241 in the cache */
   /* search150_0_0 -> 387 in the cache */
   /* search150_0_1 -> 241 in the cache */
   /* search150_0_2_0 -> 196 in the cache */
   /* search150_0_2 -> 414 in the cache */
   /* search150_0 -> 415 in the cache */
   /* search150_1_0_0 -> 196 in the cache */
   /* search150_1_0_1 -> 241 in the cache */
   /* search150_1_0 -> 391 in the cache */
   /* search150_1_1 -> 241 in the cache */
   /* search150_1_2 -> 386 in the cache */
   /* search150_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 415, 404 },
      -1,
   } },

   /* replace150_0_0 -> 196 in the cache */
   /* replace150_0 -> 414 in the cache */
   /* replace150_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 414, 386 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   /* search151_0_0_0 -> 386 in the cache */
   /* search151_0_0_1 -> 241 in the cache */
   /* search151_0_0 -> 387 in the cache */
   /* search151_0_1 -> 241 in the cache */
   /* search151_0_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 387, 241, 196 },
      -1,
   } },
   /* search151_1_0_0 -> 196 in the cache */
   /* search151_1_0_1 -> 241 in the cache */
   /* search151_1_0 -> 391 in the cache */
   /* search151_1_1 -> 241 in the cache */
   /* search151_1_2 -> 386 in the cache */
   /* search151_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 420, 404 },
      -1,
   } },

   /* replace151_0 -> 196 in the cache */
   /* replace151_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 196, 386 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('fneg', ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', ('fneg', ('fabs', 'a')), 'b') */
   /* search152_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 423 },
      -1,
   } },
   /* search152_1_0_0 -> 29 in the cache */
   /* search152_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 29, 241 },
      -1,
   } },
   /* search152_1_1 -> 241 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 425, 241, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 424, 427 },
      -1,
   } },

   /* replace152_0_0_0 -> 29 in the cache */
   /* replace152_0_0 -> 423 in the cache */
   /* replace152_0 -> 424 in the cache */
   /* replace152_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 424, 48 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('fabs', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', ('fabs', 'a'), 'b') */
   /* search153_0_0 -> 29 in the cache */
   /* search153_0 -> 423 in the cache */
   /* search153_1_0_0 -> 29 in the cache */
   /* search153_1_0_1 -> 241 in the cache */
   /* search153_1_0 -> 425 in the cache */
   /* search153_1_1 -> 241 in the cache */
   /* search153_1_2 -> 426 in the cache */
   /* search153_1 -> 427 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 423, 427 },
      -1,
   } },

   /* replace153_0_0 -> 29 in the cache */
   /* replace153_0 -> 423 in the cache */
   /* replace153_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 423, 48 },
      -1,
   } },

   /* ('fmul@32(nsz)', ('fneg', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', ('fneg', 'a'), 'b') */
   /* search154_0_0 -> 29 in the cache */
   /* search154_0 -> 293 in the cache */
   /* search154_1_0_0 -> 29 in the cache */
   /* search154_1_0_1 -> 241 in the cache */
   /* search154_1_0 -> 425 in the cache */
   /* search154_1_1 -> 241 in the cache */
   /* search154_1_2 -> 426 in the cache */
   /* search154_1 -> 427 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 293, 427 },
      -1,
   } },

   /* replace154_0_0 -> 29 in the cache */
   /* replace154_0 -> 293 in the cache */
   /* replace154_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 293, 48 },
      -1,
   } },

   /* ('fmul@32(nsz)', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search155_0 -> 29 in the cache */
   /* search155_1_0_0 -> 29 in the cache */
   /* search155_1_0_1 -> 241 in the cache */
   /* search155_1_0 -> 425 in the cache */
   /* search155_1_1 -> 241 in the cache */
   /* search155_1_2 -> 426 in the cache */
   /* search155_1 -> 427 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 29, 427 },
      -1,
   } },

   /* replace155_0 -> 29 in the cache */
   /* replace155_1 -> 48 in the cache */
   /* replace155 -> 282 in the cache */

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b')), 'c') */
   /* search156_0_0_0 -> 386 in the cache */
   /* search156_0_0_1 -> 241 in the cache */
   /* search156_0_0 -> 387 in the cache */
   /* search156_0_1 -> 241 in the cache */
   /* search156_0_2_0_0 -> 196 in the cache */
   /* search156_0_2_0 -> 388 in the cache */
   /* search156_0_2 -> 389 in the cache */
   /* search156_0 -> 390 in the cache */
   /* search156_1_0_0 -> 196 in the cache */
   /* search156_1_0_1 -> 241 in the cache */
   /* search156_1_0 -> 391 in the cache */
   /* search156_1_1 -> 241 in the cache */
   /* search156_1_2_0_0 -> 386 in the cache */
   /* search156_1_2_0 -> 392 in the cache */
   /* search156_1_2 -> 393 in the cache */
   /* search156_1 -> 394 in the cache */
   /* search156_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 390, 394, 148 },
      -1,
   } },

   /* replace156_0_0_0 -> 196 in the cache */
   /* replace156_0_0 -> 388 in the cache */
   /* replace156_0 -> 389 in the cache */
   /* replace156_1_0_0 -> 386 in the cache */
   /* replace156_1_0 -> 392 in the cache */
   /* replace156_1 -> 393 in the cache */
   /* replace156_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 389, 393, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b')), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search157_0_0_0 -> 386 in the cache */
   /* search157_0_0_1 -> 241 in the cache */
   /* search157_0_0 -> 387 in the cache */
   /* search157_0_1 -> 241 in the cache */
   /* search157_0_2_0_0 -> 196 in the cache */
   /* search157_0_2_0 -> 388 in the cache */
   /* search157_0_2 -> 389 in the cache */
   /* search157_0 -> 390 in the cache */
   /* search157_1_0_0 -> 196 in the cache */
   /* search157_1_0_1 -> 241 in the cache */
   /* search157_1_0 -> 391 in the cache */
   /* search157_1_1 -> 241 in the cache */
   /* search157_1_2_0 -> 386 in the cache */
   /* search157_1_2 -> 392 in the cache */
   /* search157_1 -> 397 in the cache */
   /* search157_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 390, 397, 148 },
      -1,
   } },

   /* replace157_0_0_0 -> 196 in the cache */
   /* replace157_0_0 -> 388 in the cache */
   /* replace157_0 -> 389 in the cache */
   /* replace157_1_0 -> 386 in the cache */
   /* replace157_1 -> 392 in the cache */
   /* replace157_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 389, 392, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b')), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fneg', 'b'), 'c') */
   /* search158_0_0_0 -> 386 in the cache */
   /* search158_0_0_1 -> 241 in the cache */
   /* search158_0_0 -> 387 in the cache */
   /* search158_0_1 -> 241 in the cache */
   /* search158_0_2_0_0 -> 196 in the cache */
   /* search158_0_2_0 -> 388 in the cache */
   /* search158_0_2 -> 389 in the cache */
   /* search158_0 -> 390 in the cache */
   /* search158_1_0_0 -> 196 in the cache */
   /* search158_1_0_1 -> 241 in the cache */
   /* search158_1_0 -> 391 in the cache */
   /* search158_1_1 -> 241 in the cache */
   /* search158_1_2_0 -> 386 in the cache */
   /* search158_1_2 -> 400 in the cache */
   /* search158_1 -> 401 in the cache */
   /* search158_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 390, 401, 148 },
      -1,
   } },

   /* replace158_0_0_0 -> 196 in the cache */
   /* replace158_0_0 -> 388 in the cache */
   /* replace158_0 -> 389 in the cache */
   /* replace158_1_0 -> 386 in the cache */
   /* replace158_1 -> 400 in the cache */
   /* replace158_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 389, 400, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', ('fabs', 'a'))), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), 'b', 'c') */
   /* search159_0_0_0 -> 386 in the cache */
   /* search159_0_0_1 -> 241 in the cache */
   /* search159_0_0 -> 387 in the cache */
   /* search159_0_1 -> 241 in the cache */
   /* search159_0_2_0_0 -> 196 in the cache */
   /* search159_0_2_0 -> 388 in the cache */
   /* search159_0_2 -> 389 in the cache */
   /* search159_0 -> 390 in the cache */
   /* search159_1_0_0 -> 196 in the cache */
   /* search159_1_0_1 -> 241 in the cache */
   /* search159_1_0 -> 391 in the cache */
   /* search159_1_1 -> 241 in the cache */
   /* search159_1_2 -> 386 in the cache */
   /* search159_1 -> 404 in the cache */
   /* search159_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 390, 404, 148 },
      -1,
   } },

   /* replace159_0_0_0 -> 196 in the cache */
   /* replace159_0_0 -> 388 in the cache */
   /* replace159_0 -> 389 in the cache */
   /* replace159_1 -> 386 in the cache */
   /* replace159_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 389, 386, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fabs', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search160_0_0_0 -> 386 in the cache */
   /* search160_0_0_1 -> 241 in the cache */
   /* search160_0_0 -> 387 in the cache */
   /* search160_0_1 -> 241 in the cache */
   /* search160_0_2_0 -> 196 in the cache */
   /* search160_0_2 -> 388 in the cache */
   /* search160_0 -> 407 in the cache */
   /* search160_1_0_0 -> 196 in the cache */
   /* search160_1_0_1 -> 241 in the cache */
   /* search160_1_0 -> 391 in the cache */
   /* search160_1_1 -> 241 in the cache */
   /* search160_1_2_0 -> 386 in the cache */
   /* search160_1_2 -> 392 in the cache */
   /* search160_1 -> 397 in the cache */
   /* search160_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 407, 397, 148 },
      -1,
   } },

   /* replace160_0_0 -> 196 in the cache */
   /* replace160_0 -> 388 in the cache */
   /* replace160_1_0 -> 386 in the cache */
   /* replace160_1 -> 392 in the cache */
   /* replace160_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 388, 392, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fneg', 'b'), 'c') */
   /* search161_0_0_0 -> 386 in the cache */
   /* search161_0_0_1 -> 241 in the cache */
   /* search161_0_0 -> 387 in the cache */
   /* search161_0_1 -> 241 in the cache */
   /* search161_0_2_0 -> 196 in the cache */
   /* search161_0_2 -> 388 in the cache */
   /* search161_0 -> 407 in the cache */
   /* search161_1_0_0 -> 196 in the cache */
   /* search161_1_0_1 -> 241 in the cache */
   /* search161_1_0 -> 391 in the cache */
   /* search161_1_1 -> 241 in the cache */
   /* search161_1_2_0 -> 386 in the cache */
   /* search161_1_2 -> 400 in the cache */
   /* search161_1 -> 401 in the cache */
   /* search161_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 407, 401, 148 },
      -1,
   } },

   /* replace161_0_0 -> 196 in the cache */
   /* replace161_0 -> 388 in the cache */
   /* replace161_1_0 -> 386 in the cache */
   /* replace161_1 -> 400 in the cache */
   /* replace161_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 388, 400, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', ('fabs', 'a'), 'b', 'c') */
   /* search162_0_0_0 -> 386 in the cache */
   /* search162_0_0_1 -> 241 in the cache */
   /* search162_0_0 -> 387 in the cache */
   /* search162_0_1 -> 241 in the cache */
   /* search162_0_2_0 -> 196 in the cache */
   /* search162_0_2 -> 388 in the cache */
   /* search162_0 -> 407 in the cache */
   /* search162_1_0_0 -> 196 in the cache */
   /* search162_1_0_1 -> 241 in the cache */
   /* search162_1_0 -> 391 in the cache */
   /* search162_1_1 -> 241 in the cache */
   /* search162_1_2 -> 386 in the cache */
   /* search162_1 -> 404 in the cache */
   /* search162_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 407, 404, 148 },
      -1,
   } },

   /* replace162_0_0 -> 196 in the cache */
   /* replace162_0 -> 388 in the cache */
   /* replace162_1 -> 386 in the cache */
   /* replace162_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 388, 386, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, ('fneg', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search163_0_0_0 -> 386 in the cache */
   /* search163_0_0_1 -> 241 in the cache */
   /* search163_0_0 -> 387 in the cache */
   /* search163_0_1 -> 241 in the cache */
   /* search163_0_2_0 -> 196 in the cache */
   /* search163_0_2 -> 414 in the cache */
   /* search163_0 -> 415 in the cache */
   /* search163_1_0_0 -> 196 in the cache */
   /* search163_1_0_1 -> 241 in the cache */
   /* search163_1_0 -> 391 in the cache */
   /* search163_1_1 -> 241 in the cache */
   /* search163_1_2_0 -> 386 in the cache */
   /* search163_1_2 -> 400 in the cache */
   /* search163_1 -> 401 in the cache */
   /* search163_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 415, 401, 148 },
      -1,
   } },

   /* replace163_0_0 -> 196 in the cache */
   /* replace163_0 -> 414 in the cache */
   /* replace163_1_0 -> 386 in the cache */
   /* replace163_1 -> 400 in the cache */
   /* replace163_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 414, 400, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, ('fneg', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c') */
   /* search164_0_0_0 -> 386 in the cache */
   /* search164_0_0_1 -> 241 in the cache */
   /* search164_0_0 -> 387 in the cache */
   /* search164_0_1 -> 241 in the cache */
   /* search164_0_2_0 -> 196 in the cache */
   /* search164_0_2 -> 414 in the cache */
   /* search164_0 -> 415 in the cache */
   /* search164_1_0_0 -> 196 in the cache */
   /* search164_1_0_1 -> 241 in the cache */
   /* search164_1_0 -> 391 in the cache */
   /* search164_1_1 -> 241 in the cache */
   /* search164_1_2 -> 386 in the cache */
   /* search164_1 -> 404 in the cache */
   /* search164_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 415, 404, 148 },
      -1,
   } },

   /* replace164_0_0 -> 196 in the cache */
   /* replace164_0 -> 414 in the cache */
   /* replace164_1 -> 386 in the cache */
   /* replace164_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 414, 386, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search165_0_0_0 -> 386 in the cache */
   /* search165_0_0_1 -> 241 in the cache */
   /* search165_0_0 -> 387 in the cache */
   /* search165_0_1 -> 241 in the cache */
   /* search165_0_2 -> 196 in the cache */
   /* search165_0 -> 420 in the cache */
   /* search165_1_0_0 -> 196 in the cache */
   /* search165_1_0_1 -> 241 in the cache */
   /* search165_1_0 -> 391 in the cache */
   /* search165_1_1 -> 241 in the cache */
   /* search165_1_2 -> 386 in the cache */
   /* search165_1 -> 404 in the cache */
   /* search165_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 420, 404, 148 },
      -1,
   } },

   /* replace165_0 -> 196 in the cache */
   /* replace165_1 -> 386 in the cache */
   /* replace165_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 196, 386, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('fneg', ('fabs', 'a')), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), 'b', 'c') */
   /* search166_0_0_0 -> 29 in the cache */
   /* search166_0_0 -> 423 in the cache */
   /* search166_0 -> 424 in the cache */
   /* search166_1_0_0 -> 29 in the cache */
   /* search166_1_0_1 -> 241 in the cache */
   /* search166_1_0 -> 425 in the cache */
   /* search166_1_1 -> 241 in the cache */
   /* search166_1_2 -> 426 in the cache */
   /* search166_1 -> 427 in the cache */
   /* search166_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 424, 427, 148 },
      -1,
   } },

   /* replace166_0_0_0 -> 29 in the cache */
   /* replace166_0_0 -> 423 in the cache */
   /* replace166_0 -> 424 in the cache */
   /* replace166_1 -> 48 in the cache */
   /* replace166_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 424, 48, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('fabs', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', ('fabs', 'a'), 'b', 'c') */
   /* search167_0_0 -> 29 in the cache */
   /* search167_0 -> 423 in the cache */
   /* search167_1_0_0 -> 29 in the cache */
   /* search167_1_0_1 -> 241 in the cache */
   /* search167_1_0 -> 425 in the cache */
   /* search167_1_1 -> 241 in the cache */
   /* search167_1_2 -> 426 in the cache */
   /* search167_1 -> 427 in the cache */
   /* search167_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 423, 427, 148 },
      -1,
   } },

   /* replace167_0_0 -> 29 in the cache */
   /* replace167_0 -> 423 in the cache */
   /* replace167_1 -> 48 in the cache */
   /* replace167_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 423, 48, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', ('fneg', 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c') */
   /* search168_0_0 -> 29 in the cache */
   /* search168_0 -> 293 in the cache */
   /* search168_1_0_0 -> 29 in the cache */
   /* search168_1_0_1 -> 241 in the cache */
   /* search168_1_0 -> 425 in the cache */
   /* search168_1_1 -> 241 in the cache */
   /* search168_1_2 -> 426 in the cache */
   /* search168_1 -> 427 in the cache */
   /* search168_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 293, 427, 148 },
      -1,
   } },

   /* replace168_0_0 -> 29 in the cache */
   /* replace168_0 -> 293 in the cache */
   /* replace168_1 -> 48 in the cache */
   /* replace168_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 293, 48, 148 },
      -1,
   } },

   /* ('ffma@32(nsz)', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search169_0 -> 29 in the cache */
   /* search169_1_0_0 -> 29 in the cache */
   /* search169_1_0_1 -> 241 in the cache */
   /* search169_1_0 -> 425 in the cache */
   /* search169_1_1 -> 241 in the cache */
   /* search169_1_2 -> 426 in the cache */
   /* search169_1 -> 427 in the cache */
   /* search169_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 29, 427, 148 },
      -1,
   } },

   /* replace169_0 -> 29 in the cache */
   /* replace169_1 -> 48 in the cache */
   /* replace169_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', ('fneg', ('fabs', 'b'))))) => ('fexp2', ('fmulz', 'a', ('fneg', ('fabs', 'b')))) */
   /* search170_0_0 -> 386 in the cache */
   /* search170_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 386, 241 },
      -1,
   } },
   /* search170_1 -> 261 in the cache */
   /* search170_2_0_0 -> 196 in the cache */
   /* search170_2_0_1_0_0 -> 386 in the cache */
   /* search170_2_0_1_0 -> 392 in the cache */
   /* search170_2_0_1 -> 393 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 196, 393 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      true,
      true,
      nir_op_bcsel,
      -1, 2,
      { 463, 261, 465 },
      -1,
   } },

   /* replace170_0_0 -> 196 in the cache */
   /* replace170_0_1_0_0 -> 386 in the cache */
   /* replace170_0_1_0 -> 392 in the cache */
   /* replace170_0_1 -> 393 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 196, 393 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 467 },
      -1,
   } },

   /* ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', ('fabs', 'b')))) => ('fexp2', ('fmulz', 'a', ('fabs', 'b'))) */
   /* search171_0_0 -> 386 in the cache */
   /* search171_0_1 -> 241 in the cache */
   /* search171_0 -> 463 in the cache */
   /* search171_1 -> 261 in the cache */
   /* search171_2_0_0 -> 196 in the cache */
   /* search171_2_0_1_0 -> 386 in the cache */
   /* search171_2_0_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 196, 392 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      true,
      true,
      nir_op_bcsel,
      -1, 2,
      { 463, 261, 470 },
      -1,
   } },

   /* replace171_0_0 -> 196 in the cache */
   /* replace171_0_1_0 -> 386 in the cache */
   /* replace171_0_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 196, 392 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 472 },
      -1,
   } },

   /* ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', ('fneg', 'b')))) => ('fexp2', ('fmulz', 'a', ('fneg', 'b'))) */
   /* search172_0_0 -> 386 in the cache */
   /* search172_0_1 -> 241 in the cache */
   /* search172_0 -> 463 in the cache */
   /* search172_1 -> 261 in the cache */
   /* search172_2_0_0 -> 196 in the cache */
   /* search172_2_0_1_0 -> 386 in the cache */
   /* search172_2_0_1 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 196, 400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 474 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      true,
      true,
      nir_op_bcsel,
      -1, 2,
      { 463, 261, 475 },
      -1,
   } },

   /* replace172_0_0 -> 196 in the cache */
   /* replace172_0_1_0 -> 386 in the cache */
   /* replace172_0_1 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 196, 400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 477 },
      -1,
   } },

   /* ('bcsel(nsz,nnan,ninf)', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b')) */
   /* search173_0_0 -> 386 in the cache */
   /* search173_0_1 -> 241 in the cache */
   /* search173_0 -> 463 in the cache */
   /* search173_1 -> 261 in the cache */
   /* search173_2_0_0 -> 196 in the cache */
   /* search173_2_0_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 196, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      true,
      true,
      nir_op_bcsel,
      -1, 2,
      { 463, 261, 480 },
      -1,
   } },

   /* replace173_0_0 -> 196 in the cache */
   /* replace173_0_1 -> 386 in the cache */
   /* replace173_0 -> 422 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 422 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search174_0 -> 29 in the cache */
   /* search174_1 -> 48 in the cache */
   /* search174_2 -> 148 in the cache */
   /* search174 -> 344 in the cache */

   /* replace174_0_0_0_0_0 -> 29 in the cache */
   /* replace174_0_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace174_0_0_0_1_0 -> 48 in the cache */
   /* replace174_0_0_0_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 483, 484 },
      -1,
   } },
   /* replace174_0_0_1_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 29, 486 },
      -1,
   } },
   /* replace174_0_0_1_1_0 -> 48 in the cache */
   /* replace174_0_0_1_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 48, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 487, 488 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 485, 489 },
      -1,
   } },
   /* replace174_0_1_0_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2ull /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 29, 491 },
      -1,
   } },
   /* replace174_0_1_0_1_0 -> 48 in the cache */
   /* replace174_0_1_0_1_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 48, 491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 492, 493 },
      -1,
   } },
   /* replace174_0_1_1_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ull /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 29, 495 },
      -1,
   } },
   /* replace174_0_1_1_1_0 -> 48 in the cache */
   /* replace174_0_1_1_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 48, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 496, 497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 494, 498 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 490, 499 },
      -1,
   } },
   /* replace174_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 500, 148 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search175_0 -> 29 in the cache */
   /* search175_1 -> 48 in the cache */
   /* search175_2 -> 148 in the cache */
   /* search175 -> 347 in the cache */

   /* replace175_0_0_0_0_0 -> 29 in the cache */
   /* replace175_0_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace175_0_0_0_1_0 -> 48 in the cache */
   /* replace175_0_0_0_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 502, 503 },
      -1,
   } },
   /* replace175_0_0_1_0_0 -> 29 in the cache */
   /* replace175_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 29, 486 },
      -1,
   } },
   /* replace175_0_0_1_1_0 -> 48 in the cache */
   /* replace175_0_0_1_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 48, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 505, 506 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 504, 507 },
      -1,
   } },
   /* replace175_0_1_0_0_0 -> 29 in the cache */
   /* replace175_0_1_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 29, 491 },
      -1,
   } },
   /* replace175_0_1_0_1_0 -> 48 in the cache */
   /* replace175_0_1_0_1_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 48, 491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 509, 510 },
      -1,
   } },
   /* replace175_0_1_1_0_0 -> 29 in the cache */
   /* replace175_0_1_1_0_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 29, 495 },
      -1,
   } },
   /* replace175_0_1_1_1_0 -> 48 in the cache */
   /* replace175_0_1_1_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 48, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 512, 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 511, 514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 508, 515 },
      -1,
   } },
   /* replace175_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 516, 148 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search176_0 -> 29 in the cache */
   /* search176_1 -> 48 in the cache */
   /* search176_2 -> 148 in the cache */
   /* search176 -> 350 in the cache */

   /* replace176_0_0_0_0_0 -> 29 in the cache */
   /* replace176_0_0_0_0_1 -> 135 in the cache */
   /* replace176_0_0_0_0 -> 483 in the cache */
   /* replace176_0_0_0_1_0 -> 48 in the cache */
   /* replace176_0_0_0_1_1 -> 135 in the cache */
   /* replace176_0_0_0_1 -> 503 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 483, 503 },
      -1,
   } },
   /* replace176_0_0_1_0_0 -> 29 in the cache */
   /* replace176_0_0_1_0_1 -> 486 in the cache */
   /* replace176_0_0_1_0 -> 487 in the cache */
   /* replace176_0_0_1_1_0 -> 48 in the cache */
   /* replace176_0_0_1_1_1 -> 486 in the cache */
   /* replace176_0_0_1_1 -> 506 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 487, 506 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 518, 519 },
      -1,
   } },
   /* replace176_0_1_0_0_0 -> 29 in the cache */
   /* replace176_0_1_0_0_1 -> 491 in the cache */
   /* replace176_0_1_0_0 -> 492 in the cache */
   /* replace176_0_1_0_1_0 -> 48 in the cache */
   /* replace176_0_1_0_1_1 -> 491 in the cache */
   /* replace176_0_1_0_1 -> 510 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 492, 510 },
      -1,
   } },
   /* replace176_0_1_1_0_0 -> 29 in the cache */
   /* replace176_0_1_1_0_1 -> 495 in the cache */
   /* replace176_0_1_1_0 -> 496 in the cache */
   /* replace176_0_1_1_1_0 -> 48 in the cache */
   /* replace176_0_1_1_1_1 -> 495 in the cache */
   /* replace176_0_1_1_1 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 496, 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 521, 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 520, 523 },
      -1,
   } },
   /* replace176_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 524, 148 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search177_0 -> 29 in the cache */
   /* search177_1 -> 48 in the cache */
   /* search177_2 -> 148 in the cache */
   /* search177 -> 356 in the cache */

   /* replace177_0_0_0_0 -> 29 in the cache */
   /* replace177_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace177_0_0_1_0 -> 48 in the cache */
   /* replace177_0_0_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 526, 527 },
      -1,
   } },
   /* replace177_0_1_0_0 -> 29 in the cache */
   /* replace177_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 29, 486 },
      -1,
   } },
   /* replace177_0_1_1_0 -> 48 in the cache */
   /* replace177_0_1_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 48, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 529, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 528, 531 },
      -1,
   } },
   /* replace177_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 532, 148 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search178_0 -> 29 in the cache */
   /* search178_1 -> 48 in the cache */
   /* search178_2 -> 148 in the cache */
   /* search178 -> 359 in the cache */

   /* replace178_0_0_0_0 -> 29 in the cache */
   /* replace178_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace178_0_0_1_0 -> 48 in the cache */
   /* replace178_0_0_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 534, 535 },
      -1,
   } },
   /* replace178_0_1_0_0 -> 29 in the cache */
   /* replace178_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 29, 486 },
      -1,
   } },
   /* replace178_0_1_1_0 -> 48 in the cache */
   /* replace178_0_1_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 48, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 537, 538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 536, 539 },
      -1,
   } },
   /* replace178_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 540, 148 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search179_0 -> 29 in the cache */
   /* search179_1 -> 48 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 29, 48, 542 },
      -1,
   } },

   /* replace179_0 -> 29 in the cache */
   /* replace179_1 -> 48 in the cache */
   /* replace179_2 -> 148 in the cache */
   /* replace179 -> 347 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search180_0 -> 29 in the cache */
   /* search180_1 -> 48 in the cache */
   /* search180_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace180_0_0 -> 29 in the cache */
   /* replace180_0_1 -> 48 in the cache */
   /* replace180_0_2 -> 135 in the cache */
   /* replace180_0 -> 365 in the cache */
   /* replace180_1 -> 148 in the cache */
   /* replace180 -> 379 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search181_0 -> 29 in the cache */
   /* search181_1 -> 48 in the cache */
   /* search181_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace181_0_0 -> 29 in the cache */
   /* replace181_0_1 -> 48 in the cache */
   /* replace181_0_2 -> 135 in the cache */
   /* replace181_0 -> 362 in the cache */
   /* replace181_1 -> 148 in the cache */
   /* replace181 -> 377 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search182_0 -> 29 in the cache */
   /* search182_1 -> 48 in the cache */
   /* search182_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 29, 48, 148 },
      -1,
   } },

   /* replace182_0_0 -> 29 in the cache */
   /* replace182_0_1 -> 48 in the cache */
   /* replace182_0_2 -> 135 in the cache */
   /* replace182_0 -> 368 in the cache */
   /* replace182_1 -> 148 in the cache */
   /* replace182 -> 381 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search183_0 -> 29 in the cache */
   /* search183_1 -> 48 in the cache */
   /* search183_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace183_0_0_0_0 -> 29 in the cache */
   /* replace183_0_0_0_1 -> 135 in the cache */
   /* replace183_0_0_0 -> 534 in the cache */
   /* replace183_0_0_1_0 -> 48 in the cache */
   /* replace183_0_0_1_1 -> 135 in the cache */
   /* replace183_0_0_1 -> 535 in the cache */
   /* replace183_0_0 -> 536 in the cache */
   /* replace183_0_1_0_0 -> 29 in the cache */
   /* replace183_0_1_0_1 -> 486 in the cache */
   /* replace183_0_1_0 -> 537 in the cache */
   /* replace183_0_1_1_0 -> 48 in the cache */
   /* replace183_0_1_1_1 -> 486 in the cache */
   /* replace183_0_1_1 -> 538 in the cache */
   /* replace183_0_1 -> 539 in the cache */
   /* replace183_0 -> 540 in the cache */
   /* replace183_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 540, 148 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search184_0 -> 29 in the cache */
   /* search184_1 -> 48 in the cache */
   /* search184_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace184_0_0_0_0 -> 29 in the cache */
   /* replace184_0_0_0_1 -> 135 in the cache */
   /* replace184_0_0_0 -> 526 in the cache */
   /* replace184_0_0_1_0 -> 48 in the cache */
   /* replace184_0_0_1_1 -> 135 in the cache */
   /* replace184_0_0_1 -> 527 in the cache */
   /* replace184_0_0 -> 528 in the cache */
   /* replace184_0_1_0_0 -> 29 in the cache */
   /* replace184_0_1_0_1 -> 486 in the cache */
   /* replace184_0_1_0 -> 529 in the cache */
   /* replace184_0_1_1_0 -> 48 in the cache */
   /* replace184_0_1_1_1 -> 486 in the cache */
   /* replace184_0_1_1 -> 530 in the cache */
   /* replace184_0_1 -> 531 in the cache */
   /* replace184_0 -> 532 in the cache */
   /* replace184_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 532, 148 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search185_0 -> 24 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 24, 551, 553 },
      -1,
   } },

   /* replace185_0 -> 552 in the cache */
   /* replace185_1 -> 551 in the cache */
   /* replace185_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 552, 551, 24 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search186_0 -> 24 in the cache */
   /* search186_1_0 -> 24 in the cache */
   /* search186_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 551 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 24, 556, 557 },
      -1,
   } },

   /* replace186_0_0 -> 551 in the cache */
   /* replace186_0_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 551, 557 },
      -1,
   } },
   /* replace186_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 559, 24 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search187_0_0 -> 24 in the cache */
   /* search187_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 551 },
      0,
   } },
   /* search187_1_0 -> 24 in the cache */
   /* search187_1_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 557 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 561, 562, 563 },
      -1,
   } },

   /* replace187_0_0 -> 551 in the cache */
   /* replace187_0_1 -> 557 in the cache */
   /* replace187_0_2 -> 563 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 551, 557, 563 },
      -1,
   } },
   /* replace187_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 565, 24 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search188_0 -> 24 in the cache */
   /* search188_1_0 -> 24 in the cache */
   /* search188_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 24, 551 },
      0,
   } },
   /* search188_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 24, 567, 557 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   /* replace188_0_1 -> 551 in the cache */
   /* replace188_0_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 569, 551, 557 },
      -1,
   } },
   /* replace188_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 570, 24 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search189_0_0 -> 24 in the cache */
   /* search189_0_1_0 -> 569 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 569, 573 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 24, 574 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search189_1_1 -> 572 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 576, 572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 575, 577 },
      -1,
   } },

   /* replace189_0 -> 24 in the cache */
   /* replace189_1 -> 576 in the cache */
   /* replace189_2 -> 572 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 24, 576, 572 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search190_0_0 -> 24 in the cache */
   /* search190_0_1_0_0 -> 569 in the cache */
   /* search190_0_1_0_1_0 -> 572 in the cache */
   /* search190_0_1_0_1 -> 573 in the cache */
   /* search190_0_1_0 -> 574 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 24, 580 },
      -1,
   } },
   /* search190_1_0 -> 576 in the cache */
   /* search190_1_1_0 -> 572 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 576, 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 581, 583 },
      -1,
   } },

   /* replace190_0 -> 24 in the cache */
   /* replace190_1 -> 576 in the cache */
   /* replace190_2_0 -> 572 in the cache */
   /* replace190_2 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 24, 576, 582 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search191_0 -> 24 in the cache */
   /* search191_1_0 -> 572 in the cache */
   /* search191_1_1_0 -> 576 in the cache */
   /* search191_1_1_1_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 576, 586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 572, 587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 24, 588 },
      -1,
   } },

   /* replace191_0 -> 24 in the cache */
   /* replace191_1 -> 576 in the cache */
   /* replace191_2 -> 572 in the cache */
   /* replace191 -> 579 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search192_0_0 -> 24 in the cache */
   /* search192_0_1_0 -> 569 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 590 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 569, 592 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 24, 593 },
      -1,
   } },
   /* search192_1_0 -> 576 in the cache */
   /* search192_1_1_0 -> 590 in the cache */
   /* search192_1_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 576, 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 594, 595 },
      -1,
   } },

   /* replace192_0 -> 590 in the cache */
   /* replace192_1 -> 576 in the cache */
   /* replace192_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 590, 576, 24 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search193_0 -> 24 in the cache */
   /* search193_1_0_0 -> 590 in the cache */
   /* search193_1_0 -> 591 in the cache */
   /* search193_1_1_0 -> 576 in the cache */
   /* search193_1_1_1_0 -> 24 in the cache */
   /* search193_1_1_1 -> 586 in the cache */
   /* search193_1_1 -> 587 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 591, 587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 24, 598 },
      -1,
   } },

   /* replace193_0 -> 590 in the cache */
   /* replace193_1 -> 576 in the cache */
   /* replace193_2 -> 24 in the cache */
   /* replace193 -> 597 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search194_0 -> 24 in the cache */
   /* search194_1_0 -> 569 in the cache */
   /* search194_1_1_0_0 -> 590 in the cache */
   /* search194_1_1_0 -> 591 in the cache */
   /* search194_1_1 -> 592 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 569, 592 },
      -1,
   } },
   /* search194_2_0 -> 576 in the cache */
   /* search194_2_1_0 -> 590 in the cache */
   /* search194_2_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 576, 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 24, 600, 601 },
      -1,
   } },

   /* replace194_0 -> 590 in the cache */
   /* replace194_1 -> 576 in the cache */
   /* replace194_2 -> 24 in the cache */
   /* replace194 -> 597 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search195_1_0 -> 590 in the cache */
   /* search195_1 -> 591 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 604 },
      -1,
   } },
   /* search195_2_1_0 -> 590 in the cache */
   /* search195_2_1 -> 591 in the cache */
   /* search195_2_2 -> 604 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 605, 591, 604 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 603, 591, 606 },
      -1,
   } },

   /* replace195_0 -> 590 in the cache */
   /* replace195_1 -> 603 in the cache */
   /* replace195_2 -> 604 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 590, 603, 604 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 609 },
      -1,
   } },
   /* search196_1_0 -> 551 in the cache */
   /* search196_1_1_0 -> 604 in the cache */
   /* search196_1_1 -> 605 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 551, 605 },
      -1,
   } },
   /* search196_2 -> 604 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 610, 611, 604 },
      -1,
   } },

   /* replace196_0 -> 609 in the cache */
   /* replace196_1 -> 551 in the cache */
   /* replace196_2 -> 604 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 551, 604 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search197_0_0 -> 609 in the cache */
   /* search197_0 -> 610 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 614 },
      -1,
   } },
   /* search197_1_1 -> 576 in the cache */
   /* search197_1_2 -> 563 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 615, 576, 563 },
      -1,
   } },
   /* search197_2_0 -> 614 in the cache */
   /* search197_2_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 614, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 610, 616, 617 },
      -1,
   } },

   /* replace197_0 -> 609 in the cache */
   /* replace197_1 -> 563 in the cache */
   /* replace197_2_0 -> 614 in the cache */
   /* replace197_2_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 614, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 609, 563, 619 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search198_0 -> 569 in the cache */
   /* search198_1_0_0_0 -> 569 in the cache */
   /* search198_1_0_0_1_0 -> 24 in the cache */
   /* search198_1_0_0_1 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 569, 586 },
      -1,
   } },
   /* search198_1_0_1_0 -> 569 in the cache */
   /* search198_1_0_1_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 569, 622 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 621, 623 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 569, 625 },
      -1,
   } },

   /* replace198_0 -> 551 in the cache */
   /* replace198_1 -> 569 in the cache */
   /* replace198_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 551, 569, 24 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search199_0 -> 29 in the cache */
   /* search199_1 -> 48 in the cache */
   /* search199_2_0 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 29, 48, 628 },
      -1,
   } },

   /* replace199_0 -> 552 in the cache */
   /* replace199_1 -> 48 in the cache */
   /* replace199_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 552, 48, 29 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search200_0 -> 29 in the cache */
   /* search200_1_0 -> 29 in the cache */
   /* search200_1_1 -> 48 in the cache */
   /* search200_1 -> 287 in the cache */
   /* search200_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 29, 287, 148 },
      -1,
   } },

   /* replace200_0_0 -> 48 in the cache */
   /* replace200_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 48, 148 },
      -1,
   } },
   /* replace200_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 632, 29 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search201_0_0 -> 29 in the cache */
   /* search201_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 29, 48 },
      0,
   } },
   /* search201_1_0 -> 29 in the cache */
   /* search201_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 29, 148 },
      0,
   } },
   /* search201_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 634, 635, 176 },
      -1,
   } },

   /* replace201_0_0 -> 48 in the cache */
   /* replace201_0_1 -> 148 in the cache */
   /* replace201_0_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 48, 148, 176 },
      -1,
   } },
   /* replace201_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 637, 29 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search202_0 -> 29 in the cache */
   /* search202_1_0 -> 29 in the cache */
   /* search202_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 29, 48 },
      0,
   } },
   /* search202_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 29, 639, 148 },
      -1,
   } },

   /* replace202_0_0 -> 261 in the cache */
   /* replace202_0_1 -> 48 in the cache */
   /* replace202_0_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 261, 48, 148 },
      -1,
   } },
   /* replace202_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 641, 29 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search203_0_0 -> 29 in the cache */
   /* search203_0_1_0 -> 261 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 261, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 29, 645 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search203_1_1 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 647, 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 646, 648 },
      -1,
   } },

   /* replace203_0 -> 29 in the cache */
   /* replace203_1 -> 647 in the cache */
   /* replace203_2 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 29, 647, 643 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search204_0_0 -> 29 in the cache */
   /* search204_0_1_0_0 -> 261 in the cache */
   /* search204_0_1_0_1_0 -> 643 in the cache */
   /* search204_0_1_0_1 -> 644 in the cache */
   /* search204_0_1_0 -> 645 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 29, 651 },
      -1,
   } },
   /* search204_1_0 -> 647 in the cache */
   /* search204_1_1_0 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 647, 653 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 652, 654 },
      -1,
   } },

   /* replace204_0 -> 29 in the cache */
   /* replace204_1 -> 647 in the cache */
   /* replace204_2_0 -> 643 in the cache */
   /* replace204_2 -> 653 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 29, 647, 653 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search205_0 -> 29 in the cache */
   /* search205_1_0 -> 643 in the cache */
   /* search205_1_1_0 -> 647 in the cache */
   /* search205_1_1_1_0 -> 29 in the cache */
   /* search205_1_1_1 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 647, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 643, 657 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 29, 658 },
      -1,
   } },

   /* replace205_0 -> 29 in the cache */
   /* replace205_1 -> 647 in the cache */
   /* replace205_2 -> 643 in the cache */
   /* replace205 -> 650 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search206_0_0 -> 29 in the cache */
   /* search206_0_1_0 -> 261 in the cache */
   /* search206_0_1_1_0_0 -> 590 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 590 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 660 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 261, 661 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 29, 662 },
      -1,
   } },
   /* search206_1_0 -> 647 in the cache */
   /* search206_1_1_0 -> 590 in the cache */
   /* search206_1_1 -> 660 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 647, 660 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 663, 664 },
      -1,
   } },

   /* replace206_0 -> 590 in the cache */
   /* replace206_1 -> 647 in the cache */
   /* replace206_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 590, 647, 29 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search207_0 -> 29 in the cache */
   /* search207_1_0_0 -> 590 in the cache */
   /* search207_1_0 -> 660 in the cache */
   /* search207_1_1_0 -> 647 in the cache */
   /* search207_1_1_1_0 -> 29 in the cache */
   /* search207_1_1_1 -> 293 in the cache */
   /* search207_1_1 -> 657 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 660, 657 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 29, 667 },
      -1,
   } },

   /* replace207_0 -> 590 in the cache */
   /* replace207_1 -> 647 in the cache */
   /* replace207_2 -> 29 in the cache */
   /* replace207 -> 666 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search208_0 -> 29 in the cache */
   /* search208_1_0 -> 261 in the cache */
   /* search208_1_1_0_0 -> 590 in the cache */
   /* search208_1_1_0 -> 660 in the cache */
   /* search208_1_1 -> 661 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 261, 661 },
      -1,
   } },
   /* search208_2_0 -> 647 in the cache */
   /* search208_2_1_0 -> 590 in the cache */
   /* search208_2_1 -> 660 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 647, 660 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 29, 669, 670 },
      -1,
   } },

   /* replace208_0 -> 590 in the cache */
   /* replace208_1 -> 647 in the cache */
   /* replace208_2 -> 29 in the cache */
   /* replace208 -> 666 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search209_0 -> 386 in the cache */
   /* search209_1_0 -> 590 in the cache */
   /* search209_1 -> 660 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 672 },
      -1,
   } },
   /* search209_2_1_0 -> 590 in the cache */
   /* search209_2_1 -> 660 in the cache */
   /* search209_2_2 -> 672 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 673, 660, 672 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 386, 660, 674 },
      -1,
   } },

   /* replace209_0 -> 590 in the cache */
   /* replace209_1 -> 386 in the cache */
   /* replace209_2 -> 672 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 590, 386, 672 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search210_0_0 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 609 },
      -1,
   } },
   /* search210_1_0 -> 48 in the cache */
   /* search210_1_1_0 -> 672 in the cache */
   /* search210_1_1 -> 673 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 48, 673 },
      -1,
   } },
   /* search210_2 -> 672 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 677, 678, 672 },
      -1,
   } },

   /* replace210_0 -> 609 in the cache */
   /* replace210_1 -> 48 in the cache */
   /* replace210_2 -> 672 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 48, 672 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search211_0_0 -> 609 in the cache */
   /* search211_0 -> 677 in the cache */
   /* search211_1_0_0 -> 196 in the cache */
   /* search211_1_0 -> 414 in the cache */
   /* search211_1_1 -> 647 in the cache */
   /* search211_1_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 414, 647, 176 },
      -1,
   } },
   /* search211_2_0 -> 196 in the cache */
   /* search211_2_1 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 196, 647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 677, 681, 682 },
      -1,
   } },

   /* replace211_0 -> 609 in the cache */
   /* replace211_1 -> 176 in the cache */
   /* replace211_2_0 -> 196 in the cache */
   /* replace211_2_1 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 196, 647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 609, 176, 684 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search212_0 -> 261 in the cache */
   /* search212_1_0_0_0 -> 261 in the cache */
   /* search212_1_0_0_1_0 -> 29 in the cache */
   /* search212_1_0_0_1 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 261, 293 },
      -1,
   } },
   /* search212_1_0_1_0 -> 261 in the cache */
   /* search212_1_0_1_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 261, 687 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 686, 688 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 261, 690 },
      -1,
   } },

   /* replace212_0 -> 48 in the cache */
   /* replace212_1 -> 261 in the cache */
   /* replace212_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 48, 261, 29 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search213_0 -> 34 in the cache */
   /* search213_1 -> 53 in the cache */
   /* search213_2_0 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 34, 53, 693 },
      -1,
   } },

   /* replace213_0 -> 552 in the cache */
   /* replace213_1 -> 53 in the cache */
   /* replace213_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 552, 53, 34 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search214_0 -> 34 in the cache */
   /* search214_1_0 -> 34 in the cache */
   /* search214_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 34, 53 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 34, 696, 697 },
      -1,
   } },

   /* replace214_0_0 -> 53 in the cache */
   /* replace214_0_1 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 53, 697 },
      -1,
   } },
   /* replace214_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 699, 34 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search215_0_0 -> 34 in the cache */
   /* search215_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 34, 53 },
      0,
   } },
   /* search215_1_0 -> 34 in the cache */
   /* search215_1_1 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 34, 697 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 701, 702, 703 },
      -1,
   } },

   /* replace215_0_0 -> 53 in the cache */
   /* replace215_0_1 -> 697 in the cache */
   /* replace215_0_2 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 697, 703 },
      -1,
   } },
   /* replace215_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 705, 34 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search216_0 -> 34 in the cache */
   /* search216_1_0 -> 34 in the cache */
   /* search216_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 34, 53 },
      0,
   } },
   /* search216_2 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 34, 707, 697 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   /* replace216_0_1 -> 53 in the cache */
   /* replace216_0_2 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 709, 53, 697 },
      -1,
   } },
   /* replace216_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 710, 34 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search217_0_0 -> 34 in the cache */
   /* search217_0_1_0 -> 709 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 709, 713 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 34, 714 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search217_1_1 -> 712 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 716, 712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 715, 717 },
      -1,
   } },

   /* replace217_0 -> 34 in the cache */
   /* replace217_1 -> 716 in the cache */
   /* replace217_2 -> 712 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 34, 716, 712 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search218_0_0 -> 34 in the cache */
   /* search218_0_1_0_0 -> 709 in the cache */
   /* search218_0_1_0_1_0 -> 712 in the cache */
   /* search218_0_1_0_1 -> 713 in the cache */
   /* search218_0_1_0 -> 714 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 714 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 34, 720 },
      -1,
   } },
   /* search218_1_0 -> 716 in the cache */
   /* search218_1_1_0 -> 712 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 716, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 721, 723 },
      -1,
   } },

   /* replace218_0 -> 34 in the cache */
   /* replace218_1 -> 716 in the cache */
   /* replace218_2_0 -> 712 in the cache */
   /* replace218_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 34, 716, 722 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search219_0 -> 34 in the cache */
   /* search219_1_0 -> 712 in the cache */
   /* search219_1_1_0 -> 716 in the cache */
   /* search219_1_1_1_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 716, 726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 712, 727 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 34, 728 },
      -1,
   } },

   /* replace219_0 -> 34 in the cache */
   /* replace219_1 -> 716 in the cache */
   /* replace219_2 -> 712 in the cache */
   /* replace219 -> 719 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search220_0_0 -> 34 in the cache */
   /* search220_0_1_0 -> 709 in the cache */
   /* search220_0_1_1_0_0 -> 590 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 590 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 730 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 709, 731 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 34, 732 },
      -1,
   } },
   /* search220_1_0 -> 716 in the cache */
   /* search220_1_1_0 -> 590 in the cache */
   /* search220_1_1 -> 730 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 716, 730 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 733, 734 },
      -1,
   } },

   /* replace220_0 -> 590 in the cache */
   /* replace220_1 -> 716 in the cache */
   /* replace220_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 590, 716, 34 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search221_0 -> 34 in the cache */
   /* search221_1_0_0 -> 590 in the cache */
   /* search221_1_0 -> 730 in the cache */
   /* search221_1_1_0 -> 716 in the cache */
   /* search221_1_1_1_0 -> 34 in the cache */
   /* search221_1_1_1 -> 726 in the cache */
   /* search221_1_1 -> 727 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 730, 727 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 34, 737 },
      -1,
   } },

   /* replace221_0 -> 590 in the cache */
   /* replace221_1 -> 716 in the cache */
   /* replace221_2 -> 34 in the cache */
   /* replace221 -> 736 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search222_0 -> 34 in the cache */
   /* search222_1_0 -> 709 in the cache */
   /* search222_1_1_0_0 -> 590 in the cache */
   /* search222_1_1_0 -> 730 in the cache */
   /* search222_1_1 -> 731 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 709, 731 },
      -1,
   } },
   /* search222_2_0 -> 716 in the cache */
   /* search222_2_1_0 -> 590 in the cache */
   /* search222_2_1 -> 730 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 716, 730 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 34, 739, 740 },
      -1,
   } },

   /* replace222_0 -> 590 in the cache */
   /* replace222_1 -> 716 in the cache */
   /* replace222_2 -> 34 in the cache */
   /* replace222 -> 736 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search223_1_0 -> 590 in the cache */
   /* search223_1 -> 730 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 743 },
      -1,
   } },
   /* search223_2_1_0 -> 590 in the cache */
   /* search223_2_1 -> 730 in the cache */
   /* search223_2_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 744, 730, 743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 742, 730, 745 },
      -1,
   } },

   /* replace223_0 -> 590 in the cache */
   /* replace223_1 -> 742 in the cache */
   /* replace223_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 590, 742, 743 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search224_0_0 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 609 },
      -1,
   } },
   /* search224_1_0 -> 53 in the cache */
   /* search224_1_1_0 -> 743 in the cache */
   /* search224_1_1 -> 744 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 53, 744 },
      -1,
   } },
   /* search224_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 748, 749, 743 },
      -1,
   } },

   /* replace224_0 -> 609 in the cache */
   /* replace224_1 -> 53 in the cache */
   /* replace224_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 53, 743 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search225_0_0 -> 609 in the cache */
   /* search225_0 -> 748 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 752 },
      -1,
   } },
   /* search225_1_1 -> 716 in the cache */
   /* search225_1_2 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 753, 716, 703 },
      -1,
   } },
   /* search225_2_0 -> 752 in the cache */
   /* search225_2_1 -> 716 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 752, 716 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 748, 754, 755 },
      -1,
   } },

   /* replace225_0 -> 609 in the cache */
   /* replace225_1 -> 703 in the cache */
   /* replace225_2_0 -> 752 in the cache */
   /* replace225_2_1 -> 716 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 752, 716 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 609, 703, 757 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search226_0 -> 709 in the cache */
   /* search226_1_0_0_0 -> 709 in the cache */
   /* search226_1_0_0_1_0 -> 34 in the cache */
   /* search226_1_0_0_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 709, 726 },
      -1,
   } },
   /* search226_1_0_1_0 -> 709 in the cache */
   /* search226_1_0_1_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 709, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 759, 761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 762 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 709, 763 },
      -1,
   } },

   /* replace226_0 -> 53 in the cache */
   /* replace226_1 -> 709 in the cache */
   /* replace226_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 709, 34 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search227_0_0 -> 162 in the cache */
   /* search227_0_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 162, 163 },
      0,
   } },
   /* search227_1_0 -> 162 in the cache */
   /* search227_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 162, 165 },
      0,
   } },
   /* search227_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 766, 767, 166 },
      -1,
   } },

   /* replace227_0_0 -> 163 in the cache */
   /* replace227_0_1 -> 165 in the cache */
   /* replace227_0_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 163, 165, 166 },
      -1,
   } },
   /* replace227_1 -> 162 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 769, 162 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search228_0 -> 0 in the cache */
   /* search228_1 -> 273 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 273, 771 },
      -1,
   } },

   /* replace228_0_0_0 -> 0 in the cache */
   /* replace228_0_0 -> 230 in the cache */
   /* replace228_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 230, 771 },
      -1,
   } },
   /* replace228_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 773, 0 },
      -1,
   } },

   /* ('ftrunc@16', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search229_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 24 },
      -1,
   } },

   /* replace229_0_0 -> 24 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 24, 776 },
      -1,
   } },
   /* replace229_1_0_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 779 },
      -1,
   } },
   /* replace229_2_0_0 -> 24 in the cache */
   /* replace229_2_0 -> 778 in the cache */
   /* replace229_2 -> 779 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 777, 780, 779 },
      -1,
   } },

   /* ('ftrunc@32', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search230_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace230_0_0 -> 29 in the cache */
   /* replace230_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 29, 241 },
      -1,
   } },
   /* replace230_1_0_0_0 -> 29 in the cache */
   /* replace230_1_0_0 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 423 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 784 },
      -1,
   } },
   /* replace230_2_0_0 -> 29 in the cache */
   /* replace230_2_0 -> 423 in the cache */
   /* replace230_2 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 783, 785, 784 },
      -1,
   } },

   /* ('ftrunc@64', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search231_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 34 },
      -1,
   } },

   /* replace231_0_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 788 },
      -1,
   } },
   /* replace231_1_0_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 790 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 791 },
      -1,
   } },
   /* replace231_2_0_0 -> 34 in the cache */
   /* replace231_2_0 -> 790 in the cache */
   /* replace231_2 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 789, 792, 791 },
      -1,
   } },

   /* ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search232_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 24 },
      -1,
   } },

   /* replace232_0 -> 24 in the cache */
   /* replace232_1_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 24, 795 },
      -1,
   } },

   /* ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search233_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace233_0 -> 29 in the cache */
   /* replace233_1_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 29, 798 },
      -1,
   } },

   /* ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search234_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 34 },
      -1,
   } },

   /* replace234_0 -> 34 in the cache */
   /* replace234_1_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 34, 801 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fadd@16', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@16', 'b', ('ffloor', 'a')) */
   /* search235_0 -> 24 in the cache */
   /* search235_1_0 -> 551 in the cache */
   /* search235_1_1_0_0 -> 24 in the cache */
   /* search235_1_1_0 -> 795 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 551, 803 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 24, 804 },
      -1,
   } },

   /* replace235_0 -> 551 in the cache */
   /* replace235_1_0 -> 24 in the cache */
   /* replace235_1 -> 794 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 551, 794 },
      -1,
   } },

   /* ('fadd@32', 'a', ('fadd@32', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@32', 'b', ('ffloor', 'a')) */
   /* search236_0 -> 29 in the cache */
   /* search236_1_0 -> 48 in the cache */
   /* search236_1_1_0_0 -> 29 in the cache */
   /* search236_1_1_0 -> 798 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 798 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 48, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 29, 808 },
      -1,
   } },

   /* replace236_0 -> 48 in the cache */
   /* replace236_1_0 -> 29 in the cache */
   /* replace236_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 48, 797 },
      -1,
   } },

   /* ('fadd@64', 'a', ('fadd@64', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@64', 'b', ('ffloor', 'a')) */
   /* search237_0 -> 34 in the cache */
   /* search237_1_0 -> 53 in the cache */
   /* search237_1_1_0_0 -> 34 in the cache */
   /* search237_1_1_0 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 801 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 53, 811 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 34, 812 },
      -1,
   } },

   /* replace237_0 -> 53 in the cache */
   /* replace237_1_0 -> 34 in the cache */
   /* replace237_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 53, 800 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search238_0 -> 24 in the cache */
   /* search238_1_0_0 -> 24 in the cache */
   /* search238_1_0 -> 795 in the cache */
   /* search238_1 -> 803 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 803 },
      -1,
   } },

   /* replace238_0 -> 24 in the cache */
   /* replace238 -> 794 in the cache */

   /* ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search239_0 -> 29 in the cache */
   /* search239_1_0_0 -> 29 in the cache */
   /* search239_1_0 -> 798 in the cache */
   /* search239_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 29, 807 },
      -1,
   } },

   /* replace239_0 -> 29 in the cache */
   /* replace239 -> 797 in the cache */

   /* ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search240_0 -> 34 in the cache */
   /* search240_1_0_0 -> 34 in the cache */
   /* search240_1_0 -> 801 in the cache */
   /* search240_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 34, 811 },
      -1,
   } },

   /* replace240_0 -> 34 in the cache */
   /* replace240 -> 800 in the cache */

   /* ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search241_0 -> 24 in the cache */
   /* search241 -> 795 in the cache */

   /* replace241_0 -> 24 in the cache */
   /* replace241_1_0 -> 24 in the cache */
   /* replace241_1 -> 794 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 24, 794 },
      -1,
   } },

   /* ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search242_0 -> 29 in the cache */
   /* search242 -> 798 in the cache */

   /* replace242_0 -> 29 in the cache */
   /* replace242_1_0 -> 29 in the cache */
   /* replace242_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 29, 797 },
      -1,
   } },

   /* ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search243_0 -> 34 in the cache */
   /* search243 -> 801 in the cache */

   /* replace243_0 -> 34 in the cache */
   /* replace243_1_0 -> 34 in the cache */
   /* replace243_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 34, 800 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search244_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace244_0_0_0 -> 9 in the cache */
   /* replace244_0_0 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 118 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 822 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search245_0 -> 24 in the cache */
   /* search245_1 -> 551 in the cache */
   /* search245_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 24, 551, 557 },
      -1,
   } },

   /* replace245_0_0 -> 24 in the cache */
   /* replace245_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 24, 551 },
      -1,
   } },
   /* replace245_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 825, 557 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search246_0 -> 29 in the cache */
   /* search246_1 -> 48 in the cache */
   /* search246_2 -> 148 in the cache */
   /* search246 -> 252 in the cache */

   /* replace246_0_0 -> 29 in the cache */
   /* replace246_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace246_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 827, 148 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search247_0 -> 34 in the cache */
   /* search247_1 -> 53 in the cache */
   /* search247_2 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 34, 53, 697 },
      -1,
   } },

   /* replace247_0_0 -> 34 in the cache */
   /* replace247_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* replace247_1 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 830, 697 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search248_0 -> 29 in the cache */
   /* search248_1 -> 48 in the cache */
   /* search248_2 -> 148 in the cache */
   /* search248 -> 462 in the cache */

   /* replace248_0_0 -> 29 in the cache */
   /* replace248_0_1 -> 48 in the cache */
   /* replace248_0 -> 147 in the cache */
   /* replace248_1 -> 148 in the cache */
   /* replace248 -> 301 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search249_0 -> 24 in the cache */
   /* search249_1 -> 551 in the cache */
   /* search249_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 24, 551, 557 },
      -1,
   } },

   /* replace249_0_0 -> 24 in the cache */
   /* replace249_0_1 -> 551 in the cache */
   /* replace249_0 -> 825 in the cache */
   /* replace249_1 -> 557 in the cache */
   /* replace249 -> 826 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search250_0 -> 29 in the cache */
   /* search250_1 -> 48 in the cache */
   /* search250_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace250_0_0 -> 29 in the cache */
   /* replace250_0_1 -> 48 in the cache */
   /* replace250_0 -> 827 in the cache */
   /* replace250_1 -> 148 in the cache */
   /* replace250 -> 828 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search251_0 -> 34 in the cache */
   /* search251_1 -> 53 in the cache */
   /* search251_2 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 34, 53, 697 },
      -1,
   } },

   /* replace251_0_0 -> 34 in the cache */
   /* replace251_0_1 -> 53 in the cache */
   /* replace251_0 -> 830 in the cache */
   /* replace251_1 -> 697 in the cache */
   /* replace251 -> 831 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search252_0 -> 29 in the cache */
   /* search252_1 -> 48 in the cache */
   /* search252_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace252_0_0 -> 29 in the cache */
   /* replace252_0_1 -> 48 in the cache */
   /* replace252_0 -> 147 in the cache */
   /* replace252_1 -> 148 in the cache */
   /* replace252 -> 301 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 837 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 839, 840 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 838, 841 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 842, 843 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 844, 845 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace253_1_0_0_0 -> 839 in the cache */
   /* replace253_1_0_0_1 -> 840 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 839, 840 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 848, 849 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 850, 851 },
      -1,
   } },
   /* replace253_2_0 -> 849 in the cache */
   /* replace253_2_1 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 849, 851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 847, 852, 853 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search254_0 -> 0 in the cache */
   /* search254_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace254_0_3 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 856, 857, 858, 283 },
      -1,
   } },
   /* replace254_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 859, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 0.0) => 0.0 */
   /* search255_0 -> 9 in the cache */
   /* search255_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* replace255 -> 8 in the cache */

   /* ('fdot3', 'a', 0.0) => 0.0 */
   /* search256_0 -> 9 in the cache */
   /* search256_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* replace256 -> 8 in the cache */

   /* ('fdot2', 'a', 0.0) => 0.0 */
   /* search257_0 -> 9 in the cache */
   /* search257_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* replace257 -> 8 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search258_0_0 -> 162 in the cache */
   /* search258_0_1 -> 163 in the cache */
   /* search258_0_2 -> 165 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 162, 163, 165, 864 },
      -1,
   } },
   /* search258_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 865, 166 },
      -1,
   } },

   /* replace258_0_0 -> 162 in the cache */
   /* replace258_0_1 -> 163 in the cache */
   /* replace258_0_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 162, 163, 165 },
      -1,
   } },
   /* replace258_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 867, 166 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search259_0_0 -> 0 in the cache */
   /* search259_0_1 -> 273 in the cache */
   /* search259_0_2 -> 273 in the cache */
   /* search259_0_3 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 273, 273, 273 },
      -1,
   } },
   /* search259_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 869, 1 },
      -1,
   } },

   /* replace259_0 -> 0 in the cache */
   /* replace259_1 -> 1 in the cache */
   /* replace259 -> 279 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search260_0_0 -> 139 in the cache */
   /* search260_0_1 -> 140 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   /* search260_0_3 -> 871 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 139, 140, 871, 871 },
      -1,
   } },
   /* search260_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 872, 142 },
      -1,
   } },

   /* replace260_0_0 -> 139 in the cache */
   /* replace260_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 139, 140 },
      -1,
   } },
   /* replace260_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 874, 142 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search261_0_0 -> 162 in the cache */
   /* search261_0_1 -> 163 in the cache */
   /* search261_0_2 -> 165 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 162, 163, 165, 876 },
      -1,
   } },
   /* search261_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 877, 166 },
      -1,
   } },

   /* replace261_0_0 -> 162 in the cache */
   /* replace261_0_1 -> 163 in the cache */
   /* replace261_0_2 -> 165 in the cache */
   /* replace261_0 -> 867 in the cache */
   /* replace261_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 867, 166 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search262_0_0 -> 0 in the cache */
   /* search262_0_1 -> 273 in the cache */
   /* search262_0_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 273, 273 },
      -1,
   } },
   /* search262_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 880, 1 },
      -1,
   } },

   /* replace262_0 -> 0 in the cache */
   /* replace262_1 -> 1 in the cache */
   /* replace262 -> 279 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search263_0_0 -> 139 in the cache */
   /* search263_0_1 -> 140 in the cache */
   /* search263_0_2 -> 871 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 139, 140, 871 },
      -1,
   } },
   /* search263_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 882, 142 },
      -1,
   } },

   /* replace263_0_0 -> 139 in the cache */
   /* replace263_0_1 -> 140 in the cache */
   /* replace263_0 -> 874 in the cache */
   /* replace263_1 -> 142 in the cache */
   /* replace263 -> 875 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search264_0_0 -> 0 in the cache */
   /* search264_0_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 273 },
      -1,
   } },
   /* search264_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 884, 1 },
      -1,
   } },

   /* replace264_0 -> 0 in the cache */
   /* replace264_1 -> 1 in the cache */
   /* replace264 -> 279 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search265_0 -> 9 in the cache */
   /* search265_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 9, 259 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 887, 888 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search266_0 -> 0 in the cache */
   /* search266_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace266_0_0 -> 0 in the cache */
   /* replace266_0_1 -> 1 in the cache */
   /* replace266_0 -> 279 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 279 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search267_0 -> 0 in the cache */
   /* search267_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace267_0_0 -> 0 in the cache */
   /* replace267_0_1 -> 1 in the cache */
   /* replace267_0 -> 279 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 279 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search268_0 -> 0 in the cache */
   /* search268_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace268_0_0 -> 0 in the cache */
   /* replace268_0_1 -> 1 in the cache */
   /* replace268_0 -> 279 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 279 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search269_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace269_0 -> 887 in the cache */
   /* replace269_1 -> 888 in the cache */
   /* replace269 -> 889 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 897 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 898 },
      0,
   } },
   /* search270_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 899, 259 },
      -1,
   } },

   /* replace270_0_0 -> 259 in the cache */
   /* replace270_0_1_0 -> 9 in the cache */
   /* replace270_0_1 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 259, 118 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 901 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search271_0_0_0 -> 139 in the cache */
   /* search271_0_0_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 139, 296 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 903, 904 },
      -1,
   } },
   /* search271_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 905, 324 },
      -1,
   } },

   /* replace271_0_0 -> 139 in the cache */
   /* replace271_0_1_0 -> 140 in the cache */
   /* replace271_0_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 140, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 139, 907 },
      -1,
   } },
   /* replace271_1_0 -> 142 in the cache */
   /* replace271_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 142, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 908, 909 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search272_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 911 },
      -1,
   } },
   /* search272_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 912, 322 },
      -1,
   } },

   /* replace272_0 -> 0 in the cache */
   /* replace272_1_0 -> 1 in the cache */
   /* replace272_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1, 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 914 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search273_0_0 -> 19 in the cache */
   /* search273_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 19, 45 },
      -1,
   } },
   /* search273_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 916, 322 },
      -1,
   } },

   /* replace273_0_0_0_0 -> 48 in the cache */
   /* replace273_0_0_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 22 },
      -1,
   } },
   /* replace273_0_0_1_0 -> 148 in the cache */
   /* replace273_0_0_1_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 148, 22 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 918, 919 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8ull /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 920, 921 },
      -1,
   } },
   /* replace273_1_0 -> 19 in the cache */
   /* replace273_1_1_0 -> 48 in the cache */
   /* replace273_1_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 48, 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 19, 923 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 922, 924, 925 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search274_0_0 -> 19 in the cache */
   /* search274_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 19, 45 },
      -1,
   } },
   /* search274_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 927, 322 },
      -1,
   } },

   /* replace274_0_0_0_0 -> 48 in the cache */
   /* replace274_0_0_0_1 -> 22 in the cache */
   /* replace274_0_0_0 -> 918 in the cache */
   /* replace274_0_0_1_0 -> 148 in the cache */
   /* replace274_0_0_1_1 -> 22 in the cache */
   /* replace274_0_0_1 -> 919 in the cache */
   /* replace274_0_0 -> 920 in the cache */
   /* replace274_0_1 -> 921 in the cache */
   /* replace274_0 -> 922 in the cache */
   /* replace274_1_0 -> 19 in the cache */
   /* replace274_1_1_0 -> 48 in the cache */
   /* replace274_1_1_1 -> 148 in the cache */
   /* replace274_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 19, 923 },
      -1,
   } },
   /* replace274_2 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 922, 929, 925 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7)) */
   /* search275_0_0 -> 19 in the cache */
   /* search275_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 19, 45 },
      -1,
   } },
   /* search275_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 931, 322 },
      -1,
   } },

   /* replace275_0 -> 19 in the cache */
   /* replace275_1_0_0_0 -> 48 in the cache */
   /* replace275_1_0_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 48, 22 },
      -1,
   } },
   /* replace275_1_0_1_0 -> 148 in the cache */
   /* replace275_1_0_1_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 148, 22 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 933, 934 },
      -1,
   } },
   /* replace275_1_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 935, 22 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 19, 936 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search276_0_0 -> 24 in the cache */
   /* search276_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 24, 45 },
      -1,
   } },
   /* search276_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 938, 322 },
      -1,
   } },

   /* replace276_0_0_0_0 -> 48 in the cache */
   /* replace276_0_0_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 27 },
      -1,
   } },
   /* replace276_0_0_1_0 -> 148 in the cache */
   /* replace276_0_0_1_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 148, 27 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 940, 941 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10ull /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 942, 943 },
      -1,
   } },
   /* replace276_1_0 -> 24 in the cache */
   /* replace276_1_1_0 -> 48 in the cache */
   /* replace276_1_1_1 -> 148 in the cache */
   /* replace276_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 24, 923 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 944, 945, 946 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search277_0_0 -> 24 in the cache */
   /* search277_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 24, 45 },
      -1,
   } },
   /* search277_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 948, 322 },
      -1,
   } },

   /* replace277_0_0_0_0 -> 48 in the cache */
   /* replace277_0_0_0_1 -> 27 in the cache */
   /* replace277_0_0_0 -> 940 in the cache */
   /* replace277_0_0_1_0 -> 148 in the cache */
   /* replace277_0_0_1_1 -> 27 in the cache */
   /* replace277_0_0_1 -> 941 in the cache */
   /* replace277_0_0 -> 942 in the cache */
   /* replace277_0_1 -> 943 in the cache */
   /* replace277_0 -> 944 in the cache */
   /* replace277_1_0 -> 24 in the cache */
   /* replace277_1_1_0 -> 48 in the cache */
   /* replace277_1_1_1 -> 148 in the cache */
   /* replace277_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 24, 923 },
      -1,
   } },
   /* replace277_2 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 944, 950, 946 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15)) */
   /* search278_0_0 -> 24 in the cache */
   /* search278_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 24, 45 },
      -1,
   } },
   /* search278_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 952, 322 },
      -1,
   } },

   /* replace278_0 -> 24 in the cache */
   /* replace278_1_0_0_0 -> 48 in the cache */
   /* replace278_1_0_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 48, 27 },
      -1,
   } },
   /* replace278_1_0_1_0 -> 148 in the cache */
   /* replace278_1_0_1_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 148, 27 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 954, 955 },
      -1,
   } },
   /* replace278_1_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 956, 27 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 24, 957 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search279_0_0 -> 29 in the cache */
   /* search279_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 45 },
      -1,
   } },
   /* search279_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 959, 322 },
      -1,
   } },

   /* replace279_0_0_0_0 -> 48 in the cache */
   /* replace279_0_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 32 },
      -1,
   } },
   /* replace279_0_0_1_0 -> 148 in the cache */
   /* replace279_0_0_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 148, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 961, 962 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20ull /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 963, 964 },
      -1,
   } },
   /* replace279_1_0 -> 29 in the cache */
   /* replace279_1_1_0 -> 48 in the cache */
   /* replace279_1_1_1 -> 148 in the cache */
   /* replace279_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 29, 923 },
      -1,
   } },
   /* replace279_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 965, 966, 135 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search280_0_0 -> 29 in the cache */
   /* search280_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 45 },
      -1,
   } },
   /* search280_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 968, 322 },
      -1,
   } },

   /* replace280_0_0_0_0 -> 48 in the cache */
   /* replace280_0_0_0_1 -> 32 in the cache */
   /* replace280_0_0_0 -> 961 in the cache */
   /* replace280_0_0_1_0 -> 148 in the cache */
   /* replace280_0_0_1_1 -> 32 in the cache */
   /* replace280_0_0_1 -> 962 in the cache */
   /* replace280_0_0 -> 963 in the cache */
   /* replace280_0_1 -> 964 in the cache */
   /* replace280_0 -> 965 in the cache */
   /* replace280_1_0 -> 29 in the cache */
   /* replace280_1_1_0 -> 48 in the cache */
   /* replace280_1_1_1 -> 148 in the cache */
   /* replace280_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 29, 923 },
      -1,
   } },
   /* replace280_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 965, 970, 135 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31)) */
   /* search281_0_0 -> 29 in the cache */
   /* search281_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 29, 45 },
      -1,
   } },
   /* search281_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 972, 322 },
      -1,
   } },

   /* replace281_0 -> 29 in the cache */
   /* replace281_1_0_0_0 -> 48 in the cache */
   /* replace281_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 48, 32 },
      -1,
   } },
   /* replace281_1_0_1_0 -> 148 in the cache */
   /* replace281_1_0_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 148, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 974, 975 },
      -1,
   } },
   /* replace281_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 976, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 29, 977 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search282_0_0 -> 34 in the cache */
   /* search282_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 45 },
      -1,
   } },
   /* search282_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 979, 322 },
      -1,
   } },

   /* replace282_0_0_0_0 -> 48 in the cache */
   /* replace282_0_0_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 37 },
      -1,
   } },
   /* replace282_0_0_1_0 -> 148 in the cache */
   /* replace282_0_0_1_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 148, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 981, 982 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40ull /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 983, 984 },
      -1,
   } },
   /* replace282_1_0 -> 34 in the cache */
   /* replace282_1_1_0 -> 48 in the cache */
   /* replace282_1_1_1 -> 148 in the cache */
   /* replace282_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 34, 923 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 985, 986, 987 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search283_0_0 -> 34 in the cache */
   /* search283_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 45 },
      -1,
   } },
   /* search283_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 989, 322 },
      -1,
   } },

   /* replace283_0_0_0_0 -> 48 in the cache */
   /* replace283_0_0_0_1 -> 37 in the cache */
   /* replace283_0_0_0 -> 981 in the cache */
   /* replace283_0_0_1_0 -> 148 in the cache */
   /* replace283_0_0_1_1 -> 37 in the cache */
   /* replace283_0_0_1 -> 982 in the cache */
   /* replace283_0_0 -> 983 in the cache */
   /* replace283_0_1 -> 984 in the cache */
   /* replace283_0 -> 985 in the cache */
   /* replace283_1_0 -> 34 in the cache */
   /* replace283_1_1_0 -> 48 in the cache */
   /* replace283_1_1_1 -> 148 in the cache */
   /* replace283_1_1 -> 923 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 34, 923 },
      -1,
   } },
   /* replace283_2 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 985, 991, 987 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63)) */
   /* search284_0_0 -> 34 in the cache */
   /* search284_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 45 },
      -1,
   } },
   /* search284_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 993, 322 },
      -1,
   } },

   /* replace284_0 -> 34 in the cache */
   /* replace284_1_0_0_0 -> 48 in the cache */
   /* replace284_1_0_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 48, 37 },
      -1,
   } },
   /* replace284_1_0_1_0 -> 148 in the cache */
   /* replace284_1_0_1_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 148, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 995, 996 },
      -1,
   } },
   /* replace284_1_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 997, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 34, 998 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search285_0_0 -> 19 in the cache */
   /* search285_0_1 -> 45 in the cache */
   /* search285_0 -> 927 in the cache */
   /* search285_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 927, 48 },
      -1,
   } },

   /* replace285_0 -> 19 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xffull /* 255 */ },
   } },
   /* replace285_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1001, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 1002 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search286_0_0 -> 19 in the cache */
   /* search286_0_1 -> 45 in the cache */
   /* search286_0 -> 931 in the cache */
   /* search286_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 931, 48 },
      -1,
   } },

   /* replace286_0 -> 19 in the cache */
   /* replace286_1_0 -> 1001 in the cache */
   /* replace286_1_1 -> 48 in the cache */
   /* replace286_1 -> 1002 in the cache */
   /* replace286 -> 1003 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search287_0_0 -> 19 in the cache */
   /* search287_0_1 -> 45 in the cache */
   /* search287_0 -> 916 in the cache */
   /* search287_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 916, 48 },
      -1,
   } },

   /* replace287_0 -> 19 in the cache */
   /* replace287_1_0 -> 1001 in the cache */
   /* replace287_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1001, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 1006 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search288_0_0 -> 24 in the cache */
   /* search288_0_1 -> 45 in the cache */
   /* search288_0 -> 948 in the cache */
   /* search288_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 948, 48 },
      -1,
   } },

   /* replace288_0 -> 24 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffffull /* 65535 */ },
   } },
   /* replace288_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1009, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 1010 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search289_0_0 -> 24 in the cache */
   /* search289_0_1 -> 45 in the cache */
   /* search289_0 -> 952 in the cache */
   /* search289_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 952, 48 },
      -1,
   } },

   /* replace289_0 -> 24 in the cache */
   /* replace289_1_0 -> 1009 in the cache */
   /* replace289_1_1 -> 48 in the cache */
   /* replace289_1 -> 1010 in the cache */
   /* replace289 -> 1011 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search290_0_0 -> 24 in the cache */
   /* search290_0_1 -> 45 in the cache */
   /* search290_0 -> 938 in the cache */
   /* search290_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 938, 48 },
      -1,
   } },

   /* replace290_0 -> 24 in the cache */
   /* replace290_1_0 -> 1009 in the cache */
   /* replace290_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1009, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 1014 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search291_0_0 -> 29 in the cache */
   /* search291_0_1 -> 45 in the cache */
   /* search291_0 -> 968 in the cache */
   /* search291_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 968, 48 },
      -1,
   } },

   /* replace291_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffull /* 4294967295 */ },
   } },
   /* replace291_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1017, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1018 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search292_0_0 -> 29 in the cache */
   /* search292_0_1 -> 45 in the cache */
   /* search292_0 -> 972 in the cache */
   /* search292_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 972, 48 },
      -1,
   } },

   /* replace292_0 -> 29 in the cache */
   /* replace292_1_0 -> 1017 in the cache */
   /* replace292_1_1 -> 48 in the cache */
   /* replace292_1 -> 1018 in the cache */
   /* replace292 -> 1019 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search293_0_0 -> 29 in the cache */
   /* search293_0_1 -> 45 in the cache */
   /* search293_0 -> 959 in the cache */
   /* search293_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 959, 48 },
      -1,
   } },

   /* replace293_0 -> 29 in the cache */
   /* replace293_1_0 -> 1017 in the cache */
   /* replace293_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1017, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1022 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search294_0_0 -> 34 in the cache */
   /* search294_0_1 -> 45 in the cache */
   /* search294_0 -> 989 in the cache */
   /* search294_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 989, 48 },
      -1,
   } },

   /* replace294_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffffull /* 18446744073709551615 */ },
   } },
   /* replace294_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1025, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 1026 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search295_0_0 -> 34 in the cache */
   /* search295_0_1 -> 45 in the cache */
   /* search295_0 -> 993 in the cache */
   /* search295_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 993, 48 },
      -1,
   } },

   /* replace295_0 -> 34 in the cache */
   /* replace295_1_0 -> 1025 in the cache */
   /* replace295_1_1 -> 48 in the cache */
   /* replace295_1 -> 1026 in the cache */
   /* replace295 -> 1027 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search296_0_0 -> 34 in the cache */
   /* search296_0_1 -> 45 in the cache */
   /* search296_0 -> 979 in the cache */
   /* search296_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 979, 48 },
      -1,
   } },

   /* replace296_0 -> 34 in the cache */
   /* replace296_1_0 -> 1025 in the cache */
   /* replace296_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1025, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 1030 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search297_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 1032 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffffffffffcull /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1033, 1034 },
      -1,
   } },

   /* replace297_0 -> 29 in the cache */
   /* replace297_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search298_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1037 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0xfffffffffffffffcull /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1038, 1039 },
      -1,
   } },

   /* replace298_0 -> 0 in the cache */
   /* replace298_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search299_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 1042 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffeull /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1043, 1044 },
      -1,
   } },

   /* replace299_0_0 -> 29 in the cache */
   /* replace299_0_1 -> 1044 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 1044 },
      -1,
   } },
   /* replace299_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1046, 48 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search300_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 1048 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffcull /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1049, 1050 },
      -1,
   } },

   /* replace300_0_0 -> 29 in the cache */
   /* replace300_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 1050 },
      -1,
   } },
   /* replace300_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1052, 48 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search301_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 1054 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8ull /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1055, 1056 },
      -1,
   } },

   /* replace301_0_0 -> 29 in the cache */
   /* replace301_0_1 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 1056 },
      -1,
   } },
   /* replace301_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1058, 48 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search302_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 1060 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0ull /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1061, 1062 },
      -1,
   } },

   /* replace302_0_0 -> 29 in the cache */
   /* replace302_0_1 -> 1062 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 1062 },
      -1,
   } },
   /* replace302_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1064, 48 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search303_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 1066 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0ull /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1067, 1068 },
      -1,
   } },

   /* replace303_0_0 -> 29 in the cache */
   /* replace303_0_1 -> 1068 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 1068 },
      -1,
   } },
   /* replace303_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1070, 48 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search304_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 1072 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0ull /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1073, 1074 },
      -1,
   } },

   /* replace304_0_0 -> 29 in the cache */
   /* replace304_0_1 -> 1074 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 1074 },
      -1,
   } },
   /* replace304_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1076, 48 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search305_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffffull /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1078 },
      -1,
   } },
   /* search305_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1079, 486 },
      -1,
   } },

   /* replace305_0 -> 29 in the cache */
   /* replace305_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 486 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search306_0_0 -> 29 in the cache */
   /* search306_0_1 -> 486 in the cache */
   /* search306_0 -> 1081 in the cache */
   /* search306_1 -> 1044 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1081, 1044 },
      -1,
   } },

   /* replace306_0 -> 29 in the cache */
   /* replace306_1 -> 486 in the cache */
   /* replace306 -> 1081 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search307_0_0 -> 29 in the cache */
   /* search307_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 486 },
      -1,
   } },
   /* search307_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1083, 1078 },
      -1,
   } },

   /* replace307_0 -> 29 in the cache */
   /* replace307_1 -> 486 in the cache */
   /* replace307 -> 1083 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search308_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffull /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1085 },
      -1,
   } },
   /* search308_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1086, 491 },
      -1,
   } },

   /* replace308_0 -> 29 in the cache */
   /* replace308_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 491 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search309_0_0 -> 29 in the cache */
   /* search309_0_1 -> 491 in the cache */
   /* search309_0 -> 1088 in the cache */
   /* search309_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1088, 1050 },
      -1,
   } },

   /* replace309_0 -> 29 in the cache */
   /* replace309_1 -> 491 in the cache */
   /* replace309 -> 1088 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search310_0_0 -> 29 in the cache */
   /* search310_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 491 },
      -1,
   } },
   /* search310_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1090, 1085 },
      -1,
   } },

   /* replace310_0 -> 29 in the cache */
   /* replace310_1 -> 491 in the cache */
   /* replace310 -> 1090 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search311_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffull /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1092 },
      -1,
   } },
   /* search311_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1093, 943 },
      -1,
   } },

   /* replace311_0 -> 29 in the cache */
   /* replace311_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 943 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search312_0_0 -> 29 in the cache */
   /* search312_0_1 -> 943 in the cache */
   /* search312_0 -> 1095 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000ull /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1095, 1096 },
      -1,
   } },

   /* replace312_0 -> 29 in the cache */
   /* replace312_1 -> 943 in the cache */
   /* replace312 -> 1095 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search313_0_0 -> 29 in the cache */
   /* search313_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 943 },
      -1,
   } },
   /* search313_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1098, 1092 },
      -1,
   } },

   /* replace313_0 -> 29 in the cache */
   /* replace313_1 -> 943 in the cache */
   /* replace313 -> 1098 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search314_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffull /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1100 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18ull /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1101, 1102 },
      -1,
   } },

   /* replace314_0 -> 29 in the cache */
   /* replace314_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 1102 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search315_0_0 -> 29 in the cache */
   /* search315_0_1 -> 1102 in the cache */
   /* search315_0 -> 1104 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000ull /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1104, 1105 },
      -1,
   } },

   /* replace315_0 -> 29 in the cache */
   /* replace315_1 -> 1102 in the cache */
   /* replace315 -> 1104 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search316_0_0 -> 29 in the cache */
   /* search316_0_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 1102 },
      -1,
   } },
   /* search316_1 -> 1100 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1107, 1100 },
      -1,
   } },

   /* replace316_0 -> 29 in the cache */
   /* replace316_1 -> 1102 in the cache */
   /* replace316 -> 1107 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search317_0_0 -> 0 in the cache */
   /* search317_0_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 911 },
      -1,
   } },
   /* search317_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1109, 322 },
      -1,
   } },

   /* replace317_0_0 -> 0 in the cache */
   /* replace317_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 148 },
      -1,
   } },
   /* replace317_1_0 -> 1 in the cache */
   /* replace317_1_1 -> 148 in the cache */
   /* replace317_1 -> 914 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1111, 914 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search318_0_0 -> 139 in the cache */
   /* search318_0_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 139, 296 },
      0,
   } },
   /* search318_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1113, 904 },
      -1,
   } },

   /* replace318_0_0 -> 139 in the cache */
   /* replace318_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace318_1_0 -> 140 in the cache */
   /* replace318_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 1115, 1116 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search319_0_0_0 -> 162 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 162, 1118 },
      0,
   } },
   /* search319_0_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 1119, 165 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 1120, 1121 },
      -1,
   } },

   /* replace319_0_0_0 -> 162 in the cache */
   /* replace319_0_0_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 162, 165 },
      -1,
   } },
   /* replace319_0_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 1123, 166 },
      -1,
   } },
   /* replace319_1_0 -> 163 in the cache */
   /* replace319_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 1124, 1125 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search320_0_0_0 -> 139 in the cache */
   /* search320_0_0_1 -> 296 in the cache */
   /* search320_0_0 -> 1113 in the cache */
   /* search320_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1113, 142 },
      0,
   } },
   /* search320_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 1127, 324 },
      -1,
   } },

   /* replace320_0_0_0 -> 139 in the cache */
   /* replace320_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace320_0_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1129, 176 },
      -1,
   } },
   /* replace320_1_0 -> 140 in the cache */
   /* replace320_1_1 -> 176 in the cache */
   /* replace320_1 -> 907 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1130, 907 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1132, 1133 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1134 },
      -1,
   } },

   /* replace321_0 -> 0 in the cache */
   /* replace321_1 -> 1 in the cache */
   /* replace321 -> 6 in the cache */

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search322_0_0 -> 1132 in the cache */
   /* search322_0_1 -> 1133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1132, 1133 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1136 },
      -1,
   } },

   /* replace322_0 -> 0 in the cache */
   /* replace322_1 -> 1 in the cache */
   /* replace322 -> 3 in the cache */

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search323_0_0 -> 0 in the cache */
   /* search323_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1138 },
      -1,
   } },

   /* replace323_0 -> 0 in the cache */
   /* replace323_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search324_0_0 -> 0 in the cache */
   /* search324_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1141 },
      -1,
   } },

   /* replace324_0 -> 0 in the cache */
   /* replace324_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search325_0_0 -> 0 in the cache */
   /* search325_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1144 },
      -1,
   } },

   /* replace325_0 -> 0 in the cache */
   /* replace325_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search326_0_0 -> 0 in the cache */
   /* search326_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1147 },
      -1,
   } },

   /* replace326_0 -> 0 in the cache */
   /* replace326_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search327_0_0 -> 0 in the cache */
   /* search327_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1150 },
      -1,
   } },

   /* replace327_0 -> 0 in the cache */
   /* replace327_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search328_0_0 -> 0 in the cache */
   /* search328_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1153 },
      -1,
   } },

   /* replace328_0 -> 0 in the cache */
   /* replace328_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search329_0_0 -> 0 in the cache */
   /* search329_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1156 },
      -1,
   } },

   /* replace329_0 -> 0 in the cache */
   /* replace329_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search330_0_0 -> 0 in the cache */
   /* search330_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1159 },
      -1,
   } },

   /* replace330_0 -> 0 in the cache */
   /* replace330_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search331_0_0 -> 0 in the cache */
   /* search331_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search331_1_0 -> 0 in the cache */
   /* search331_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1162, 1163 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search332_0_0 -> 0 in the cache */
   /* search332_0_1 -> 1 in the cache */
   /* search332_0 -> 3 in the cache */
   /* search332_1_0 -> 1 in the cache */
   /* search332_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3, 1166 },
      -1,
   } },

   /* replace332 -> 1165 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search333_0_0 -> 0 in the cache */
   /* search333_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search333_1_0 -> 0 in the cache */
   /* search333_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1168, 1169 },
      -1,
   } },

   /* replace333 -> 1165 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search334_0_0 -> 0 in the cache */
   /* search334_0_1 -> 1 in the cache */
   /* search334_0 -> 1152 in the cache */
   /* search334_1_0 -> 1 in the cache */
   /* search334_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1152, 1171 },
      -1,
   } },

   /* replace334 -> 1165 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search335_0_0 -> 0 in the cache */
   /* search335_0_1 -> 1 in the cache */
   /* search335_0 -> 1155 in the cache */
   /* search335_1_0 -> 1 in the cache */
   /* search335_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1155, 1173 },
      -1,
   } },

   /* replace335 -> 1165 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search336_0_0 -> 0 in the cache */
   /* search336_0 -> 230 in the cache */
   /* search336_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 230, 1175 },
      -1,
   } },

   /* replace336_0 -> 1 in the cache */
   /* replace336_1 -> 0 in the cache */
   /* replace336 -> 1166 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search337_0_0 -> 0 in the cache */
   /* search337_0 -> 230 in the cache */
   /* search337_1_0 -> 1 in the cache */
   /* search337_1 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 230, 1175 },
      -1,
   } },

   /* replace337_0 -> 1 in the cache */
   /* replace337_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search338_0_0 -> 0 in the cache */
   /* search338_0 -> 230 in the cache */
   /* search338_1_0 -> 1 in the cache */
   /* search338_1 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 230, 1175 },
      -1,
   } },

   /* replace338_0 -> 1 in the cache */
   /* replace338_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search339_0_0 -> 0 in the cache */
   /* search339_0 -> 230 in the cache */
   /* search339_1_0 -> 1 in the cache */
   /* search339_1 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 230, 1175 },
      -1,
   } },

   /* replace339_0 -> 1 in the cache */
   /* replace339_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a(is_not_const)'), '#b') => ('flt', ('fneg', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1183 },
      -1,
   } },
   /* search340_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1184, 911 },
      -1,
   } },

   /* replace340_0_0 -> 1 in the cache */
   /* replace340_0 -> 1175 in the cache */
   /* replace340_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1175, 0 },
      -1,
   } },

   /* ('flt', '#b', ('fneg', 'a(is_not_const)')) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1188 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1187, 1189 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1191, 1193 },
      -1,
   } },

   /* ('fge', ('fneg', 'a(is_not_const)'), '#b') => ('fge', ('fneg', 'b'), 'a') */
   /* search342_0_0 -> 1183 in the cache */
   /* search342_0 -> 1184 in the cache */
   /* search342_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1184, 911 },
      -1,
   } },

   /* replace342_0_0 -> 1 in the cache */
   /* replace342_0 -> 1175 in the cache */
   /* replace342_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1175, 0 },
      -1,
   } },

   /* ('fge', '#b', ('fneg', 'a(is_not_const)')) => ('fge', 'a', ('fneg', 'b')) */
   /* search343_0 -> 1187 in the cache */
   /* search343_1_0 -> 1188 in the cache */
   /* search343_1 -> 1189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1187, 1189 },
      -1,
   } },

   /* replace343_0 -> 1191 in the cache */
   /* replace343_1_0 -> 1192 in the cache */
   /* replace343_1 -> 1193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1191, 1193 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a(is_not_const)'), '#b') => ('fneu', ('fneg', 'b'), 'a') */
   /* search344_0_0 -> 1183 in the cache */
   /* search344_0 -> 1184 in the cache */
   /* search344_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1184, 911 },
      -1,
   } },

   /* replace344_0_0 -> 1 in the cache */
   /* replace344_0 -> 1175 in the cache */
   /* replace344_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1175, 0 },
      -1,
   } },

   /* ('feq', '#b', ('fneg', 'a(is_not_const)')) => ('feq', 'a', ('fneg', 'b')) */
   /* search345_0 -> 1187 in the cache */
   /* search345_1_0 -> 1188 in the cache */
   /* search345_1 -> 1189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1187, 1189 },
      -1,
   } },

   /* replace345_0 -> 1191 in the cache */
   /* replace345_1_0 -> 1192 in the cache */
   /* replace345_1 -> 1193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1191, 1193 },
      -1,
   } },

   /* ('flt', 'a', '#b(is_negative_zero)') => ('flt', 'a', 0.0) */
   /* search346_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1203 },
      -1,
   } },

   /* replace346_0 -> 0 in the cache */
   /* replace346_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 273 },
      -1,
   } },

   /* ('flt', '#b(is_negative_zero)', 'a') => ('flt', 0.0, 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search347_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1206, 1191 },
      -1,
   } },

   /* replace347_0 -> 273 in the cache */
   /* replace347_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 273, 1191 },
      -1,
   } },

   /* ('fge', 'a', '#b(is_negative_zero)') => ('fge', 'a', 0.0) */
   /* search348_0 -> 0 in the cache */
   /* search348_1 -> 1203 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1203 },
      -1,
   } },

   /* replace348_0 -> 0 in the cache */
   /* replace348_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 273 },
      -1,
   } },

   /* ('fge', '#b(is_negative_zero)', 'a') => ('fge', 0.0, 'a') */
   /* search349_0 -> 1206 in the cache */
   /* search349_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1206, 1191 },
      -1,
   } },

   /* replace349_0 -> 273 in the cache */
   /* replace349_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 273, 1191 },
      -1,
   } },

   /* ('fneu', 'a', '#b(is_negative_zero)') => ('fneu', 0.0, 'a') */
   /* search350_0 -> 0 in the cache */
   /* search350_1 -> 1203 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1203 },
      -1,
   } },

   /* replace350_0 -> 273 in the cache */
   /* replace350_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 273, 0 },
      -1,
   } },

   /* ('feq', '#b(is_negative_zero)', 'a') => ('feq', 'a', 0.0) */
   /* search351_0 -> 1206 in the cache */
   /* search351_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1206, 1191 },
      -1,
   } },

   /* replace351_0 -> 1191 in the cache */
   /* replace351_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1191, 273 },
      -1,
   } },

   /* ('ieq', ('ineg', 'a'), 0) => ('ieq', 'a', 0) */
   /* search352_0_0 -> 9 in the cache */
   /* search352_0 -> 120 in the cache */
   /* search352_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 120, 73 },
      -1,
   } },

   /* replace352_0 -> 9 in the cache */
   /* replace352_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* ('ine', ('ineg', 'a'), 0) => ('ine', 'a', 0) */
   /* search353_0_0 -> 9 in the cache */
   /* search353_0 -> 120 in the cache */
   /* search353_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 120, 73 },
      -1,
   } },

   /* replace353_0 -> 9 in the cache */
   /* replace353_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* ('ieq', ('iabs', 'a'), 0) => ('ieq', 'a', 0) */
   /* search354_0_0 -> 9 in the cache */
   /* search354_0 -> 125 in the cache */
   /* search354_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 125, 73 },
      -1,
   } },

   /* replace354_0 -> 9 in the cache */
   /* replace354_1 -> 73 in the cache */
   /* replace354 -> 1218 in the cache */

   /* ('ine', ('iabs', 'a'), 0) => ('ine', 'a', 0) */
   /* search355_0_0 -> 9 in the cache */
   /* search355_0 -> 125 in the cache */
   /* search355_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 125, 73 },
      -1,
   } },

   /* replace355_0 -> 9 in the cache */
   /* replace355_1 -> 73 in the cache */
   /* replace355 -> 1220 in the cache */

   /* ('fneu', ('fabs', 'a'), 0.0) => ('fneu', 'a', 0.0) */
   /* search356_0_0 -> 9 in the cache */
   /* search356_0 -> 11 in the cache */
   /* search356_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 8 },
      -1,
   } },

   /* replace356_0 -> 9 in the cache */
   /* replace356_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* ('feq', ('fabs', 'a'), 0.0) => ('feq', 'a', 0.0) */
   /* search357_0_0 -> 9 in the cache */
   /* search357_0 -> 11 in the cache */
   /* search357_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 8 },
      -1,
   } },

   /* replace357_0 -> 9 in the cache */
   /* replace357_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 8 },
      -1,
   } },

   /* ('fneu', ('fabs', 'a'), ('fabs', 'a')) => ('fneu', 'a', 'a') */
   /* search358_0_0 -> 9 in the cache */
   /* search358_0 -> 11 in the cache */
   /* search358_1_0 -> 9 in the cache */
   /* search358_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 11, 11 },
      -1,
   } },

   /* replace358_0 -> 9 in the cache */
   /* replace358_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* ('feq', ('fabs', 'a'), ('fabs', 'a')) => ('feq', 'a', 'a') */
   /* search359_0_0 -> 9 in the cache */
   /* search359_0 -> 11 in the cache */
   /* search359_1_0 -> 9 in the cache */
   /* search359_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 11, 11 },
      -1,
   } },

   /* replace359_0 -> 9 in the cache */
   /* replace359_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search360_1_0 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1191 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1231, 1232 },
      -1,
   } },

   /* replace360_0 -> 1192 in the cache */
   /* replace360_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1192, 1191 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search361_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1235, 1236 },
      -1,
   } },

   /* replace361_0 -> 0 in the cache */
   /* replace361_1 -> 1 in the cache */
   /* replace361 -> 6 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search362_0_0 -> 0 in the cache */
   /* search362_0 -> 1235 in the cache */
   /* search362_1 -> 1236 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1235, 1236 },
      -1,
   } },

   /* replace362_0 -> 0 in the cache */
   /* replace362_1 -> 1 in the cache */
   /* replace362 -> 1143 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search363_0_0 -> 0 in the cache */
   /* search363_0 -> 1235 in the cache */
   /* search363_1 -> 1236 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1235, 1236 },
      -1,
   } },

   /* replace363_0 -> 0 in the cache */
   /* replace363_1 -> 1 in the cache */
   /* replace363 -> 1140 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search364_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 9 },
      0,
   } },
   /* search364_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1240, 259 },
      -1,
   } },

   /* replace364_0 -> 9 in the cache */
   /* replace364_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 259 },
      -1,
   } },

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search365_0 -> 8 in the cache */
   /* search365_1_0 -> 9 in the cache */
   /* search365_1 -> 1240 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 8, 1240 },
      -1,
   } },

   /* replace365_0 -> 8 in the cache */
   /* replace365_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 8, 9 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   /* search366_1_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1245, 1246 },
      -1,
   } },

   /* replace366_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search367_0_0_0 -> 847 in the cache */
   /* search367_0_0 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1246 },
      -1,
   } },
   /* search367_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1249, 1245 },
      -1,
   } },

   /* replace367_0 -> 847 in the cache */
   /* replace367 -> 1248 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search368_0_0_0 -> 847 in the cache */
   /* search368_0_0 -> 1246 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1246, 1252 },
      -1,
   } },
   /* search368_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1253, 1245 },
      -1,
   } },

   /* replace368_0 -> 847 in the cache */
   /* replace368_1 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 847, 1251 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search369_0_0 -> 847 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   /* search369_0_2_0 -> 1251 in the cache */
   /* search369_0_2 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1256, 1252 },
      -1,
   } },
   /* search369_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1257, 1245 },
      -1,
   } },

   /* replace369_0 -> 847 in the cache */
   /* replace369_1 -> 1251 in the cache */
   /* replace369 -> 1255 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search370_0_0 -> 847 in the cache */
   /* search370_0 -> 1246 in the cache */
   /* search370_1_0_0 -> 1251 in the cache */
   /* search370_1_0 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1252 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1246, 1259 },
      -1,
   } },

   /* replace370_0 -> 847 in the cache */
   /* replace370_1 -> 1251 in the cache */
   /* replace370 -> 1255 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search371_0_0_0 -> 847 in the cache */
   /* search371_0_0 -> 1246 in the cache */
   /* search371_0_1_0 -> 1251 in the cache */
   /* search371_0_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1246, 1252 },
      -1,
   } },
   /* search371_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1261, 1245 },
      -1,
   } },

   /* replace371_0 -> 847 in the cache */
   /* replace371_1 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 847, 1251 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search372_0_0 -> 847 in the cache */
   /* search372_0_1_0 -> 1251 in the cache */
   /* search372_0_1 -> 1252 in the cache */
   /* search372_0_2 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1252, 1245 },
      -1,
   } },
   /* search372_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1264, 1245 },
      -1,
   } },

   /* replace372_0 -> 847 in the cache */
   /* replace372_1 -> 1251 in the cache */
   /* replace372 -> 1263 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search373_0_0_0 -> 847 in the cache */
   /* search373_0_0 -> 1246 in the cache */
   /* search373_0_1_0_0 -> 1251 in the cache */
   /* search373_0_1_0 -> 1252 in the cache */
   /* search373_0_1 -> 1259 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1246, 1259 },
      -1,
   } },
   /* search373_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1266, 1245 },
      -1,
   } },

   /* replace373_0 -> 847 in the cache */
   /* replace373_1 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 847, 1251 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search374_0_0 -> 847 in the cache */
   /* search374_0 -> 1246 in the cache */
   /* search374_1_0 -> 1251 in the cache */
   /* search374_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1246, 1252 },
      -1,
   } },

   /* replace374_0 -> 847 in the cache */
   /* replace374_1 -> 1251 in the cache */
   /* replace374 -> 1268 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search375_0_0_0 -> 847 in the cache */
   /* search375_0_0 -> 1246 in the cache */
   /* search375_0 -> 1249 in the cache */
   /* search375_1_0_0 -> 1251 in the cache */
   /* search375_1_0 -> 1252 in the cache */
   /* search375_1 -> 1259 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1249, 1259 },
      -1,
   } },

   /* replace375_0 -> 847 in the cache */
   /* replace375_1 -> 1251 in the cache */
   /* replace375 -> 1268 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search376_0_0_0 -> 847 in the cache */
   /* search376_0_0 -> 1246 in the cache */
   /* search376_0_1_0 -> 1251 in the cache */
   /* search376_0_1 -> 1252 in the cache */
   /* search376_0 -> 1253 in the cache */
   /* search376_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1253, 1245 },
      -1,
   } },

   /* replace376_0_0 -> 847 in the cache */
   /* replace376_0_1 -> 1251 in the cache */
   /* replace376_0 -> 1255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1255 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search377_0_0 -> 847 in the cache */
   /* search377_0_1 -> 1256 in the cache */
   /* search377_0_2_0 -> 1251 in the cache */
   /* search377_0_2 -> 1252 in the cache */
   /* search377_0 -> 1257 in the cache */
   /* search377_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1257, 1245 },
      -1,
   } },

   /* replace377_0_0 -> 847 in the cache */
   /* replace377_0_1 -> 1251 in the cache */
   /* replace377_0 -> 1255 in the cache */
   /* replace377 -> 1272 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search378_0_0 -> 847 in the cache */
   /* search378_0 -> 1246 in the cache */
   /* search378_1_0_0 -> 1251 in the cache */
   /* search378_1_0 -> 1252 in the cache */
   /* search378_1 -> 1259 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1246, 1259 },
      -1,
   } },

   /* replace378_0_0 -> 847 in the cache */
   /* replace378_0_1 -> 1251 in the cache */
   /* replace378_0 -> 1255 in the cache */
   /* replace378 -> 1272 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search379_0_0_0 -> 847 in the cache */
   /* search379_0_0 -> 1246 in the cache */
   /* search379_0_1_0 -> 1251 in the cache */
   /* search379_0_1 -> 1252 in the cache */
   /* search379_0 -> 1261 in the cache */
   /* search379_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1261, 1245 },
      -1,
   } },

   /* replace379_0_0 -> 847 in the cache */
   /* replace379_0_1 -> 1251 in the cache */
   /* replace379_0 -> 1263 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1263 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search380_0_0 -> 847 in the cache */
   /* search380_0_1_0 -> 1251 in the cache */
   /* search380_0_1 -> 1252 in the cache */
   /* search380_0_2 -> 1245 in the cache */
   /* search380_0 -> 1264 in the cache */
   /* search380_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1264, 1245 },
      -1,
   } },

   /* replace380_0_0 -> 847 in the cache */
   /* replace380_0_1 -> 1251 in the cache */
   /* replace380_0 -> 1263 in the cache */
   /* replace380 -> 1276 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search381_0_0_0 -> 847 in the cache */
   /* search381_0_0 -> 1246 in the cache */
   /* search381_0_1_0_0 -> 1251 in the cache */
   /* search381_0_1_0 -> 1252 in the cache */
   /* search381_0_1 -> 1259 in the cache */
   /* search381_0 -> 1266 in the cache */
   /* search381_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1266, 1245 },
      -1,
   } },

   /* replace381_0 -> 847 in the cache */
   /* replace381_1 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 847, 1251 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search382_0_0 -> 847 in the cache */
   /* search382_0 -> 1246 in the cache */
   /* search382_1_0 -> 1251 in the cache */
   /* search382_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1246, 1252 },
      -1,
   } },

   /* replace382_0 -> 847 in the cache */
   /* replace382_1 -> 1251 in the cache */
   /* replace382 -> 1279 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search383_0_0_0 -> 847 in the cache */
   /* search383_0_0 -> 1246 in the cache */
   /* search383_0 -> 1249 in the cache */
   /* search383_1_0_0 -> 1251 in the cache */
   /* search383_1_0 -> 1252 in the cache */
   /* search383_1 -> 1259 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1249, 1259 },
      -1,
   } },

   /* replace383_0 -> 847 in the cache */
   /* replace383_1 -> 1251 in the cache */
   /* replace383 -> 1279 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search384_0_0_0_0 -> 847 in the cache */
   /* search384_0_0_0 -> 1246 in the cache */
   /* search384_0_0_1_0 -> 1251 in the cache */
   /* search384_0_0_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1246, 1252 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1282 },
      -1,
   } },
   /* search384_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1283, 1245 },
      -1,
   } },

   /* replace384_0 -> 847 in the cache */
   /* replace384_1 -> 1251 in the cache */
   /* replace384 -> 1255 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search385_0 -> 1245 in the cache */
   /* search385_1_0_0 -> 847 in the cache */
   /* search385_1_0 -> 1246 in the cache */
   /* search385_1_1_0 -> 1251 in the cache */
   /* search385_1_1 -> 1252 in the cache */
   /* search385_1 -> 1282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1245, 1282 },
      -1,
   } },

   /* replace385_0 -> 847 in the cache */
   /* replace385_1 -> 1251 in the cache */
   /* replace385 -> 1255 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search386_0_0_0_0 -> 847 in the cache */
   /* search386_0_0_0 -> 1246 in the cache */
   /* search386_0_0_1_0 -> 1251 in the cache */
   /* search386_0_0_1 -> 1252 in the cache */
   /* search386_0_0 -> 1282 in the cache */
   /* search386_0 -> 1283 in the cache */
   /* search386_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1283, 1245 },
      -1,
   } },

   /* replace386_0_0 -> 847 in the cache */
   /* replace386_0_1 -> 1251 in the cache */
   /* replace386_0 -> 1255 in the cache */
   /* replace386 -> 1272 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search387_0 -> 1245 in the cache */
   /* search387_1_0_0 -> 847 in the cache */
   /* search387_1_0 -> 1246 in the cache */
   /* search387_1_1_0 -> 1251 in the cache */
   /* search387_1_1 -> 1252 in the cache */
   /* search387_1 -> 1282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1245, 1282 },
      -1,
   } },

   /* replace387_0_0 -> 847 in the cache */
   /* replace387_0_1 -> 1251 in the cache */
   /* replace387_0 -> 1255 in the cache */
   /* replace387 -> 1272 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search388_0 -> 9 in the cache */
   /* search388_1_0 -> 9 in the cache */
   /* search388_1 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 118 },
      -1,
   } },

   /* replace388_0 -> 9 in the cache */
   /* replace388_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 8 },
      -1,
   } },

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search389_0 -> 9 in the cache */
   /* search389_1_0 -> 9 in the cache */
   /* search389_1 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 118 },
      -1,
   } },

   /* replace389_0 -> 9 in the cache */
   /* replace389_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 8 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1293 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1294, 1296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1297 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1292, 1298 },
      -1,
   } },
   /* search390_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1299, 8 },
      -1,
   } },

   /* replace390_0_0 -> 1292 in the cache */
   /* replace390_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1292, 8 },
      -1,
   } },
   /* replace390_1_0 -> 1293 in the cache */
   /* replace390_1_1 -> 1295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1293, 1295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1301, 1302 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search391_0_0 -> 0 in the cache */
   /* search391_0_1 -> 1 in the cache */
   /* search391_0 -> 285 in the cache */
   /* search391_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 285, 0 },
      -1,
   } },

   /* replace391_0 -> 1 in the cache */
   /* replace391_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 273 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search392_0_0 -> 0 in the cache */
   /* search392_0_1 -> 1 in the cache */
   /* search392_0 -> 285 in the cache */
   /* search392_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 285, 0 },
      -1,
   } },

   /* replace392_0 -> 1 in the cache */
   /* replace392_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 273 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search393_0_0 -> 0 in the cache */
   /* search393_0_1 -> 1 in the cache */
   /* search393_0 -> 231 in the cache */
   /* search393_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 231, 0 },
      -1,
   } },

   /* replace393_0 -> 1 in the cache */
   /* replace393_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 273 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search394_0_0 -> 0 in the cache */
   /* search394_0_1 -> 1 in the cache */
   /* search394_0 -> 231 in the cache */
   /* search394_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 231, 0 },
      -1,
   } },

   /* replace394_0 -> 1 in the cache */
   /* replace394_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 273 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search395_0_0 -> 139 in the cache */
   /* search395_0_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 139, 296 },
      0,
   } },
   /* search395_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1312, 904 },
      -1,
   } },

   /* replace395_0 -> 139 in the cache */
   /* replace395_1_0 -> 142 in the cache */
   /* replace395_1_1_0 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 142, 1314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 139, 1315 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search396_0_0_0 -> 139 in the cache */
   /* search396_0_0_1 -> 296 in the cache */
   /* search396_0_0 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1312 },
      0,
   } },
   /* search396_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1317, 904 },
      -1,
   } },

   /* replace396_0_0_0 -> 142 in the cache */
   /* replace396_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 142, 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1319 },
      -1,
   } },
   /* replace396_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1320, 139 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search397_0_0 -> 139 in the cache */
   /* search397_0_1 -> 296 in the cache */
   /* search397_0 -> 1312 in the cache */
   /* search397_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1312, 904 },
      -1,
   } },

   /* replace397_0 -> 139 in the cache */
   /* replace397_1_0 -> 142 in the cache */
   /* replace397_1_1_0 -> 140 in the cache */
   /* replace397_1_1 -> 1314 in the cache */
   /* replace397_1 -> 1315 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 139, 1315 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search398_0_0_0 -> 139 in the cache */
   /* search398_0_0_1 -> 296 in the cache */
   /* search398_0_0 -> 1312 in the cache */
   /* search398_0 -> 1317 in the cache */
   /* search398_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1317, 904 },
      -1,
   } },

   /* replace398_0_0_0 -> 142 in the cache */
   /* replace398_0_0_1 -> 140 in the cache */
   /* replace398_0_0 -> 1319 in the cache */
   /* replace398_0 -> 1320 in the cache */
   /* replace398_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1320, 139 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search399_0_0 -> 139 in the cache */
   /* search399_0_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 296 },
      0,
   } },
   /* search399_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1326, 904 },
      -1,
   } },

   /* replace399_0 -> 139 in the cache */
   /* replace399_1_0 -> 142 in the cache */
   /* replace399_1_1_0 -> 140 in the cache */
   /* replace399_1_1 -> 1314 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 142, 1314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 139, 1328 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search400_0_0_0 -> 139 in the cache */
   /* search400_0_0_1 -> 296 in the cache */
   /* search400_0_0 -> 1326 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1326 },
      0,
   } },
   /* search400_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1330, 904 },
      -1,
   } },

   /* replace400_0_0_0 -> 142 in the cache */
   /* replace400_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 142, 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1332 },
      -1,
   } },
   /* replace400_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1333, 139 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search401_0_0 -> 139 in the cache */
   /* search401_0_1 -> 296 in the cache */
   /* search401_0 -> 1326 in the cache */
   /* search401_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1326, 904 },
      -1,
   } },

   /* replace401_0 -> 139 in the cache */
   /* replace401_1_0 -> 142 in the cache */
   /* replace401_1_1_0 -> 140 in the cache */
   /* replace401_1_1 -> 1314 in the cache */
   /* replace401_1 -> 1328 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 139, 1328 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search402_0_0_0 -> 139 in the cache */
   /* search402_0_0_1 -> 296 in the cache */
   /* search402_0_0 -> 1326 in the cache */
   /* search402_0 -> 1330 in the cache */
   /* search402_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1330, 904 },
      -1,
   } },

   /* replace402_0_0_0 -> 142 in the cache */
   /* replace402_0_0_1 -> 140 in the cache */
   /* replace402_0_0 -> 1332 in the cache */
   /* replace402_0 -> 1333 in the cache */
   /* replace402_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1333, 139 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search403_0_0 -> 0 in the cache */
   /* search403_0_1 -> 1 in the cache */
   /* search403_0 -> 226 in the cache */
   /* search403_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 226, 0 },
      -1,
   } },

   /* replace403_0 -> 1 in the cache */
   /* replace403_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1, 98 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search404_0_0 -> 0 in the cache */
   /* search404_0_1 -> 1 in the cache */
   /* search404_0 -> 226 in the cache */
   /* search404_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 226, 0 },
      -1,
   } },

   /* replace404_0 -> 1 in the cache */
   /* replace404_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1, 98 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search405_0_0 -> 847 in the cache */
   /* search405_0 -> 1246 in the cache */
   /* search405_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1246, 1245 },
      -1,
   } },

   /* replace405_0 -> 847 in the cache */
   /* replace405 -> 1248 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search406_0_0 -> 847 in the cache */
   /* search406_0 -> 1246 in the cache */
   /* search406_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1246, 1245 },
      -1,
   } },

   /* replace406 -> 847 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search407_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 847 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1345, 1346 },
      -1,
   } },

   /* replace407_0 -> 847 in the cache */
   /* replace407 -> 1248 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search408_0_0 -> 847 in the cache */
   /* search408_0 -> 1345 in the cache */
   /* search408_1 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1345, 1346 },
      -1,
   } },

   /* replace408 -> 847 in the cache */

   /* ('ieq', 'a@1', False) => ('inot', 'a') */
   /* search409_0 -> 847 in the cache */
   /* search409_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 847, 1165 },
      -1,
   } },

   /* replace409_0 -> 847 in the cache */
   /* replace409 -> 1248 in the cache */

   /* ('ieq', 'a@1', True) => a */
   /* search410_0 -> 847 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 847, 1350 },
      -1,
   } },

   /* replace410 -> 847 in the cache */

   /* ('ine', 'a@1', False) => a */
   /* search411_0 -> 847 in the cache */
   /* search411_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 847, 1165 },
      -1,
   } },

   /* replace411 -> 847 in the cache */

   /* ('ine', 'a@1', True) => ('inot', 'a') */
   /* search412_0 -> 847 in the cache */
   /* search412_1 -> 1350 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 847, 1350 },
      -1,
   } },

   /* replace412_0 -> 847 in the cache */
   /* replace412 -> 1248 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search413_0_0 -> 9 in the cache */
   /* search413_0 -> 123 in the cache */
   /* search413_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 123, 1245 },
      -1,
   } },

   /* replace413_0 -> 9 in the cache */
   /* replace413_1 -> 73 in the cache */
   /* replace413 -> 1220 in the cache */

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search414_0_0 -> 9 in the cache */
   /* search414_0 -> 123 in the cache */
   /* search414_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 123, 1245 },
      -1,
   } },

   /* replace414_0 -> 9 in the cache */
   /* replace414_1 -> 73 in the cache */
   /* replace414 -> 1218 in the cache */

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search415_0_0 -> 9 in the cache */
   /* search415_0 -> 123 in the cache */
   /* search415_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 123, 1245 },
      -1,
   } },

   /* replace415 -> 1350 in the cache */

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search416_0 -> 1245 in the cache */
   /* search416_1_0 -> 9 in the cache */
   /* search416_1 -> 123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1245, 123 },
      -1,
   } },

   /* replace416_0 -> 73 in the cache */
   /* replace416_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 73, 9 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search417_0_0 -> 9 in the cache */
   /* search417_0 -> 123 in the cache */
   /* search417_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 123, 1245 },
      -1,
   } },

   /* replace417 -> 1165 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search418_0 -> 1245 in the cache */
   /* search418_1_0 -> 9 in the cache */
   /* search418_1 -> 123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1245, 123 },
      -1,
   } },

   /* replace418_0 -> 73 in the cache */
   /* replace418_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 73, 9 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search419_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search419_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1362, 1245 },
      -1,
   } },

   /* replace419_0 -> 9 in the cache */
   /* replace419_1 -> 73 in the cache */
   /* replace419 -> 1220 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search420_0_0 -> 9 in the cache */
   /* search420_0 -> 1362 in the cache */
   /* search420_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1362, 1245 },
      -1,
   } },

   /* replace420_0 -> 9 in the cache */
   /* replace420_1 -> 73 in the cache */
   /* replace420 -> 1218 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search421_0_0 -> 9 in the cache */
   /* search421_0 -> 1362 in the cache */
   /* search421_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1362, 1245 },
      -1,
   } },

   /* replace421_0 -> 9 in the cache */
   /* replace421_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search422_0 -> 1245 in the cache */
   /* search422_1_0 -> 9 in the cache */
   /* search422_1 -> 1362 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1245, 1362 },
      -1,
   } },

   /* replace422_0 -> 73 in the cache */
   /* replace422_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 73, 9 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search423_0_0 -> 9 in the cache */
   /* search423_0 -> 1362 in the cache */
   /* search423_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1362, 1245 },
      -1,
   } },

   /* replace423_0 -> 9 in the cache */
   /* replace423_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search424_0 -> 1245 in the cache */
   /* search424_1_0 -> 9 in the cache */
   /* search424_1 -> 1362 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1245, 1362 },
      -1,
   } },

   /* replace424_0 -> 73 in the cache */
   /* replace424_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 73, 9 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search425_0 -> 8 in the cache */
   /* search425_1_0 -> 9 in the cache */
   /* search425_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 8, 11 },
      -1,
   } },

   /* replace425_0 -> 9 in the cache */
   /* replace425_1 -> 8 in the cache */
   /* replace425 -> 1224 in the cache */

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search426_0_0_0 -> 9 in the cache */
   /* search426_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   /* search426_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1374, 8 },
      -1,
   } },

   /* replace426_0 -> 9 in the cache */
   /* replace426_1 -> 8 in the cache */
   /* replace426 -> 1224 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search427_0 -> 8 in the cache */
   /* search427_1_0 -> 9 in the cache */
   /* search427_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 8, 11 },
      -1,
   } },

   /* replace427_0 -> 9 in the cache */
   /* replace427_1 -> 8 in the cache */
   /* replace427 -> 1226 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search428_0_0_0 -> 9 in the cache */
   /* search428_0_0 -> 11 in the cache */
   /* search428_0 -> 1374 in the cache */
   /* search428_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1374, 8 },
      -1,
   } },

   /* replace428_0 -> 9 in the cache */
   /* replace428_1 -> 8 in the cache */
   /* replace428 -> 1226 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search429_0_0 -> 9 in the cache */
   /* search429_0_1 -> 8 in the cache */
   /* search429_0 -> 1291 in the cache */
   /* search429_1_0 -> 259 in the cache */
   /* search429_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 259, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1291, 1378 },
      -1,
   } },

   /* replace429_0 -> 9 in the cache */
   /* replace429_1_0 -> 9 in the cache */
   /* replace429_1 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 235 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search430_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 847 },
      0,
   } },
   /* search430_1_0 -> 1251 in the cache */
   /* search430_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1381, 1252 },
      -1,
   } },

   /* replace430_0_0 -> 847 in the cache */
   /* replace430_0_1 -> 1251 in the cache */
   /* replace430_0 -> 1255 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1255 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search431_0_0_0 -> 847 in the cache */
   /* search431_0_0 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1381 },
      0,
   } },
   /* search431_1_0_0 -> 1251 in the cache */
   /* search431_1_0 -> 1252 in the cache */
   /* search431_1 -> 1259 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1384, 1259 },
      -1,
   } },

   /* replace431_0_0_0 -> 847 in the cache */
   /* replace431_0_0_1 -> 1251 in the cache */
   /* replace431_0_0 -> 1263 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1263 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1386 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search432_0_0 -> 847 in the cache */
   /* search432_0 -> 1381 in the cache */
   /* search432_1_0 -> 1251 in the cache */
   /* search432_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1381, 1252 },
      -1,
   } },

   /* replace432_0_0 -> 847 in the cache */
   /* replace432_0_1 -> 1251 in the cache */
   /* replace432_0 -> 1263 in the cache */
   /* replace432 -> 1386 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search433_0_0_0 -> 847 in the cache */
   /* search433_0_0 -> 1381 in the cache */
   /* search433_0 -> 1384 in the cache */
   /* search433_1_0_0 -> 1251 in the cache */
   /* search433_1_0 -> 1252 in the cache */
   /* search433_1 -> 1259 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1384, 1259 },
      -1,
   } },

   /* replace433_0_0_0 -> 847 in the cache */
   /* replace433_0_0_1 -> 1251 in the cache */
   /* replace433_0_0 -> 1255 in the cache */
   /* replace433_0 -> 1383 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1383 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search434_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search434_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1391, 911 },
      -1,
   } },

   /* replace434_0 -> 847 in the cache */
   /* replace434_1_0 -> 1 in the cache */
   /* replace434_1_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 283 },
      -1,
   } },
   /* replace434_2_0 -> 1 in the cache */
   /* replace434_2_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1, 273 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 1393, 1394 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search435_0_0 -> 0 in the cache */
   /* search435_0_1_0 -> 1 in the cache */
   /* search435_0_1 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1175 },
      0,
   } },
   /* search435_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1396, 273 },
      -1,
   } },

   /* replace435_0 -> 0 in the cache */
   /* replace435_1 -> 1 in the cache */
   /* replace435 -> 3 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search436_0_0_0 -> 9 in the cache */
   /* search436_0_0 -> 11 in the cache */
   /* search436_0 -> 1374 in the cache */
   /* search436_1 -> 8 in the cache */
   /* search436 -> 1377 in the cache */

   /* replace436_0 -> 9 in the cache */
   /* replace436_1 -> 8 in the cache */
   /* replace436 -> 1226 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search437_0_0 -> 1192 in the cache */
   /* search437_0_1 -> 1191 in the cache */
   /* search437_0 -> 1234 in the cache */
   /* search437_1 -> 1192 in the cache */
   /* search437_2 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1234, 1192, 1191 },
      -1,
   } },

   /* replace437_0 -> 1191 in the cache */
   /* replace437_1 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1191, 1192 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search438_0_0 -> 0 in the cache */
   /* search438_0_1 -> 1 in the cache */
   /* search438_0 -> 3 in the cache */
   /* search438_1 -> 1 in the cache */
   /* search438_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3, 1, 0 },
      -1,
   } },

   /* replace438_0 -> 0 in the cache */
   /* replace438_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search439_0_0 -> 0 in the cache */
   /* search439_0_1 -> 1 in the cache */
   /* search439_0 -> 6 in the cache */
   /* search439_1 -> 1 in the cache */
   /* search439_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 6, 1, 0 },
      -1,
   } },

   /* replace439_0 -> 0 in the cache */
   /* replace439_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search440_0_0 -> 1192 in the cache */
   /* search440_0_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1192, 1191 },
      -1,
   } },
   /* search440_1 -> 1192 in the cache */
   /* search440_2 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1404, 1192, 1191 },
      -1,
   } },

   /* replace440_0 -> 1191 in the cache */
   /* replace440_1 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1191, 1192 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search441_0_0 -> 847 in the cache */
   /* search441_0 -> 1248 in the cache */
   /* search441_1 -> 140 in the cache */
   /* search441_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1248, 140, 142 },
      -1,
   } },

   /* replace441_0 -> 847 in the cache */
   /* replace441_1 -> 142 in the cache */
   /* replace441_2 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 142, 140 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search442_0 -> 847 in the cache */
   /* search442_1_0 -> 847 in the cache */
   /* search442_1_1 -> 163 in the cache */
   /* search442_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 163, 165 },
      -1,
   } },
   /* search442_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1409, 166 },
      -1,
   } },

   /* replace442_0 -> 847 in the cache */
   /* replace442_1 -> 163 in the cache */
   /* replace442_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 163, 166 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search443_0 -> 847 in the cache */
   /* search443_1 -> 163 in the cache */
   /* search443_2_0 -> 847 in the cache */
   /* search443_2_1 -> 165 in the cache */
   /* search443_2_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 163, 1412 },
      -1,
   } },

   /* replace443_0 -> 847 in the cache */
   /* replace443_1 -> 163 in the cache */
   /* replace443_2 -> 166 in the cache */
   /* replace443 -> 1411 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search444_0 -> 847 in the cache */
   /* search444_1_0 -> 1251 in the cache */
   /* search444_1_1 -> 840 in the cache */
   /* search444_1_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 840, 849 },
      -1,
   } },
   /* search444_2_0 -> 1251 in the cache */
   /* search444_2_1 -> 840 in the cache */
   /* search444_2_2 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 840, 851 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1414, 1415 },
      -1,
   } },

   /* replace444_0 -> 1251 in the cache */
   /* replace444_1 -> 840 in the cache */
   /* replace444_2_0 -> 847 in the cache */
   /* replace444_2_1 -> 849 in the cache */
   /* replace444_2_2 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 849, 851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 840, 1417 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search445_0 -> 847 in the cache */
   /* search445_1_0 -> 1251 in the cache */
   /* search445_1_1 -> 840 in the cache */
   /* search445_1_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 840, 849 },
      0,
   } },
   /* search445_2_0 -> 1251 in the cache */
   /* search445_2_1 -> 840 in the cache */
   /* search445_2_2 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 840, 851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1419, 1420 },
      -1,
   } },

   /* replace445_0 -> 1251 in the cache */
   /* replace445_1 -> 840 in the cache */
   /* replace445_2_0 -> 847 in the cache */
   /* replace445_2_1 -> 849 in the cache */
   /* replace445_2_2 -> 851 in the cache */
   /* replace445_2 -> 1417 in the cache */
   /* replace445 -> 1418 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search446_0 -> 847 in the cache */
   /* search446_1_0 -> 1251 in the cache */
   /* search446_1_1 -> 165 in the cache */
   /* search446_1_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 165, 166 },
      -1,
   } },
   /* search446_2_0 -> 1251 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search446_2_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 1423, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1422, 1424 },
      -1,
   } },

   /* replace446_0 -> 1251 in the cache */
   /* replace446_1_0 -> 847 in the cache */
   /* replace446_1_1 -> 165 in the cache */
   /* replace446_1_2 -> 1423 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 165, 1423 },
      -1,
   } },
   /* replace446_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 1426, 166 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search447_0 -> 847 in the cache */
   /* search447_1_0 -> 1251 in the cache */
   /* search447_1_1 -> 165 in the cache */
   /* search447_1_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 165, 166 },
      0,
   } },
   /* search447_2_0 -> 1251 in the cache */
   /* search447_2_1 -> 1423 in the cache */
   /* search447_2_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1251, 1423, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1428, 1429 },
      -1,
   } },

   /* replace447_0 -> 1251 in the cache */
   /* replace447_1_0 -> 847 in the cache */
   /* replace447_1_1 -> 165 in the cache */
   /* replace447_1_2 -> 1423 in the cache */
   /* replace447_1 -> 1426 in the cache */
   /* replace447_2 -> 166 in the cache */
   /* replace447 -> 1427 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search448_0 -> 847 in the cache */
   /* search448_1 -> 1350 in the cache */
   /* search448_2 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1350, 1251 },
      -1,
   } },

   /* replace448_0 -> 847 in the cache */
   /* replace448_1 -> 1251 in the cache */
   /* replace448 -> 1255 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search449_0 -> 847 in the cache */
   /* search449_1 -> 847 in the cache */
   /* search449_2 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 847, 1251 },
      -1,
   } },

   /* replace449_0 -> 847 in the cache */
   /* replace449_1 -> 1251 in the cache */
   /* replace449 -> 1255 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search450_0 -> 847 in the cache */
   /* search450_1 -> 1251 in the cache */
   /* search450_2 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1251, 1165 },
      -1,
   } },

   /* replace450_0 -> 847 in the cache */
   /* replace450_1 -> 1251 in the cache */
   /* replace450 -> 1263 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search451_0 -> 847 in the cache */
   /* search451_1 -> 1251 in the cache */
   /* search451_2 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1251, 847 },
      -1,
   } },

   /* replace451_0 -> 847 in the cache */
   /* replace451_1 -> 1251 in the cache */
   /* replace451 -> 1263 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search452_0 -> 9 in the cache */
   /* search452_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace452 -> 9 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search453_0 -> 9 in the cache */
   /* search453_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace453 -> 9 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search454_0 -> 9 in the cache */
   /* search454_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace454 -> 9 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search455_0 -> 9 in the cache */
   /* search455_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace455 -> 9 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search456_0 -> 9 in the cache */
   /* search456_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace456 -> 9 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search457_0 -> 9 in the cache */
   /* search457_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace457 -> 73 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search458_0 -> 9 in the cache */
   /* search458_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 9, 75 },
      -1,
   } },

   /* replace458 -> 9 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search459_0 -> 9 in the cache */
   /* search459_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace459 -> 9 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search460_0 -> 9 in the cache */
   /* search460_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace460 -> 9 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search461_0 -> 9 in the cache */
   /* search461_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 9, 75 },
      -1,
   } },

   /* replace461 -> 75 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search462_0_0 -> 0 in the cache */
   /* search462_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search462_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1445, 1 },
      -1,
   } },

   /* replace462_0 -> 0 in the cache */
   /* replace462_1 -> 1 in the cache */
   /* replace462 -> 1401 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search463_0_0 -> 0 in the cache */
   /* search463_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search463_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1447, 1 },
      -1,
   } },

   /* replace463_0 -> 0 in the cache */
   /* replace463_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search464_0_0 -> 0 in the cache */
   /* search464_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search464_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1450, 1 },
      -1,
   } },

   /* replace464_0 -> 0 in the cache */
   /* replace464_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search465_0_0 -> 0 in the cache */
   /* search465_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search465_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1453, 1 },
      -1,
   } },

   /* replace465_0 -> 0 in the cache */
   /* replace465_1 -> 1 in the cache */
   /* replace465 -> 1403 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search466_0_0 -> 0 in the cache */
   /* search466_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search466_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1455, 1 },
      -1,
   } },

   /* replace466_0 -> 0 in the cache */
   /* replace466_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search467_0_0 -> 0 in the cache */
   /* search467_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search467_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1458, 1 },
      -1,
   } },

   /* replace467_0 -> 0 in the cache */
   /* replace467_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search468_0_0_0 -> 139 in the cache */
   /* search468_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 139, 140 },
      -1,
   } },
   /* search468_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1461, 142 },
      -1,
   } },
   /* search468_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1462, 139 },
      -1,
   } },

   /* replace468_0_0 -> 139 in the cache */
   /* replace468_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* replace468_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1464, 142 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search469_0_0_0 -> 139 in the cache */
   /* search469_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 139, 140 },
      -1,
   } },
   /* search469_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1466, 142 },
      -1,
   } },
   /* search469_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1467, 139 },
      -1,
   } },

   /* replace469_0_0 -> 139 in the cache */
   /* replace469_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* replace469_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1469, 142 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search470_0_0_0 -> 139 in the cache */
   /* search470_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 139, 140 },
      -1,
   } },
   /* search470_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1471, 142 },
      -1,
   } },
   /* search470_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1472, 139 },
      -1,
   } },

   /* replace470_0_0 -> 139 in the cache */
   /* replace470_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* replace470_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1474, 142 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search471_0_0_0 -> 139 in the cache */
   /* search471_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 139, 140 },
      -1,
   } },
   /* search471_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1476, 142 },
      -1,
   } },
   /* search471_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1477, 139 },
      -1,
   } },

   /* replace471_0_0 -> 139 in the cache */
   /* replace471_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* replace471_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1479, 142 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search472_0_0_0 -> 139 in the cache */
   /* search472_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 139, 140 },
      -1,
   } },
   /* search472_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1481, 142 },
      -1,
   } },
   /* search472_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1482, 139 },
      -1,
   } },

   /* replace472_0_0 -> 139 in the cache */
   /* replace472_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* replace472_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1484, 142 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search473_0_0_0 -> 139 in the cache */
   /* search473_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 139, 140 },
      -1,
   } },
   /* search473_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1486, 142 },
      -1,
   } },
   /* search473_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1487, 139 },
      -1,
   } },

   /* replace473_0_0 -> 139 in the cache */
   /* replace473_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 139, 140 },
      -1,
   } },
   /* replace473_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1489, 142 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search474_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search474_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1491, 1492 },
      -1,
   } },

   /* replace474_0 -> 847 in the cache */
   /* replace474_1 -> 1251 in the cache */
   /* replace474 -> 1279 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search475_0_0 -> 847 in the cache */
   /* search475_0 -> 1491 in the cache */
   /* search475_1_0 -> 1251 in the cache */
   /* search475_1 -> 1492 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1491, 1492 },
      -1,
   } },

   /* replace475_0 -> 847 in the cache */
   /* replace475_1 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 847, 1251 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search476_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search476_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1496, 1497 },
      -1,
   } },

   /* replace476_0 -> 847 in the cache */
   /* replace476_1 -> 1251 in the cache */
   /* replace476 -> 1279 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search477_0_0 -> 847 in the cache */
   /* search477_0 -> 1496 in the cache */
   /* search477_1_0 -> 1251 in the cache */
   /* search477_1 -> 1497 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1496, 1497 },
      -1,
   } },

   /* replace477_0 -> 847 in the cache */
   /* replace477_1 -> 1251 in the cache */
   /* replace477 -> 1495 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search478_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search478_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1500, 1501 },
      -1,
   } },

   /* replace478_0 -> 847 in the cache */
   /* replace478_1 -> 1251 in the cache */
   /* replace478 -> 1279 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search479_0_0 -> 847 in the cache */
   /* search479_0 -> 1500 in the cache */
   /* search479_1_0 -> 1251 in the cache */
   /* search479_1 -> 1501 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1500, 1501 },
      -1,
   } },

   /* replace479_0 -> 847 in the cache */
   /* replace479_1 -> 1251 in the cache */
   /* replace479 -> 1495 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search480_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search480_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1504, 1505 },
      -1,
   } },

   /* replace480_0 -> 847 in the cache */
   /* replace480_1 -> 1251 in the cache */
   /* replace480 -> 1279 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search481_0_0 -> 847 in the cache */
   /* search481_0 -> 1504 in the cache */
   /* search481_1_0 -> 1251 in the cache */
   /* search481_1 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1504, 1505 },
      -1,
   } },

   /* replace481_0 -> 847 in the cache */
   /* replace481_1 -> 1251 in the cache */
   /* replace481 -> 1495 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search482_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search482_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1508, 1509 },
      -1,
   } },

   /* replace482_0 -> 847 in the cache */
   /* replace482_1 -> 1251 in the cache */
   /* replace482 -> 1279 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search483_0_0 -> 847 in the cache */
   /* search483_0 -> 1508 in the cache */
   /* search483_1_0 -> 1251 in the cache */
   /* search483_1 -> 1509 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1508, 1509 },
      -1,
   } },

   /* replace483_0 -> 847 in the cache */
   /* replace483_1 -> 1251 in the cache */
   /* replace483 -> 1495 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search484_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search484_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1512, 1513 },
      -1,
   } },

   /* replace484_0 -> 847 in the cache */
   /* replace484_1 -> 1251 in the cache */
   /* replace484 -> 1279 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search485_0_0 -> 847 in the cache */
   /* search485_0 -> 1512 in the cache */
   /* search485_1_0 -> 1251 in the cache */
   /* search485_1 -> 1513 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1512, 1513 },
      -1,
   } },

   /* replace485_0 -> 847 in the cache */
   /* replace485_1 -> 1251 in the cache */
   /* replace485 -> 1495 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search486_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 847 },
      -1,
   } },
   /* search486_1_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1516, 1517 },
      -1,
   } },

   /* replace486_0 -> 847 in the cache */
   /* replace486_1 -> 1251 in the cache */
   /* replace486 -> 1279 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search487_0_0 -> 847 in the cache */
   /* search487_0 -> 1516 in the cache */
   /* search487_1_0 -> 1251 in the cache */
   /* search487_1 -> 1517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1516, 1517 },
      -1,
   } },

   /* replace487_0 -> 847 in the cache */
   /* replace487_1 -> 1251 in the cache */
   /* replace487 -> 1495 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search488_0 -> 19 in the cache */
   /* search488_1_0_0 -> 19 in the cache */
   /* search488_1_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 19, 22 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1520 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 1521 },
      -1,
   } },

   /* replace488_0 -> 19 in the cache */
   /* replace488_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 19, 925 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search489_0_0 -> 19 in the cache */
   /* search489_0_1 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 19, 20 },
      -1,
   } },
   /* search489_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1524, 925 },
      -1,
   } },

   /* replace489_0 -> 19 in the cache */
   /* replace489_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 19, 925 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search490_0_0 -> 19 in the cache */
   /* search490_0_1 -> 20 in the cache */
   /* search490_0 -> 1524 in the cache */
   /* search490_1 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1524, 20 },
      -1,
   } },

   /* replace490_0 -> 19 in the cache */
   /* replace490_1 -> 925 in the cache */
   /* replace490 -> 1526 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search491_0_0 -> 19 in the cache */
   /* search491_0_1 -> 20 in the cache */
   /* search491_0 -> 1524 in the cache */
   /* search491_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1524, 925 },
      -1,
   } },

   /* replace491_0 -> 19 in the cache */
   /* replace491_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 925 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search492_0_0 -> 19 in the cache */
   /* search492_0_1 -> 20 in the cache */
   /* search492_0 -> 1524 in the cache */
   /* search492_1 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1524, 20 },
      -1,
   } },

   /* replace492_0 -> 19 in the cache */
   /* replace492_1 -> 925 in the cache */
   /* replace492 -> 1529 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search493_0_0 -> 19 in the cache */
   /* search493_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 19, 22 },
      -1,
   } },
   /* search493_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1531, 925 },
      -1,
   } },

   /* replace493_0 -> 19 in the cache */
   /* replace493_1 -> 925 in the cache */
   /* replace493 -> 1529 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search494_0_0 -> 19 in the cache */
   /* search494_0_1 -> 22 in the cache */
   /* search494_0 -> 1531 in the cache */
   /* search494_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1531, 925 },
      -1,
   } },

   /* replace494_0 -> 19 in the cache */
   /* replace494_1 -> 925 in the cache */
   /* replace494 -> 1526 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search495_0_0 -> 19 in the cache */
   /* search495_0_1 -> 22 in the cache */
   /* search495_0 -> 1531 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1531, 1534 },
      -1,
   } },

   /* replace495_0 -> 19 in the cache */
   /* replace495_1 -> 925 in the cache */
   /* replace495 -> 1529 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search496_0_0 -> 19 in the cache */
   /* search496_0_1 -> 22 in the cache */
   /* search496_0 -> 1531 in the cache */
   /* search496_1 -> 1534 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1531, 1534 },
      -1,
   } },

   /* replace496_0 -> 19 in the cache */
   /* replace496_1 -> 925 in the cache */
   /* replace496 -> 1526 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search497_0_0 -> 19 in the cache */
   /* search497_0_1 -> 22 in the cache */
   /* search497_0 -> 1520 in the cache */
   /* search497_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1520, 925 },
      -1,
   } },

   /* replace497_0 -> 19 in the cache */
   /* replace497_1 -> 925 in the cache */
   /* replace497 -> 1529 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search498_0_0 -> 19 in the cache */
   /* search498_0_1 -> 22 in the cache */
   /* search498_0 -> 1520 in the cache */
   /* search498_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1520, 925 },
      -1,
   } },

   /* replace498_0 -> 19 in the cache */
   /* replace498_1 -> 925 in the cache */
   /* replace498 -> 1526 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search499_0_0 -> 19 in the cache */
   /* search499_0_1 -> 22 in the cache */
   /* search499_0 -> 1520 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1520, 1539 },
      -1,
   } },

   /* replace499_0 -> 19 in the cache */
   /* replace499_1 -> 925 in the cache */
   /* replace499 -> 1529 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search500_0_0 -> 19 in the cache */
   /* search500_0_1 -> 22 in the cache */
   /* search500_0 -> 1520 in the cache */
   /* search500_1 -> 1539 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1520, 1539 },
      -1,
   } },

   /* replace500_0 -> 19 in the cache */
   /* replace500_1 -> 925 in the cache */
   /* replace500 -> 1526 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search501_0 -> 24 in the cache */
   /* search501_1_0_0 -> 24 in the cache */
   /* search501_1_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 24, 27 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1542 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 1543 },
      -1,
   } },

   /* replace501_0 -> 24 in the cache */
   /* replace501_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 24, 946 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search502_0_0 -> 24 in the cache */
   /* search502_0_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 24, 25 },
      -1,
   } },
   /* search502_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1546, 946 },
      -1,
   } },

   /* replace502_0 -> 24 in the cache */
   /* replace502_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 946 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search503_0_0 -> 24 in the cache */
   /* search503_0_1 -> 25 in the cache */
   /* search503_0 -> 1546 in the cache */
   /* search503_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1546, 25 },
      -1,
   } },

   /* replace503_0 -> 24 in the cache */
   /* replace503_1 -> 946 in the cache */
   /* replace503 -> 1548 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search504_0_0 -> 24 in the cache */
   /* search504_0_1 -> 25 in the cache */
   /* search504_0 -> 1546 in the cache */
   /* search504_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1546, 946 },
      -1,
   } },

   /* replace504_0 -> 24 in the cache */
   /* replace504_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 946 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search505_0_0 -> 24 in the cache */
   /* search505_0_1 -> 25 in the cache */
   /* search505_0 -> 1546 in the cache */
   /* search505_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1546, 25 },
      -1,
   } },

   /* replace505_0 -> 24 in the cache */
   /* replace505_1 -> 946 in the cache */
   /* replace505 -> 1551 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search506_0_0 -> 24 in the cache */
   /* search506_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 24, 27 },
      -1,
   } },
   /* search506_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1553, 946 },
      -1,
   } },

   /* replace506_0 -> 24 in the cache */
   /* replace506_1 -> 946 in the cache */
   /* replace506 -> 1551 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search507_0_0 -> 24 in the cache */
   /* search507_0_1 -> 27 in the cache */
   /* search507_0 -> 1553 in the cache */
   /* search507_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1553, 946 },
      -1,
   } },

   /* replace507_0 -> 24 in the cache */
   /* replace507_1 -> 946 in the cache */
   /* replace507 -> 1548 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search508_0_0 -> 24 in the cache */
   /* search508_0_1 -> 27 in the cache */
   /* search508_0 -> 1553 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1553, 1556 },
      -1,
   } },

   /* replace508_0 -> 24 in the cache */
   /* replace508_1 -> 946 in the cache */
   /* replace508 -> 1551 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search509_0_0 -> 24 in the cache */
   /* search509_0_1 -> 27 in the cache */
   /* search509_0 -> 1553 in the cache */
   /* search509_1 -> 1556 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1553, 1556 },
      -1,
   } },

   /* replace509_0 -> 24 in the cache */
   /* replace509_1 -> 946 in the cache */
   /* replace509 -> 1548 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search510_0_0 -> 24 in the cache */
   /* search510_0_1 -> 27 in the cache */
   /* search510_0 -> 1542 in the cache */
   /* search510_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1542, 946 },
      -1,
   } },

   /* replace510_0 -> 24 in the cache */
   /* replace510_1 -> 946 in the cache */
   /* replace510 -> 1551 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search511_0_0 -> 24 in the cache */
   /* search511_0_1 -> 27 in the cache */
   /* search511_0 -> 1542 in the cache */
   /* search511_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1542, 946 },
      -1,
   } },

   /* replace511_0 -> 24 in the cache */
   /* replace511_1 -> 946 in the cache */
   /* replace511 -> 1548 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search512_0_0 -> 24 in the cache */
   /* search512_0_1 -> 27 in the cache */
   /* search512_0 -> 1542 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1542, 1561 },
      -1,
   } },

   /* replace512_0 -> 24 in the cache */
   /* replace512_1 -> 946 in the cache */
   /* replace512 -> 1551 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search513_0_0 -> 24 in the cache */
   /* search513_0_1 -> 27 in the cache */
   /* search513_0 -> 1542 in the cache */
   /* search513_1 -> 1561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1542, 1561 },
      -1,
   } },

   /* replace513_0 -> 24 in the cache */
   /* replace513_1 -> 946 in the cache */
   /* replace513 -> 1548 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search514_0 -> 29 in the cache */
   /* search514_1_0_0 -> 29 in the cache */
   /* search514_1_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 29, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1564 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1565 },
      -1,
   } },

   /* replace514_0 -> 29 in the cache */
   /* replace514_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 29, 135 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search515_0_0 -> 29 in the cache */
   /* search515_0_1 -> 30 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 30 },
      -1,
   } },
   /* search515_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1568, 135 },
      -1,
   } },

   /* replace515_0 -> 29 in the cache */
   /* replace515_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 135 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search516_0_0 -> 29 in the cache */
   /* search516_0_1 -> 30 in the cache */
   /* search516_0 -> 1568 in the cache */
   /* search516_1 -> 30 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1568, 30 },
      -1,
   } },

   /* replace516_0 -> 29 in the cache */
   /* replace516_1 -> 135 in the cache */
   /* replace516 -> 1570 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search517_0_0 -> 29 in the cache */
   /* search517_0_1 -> 30 in the cache */
   /* search517_0 -> 1568 in the cache */
   /* search517_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1568, 135 },
      -1,
   } },

   /* replace517_0 -> 29 in the cache */
   /* replace517_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 135 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search518_0_0 -> 29 in the cache */
   /* search518_0_1 -> 30 in the cache */
   /* search518_0 -> 1568 in the cache */
   /* search518_1 -> 30 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1568, 30 },
      -1,
   } },

   /* replace518_0 -> 29 in the cache */
   /* replace518_1 -> 135 in the cache */
   /* replace518 -> 1573 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search519_0_0 -> 29 in the cache */
   /* search519_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 32 },
      -1,
   } },
   /* search519_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1575, 135 },
      -1,
   } },

   /* replace519_0 -> 29 in the cache */
   /* replace519_1 -> 135 in the cache */
   /* replace519 -> 1573 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search520_0_0 -> 29 in the cache */
   /* search520_0_1 -> 32 in the cache */
   /* search520_0 -> 1575 in the cache */
   /* search520_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1575, 135 },
      -1,
   } },

   /* replace520_0 -> 29 in the cache */
   /* replace520_1 -> 135 in the cache */
   /* replace520 -> 1570 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search521_0_0 -> 29 in the cache */
   /* search521_0_1 -> 32 in the cache */
   /* search521_0 -> 1575 in the cache */
   /* search521_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1575, 486 },
      -1,
   } },

   /* replace521_0 -> 29 in the cache */
   /* replace521_1 -> 135 in the cache */
   /* replace521 -> 1573 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search522_0_0 -> 29 in the cache */
   /* search522_0_1 -> 32 in the cache */
   /* search522_0 -> 1575 in the cache */
   /* search522_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1575, 486 },
      -1,
   } },

   /* replace522_0 -> 29 in the cache */
   /* replace522_1 -> 135 in the cache */
   /* replace522 -> 1570 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search523_0_0 -> 29 in the cache */
   /* search523_0_1 -> 32 in the cache */
   /* search523_0 -> 1564 in the cache */
   /* search523_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1564, 135 },
      -1,
   } },

   /* replace523_0 -> 29 in the cache */
   /* replace523_1 -> 135 in the cache */
   /* replace523 -> 1573 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search524_0_0 -> 29 in the cache */
   /* search524_0_1 -> 32 in the cache */
   /* search524_0 -> 1564 in the cache */
   /* search524_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1564, 135 },
      -1,
   } },

   /* replace524_0 -> 29 in the cache */
   /* replace524_1 -> 135 in the cache */
   /* replace524 -> 1570 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search525_0_0 -> 29 in the cache */
   /* search525_0_1 -> 32 in the cache */
   /* search525_0 -> 1564 in the cache */
   /* search525_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1564, 137 },
      -1,
   } },

   /* replace525_0 -> 29 in the cache */
   /* replace525_1 -> 135 in the cache */
   /* replace525 -> 1573 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search526_0_0 -> 29 in the cache */
   /* search526_0_1 -> 32 in the cache */
   /* search526_0 -> 1564 in the cache */
   /* search526_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1564, 137 },
      -1,
   } },

   /* replace526_0 -> 29 in the cache */
   /* replace526_1 -> 135 in the cache */
   /* replace526 -> 1570 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search527_0 -> 34 in the cache */
   /* search527_1_0_0 -> 34 in the cache */
   /* search527_1_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1584 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 1585 },
      -1,
   } },

   /* replace527_0 -> 34 in the cache */
   /* replace527_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 34, 987 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search528_0_0 -> 34 in the cache */
   /* search528_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 34, 35 },
      -1,
   } },
   /* search528_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1588, 987 },
      -1,
   } },

   /* replace528_0 -> 34 in the cache */
   /* replace528_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 987 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search529_0_0 -> 34 in the cache */
   /* search529_0_1 -> 35 in the cache */
   /* search529_0 -> 1588 in the cache */
   /* search529_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1588, 35 },
      -1,
   } },

   /* replace529_0 -> 34 in the cache */
   /* replace529_1 -> 987 in the cache */
   /* replace529 -> 1590 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search530_0_0 -> 34 in the cache */
   /* search530_0_1 -> 35 in the cache */
   /* search530_0 -> 1588 in the cache */
   /* search530_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1588, 987 },
      -1,
   } },

   /* replace530_0 -> 34 in the cache */
   /* replace530_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 987 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search531_0_0 -> 34 in the cache */
   /* search531_0_1 -> 35 in the cache */
   /* search531_0 -> 1588 in the cache */
   /* search531_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1588, 35 },
      -1,
   } },

   /* replace531_0 -> 34 in the cache */
   /* replace531_1 -> 987 in the cache */
   /* replace531 -> 1593 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search532_0_0 -> 34 in the cache */
   /* search532_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 37 },
      -1,
   } },
   /* search532_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1595, 987 },
      -1,
   } },

   /* replace532_0 -> 34 in the cache */
   /* replace532_1 -> 987 in the cache */
   /* replace532 -> 1593 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search533_0_0 -> 34 in the cache */
   /* search533_0_1 -> 37 in the cache */
   /* search533_0 -> 1595 in the cache */
   /* search533_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1595, 987 },
      -1,
   } },

   /* replace533_0 -> 34 in the cache */
   /* replace533_1 -> 987 in the cache */
   /* replace533 -> 1590 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search534_0_0 -> 34 in the cache */
   /* search534_0_1 -> 37 in the cache */
   /* search534_0 -> 1595 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1595, 1598 },
      -1,
   } },

   /* replace534_0 -> 34 in the cache */
   /* replace534_1 -> 987 in the cache */
   /* replace534 -> 1593 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search535_0_0 -> 34 in the cache */
   /* search535_0_1 -> 37 in the cache */
   /* search535_0 -> 1595 in the cache */
   /* search535_1 -> 1598 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1595, 1598 },
      -1,
   } },

   /* replace535_0 -> 34 in the cache */
   /* replace535_1 -> 987 in the cache */
   /* replace535 -> 1590 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search536_0_0 -> 34 in the cache */
   /* search536_0_1 -> 37 in the cache */
   /* search536_0 -> 1584 in the cache */
   /* search536_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1584, 987 },
      -1,
   } },

   /* replace536_0 -> 34 in the cache */
   /* replace536_1 -> 987 in the cache */
   /* replace536 -> 1593 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search537_0_0 -> 34 in the cache */
   /* search537_0_1 -> 37 in the cache */
   /* search537_0 -> 1584 in the cache */
   /* search537_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1584, 987 },
      -1,
   } },

   /* replace537_0 -> 34 in the cache */
   /* replace537_1 -> 987 in the cache */
   /* replace537 -> 1590 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search538_0_0 -> 34 in the cache */
   /* search538_0_1 -> 37 in the cache */
   /* search538_0 -> 1584 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1584, 1603 },
      -1,
   } },

   /* replace538_0 -> 34 in the cache */
   /* replace538_1 -> 987 in the cache */
   /* replace538 -> 1593 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search539_0_0 -> 34 in the cache */
   /* search539_0_1 -> 37 in the cache */
   /* search539_0 -> 1584 in the cache */
   /* search539_1 -> 1603 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1584, 1603 },
      -1,
   } },

   /* replace539_0 -> 34 in the cache */
   /* replace539_1 -> 987 in the cache */
   /* replace539 -> 1590 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search540_0 -> 9 in the cache */
   /* search540_1_0 -> 9 in the cache */
   /* search540_1 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 9, 118 },
      -1,
   } },

   /* replace540_0_0 -> 9 in the cache */
   /* replace540_0 -> 11 in the cache */
   /* replace540 -> 1374 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search541_0 -> 9 in the cache */
   /* search541_1_0 -> 9 in the cache */
   /* search541_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 9, 120 },
      -1,
   } },

   /* replace541_0_0 -> 9 in the cache */
   /* replace541_0 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 125 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search542_0 -> 9 in the cache */
   /* search542_1_0_0 -> 9 in the cache */
   /* search542_1_0 -> 11 in the cache */
   /* search542_1 -> 1374 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 9, 1374 },
      -1,
   } },

   /* replace542_0_0 -> 9 in the cache */
   /* replace542_0 -> 11 in the cache */
   /* replace542 -> 1374 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search543_0 -> 9 in the cache */
   /* search543_1_0_0 -> 9 in the cache */
   /* search543_1_0 -> 125 in the cache */
   /* search543_1 -> 1608 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 9, 1608 },
      -1,
   } },

   /* replace543_0_0 -> 9 in the cache */
   /* replace543_0 -> 125 in the cache */
   /* replace543 -> 1608 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search544_0 -> 9 in the cache */
   /* search544_1_0 -> 9 in the cache */
   /* search544_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 9, 11 },
      -1,
   } },

   /* replace544 -> 9 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search545_0 -> 9 in the cache */
   /* search545_1_0 -> 9 in the cache */
   /* search545_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 9, 125 },
      -1,
   } },

   /* replace545 -> 9 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search546_0 -> 9 in the cache */
   /* search546_1_0_0 -> 9 in the cache */
   /* search546_1_0 -> 11 in the cache */
   /* search546_1 -> 1374 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 9, 1374 },
      -1,
   } },

   /* replace546 -> 9 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search547_0 -> 9 in the cache */
   /* search547_1_0_0 -> 9 in the cache */
   /* search547_1_0 -> 125 in the cache */
   /* search547_1 -> 1608 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 9, 1608 },
      -1,
   } },

   /* replace547 -> 9 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search548_0 -> 9 in the cache */
   /* search548_1_0 -> 9 in the cache */
   /* search548_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 9, 11 },
      -1,
   } },

   /* replace548_0 -> 9 in the cache */
   /* replace548 -> 11 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search549_0 -> 9 in the cache */
   /* search549_1_0 -> 9 in the cache */
   /* search549_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 9, 125 },
      -1,
   } },

   /* replace549_0 -> 9 in the cache */
   /* replace549 -> 125 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search550_0 -> 9 in the cache */
   /* search550_1_0 -> 9 in the cache */
   /* search550_1 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 9, 118 },
      -1,
   } },

   /* replace550_0 -> 9 in the cache */
   /* replace550 -> 11 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search551_0 -> 9 in the cache */
   /* search551_1_0 -> 9 in the cache */
   /* search551_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 9, 120 },
      -1,
   } },

   /* replace551_0 -> 9 in the cache */
   /* replace551 -> 125 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search552_0_0 -> 9 in the cache */
   /* search552_0 -> 11 in the cache */
   /* search552_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 8 },
      -1,
   } },

   /* replace552_0 -> 9 in the cache */
   /* replace552 -> 11 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search553_0_0 -> 9 in the cache */
   /* search553_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 9, 8 },
      -1,
   } },
   /* search553_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1620, 259 },
      -1,
   } },

   /* replace553_0 -> 9 in the cache */
   /* replace553 -> 235 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search554_0_0 -> 9 in the cache */
   /* search554_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 9, 259 },
      -1,
   } },
   /* search554_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1622, 8 },
      -1,
   } },

   /* replace554_0 -> 9 in the cache */
   /* replace554 -> 235 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search555_0_0 -> 9 in the cache */
   /* search555_0_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 9, 265 },
      -1,
   } },
   /* search555_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1624, 8 },
      -1,
   } },

   /* replace555_0_0_0 -> 9 in the cache */
   /* replace555_0_0 -> 118 in the cache */
   /* replace555_0 -> 236 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 236 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search556_0_0 -> 9 in the cache */
   /* search556_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 9, 8 },
      -1,
   } },
   /* search556_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1627, 265 },
      -1,
   } },

   /* replace556_0_0_0 -> 9 in the cache */
   /* replace556_0_0 -> 118 in the cache */
   /* replace556_0 -> 236 in the cache */
   /* replace556 -> 1626 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search557_0_0 -> 9 in the cache */
   /* search557_0 -> 110 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 110 },
      -1,
   } },

   /* replace557_0_0 -> 8 in the cache */
   /* replace557_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 8, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1630 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search558_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1632 },
      -1,
   } },

   /* replace558_0 -> 9 in the cache */
   /* replace558 -> 1632 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search559_0 -> 9 in the cache */
   /* search559 -> 235 in the cache */

   /* replace559_0_0 -> 9 in the cache */
   /* replace559_0_1 -> 8 in the cache */
   /* replace559_0 -> 1620 in the cache */
   /* replace559_1 -> 259 in the cache */
   /* replace559 -> 1621 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search560_0_0 -> 9 in the cache */
   /* search560_0 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 235 },
      -1,
   } },

   /* replace560_0 -> 9 in the cache */
   /* replace560 -> 235 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search561_0_0_0 -> 0 in the cache */
   /* search561_0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1635 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1636 },
      -1,
   } },

   /* replace561_0_0_0 -> 0 in the cache */
   /* replace561_0_0 -> 230 in the cache */
   /* replace561_0_1_0 -> 1 in the cache */
   /* replace561_0_1 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 230, 1175 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1638 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search562_0_0_0 -> 0 in the cache */
   /* search562_0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1640 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1641 },
      -1,
   } },

   /* replace562_0_0_0 -> 0 in the cache */
   /* replace562_0_0 -> 230 in the cache */
   /* replace562_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 230, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1643 },
      -1,
   } },

   /* ('fsat(nsz)', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search563_0_0_0 -> 29 in the cache */
   /* search563_0_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 29, 48 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1645 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1646 },
      -1,
   } },

   /* replace563_0_0_0 -> 29 in the cache */
   /* replace563_0_0 -> 293 in the cache */
   /* replace563_0_1 -> 48 in the cache */
   /* replace563_0 -> 433 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 433 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search564_0_0_0 -> 0 in the cache */
   /* search564_0_0_1 -> 1 in the cache */
   /* search564_0_0 -> 1640 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1640 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1649 },
      -1,
   } },

   /* replace564_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace564_0_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1651, 1652 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1653 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search565_0_0_0_0 -> 139 in the cache */
   /* search565_0_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 139, 140 },
      -1,
   } },
   /* search565_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1655, 142 },
      -1,
   } },
   /* search565_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1656, 140 },
      -1,
   } },
   /* search565_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1657, 142 },
      -1,
   } },

   /* replace565_0_0 -> 139 in the cache */
   /* replace565_0_1 -> 140 in the cache */
   /* replace565_0 -> 1464 in the cache */
   /* replace565_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1464, 142 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search566_0_0_0_0 -> 139 in the cache */
   /* search566_0_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 139, 140 },
      -1,
   } },
   /* search566_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1660, 142 },
      -1,
   } },
   /* search566_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1661, 140 },
      -1,
   } },
   /* search566_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1662, 142 },
      -1,
   } },

   /* replace566_0_0 -> 139 in the cache */
   /* replace566_0_1 -> 140 in the cache */
   /* replace566_0 -> 1474 in the cache */
   /* replace566_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1474, 142 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search567_0_0_0_0 -> 139 in the cache */
   /* search567_0_0_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 139, 140 },
      -1,
   } },
   /* search567_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1665, 142 },
      -1,
   } },
   /* search567_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1666, 140 },
      -1,
   } },
   /* search567_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1667, 142 },
      -1,
   } },

   /* replace567_0_0 -> 139 in the cache */
   /* replace567_0_1 -> 140 in the cache */
   /* replace567_0 -> 1469 in the cache */
   /* replace567_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1469, 142 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search568_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1670, 1671 },
      -1,
   } },

   /* replace568_0_0 -> 0 in the cache */
   /* replace568_0_1 -> 1 in the cache */
   /* replace568_0 -> 1401 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1401 },
      -1,
   } },

   /* ('fmax', ('fsat(is_used_once)', 'a'), ('fsat(is_used_once)', 'b')) => ('fsat', ('fmax', 'a', 'b')) */
   /* search569_0_0 -> 0 in the cache */
   /* search569_0 -> 1235 in the cache */
   /* search569_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1235, 1674 },
      -1,
   } },

   /* replace569_0_0 -> 0 in the cache */
   /* replace569_0_1 -> 1 in the cache */
   /* replace569_0 -> 1401 in the cache */
   /* replace569 -> 1673 in the cache */

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search570_0_0 -> 0 in the cache */
   /* search570_0 -> 1670 in the cache */
   /* search570_1 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1670, 1671 },
      -1,
   } },

   /* replace570_0_0 -> 0 in the cache */
   /* replace570_0_1 -> 1 in the cache */
   /* replace570_0 -> 1403 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1403 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search571_0_0_0 -> 1192 in the cache */
   /* search571_0_0_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1192, 1191 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1678 },
      -1,
   } },
   /* search571_1 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1679, 1192 },
      -1,
   } },

   /* replace571_0_0 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1192 },
      -1,
   } },
   /* replace571_1_0 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1191 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1681, 1682 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search572_0_0_0 -> 1192 in the cache */
   /* search572_0_0_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1192, 1191 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1684 },
      -1,
   } },
   /* search572_1 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1685, 1192 },
      -1,
   } },

   /* replace572_0_0_0 -> 1192 in the cache */
   /* replace572_0_0 -> 1681 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1681 },
      -1,
   } },
   /* replace572_1_0 -> 1191 in the cache */
   /* replace572_1 -> 1682 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1687, 1682 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1689 },
      -1,
   } },
   /* search573_0_1 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1690, 1671 },
      0,
   } },
   /* search573_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1691, 273 },
      -1,
   } },

   /* replace573_0_0_0 -> 0 in the cache */
   /* replace573_0_0 -> 230 in the cache */
   /* replace573_0_1 -> 1 in the cache */
   /* replace573_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 290 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search574_0_0_0 -> 9 in the cache */
   /* search574_0_0_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 9, 73 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffull /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1694, 1695 },
      -1,
   } },
   /* search574_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1696, 73 },
      -1,
   } },

   /* replace574_0_0 -> 9 in the cache */
   /* replace574_0_1 -> 73 in the cache */
   /* replace574_0 -> 1694 in the cache */
   /* replace574_1 -> 1695 in the cache */
   /* replace574 -> 1696 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search575_0_0 -> 139 in the cache */
   /* search575_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 139, 140 },
      0,
   } },
   /* search575_1_0 -> 139 in the cache */
   /* search575_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1698, 1699 },
      -1,
   } },

   /* replace575_0 -> 139 in the cache */
   /* replace575_1_0 -> 140 in the cache */
   /* replace575_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 139, 1701 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search576_0_0 -> 0 in the cache */
   /* search576_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 771 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search576_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1704, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1703, 1705 },
      -1,
   } },

   /* replace576_0_0 -> 0 in the cache */
   /* replace576_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace576_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1707, 771 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search577_0_0 -> 139 in the cache */
   /* search577_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 140 },
      0,
   } },
   /* search577_1_0 -> 139 in the cache */
   /* search577_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1709, 1710 },
      -1,
   } },

   /* replace577_0 -> 139 in the cache */
   /* replace577_1_0 -> 140 in the cache */
   /* replace577_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 139, 1712 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search578_0_0 -> 0 in the cache */
   /* search578_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 771 },
      0,
   } },
   /* search578_1_0 -> 1704 in the cache */
   /* search578_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1704, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1714, 1715 },
      -1,
   } },

   /* replace578_0_0 -> 0 in the cache */
   /* replace578_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace578_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1717, 771 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search579_0_0 -> 139 in the cache */
   /* search579_0_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 139, 296 },
      -1,
   } },
   /* search579_1_0 -> 139 in the cache */
   /* search579_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 139, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1719, 1720 },
      -1,
   } },

   /* replace579_0 -> 139 in the cache */
   /* replace579_1_0 -> 140 in the cache */
   /* replace579_1_1 -> 142 in the cache */
   /* replace579_1 -> 1701 in the cache */
   /* replace579 -> 1702 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search580_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1722, 771 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search580_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1724, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1723, 1725 },
      -1,
   } },

   /* replace580_0_0 -> 0 in the cache */
   /* replace580_0_1 -> 1704 in the cache */
   /* replace580_0 -> 1707 in the cache */
   /* replace580_1 -> 771 in the cache */
   /* replace580 -> 1708 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search581_0_0 -> 139 in the cache */
   /* search581_0_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 296 },
      -1,
   } },
   /* search581_1_0 -> 139 in the cache */
   /* search581_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1727, 1728 },
      -1,
   } },

   /* replace581_0 -> 139 in the cache */
   /* replace581_1_0 -> 140 in the cache */
   /* replace581_1_1 -> 142 in the cache */
   /* replace581_1 -> 1712 in the cache */
   /* replace581 -> 1713 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search582_0_0 -> 1722 in the cache */
   /* search582_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1722, 771 },
      -1,
   } },
   /* search582_1_0 -> 1724 in the cache */
   /* search582_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1724, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1730, 1731 },
      -1,
   } },

   /* replace582_0_0 -> 0 in the cache */
   /* replace582_0_1 -> 1704 in the cache */
   /* replace582_0 -> 1717 in the cache */
   /* replace582_1 -> 771 in the cache */
   /* replace582 -> 1718 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search583_0_0 -> 139 in the cache */
   /* search583_0_1 -> 140 in the cache */
   /* search583_0 -> 1698 in the cache */
   /* search583_1_0 -> 139 in the cache */
   /* search583_1_1 -> 142 in the cache */
   /* search583_1 -> 1699 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1698, 1699 },
      -1,
   } },

   /* replace583_0 -> 139 in the cache */
   /* replace583_1_0 -> 140 in the cache */
   /* replace583_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 139, 1734 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search584_0_0 -> 0 in the cache */
   /* search584_0_1 -> 771 in the cache */
   /* search584_0 -> 1703 in the cache */
   /* search584_1_0 -> 1704 in the cache */
   /* search584_1_1 -> 771 in the cache */
   /* search584_1 -> 1705 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1703, 1705 },
      -1,
   } },

   /* replace584_0_0 -> 0 in the cache */
   /* replace584_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace584_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1737, 771 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search585_0_0 -> 139 in the cache */
   /* search585_0_1 -> 140 in the cache */
   /* search585_0 -> 1709 in the cache */
   /* search585_1_0 -> 139 in the cache */
   /* search585_1_1 -> 142 in the cache */
   /* search585_1 -> 1710 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1709, 1710 },
      -1,
   } },

   /* replace585_0 -> 139 in the cache */
   /* replace585_1_0 -> 140 in the cache */
   /* replace585_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 139, 1740 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search586_0_0 -> 0 in the cache */
   /* search586_0_1 -> 771 in the cache */
   /* search586_0 -> 1714 in the cache */
   /* search586_1_0 -> 1704 in the cache */
   /* search586_1_1 -> 771 in the cache */
   /* search586_1 -> 1715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1714, 1715 },
      -1,
   } },

   /* replace586_0_0 -> 0 in the cache */
   /* replace586_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace586_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1743, 771 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search587_0_0 -> 139 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 139, 1745 },
      -1,
   } },
   /* search587_1_0 -> 139 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 139, 1747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1746, 1748 },
      -1,
   } },

   /* replace587_0 -> 139 in the cache */
   /* replace587_1_0 -> 140 in the cache */
   /* replace587_1_1 -> 142 in the cache */
   /* replace587_1 -> 1734 in the cache */
   /* replace587 -> 1735 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search588_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1750, 771 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search588_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1752, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1751, 1753 },
      -1,
   } },

   /* replace588_0_0 -> 0 in the cache */
   /* replace588_0_1 -> 1704 in the cache */
   /* replace588_0 -> 1737 in the cache */
   /* replace588_1 -> 771 in the cache */
   /* replace588 -> 1738 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search589_0_0 -> 139 in the cache */
   /* search589_0_1 -> 1745 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 1745 },
      -1,
   } },
   /* search589_1_0 -> 139 in the cache */
   /* search589_1_1 -> 1747 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 1747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1755, 1756 },
      -1,
   } },

   /* replace589_0 -> 139 in the cache */
   /* replace589_1_0 -> 140 in the cache */
   /* replace589_1_1 -> 142 in the cache */
   /* replace589_1 -> 1740 in the cache */
   /* replace589 -> 1741 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search590_0_0 -> 1750 in the cache */
   /* search590_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1750, 771 },
      -1,
   } },
   /* search590_1_0 -> 1752 in the cache */
   /* search590_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1752, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1758, 1759 },
      -1,
   } },

   /* replace590_0_0 -> 0 in the cache */
   /* replace590_0_1 -> 1704 in the cache */
   /* replace590_0 -> 1743 in the cache */
   /* replace590_1 -> 771 in the cache */
   /* replace590 -> 1744 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search591_0_0 -> 139 in the cache */
   /* search591_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 139, 140 },
      0,
   } },
   /* search591_1_0 -> 139 in the cache */
   /* search591_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1761, 1762 },
      -1,
   } },

   /* replace591_0 -> 139 in the cache */
   /* replace591_1_0 -> 140 in the cache */
   /* replace591_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 139, 1764 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search592_0_0 -> 0 in the cache */
   /* search592_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 771 },
      0,
   } },
   /* search592_1_0 -> 1704 in the cache */
   /* search592_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1704, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1766, 1767 },
      -1,
   } },

   /* replace592_0_0 -> 0 in the cache */
   /* replace592_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace592_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1769, 771 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search593_0_0 -> 139 in the cache */
   /* search593_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 139, 140 },
      0,
   } },
   /* search593_1_0 -> 139 in the cache */
   /* search593_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1771, 1772 },
      -1,
   } },

   /* replace593_0 -> 139 in the cache */
   /* replace593_1_0 -> 140 in the cache */
   /* replace593_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 139, 1774 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search594_0_0 -> 0 in the cache */
   /* search594_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 771 },
      0,
   } },
   /* search594_1_0 -> 1704 in the cache */
   /* search594_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1704, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1776, 1777 },
      -1,
   } },

   /* replace594_0_0 -> 0 in the cache */
   /* replace594_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace594_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1779, 771 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search595_0_0 -> 139 in the cache */
   /* search595_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 139, 140 },
      0,
   } },
   /* search595_1_0 -> 139 in the cache */
   /* search595_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1781, 1782 },
      -1,
   } },

   /* replace595_0 -> 139 in the cache */
   /* replace595_1_0 -> 140 in the cache */
   /* replace595_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 139, 1784 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search596_0_0 -> 0 in the cache */
   /* search596_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 771 },
      0,
   } },
   /* search596_1_0 -> 1704 in the cache */
   /* search596_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1704, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1786, 1787 },
      -1,
   } },

   /* replace596_0_0 -> 0 in the cache */
   /* replace596_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace596_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1789, 771 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search597_0_0 -> 139 in the cache */
   /* search597_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 139, 140 },
      0,
   } },
   /* search597_1_0 -> 139 in the cache */
   /* search597_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 139, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1791, 1792 },
      -1,
   } },

   /* replace597_0 -> 139 in the cache */
   /* replace597_1_0 -> 140 in the cache */
   /* replace597_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 139, 1794 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search598_0_0 -> 0 in the cache */
   /* search598_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 771 },
      0,
   } },
   /* search598_1_0 -> 1704 in the cache */
   /* search598_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1704, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1796, 1797 },
      -1,
   } },

   /* replace598_0_0 -> 0 in the cache */
   /* replace598_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1704 },
      -1,
   } },
   /* replace598_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1799, 771 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search599_0_0 -> 139 in the cache */
   /* search599_0_1 -> 140 in the cache */
   /* search599_0 -> 1761 in the cache */
   /* search599_1_0 -> 139 in the cache */
   /* search599_1_1 -> 142 in the cache */
   /* search599_1 -> 1762 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1761, 1762 },
      -1,
   } },

   /* replace599_0 -> 139 in the cache */
   /* replace599_1_0 -> 140 in the cache */
   /* replace599_1_1 -> 142 in the cache */
   /* replace599_1 -> 1774 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 139, 1774 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search600_0_0 -> 0 in the cache */
   /* search600_0_1 -> 771 in the cache */
   /* search600_0 -> 1766 in the cache */
   /* search600_1_0 -> 1704 in the cache */
   /* search600_1_1 -> 771 in the cache */
   /* search600_1 -> 1767 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1766, 1767 },
      -1,
   } },

   /* replace600_0_0 -> 0 in the cache */
   /* replace600_0_1 -> 1704 in the cache */
   /* replace600_0 -> 1779 in the cache */
   /* replace600_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1779, 771 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search601_0_0 -> 139 in the cache */
   /* search601_0_1 -> 140 in the cache */
   /* search601_0 -> 1771 in the cache */
   /* search601_1_0 -> 139 in the cache */
   /* search601_1_1 -> 142 in the cache */
   /* search601_1 -> 1772 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1771, 1772 },
      -1,
   } },

   /* replace601_0 -> 139 in the cache */
   /* replace601_1_0 -> 140 in the cache */
   /* replace601_1_1 -> 142 in the cache */
   /* replace601_1 -> 1764 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 139, 1764 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search602_0_0 -> 0 in the cache */
   /* search602_0_1 -> 771 in the cache */
   /* search602_0 -> 1776 in the cache */
   /* search602_1_0 -> 1704 in the cache */
   /* search602_1_1 -> 771 in the cache */
   /* search602_1 -> 1777 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1776, 1777 },
      -1,
   } },

   /* replace602_0_0 -> 0 in the cache */
   /* replace602_0_1 -> 1704 in the cache */
   /* replace602_0 -> 1769 in the cache */
   /* replace602_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1769, 771 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search603_0_0 -> 139 in the cache */
   /* search603_0_1 -> 140 in the cache */
   /* search603_0 -> 1781 in the cache */
   /* search603_1_0 -> 139 in the cache */
   /* search603_1_1 -> 142 in the cache */
   /* search603_1 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1781, 1782 },
      -1,
   } },

   /* replace603_0 -> 139 in the cache */
   /* replace603_1_0 -> 140 in the cache */
   /* replace603_1_1 -> 142 in the cache */
   /* replace603_1 -> 1794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 139, 1794 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search604_0_0 -> 0 in the cache */
   /* search604_0_1 -> 771 in the cache */
   /* search604_0 -> 1786 in the cache */
   /* search604_1_0 -> 1704 in the cache */
   /* search604_1_1 -> 771 in the cache */
   /* search604_1 -> 1787 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1786, 1787 },
      -1,
   } },

   /* replace604_0_0 -> 0 in the cache */
   /* replace604_0_1 -> 1704 in the cache */
   /* replace604_0 -> 1799 in the cache */
   /* replace604_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1799, 771 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search605_0_0 -> 139 in the cache */
   /* search605_0_1 -> 140 in the cache */
   /* search605_0 -> 1791 in the cache */
   /* search605_1_0 -> 139 in the cache */
   /* search605_1_1 -> 142 in the cache */
   /* search605_1 -> 1792 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1791, 1792 },
      -1,
   } },

   /* replace605_0 -> 139 in the cache */
   /* replace605_1_0 -> 140 in the cache */
   /* replace605_1_1 -> 142 in the cache */
   /* replace605_1 -> 1784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 139, 1784 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search606_0_0 -> 0 in the cache */
   /* search606_0_1 -> 771 in the cache */
   /* search606_0 -> 1796 in the cache */
   /* search606_1_0 -> 1704 in the cache */
   /* search606_1_1 -> 771 in the cache */
   /* search606_1 -> 1797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1796, 1797 },
      -1,
   } },

   /* replace606_0_0 -> 0 in the cache */
   /* replace606_0_1 -> 1704 in the cache */
   /* replace606_0 -> 1789 in the cache */
   /* replace606_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1789, 771 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search607_0_0_0 -> 0 in the cache */
   /* search607_0_0_1 -> 771 in the cache */
   /* search607_0_0 -> 1703 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1703, 1817 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search607_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1819, 771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1818, 1820 },
      -1,
   } },

   /* replace607_0_0_0 -> 0 in the cache */
   /* replace607_0_0_1 -> 1819 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1819 },
      -1,
   } },
   /* replace607_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1822, 771 },
      -1,
   } },
   /* replace607_1 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1823, 1817 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search608_0_0_0 -> 0 in the cache */
   /* search608_0_0_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 771 },
      -1,
   } },
   /* search608_0_1 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1825, 1817 },
      0,
   } },
   /* search608_1_0 -> 1819 in the cache */
   /* search608_1_1 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1819, 771 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1826, 1827 },
      -1,
   } },

   /* replace608_0_0_0 -> 0 in the cache */
   /* replace608_0_0_1 -> 1819 in the cache */
   /* replace608_0_0 -> 1822 in the cache */
   /* replace608_0_1 -> 771 in the cache */
   /* replace608_0 -> 1823 in the cache */
   /* replace608_1 -> 1817 in the cache */
   /* replace608 -> 1824 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search609_0_0_0 -> 162 in the cache */
   /* search609_0_0_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 162, 163 },
      0,
   } },
   /* search609_0_1 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1829, 1817 },
      0,
   } },
   /* search609_1_0 -> 162 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 162, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1830, 1832 },
      -1,
   } },

   /* replace609_0_0 -> 162 in the cache */
   /* replace609_0_1_0 -> 163 in the cache */
   /* replace609_0_1_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 163, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 162, 1834 },
      -1,
   } },
   /* replace609_1 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1835, 1817 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search610_0_0_0 -> 162 in the cache */
   /* search610_0_0_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 162, 163 },
      -1,
   } },
   /* search610_0_1 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1837, 1817 },
      0,
   } },
   /* search610_1_0 -> 162 in the cache */
   /* search610_1_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 162, 1831 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1838, 1839 },
      -1,
   } },

   /* replace610_0_0 -> 162 in the cache */
   /* replace610_0_1_0 -> 163 in the cache */
   /* replace610_0_1_1 -> 1831 in the cache */
   /* replace610_0_1 -> 1834 in the cache */
   /* replace610_0 -> 1835 in the cache */
   /* replace610_1 -> 1817 in the cache */
   /* replace610 -> 1836 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search611_0_0 -> 1132 in the cache */
   /* search611_0_1 -> 1133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1132, 1133 },
      -1,
   } },
   /* search611_1_0 -> 1 in the cache */
   /* search611_1_1 -> 0 in the cache */
   /* search611_1 -> 1166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1841, 1166 },
      -1,
   } },

   /* replace611_0 -> 0 in the cache */
   /* replace611_1 -> 1 in the cache */
   /* replace611 -> 1140 in the cache */

   /* ('umin', ('iand', 'a', '#b(is_pos_power_of_two)'), ('iand', 'c', 'b')) => ('iand', ('iand', 'a', 'b'), ('iand', 'c', 'b')) */
   /* search612_0_0 -> 0 in the cache */
   /* search612_0_1 -> 15 in the cache */
   /* search612_0 -> 212 in the cache */
   /* search612_1_0 -> 153 in the cache */
   /* search612_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 153, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 212, 1843 },
      -1,
   } },

   /* replace612_0_0 -> 0 in the cache */
   /* replace612_0_1 -> 1 in the cache */
   /* replace612_0 -> 214 in the cache */
   /* replace612_1_0 -> 153 in the cache */
   /* replace612_1_1 -> 1 in the cache */
   /* replace612_1 -> 1843 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 214, 1843 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search613_0_0 -> 776 in the cache */
   /* search613_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 776, 24 },
      0,
   } },
   /* search613_1_0 -> 551 in the cache */
   /* search613_1_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 551, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1846, 1847 },
      -1,
   } },

   /* replace613_0 -> 776 in the cache */
   /* replace613_1_0 -> 24 in the cache */
   /* replace613_1_1_0 -> 551 in the cache */
   /* replace613_1_1 -> 622 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 24, 622 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 776, 1849 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search614_0_0 -> 776 in the cache */
   /* search614_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 776, 24 },
      -1,
   } },
   /* search614_1_0 -> 551 in the cache */
   /* search614_1_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 551, 776 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1851, 1852 },
      -1,
   } },

   /* replace614_0 -> 776 in the cache */
   /* replace614_1_0 -> 24 in the cache */
   /* replace614_1_1_0 -> 551 in the cache */
   /* replace614_1_1 -> 622 in the cache */
   /* replace614_1 -> 1849 in the cache */
   /* replace614 -> 1850 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search615_0_0 -> 776 in the cache */
   /* search615_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 776, 24 },
      0,
   } },
   /* search615_1_0 -> 551 in the cache */
   /* search615_1_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 551, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1854, 1855 },
      -1,
   } },

   /* replace615_0 -> 776 in the cache */
   /* replace615_1_0 -> 24 in the cache */
   /* replace615_1_1_0 -> 551 in the cache */
   /* replace615_1_1 -> 622 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 24, 622 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 776, 1857 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search616_0_0 -> 776 in the cache */
   /* search616_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 776, 24 },
      -1,
   } },
   /* search616_1_0 -> 551 in the cache */
   /* search616_1_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 551, 776 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1859, 1860 },
      -1,
   } },

   /* replace616_0 -> 776 in the cache */
   /* replace616_1_0 -> 24 in the cache */
   /* replace616_1_1_0 -> 551 in the cache */
   /* replace616_1_1 -> 622 in the cache */
   /* replace616_1 -> 1857 in the cache */
   /* replace616 -> 1858 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search617_0_0 -> 776 in the cache */
   /* search617_0_1 -> 24 in the cache */
   /* search617_0 -> 1846 in the cache */
   /* search617_1_0 -> 551 in the cache */
   /* search617_1_1 -> 776 in the cache */
   /* search617_1 -> 1847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1846, 1847 },
      -1,
   } },

   /* replace617_0 -> 776 in the cache */
   /* replace617_1_0 -> 24 in the cache */
   /* replace617_1_1_0 -> 551 in the cache */
   /* replace617_1_1 -> 622 in the cache */
   /* replace617_1 -> 1857 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 776, 1857 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search618_0_0 -> 776 in the cache */
   /* search618_0_1 -> 24 in the cache */
   /* search618_0 -> 1851 in the cache */
   /* search618_1_0 -> 551 in the cache */
   /* search618_1_1 -> 776 in the cache */
   /* search618_1 -> 1852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1851, 1852 },
      -1,
   } },

   /* replace618_0 -> 776 in the cache */
   /* replace618_1_0 -> 24 in the cache */
   /* replace618_1_1_0 -> 551 in the cache */
   /* replace618_1_1 -> 622 in the cache */
   /* replace618_1 -> 1857 in the cache */
   /* replace618 -> 1863 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search619_0_0 -> 776 in the cache */
   /* search619_0_1 -> 24 in the cache */
   /* search619_0 -> 1854 in the cache */
   /* search619_1_0 -> 551 in the cache */
   /* search619_1_1 -> 776 in the cache */
   /* search619_1 -> 1855 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1854, 1855 },
      -1,
   } },

   /* replace619_0 -> 776 in the cache */
   /* replace619_1_0 -> 24 in the cache */
   /* replace619_1_1_0 -> 551 in the cache */
   /* replace619_1_1 -> 622 in the cache */
   /* replace619_1 -> 1849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 776, 1849 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search620_0_0 -> 776 in the cache */
   /* search620_0_1 -> 24 in the cache */
   /* search620_0 -> 1859 in the cache */
   /* search620_1_0 -> 551 in the cache */
   /* search620_1_1 -> 776 in the cache */
   /* search620_1 -> 1860 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1859, 1860 },
      -1,
   } },

   /* replace620_0 -> 776 in the cache */
   /* replace620_1_0 -> 24 in the cache */
   /* replace620_1_1_0 -> 551 in the cache */
   /* replace620_1_1 -> 622 in the cache */
   /* replace620_1 -> 1849 in the cache */
   /* replace620 -> 1866 in the cache */

   /* ('ior', ('feq(is_used_once)', 'a@16', 0.0), ('feq', 'b@16', 0.0)) => ('feq', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search621_0_0 -> 24 in the cache */
   /* search621_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 24, 776 },
      0,
   } },
   /* search621_1_0 -> 551 in the cache */
   /* search621_1_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 551, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1868, 1869 },
      -1,
   } },

   /* replace621_0_0_0 -> 24 in the cache */
   /* replace621_0_0 -> 778 in the cache */
   /* replace621_0_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 778, 1871 },
      -1,
   } },
   /* replace621_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1872, 776 },
      -1,
   } },

   /* ('ior', ('fneu(is_used_once)', 'a@16', 0.0), ('fneu', 'b@16', 0.0)) => ('fneu', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search622_0_0 -> 24 in the cache */
   /* search622_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 24, 776 },
      0,
   } },
   /* search622_1_0 -> 551 in the cache */
   /* search622_1_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 551, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1874, 1875 },
      -1,
   } },

   /* replace622_0_0_0 -> 24 in the cache */
   /* replace622_0_0 -> 778 in the cache */
   /* replace622_0_1_0 -> 551 in the cache */
   /* replace622_0_1 -> 1871 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 778, 1871 },
      -1,
   } },
   /* replace622_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1877, 776 },
      -1,
   } },

   /* ('iand', ('feq(is_used_once)', 'a@16', 0.0), ('feq', 'b@16', 0.0)) => ('feq', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search623_0_0 -> 24 in the cache */
   /* search623_0_1 -> 776 in the cache */
   /* search623_0 -> 1868 in the cache */
   /* search623_1_0 -> 551 in the cache */
   /* search623_1_1 -> 776 in the cache */
   /* search623_1 -> 1869 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1868, 1869 },
      -1,
   } },

   /* replace623_0_0_0 -> 24 in the cache */
   /* replace623_0_0 -> 778 in the cache */
   /* replace623_0_1_0 -> 551 in the cache */
   /* replace623_0_1 -> 1871 in the cache */
   /* replace623_0 -> 1877 in the cache */
   /* replace623_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1877, 776 },
      -1,
   } },

   /* ('iand', ('fneu(is_used_once)', 'a@16', 0.0), ('fneu', 'b@16', 0.0)) => ('fneu', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search624_0_0 -> 24 in the cache */
   /* search624_0_1 -> 776 in the cache */
   /* search624_0 -> 1874 in the cache */
   /* search624_1_0 -> 551 in the cache */
   /* search624_1_1 -> 776 in the cache */
   /* search624_1 -> 1875 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1874, 1875 },
      -1,
   } },

   /* replace624_0_0_0 -> 24 in the cache */
   /* replace624_0_0 -> 778 in the cache */
   /* replace624_0_1_0 -> 551 in the cache */
   /* replace624_0_1 -> 1871 in the cache */
   /* replace624_0 -> 1872 in the cache */
   /* replace624_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1872, 776 },
      -1,
   } },

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search625_0_0 -> 24 in the cache */
   /* search625_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 24, 776 },
      -1,
   } },
   /* search625_1 -> 569 in the cache */
   /* search625_2_0_0_0_0 -> 776 in the cache */
   /* search625_2_0_0_0_1 -> 24 in the cache */
   /* search625_2_0_0_0 -> 1851 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1851 },
      -1,
   } },
   /* search625_2_0_1_0_0_0 -> 24 in the cache */
   /* search625_2_0_1_0_0_1 -> 776 in the cache */
   /* search625_2_0_1_0_0 -> 777 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 777 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1885 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1884, 1886 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1883, 569, 1888 },
      -1,
   } },

   /* replace625_0_0_0_0 -> 24 in the cache */
   /* replace625_0_0_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 24, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1890 },
      -1,
   } },
   /* replace625_0_1_0_0_0 -> 24 in the cache */
   /* replace625_0_1_0_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 24, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1893 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1891, 1894 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1895 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search626_0 -> 847 in the cache */
   /* search626_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 551 },
      0,
   } },
   /* search626_2_0 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1897, 1898 },
      -1,
   } },

   /* replace626_0_0 -> 847 in the cache */
   /* replace626_0_1 -> 551 in the cache */
   /* replace626_0_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 551, 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1900 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search627_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1902 },
      -1,
   } },

   /* replace627_0 -> 24 in the cache */
   /* replace627 -> 775 in the cache */

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search628_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1904 },
      -1,
   } },

   /* replace628 -> 24 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search629_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1906 },
      -1,
   } },

   /* replace629 -> 24 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search630_0_0 -> 24 in the cache */
   /* search630_0 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1904 },
      -1,
   } },

   /* replace630 -> 24 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search631_0_0 -> 24 in the cache */
   /* search631_0 -> 1906 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1906 },
      -1,
   } },

   /* replace631 -> 24 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search632_0_0_0 -> 776 in the cache */
   /* search632_0_0_1 -> 24 in the cache */
   /* search632_0_0 -> 1851 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1851 },
      -1,
   } },
   /* search632_1_0_0_0 -> 24 in the cache */
   /* search632_1_0_0_1 -> 776 in the cache */
   /* search632_1_0_0 -> 777 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 777 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1911 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1910, 1912 },
      -1,
   } },

   /* replace632_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search633_0_0_0 -> 946 in the cache */
   /* search633_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 946, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1915 },
      -1,
   } },
   /* search633_1_0_0_0 -> 24 in the cache */
   /* search633_1_0_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 24, 946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1917 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1918 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1916, 1919 },
      -1,
   } },

   /* replace633_0_0 -> 24 in the cache */
   /* replace633_0 -> 1914 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1914 },
      -1,
   } },

   /* ('~f2f16', ('f2f', 'a')) => ('f2f16', 'a') */
   /* search634_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace634_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2f16', ('u2f', 'a')) => ('u2f16', 'a') */
   /* search635_0_0 -> 9 in the cache */
   /* search635_0 -> 123 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 123 },
      -1,
   } },

   /* replace635_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2f16', ('i2f', 'a')) => ('i2f16', 'a') */
   /* search636_0_0 -> 9 in the cache */
   /* search636_0 -> 1362 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1362 },
      -1,
   } },

   /* replace636_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2u16', ('f2f', 'a')) => ('f2u16', 'a') */
   /* search637_0_0 -> 9 in the cache */
   /* search637_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace637_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2i16', ('f2f', 'a')) => ('f2i16', 'a') */
   /* search638_0_0 -> 9 in the cache */
   /* search638_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace638_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('i2f16', ('f2i', ('fsign', 'a@16'))) => ('fsign', 'a') */
   /* search639_0_0_0 -> 24 in the cache */
   /* search639_0_0 -> 1914 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1914 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1933 },
      -1,
   } },

   /* replace639_0 -> 24 in the cache */
   /* replace639 -> 1914 in the cache */

   /* ('~f2f16', ('f2f32', 'a@16')) => a */
   /* search640_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace640 -> 24 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search641_0_0 -> 24 in the cache */
   /* search641_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace641_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search642_0_0 -> 24 in the cache */
   /* search642_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace642_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search643_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1941 },
      -1,
   } },

   /* replace643_0 -> 9 in the cache */
   /* replace643 -> 1926 in the cache */

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search644_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1943 },
      -1,
   } },

   /* replace644_0 -> 9 in the cache */
   /* replace644 -> 1928 in the cache */

   /* ('~f2f16', ('f2f64', 'a@16')) => a */
   /* search645_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace645 -> 24 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search646_0_0 -> 24 in the cache */
   /* search646_0 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace646_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search647_0_0 -> 24 in the cache */
   /* search647_0 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace647_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search648_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1951 },
      -1,
   } },

   /* replace648_0 -> 9 in the cache */
   /* replace648 -> 1926 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search649_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1953 },
      -1,
   } },

   /* replace649_0 -> 9 in the cache */
   /* replace649 -> 1928 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search650_0_0 -> 241 in the cache */
   /* search650_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 241, 29 },
      0,
   } },
   /* search650_1_0 -> 48 in the cache */
   /* search650_1_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 48, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1955, 1956 },
      -1,
   } },

   /* replace650_0 -> 241 in the cache */
   /* replace650_1_0 -> 29 in the cache */
   /* replace650_1_1_0 -> 48 in the cache */
   /* replace650_1_1 -> 687 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 29, 687 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 241, 1958 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search651_0_0 -> 241 in the cache */
   /* search651_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 241, 29 },
      -1,
   } },
   /* search651_1_0 -> 48 in the cache */
   /* search651_1_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 48, 241 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1960, 1961 },
      -1,
   } },

   /* replace651_0 -> 241 in the cache */
   /* replace651_1_0 -> 29 in the cache */
   /* replace651_1_1_0 -> 48 in the cache */
   /* replace651_1_1 -> 687 in the cache */
   /* replace651_1 -> 1958 in the cache */
   /* replace651 -> 1959 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search652_0_0 -> 241 in the cache */
   /* search652_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 241, 29 },
      0,
   } },
   /* search652_1_0 -> 48 in the cache */
   /* search652_1_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 48, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1963, 1964 },
      -1,
   } },

   /* replace652_0 -> 241 in the cache */
   /* replace652_1_0 -> 29 in the cache */
   /* replace652_1_1_0 -> 48 in the cache */
   /* replace652_1_1 -> 687 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 29, 687 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 241, 1966 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search653_0_0 -> 241 in the cache */
   /* search653_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 241, 29 },
      -1,
   } },
   /* search653_1_0 -> 48 in the cache */
   /* search653_1_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 48, 241 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1968, 1969 },
      -1,
   } },

   /* replace653_0 -> 241 in the cache */
   /* replace653_1_0 -> 29 in the cache */
   /* replace653_1_1_0 -> 48 in the cache */
   /* replace653_1_1 -> 687 in the cache */
   /* replace653_1 -> 1966 in the cache */
   /* replace653 -> 1967 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search654_0_0 -> 241 in the cache */
   /* search654_0_1 -> 29 in the cache */
   /* search654_0 -> 1955 in the cache */
   /* search654_1_0 -> 48 in the cache */
   /* search654_1_1 -> 241 in the cache */
   /* search654_1 -> 1956 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1955, 1956 },
      -1,
   } },

   /* replace654_0 -> 241 in the cache */
   /* replace654_1_0 -> 29 in the cache */
   /* replace654_1_1_0 -> 48 in the cache */
   /* replace654_1_1 -> 687 in the cache */
   /* replace654_1 -> 1966 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 241, 1966 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search655_0_0 -> 241 in the cache */
   /* search655_0_1 -> 29 in the cache */
   /* search655_0 -> 1960 in the cache */
   /* search655_1_0 -> 48 in the cache */
   /* search655_1_1 -> 241 in the cache */
   /* search655_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1960, 1961 },
      -1,
   } },

   /* replace655_0 -> 241 in the cache */
   /* replace655_1_0 -> 29 in the cache */
   /* replace655_1_1_0 -> 48 in the cache */
   /* replace655_1_1 -> 687 in the cache */
   /* replace655_1 -> 1966 in the cache */
   /* replace655 -> 1972 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search656_0_0 -> 241 in the cache */
   /* search656_0_1 -> 29 in the cache */
   /* search656_0 -> 1963 in the cache */
   /* search656_1_0 -> 48 in the cache */
   /* search656_1_1 -> 241 in the cache */
   /* search656_1 -> 1964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1963, 1964 },
      -1,
   } },

   /* replace656_0 -> 241 in the cache */
   /* replace656_1_0 -> 29 in the cache */
   /* replace656_1_1_0 -> 48 in the cache */
   /* replace656_1_1 -> 687 in the cache */
   /* replace656_1 -> 1958 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 241, 1958 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search657_0_0 -> 241 in the cache */
   /* search657_0_1 -> 29 in the cache */
   /* search657_0 -> 1968 in the cache */
   /* search657_1_0 -> 48 in the cache */
   /* search657_1_1 -> 241 in the cache */
   /* search657_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1968, 1969 },
      -1,
   } },

   /* replace657_0 -> 241 in the cache */
   /* replace657_1_0 -> 29 in the cache */
   /* replace657_1_1_0 -> 48 in the cache */
   /* replace657_1_1 -> 687 in the cache */
   /* replace657_1 -> 1958 in the cache */
   /* replace657 -> 1975 in the cache */

   /* ('ior', ('feq(is_used_once)', 'a@32', 0.0), ('feq', 'b@32', 0.0)) => ('feq', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search658_0_0 -> 29 in the cache */
   /* search658_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 29, 241 },
      0,
   } },
   /* search658_1_0 -> 48 in the cache */
   /* search658_1_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 48, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1977, 1978 },
      -1,
   } },

   /* replace658_0_0_0 -> 29 in the cache */
   /* replace658_0_0 -> 423 in the cache */
   /* replace658_0_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 423, 1980 },
      -1,
   } },
   /* replace658_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1981, 241 },
      -1,
   } },

   /* ('ior', ('fneu(is_used_once)', 'a@32', 0.0), ('fneu', 'b@32', 0.0)) => ('fneu', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search659_0_0 -> 29 in the cache */
   /* search659_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 29, 241 },
      0,
   } },
   /* search659_1_0 -> 48 in the cache */
   /* search659_1_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 48, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1983, 1984 },
      -1,
   } },

   /* replace659_0_0_0 -> 29 in the cache */
   /* replace659_0_0 -> 423 in the cache */
   /* replace659_0_1_0 -> 48 in the cache */
   /* replace659_0_1 -> 1980 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 423, 1980 },
      -1,
   } },
   /* replace659_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1986, 241 },
      -1,
   } },

   /* ('iand', ('feq(is_used_once)', 'a@32', 0.0), ('feq', 'b@32', 0.0)) => ('feq', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search660_0_0 -> 29 in the cache */
   /* search660_0_1 -> 241 in the cache */
   /* search660_0 -> 1977 in the cache */
   /* search660_1_0 -> 48 in the cache */
   /* search660_1_1 -> 241 in the cache */
   /* search660_1 -> 1978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1977, 1978 },
      -1,
   } },

   /* replace660_0_0_0 -> 29 in the cache */
   /* replace660_0_0 -> 423 in the cache */
   /* replace660_0_1_0 -> 48 in the cache */
   /* replace660_0_1 -> 1980 in the cache */
   /* replace660_0 -> 1986 in the cache */
   /* replace660_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1986, 241 },
      -1,
   } },

   /* ('iand', ('fneu(is_used_once)', 'a@32', 0.0), ('fneu', 'b@32', 0.0)) => ('fneu', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search661_0_0 -> 29 in the cache */
   /* search661_0_1 -> 241 in the cache */
   /* search661_0 -> 1983 in the cache */
   /* search661_1_0 -> 48 in the cache */
   /* search661_1_1 -> 241 in the cache */
   /* search661_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1983, 1984 },
      -1,
   } },

   /* replace661_0_0_0 -> 29 in the cache */
   /* replace661_0_0 -> 423 in the cache */
   /* replace661_0_1_0 -> 48 in the cache */
   /* replace661_0_1 -> 1980 in the cache */
   /* replace661_0 -> 1981 in the cache */
   /* replace661_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1981, 241 },
      -1,
   } },

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search662_0_0 -> 29 in the cache */
   /* search662_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 29, 241 },
      -1,
   } },
   /* search662_1 -> 261 in the cache */
   /* search662_2_0_0_0_0 -> 241 in the cache */
   /* search662_2_0_0_0_1 -> 29 in the cache */
   /* search662_2_0_0_0 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1960 },
      -1,
   } },
   /* search662_2_0_1_0_0_0 -> 29 in the cache */
   /* search662_2_0_1_0_0_1 -> 241 in the cache */
   /* search662_2_0_1_0_0 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 783 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1994 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1993, 1995 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1996 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1992, 261, 1997 },
      -1,
   } },

   /* replace662_0_0_0_0 -> 29 in the cache */
   /* replace662_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 29, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1999 },
      -1,
   } },
   /* replace662_0_1_0_0_0 -> 29 in the cache */
   /* replace662_0_1_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 29, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 2001 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2002 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 2000, 2003 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 2004 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search663_0 -> 847 in the cache */
   /* search663_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 48 },
      0,
   } },
   /* search663_2_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 2006, 2007 },
      -1,
   } },

   /* replace663_0_0 -> 847 in the cache */
   /* replace663_0_1 -> 48 in the cache */
   /* replace663_0_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 48, 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 2009 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search664_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2011 },
      -1,
   } },

   /* replace664_0 -> 29 in the cache */
   /* replace664 -> 782 in the cache */

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search665_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 2013 },
      -1,
   } },

   /* replace665 -> 29 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search666_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 2015 },
      -1,
   } },

   /* replace666 -> 29 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search667_0_0 -> 29 in the cache */
   /* search667_0 -> 2013 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 2013 },
      -1,
   } },

   /* replace667 -> 29 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search668_0_0 -> 29 in the cache */
   /* search668_0 -> 2015 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 2015 },
      -1,
   } },

   /* replace668 -> 29 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search669_0_0_0 -> 241 in the cache */
   /* search669_0_0_1 -> 29 in the cache */
   /* search669_0_0 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1960 },
      -1,
   } },
   /* search669_1_0_0_0 -> 29 in the cache */
   /* search669_1_0_0_1 -> 241 in the cache */
   /* search669_1_0_0 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 783 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 2019, 2021 },
      -1,
   } },

   /* replace669_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search670_0_0_0 -> 135 in the cache */
   /* search670_0_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 135, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 2024 },
      -1,
   } },
   /* search670_1_0_0_0 -> 29 in the cache */
   /* search670_1_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 2026 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2027 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 2025, 2028 },
      -1,
   } },

   /* replace670_0_0 -> 29 in the cache */
   /* replace670_0 -> 2023 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 2023 },
      -1,
   } },

   /* ('~f2f32', ('f2f', 'a')) => ('f2f32', 'a') */
   /* search671_0_0 -> 9 in the cache */
   /* search671_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace671_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2f32', ('u2f', 'a')) => ('u2f32', 'a') */
   /* search672_0_0 -> 9 in the cache */
   /* search672_0 -> 123 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 123 },
      -1,
   } },

   /* replace672_0 -> 9 in the cache */
   /* replace672 -> 1941 in the cache */

   /* ('~f2f32', ('i2f', 'a')) => ('i2f32', 'a') */
   /* search673_0_0 -> 9 in the cache */
   /* search673_0 -> 1362 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1362 },
      -1,
   } },

   /* replace673_0 -> 9 in the cache */
   /* replace673 -> 1943 in the cache */

   /* ('~f2u32', ('f2f', 'a')) => ('f2u32', 'a') */
   /* search674_0_0 -> 9 in the cache */
   /* search674_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace674_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2i32', ('f2f', 'a')) => ('f2i32', 'a') */
   /* search675_0_0 -> 9 in the cache */
   /* search675_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace675_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('i2f32', ('f2i', ('fsign', 'a@32'))) => ('fsign', 'a') */
   /* search676_0_0_0 -> 29 in the cache */
   /* search676_0_0 -> 2023 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 2023 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2039 },
      -1,
   } },

   /* replace676_0 -> 29 in the cache */
   /* replace676 -> 2023 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search677_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2041 },
      -1,
   } },

   /* replace677 -> 29 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search678_0_0 -> 29 in the cache */
   /* search678_0 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 2041 },
      -1,
   } },

   /* replace678_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search679_0_0 -> 29 in the cache */
   /* search679_0 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 2041 },
      -1,
   } },

   /* replace679_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search680_0_0 -> 9 in the cache */
   /* search680_0 -> 1951 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1951 },
      -1,
   } },

   /* replace680_0 -> 9 in the cache */
   /* replace680 -> 1941 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search681_0_0 -> 9 in the cache */
   /* search681_0 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1953 },
      -1,
   } },

   /* replace681_0 -> 9 in the cache */
   /* replace681 -> 1943 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search682_0_0 -> 788 in the cache */
   /* search682_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 788, 34 },
      0,
   } },
   /* search682_1_0 -> 53 in the cache */
   /* search682_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 53, 788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2049, 2050 },
      -1,
   } },

   /* replace682_0 -> 788 in the cache */
   /* replace682_1_0 -> 34 in the cache */
   /* replace682_1_1_0 -> 53 in the cache */
   /* replace682_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 34, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 788, 2052 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search683_0_0 -> 788 in the cache */
   /* search683_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 788, 34 },
      -1,
   } },
   /* search683_1_0 -> 53 in the cache */
   /* search683_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 53, 788 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2054, 2055 },
      -1,
   } },

   /* replace683_0 -> 788 in the cache */
   /* replace683_1_0 -> 34 in the cache */
   /* replace683_1_1_0 -> 53 in the cache */
   /* replace683_1_1 -> 760 in the cache */
   /* replace683_1 -> 2052 in the cache */
   /* replace683 -> 2053 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search684_0_0 -> 788 in the cache */
   /* search684_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 788, 34 },
      0,
   } },
   /* search684_1_0 -> 53 in the cache */
   /* search684_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 53, 788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2057, 2058 },
      -1,
   } },

   /* replace684_0 -> 788 in the cache */
   /* replace684_1_0 -> 34 in the cache */
   /* replace684_1_1_0 -> 53 in the cache */
   /* replace684_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 34, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 788, 2060 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search685_0_0 -> 788 in the cache */
   /* search685_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 788, 34 },
      -1,
   } },
   /* search685_1_0 -> 53 in the cache */
   /* search685_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 53, 788 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2062, 2063 },
      -1,
   } },

   /* replace685_0 -> 788 in the cache */
   /* replace685_1_0 -> 34 in the cache */
   /* replace685_1_1_0 -> 53 in the cache */
   /* replace685_1_1 -> 760 in the cache */
   /* replace685_1 -> 2060 in the cache */
   /* replace685 -> 2061 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search686_0_0 -> 788 in the cache */
   /* search686_0_1 -> 34 in the cache */
   /* search686_0 -> 2049 in the cache */
   /* search686_1_0 -> 53 in the cache */
   /* search686_1_1 -> 788 in the cache */
   /* search686_1 -> 2050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2049, 2050 },
      -1,
   } },

   /* replace686_0 -> 788 in the cache */
   /* replace686_1_0 -> 34 in the cache */
   /* replace686_1_1_0 -> 53 in the cache */
   /* replace686_1_1 -> 760 in the cache */
   /* replace686_1 -> 2060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 788, 2060 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search687_0_0 -> 788 in the cache */
   /* search687_0_1 -> 34 in the cache */
   /* search687_0 -> 2054 in the cache */
   /* search687_1_0 -> 53 in the cache */
   /* search687_1_1 -> 788 in the cache */
   /* search687_1 -> 2055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2054, 2055 },
      -1,
   } },

   /* replace687_0 -> 788 in the cache */
   /* replace687_1_0 -> 34 in the cache */
   /* replace687_1_1_0 -> 53 in the cache */
   /* replace687_1_1 -> 760 in the cache */
   /* replace687_1 -> 2060 in the cache */
   /* replace687 -> 2066 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search688_0_0 -> 788 in the cache */
   /* search688_0_1 -> 34 in the cache */
   /* search688_0 -> 2057 in the cache */
   /* search688_1_0 -> 53 in the cache */
   /* search688_1_1 -> 788 in the cache */
   /* search688_1 -> 2058 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2057, 2058 },
      -1,
   } },

   /* replace688_0 -> 788 in the cache */
   /* replace688_1_0 -> 34 in the cache */
   /* replace688_1_1_0 -> 53 in the cache */
   /* replace688_1_1 -> 760 in the cache */
   /* replace688_1 -> 2052 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 788, 2052 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search689_0_0 -> 788 in the cache */
   /* search689_0_1 -> 34 in the cache */
   /* search689_0 -> 2062 in the cache */
   /* search689_1_0 -> 53 in the cache */
   /* search689_1_1 -> 788 in the cache */
   /* search689_1 -> 2063 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2062, 2063 },
      -1,
   } },

   /* replace689_0 -> 788 in the cache */
   /* replace689_1_0 -> 34 in the cache */
   /* replace689_1_1_0 -> 53 in the cache */
   /* replace689_1_1 -> 760 in the cache */
   /* replace689_1 -> 2052 in the cache */
   /* replace689 -> 2069 in the cache */

   /* ('ior', ('feq(is_used_once)', 'a@64', 0.0), ('feq', 'b@64', 0.0)) => ('feq', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search690_0_0 -> 34 in the cache */
   /* search690_0_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 34, 788 },
      0,
   } },
   /* search690_1_0 -> 53 in the cache */
   /* search690_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 53, 788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2071, 2072 },
      -1,
   } },

   /* replace690_0_0_0 -> 34 in the cache */
   /* replace690_0_0 -> 790 in the cache */
   /* replace690_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 790, 2074 },
      -1,
   } },
   /* replace690_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2075, 788 },
      -1,
   } },

   /* ('ior', ('fneu(is_used_once)', 'a@64', 0.0), ('fneu', 'b@64', 0.0)) => ('fneu', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search691_0_0 -> 34 in the cache */
   /* search691_0_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 34, 788 },
      0,
   } },
   /* search691_1_0 -> 53 in the cache */
   /* search691_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 53, 788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2077, 2078 },
      -1,
   } },

   /* replace691_0_0_0 -> 34 in the cache */
   /* replace691_0_0 -> 790 in the cache */
   /* replace691_0_1_0 -> 53 in the cache */
   /* replace691_0_1 -> 2074 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 790, 2074 },
      -1,
   } },
   /* replace691_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2080, 788 },
      -1,
   } },

   /* ('iand', ('feq(is_used_once)', 'a@64', 0.0), ('feq', 'b@64', 0.0)) => ('feq', ('fadd', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search692_0_0 -> 34 in the cache */
   /* search692_0_1 -> 788 in the cache */
   /* search692_0 -> 2071 in the cache */
   /* search692_1_0 -> 53 in the cache */
   /* search692_1_1 -> 788 in the cache */
   /* search692_1 -> 2072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2071, 2072 },
      -1,
   } },

   /* replace692_0_0_0 -> 34 in the cache */
   /* replace692_0_0 -> 790 in the cache */
   /* replace692_0_1_0 -> 53 in the cache */
   /* replace692_0_1 -> 2074 in the cache */
   /* replace692_0 -> 2080 in the cache */
   /* replace692_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2080, 788 },
      -1,
   } },

   /* ('iand', ('fneu(is_used_once)', 'a@64', 0.0), ('fneu', 'b@64', 0.0)) => ('fneu', ('fmin', ('fabs', 'a'), ('fabs', 'b')), 0.0) */
   /* search693_0_0 -> 34 in the cache */
   /* search693_0_1 -> 788 in the cache */
   /* search693_0 -> 2077 in the cache */
   /* search693_1_0 -> 53 in the cache */
   /* search693_1_1 -> 788 in the cache */
   /* search693_1 -> 2078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2077, 2078 },
      -1,
   } },

   /* replace693_0_0_0 -> 34 in the cache */
   /* replace693_0_0 -> 790 in the cache */
   /* replace693_0_1_0 -> 53 in the cache */
   /* replace693_0_1 -> 2074 in the cache */
   /* replace693_0 -> 2075 in the cache */
   /* replace693_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2075, 788 },
      -1,
   } },

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search694_0_0 -> 34 in the cache */
   /* search694_0_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 34, 788 },
      -1,
   } },
   /* search694_1 -> 709 in the cache */
   /* search694_2_0_0_0_0 -> 788 in the cache */
   /* search694_2_0_0_0_1 -> 34 in the cache */
   /* search694_2_0_0_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 2054 },
      -1,
   } },
   /* search694_2_0_1_0_0_0 -> 34 in the cache */
   /* search694_2_0_1_0_0_1 -> 788 in the cache */
   /* search694_2_0_1_0_0 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 789 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2088 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 2087, 2089 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 2090 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 2086, 709, 2091 },
      -1,
   } },

   /* replace694_0_0_0_0 -> 34 in the cache */
   /* replace694_0_0_0_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 34, 788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 2093 },
      -1,
   } },
   /* replace694_0_1_0_0_0 -> 34 in the cache */
   /* replace694_0_1_0_0_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 2095 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2096 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 2094, 2097 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 2098 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search695_0 -> 847 in the cache */
   /* search695_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 53 },
      0,
   } },
   /* search695_2_0 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 2100, 2101 },
      -1,
   } },

   /* replace695_0_0 -> 847 in the cache */
   /* replace695_0_1 -> 53 in the cache */
   /* replace695_0_2 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 53, 697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 2103 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search696_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2105 },
      -1,
   } },

   /* replace696_0 -> 34 in the cache */
   /* replace696 -> 787 in the cache */

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search697_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 2107 },
      -1,
   } },

   /* replace697 -> 34 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search698_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 2109 },
      -1,
   } },

   /* replace698 -> 34 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search699_0_0 -> 34 in the cache */
   /* search699_0 -> 2107 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 2107 },
      -1,
   } },

   /* replace699 -> 34 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search700_0_0 -> 34 in the cache */
   /* search700_0 -> 2109 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 2109 },
      -1,
   } },

   /* replace700 -> 34 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search701_0_0_0 -> 788 in the cache */
   /* search701_0_0_1 -> 34 in the cache */
   /* search701_0_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 2054 },
      -1,
   } },
   /* search701_1_0_0_0 -> 34 in the cache */
   /* search701_1_0_0_1 -> 788 in the cache */
   /* search701_1_0_0 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 789 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 2113, 2115 },
      -1,
   } },

   /* replace701_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 34 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search702_0_0_0 -> 987 in the cache */
   /* search702_0_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 987, 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 2118 },
      -1,
   } },
   /* search702_1_0_0_0 -> 34 in the cache */
   /* search702_1_0_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 2120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 2119, 2122 },
      -1,
   } },

   /* replace702_0_0 -> 34 in the cache */
   /* replace702_0 -> 2117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 2117 },
      -1,
   } },

   /* ('~f2f64', ('f2f', 'a')) => ('f2f64', 'a') */
   /* search703_0_0 -> 9 in the cache */
   /* search703_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace703_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2f64', ('u2f', 'a')) => ('u2f64', 'a') */
   /* search704_0_0 -> 9 in the cache */
   /* search704_0 -> 123 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 123 },
      -1,
   } },

   /* replace704_0 -> 9 in the cache */
   /* replace704 -> 1951 in the cache */

   /* ('~f2f64', ('i2f', 'a')) => ('i2f64', 'a') */
   /* search705_0_0 -> 9 in the cache */
   /* search705_0 -> 1362 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 1362 },
      -1,
   } },

   /* replace705_0 -> 9 in the cache */
   /* replace705 -> 1953 in the cache */

   /* ('~f2u64', ('f2f', 'a')) => ('f2u64', 'a') */
   /* search706_0_0 -> 9 in the cache */
   /* search706_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace706_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~f2i64', ('f2f', 'a')) => ('f2i64', 'a') */
   /* search707_0_0 -> 9 in the cache */
   /* search707_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace707_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('i2f64', ('f2i', ('fsign', 'a@64'))) => ('fsign', 'a') */
   /* search708_0_0_0 -> 34 in the cache */
   /* search708_0_0 -> 2117 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 2117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2133 },
      -1,
   } },

   /* replace708_0 -> 34 in the cache */
   /* replace708 -> 2117 in the cache */

   /* ('i2i1', ('i2i8', 'a@1')) => a */
   /* search709_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace709 -> 847 in the cache */

   /* ('u2u1', ('u2u8', 'a@1')) => a */
   /* search710_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace710 -> 847 in the cache */

   /* ('i2i1', ('i2i16', 'a@1')) => a */
   /* search711_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace711 -> 847 in the cache */

   /* ('u2u1', ('u2u16', 'a@1')) => a */
   /* search712_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace712 -> 847 in the cache */

   /* ('u2f16', ('u2u8', 'a@1')) => ('u2f16', 'a') */
   /* search713_0_0 -> 847 in the cache */
   /* search713_0 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace713_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('i2f16', ('i2i8', 'a@1')) => ('i2f16', 'a') */
   /* search714_0_0 -> 847 in the cache */
   /* search714_0 -> 2135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace714_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('u2f16', ('u2u16', 'a@1')) => ('u2f16', 'a') */
   /* search715_0_0 -> 847 in the cache */
   /* search715_0 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace715_0 -> 847 in the cache */
   /* replace715 -> 2144 in the cache */

   /* ('i2f16', ('i2i16', 'a@1')) => ('i2f16', 'a') */
   /* search716_0_0 -> 847 in the cache */
   /* search716_0 -> 2139 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace716_0 -> 847 in the cache */
   /* replace716 -> 2146 in the cache */

   /* ('u2f16', ('u2u32', 'a@1')) => ('u2f16', 'a') */
   /* search717_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2149 },
      -1,
   } },

   /* replace717_0 -> 847 in the cache */
   /* replace717 -> 2144 in the cache */

   /* ('i2f16', ('i2i32', 'a@1')) => ('i2f16', 'a') */
   /* search718_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2151 },
      -1,
   } },

   /* replace718_0 -> 847 in the cache */
   /* replace718 -> 2146 in the cache */

   /* ('u2f16', ('u2u64', 'a@1')) => ('u2f16', 'a') */
   /* search719_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2153 },
      -1,
   } },

   /* replace719_0 -> 847 in the cache */
   /* replace719 -> 2144 in the cache */

   /* ('i2f16', ('i2i64', 'a@1')) => ('i2f16', 'a') */
   /* search720_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2155 },
      -1,
   } },

   /* replace720_0 -> 847 in the cache */
   /* replace720 -> 2146 in the cache */

   /* ('i2i1', ('i2i32', 'a@1')) => a */
   /* search721_0_0 -> 847 in the cache */
   /* search721_0 -> 2151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 2151 },
      -1,
   } },

   /* replace721 -> 847 in the cache */

   /* ('u2u1', ('u2u32', 'a@1')) => a */
   /* search722_0_0 -> 847 in the cache */
   /* search722_0 -> 2149 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 2149 },
      -1,
   } },

   /* replace722 -> 847 in the cache */

   /* ('u2f32', ('u2u8', 'a@1')) => ('u2f32', 'a') */
   /* search723_0_0 -> 847 in the cache */
   /* search723_0 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace723_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('i2f32', ('i2i8', 'a@1')) => ('i2f32', 'a') */
   /* search724_0_0 -> 847 in the cache */
   /* search724_0 -> 2135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace724_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('u2f32', ('u2u16', 'a@1')) => ('u2f32', 'a') */
   /* search725_0_0 -> 847 in the cache */
   /* search725_0 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace725_0 -> 847 in the cache */
   /* replace725 -> 2160 in the cache */

   /* ('i2f32', ('i2i16', 'a@1')) => ('i2f32', 'a') */
   /* search726_0_0 -> 847 in the cache */
   /* search726_0 -> 2139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace726_0 -> 847 in the cache */
   /* replace726 -> 2162 in the cache */

   /* ('u2f32', ('u2u32', 'a@1')) => ('u2f32', 'a') */
   /* search727_0_0 -> 847 in the cache */
   /* search727_0 -> 2149 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2149 },
      -1,
   } },

   /* replace727_0 -> 847 in the cache */
   /* replace727 -> 2160 in the cache */

   /* ('i2f32', ('i2i32', 'a@1')) => ('i2f32', 'a') */
   /* search728_0_0 -> 847 in the cache */
   /* search728_0 -> 2151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2151 },
      -1,
   } },

   /* replace728_0 -> 847 in the cache */
   /* replace728 -> 2162 in the cache */

   /* ('u2f32', ('u2u64', 'a@1')) => ('u2f32', 'a') */
   /* search729_0_0 -> 847 in the cache */
   /* search729_0 -> 2153 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2153 },
      -1,
   } },

   /* replace729_0 -> 847 in the cache */
   /* replace729 -> 2160 in the cache */

   /* ('i2f32', ('i2i64', 'a@1')) => ('i2f32', 'a') */
   /* search730_0_0 -> 847 in the cache */
   /* search730_0 -> 2155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2155 },
      -1,
   } },

   /* replace730_0 -> 847 in the cache */
   /* replace730 -> 2162 in the cache */

   /* ('i2i1', ('i2i64', 'a@1')) => a */
   /* search731_0_0 -> 847 in the cache */
   /* search731_0 -> 2155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 2155 },
      -1,
   } },

   /* replace731 -> 847 in the cache */

   /* ('u2u1', ('u2u64', 'a@1')) => a */
   /* search732_0_0 -> 847 in the cache */
   /* search732_0 -> 2153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 2153 },
      -1,
   } },

   /* replace732 -> 847 in the cache */

   /* ('u2f64', ('u2u8', 'a@1')) => ('u2f64', 'a') */
   /* search733_0_0 -> 847 in the cache */
   /* search733_0 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace733_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('i2f64', ('i2i8', 'a@1')) => ('i2f64', 'a') */
   /* search734_0_0 -> 847 in the cache */
   /* search734_0 -> 2135 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace734_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('u2f64', ('u2u16', 'a@1')) => ('u2f64', 'a') */
   /* search735_0_0 -> 847 in the cache */
   /* search735_0 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace735_0 -> 847 in the cache */
   /* replace735 -> 2172 in the cache */

   /* ('i2f64', ('i2i16', 'a@1')) => ('i2f64', 'a') */
   /* search736_0_0 -> 847 in the cache */
   /* search736_0 -> 2139 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace736_0 -> 847 in the cache */
   /* replace736 -> 2174 in the cache */

   /* ('u2f64', ('u2u32', 'a@1')) => ('u2f64', 'a') */
   /* search737_0_0 -> 847 in the cache */
   /* search737_0 -> 2149 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2149 },
      -1,
   } },

   /* replace737_0 -> 847 in the cache */
   /* replace737 -> 2172 in the cache */

   /* ('i2f64', ('i2i32', 'a@1')) => ('i2f64', 'a') */
   /* search738_0_0 -> 847 in the cache */
   /* search738_0 -> 2151 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2151 },
      -1,
   } },

   /* replace738_0 -> 847 in the cache */
   /* replace738 -> 2174 in the cache */

   /* ('u2f64', ('u2u64', 'a@1')) => ('u2f64', 'a') */
   /* search739_0_0 -> 847 in the cache */
   /* search739_0 -> 2153 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2153 },
      -1,
   } },

   /* replace739_0 -> 847 in the cache */
   /* replace739 -> 2172 in the cache */

   /* ('i2f64', ('i2i64', 'a@1')) => ('i2f64', 'a') */
   /* search740_0_0 -> 847 in the cache */
   /* search740_0 -> 2155 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2155 },
      -1,
   } },

   /* replace740_0 -> 847 in the cache */
   /* replace740 -> 2174 in the cache */

   /* ('i2i8', ('i2i16', 'a@8')) => a */
   /* search741_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2181 },
      -1,
   } },

   /* replace741 -> 19 in the cache */

   /* ('u2u8', ('u2u16', 'a@8')) => a */
   /* search742_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2183 },
      -1,
   } },

   /* replace742 -> 19 in the cache */

   /* ('u2f16', ('u2u16', 'a@8')) => ('u2f16', 'a') */
   /* search743_0_0 -> 19 in the cache */
   /* search743_0 -> 2183 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2183 },
      -1,
   } },

   /* replace743_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('i2f16', ('i2i16', 'a@8')) => ('i2f16', 'a') */
   /* search744_0_0 -> 19 in the cache */
   /* search744_0 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2181 },
      -1,
   } },

   /* replace744_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('u2f16', ('u2u32', 'a@8')) => ('u2f16', 'a') */
   /* search745_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2189 },
      -1,
   } },

   /* replace745_0 -> 19 in the cache */
   /* replace745 -> 2186 in the cache */

   /* ('i2f16', ('i2i32', 'a@8')) => ('i2f16', 'a') */
   /* search746_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2191 },
      -1,
   } },

   /* replace746_0 -> 19 in the cache */
   /* replace746 -> 2188 in the cache */

   /* ('u2f16', ('u2u64', 'a@8')) => ('u2f16', 'a') */
   /* search747_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2193 },
      -1,
   } },

   /* replace747_0 -> 19 in the cache */
   /* replace747 -> 2186 in the cache */

   /* ('i2f16', ('i2i64', 'a@8')) => ('i2f16', 'a') */
   /* search748_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2195 },
      -1,
   } },

   /* replace748_0 -> 19 in the cache */
   /* replace748 -> 2188 in the cache */

   /* ('i2i8', ('i2i32', 'a@8')) => a */
   /* search749_0_0 -> 19 in the cache */
   /* search749_0 -> 2191 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2191 },
      -1,
   } },

   /* replace749 -> 19 in the cache */

   /* ('u2u8', ('u2u32', 'a@8')) => a */
   /* search750_0_0 -> 19 in the cache */
   /* search750_0 -> 2189 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2189 },
      -1,
   } },

   /* replace750 -> 19 in the cache */

   /* ('u2f32', ('u2u16', 'a@8')) => ('u2f32', 'a') */
   /* search751_0_0 -> 19 in the cache */
   /* search751_0 -> 2183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2183 },
      -1,
   } },

   /* replace751_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('i2f32', ('i2i16', 'a@8')) => ('i2f32', 'a') */
   /* search752_0_0 -> 19 in the cache */
   /* search752_0 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2181 },
      -1,
   } },

   /* replace752_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@8')) => ('u2f32', 'a') */
   /* search753_0_0 -> 19 in the cache */
   /* search753_0 -> 2189 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2189 },
      -1,
   } },

   /* replace753_0 -> 19 in the cache */
   /* replace753 -> 2200 in the cache */

   /* ('i2f32', ('i2i32', 'a@8')) => ('i2f32', 'a') */
   /* search754_0_0 -> 19 in the cache */
   /* search754_0 -> 2191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2191 },
      -1,
   } },

   /* replace754_0 -> 19 in the cache */
   /* replace754 -> 2202 in the cache */

   /* ('u2f32', ('u2u64', 'a@8')) => ('u2f32', 'a') */
   /* search755_0_0 -> 19 in the cache */
   /* search755_0 -> 2193 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2193 },
      -1,
   } },

   /* replace755_0 -> 19 in the cache */
   /* replace755 -> 2200 in the cache */

   /* ('i2f32', ('i2i64', 'a@8')) => ('i2f32', 'a') */
   /* search756_0_0 -> 19 in the cache */
   /* search756_0 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2195 },
      -1,
   } },

   /* replace756_0 -> 19 in the cache */
   /* replace756 -> 2202 in the cache */

   /* ('i2i8', ('i2i64', 'a@8')) => a */
   /* search757_0_0 -> 19 in the cache */
   /* search757_0 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2195 },
      -1,
   } },

   /* replace757 -> 19 in the cache */

   /* ('u2u8', ('u2u64', 'a@8')) => a */
   /* search758_0_0 -> 19 in the cache */
   /* search758_0 -> 2193 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2193 },
      -1,
   } },

   /* replace758 -> 19 in the cache */

   /* ('u2f64', ('u2u16', 'a@8')) => ('u2f64', 'a') */
   /* search759_0_0 -> 19 in the cache */
   /* search759_0 -> 2183 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2183 },
      -1,
   } },

   /* replace759_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('i2f64', ('i2i16', 'a@8')) => ('i2f64', 'a') */
   /* search760_0_0 -> 19 in the cache */
   /* search760_0 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2181 },
      -1,
   } },

   /* replace760_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('u2f64', ('u2u32', 'a@8')) => ('u2f64', 'a') */
   /* search761_0_0 -> 19 in the cache */
   /* search761_0 -> 2189 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2189 },
      -1,
   } },

   /* replace761_0 -> 19 in the cache */
   /* replace761 -> 2210 in the cache */

   /* ('i2f64', ('i2i32', 'a@8')) => ('i2f64', 'a') */
   /* search762_0_0 -> 19 in the cache */
   /* search762_0 -> 2191 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2191 },
      -1,
   } },

   /* replace762_0 -> 19 in the cache */
   /* replace762 -> 2212 in the cache */

   /* ('u2f64', ('u2u64', 'a@8')) => ('u2f64', 'a') */
   /* search763_0_0 -> 19 in the cache */
   /* search763_0 -> 2193 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2193 },
      -1,
   } },

   /* replace763_0 -> 19 in the cache */
   /* replace763 -> 2210 in the cache */

   /* ('i2f64', ('i2i64', 'a@8')) => ('i2f64', 'a') */
   /* search764_0_0 -> 19 in the cache */
   /* search764_0 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2195 },
      -1,
   } },

   /* replace764_0 -> 19 in the cache */
   /* replace764 -> 2212 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search765_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2217 },
      -1,
   } },

   /* replace765 -> 24 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search766_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* replace766 -> 24 in the cache */

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search767_0_0 -> 24 in the cache */
   /* search767_0 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* replace767_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search768_0_0 -> 24 in the cache */
   /* search768_0 -> 2217 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2217 },
      -1,
   } },

   /* replace768_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('u2f32', ('u2u64', 'a@16')) => ('u2f32', 'a') */
   /* search769_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 2225 },
      -1,
   } },

   /* replace769_0 -> 24 in the cache */
   /* replace769 -> 2222 in the cache */

   /* ('i2f32', ('i2i64', 'a@16')) => ('i2f32', 'a') */
   /* search770_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2227 },
      -1,
   } },

   /* replace770_0 -> 24 in the cache */
   /* replace770 -> 2224 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search771_0_0 -> 24 in the cache */
   /* search771_0 -> 2227 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2227 },
      -1,
   } },

   /* replace771 -> 24 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search772_0_0 -> 24 in the cache */
   /* search772_0 -> 2225 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2225 },
      -1,
   } },

   /* replace772 -> 24 in the cache */

   /* ('u2f64', ('u2u32', 'a@16')) => ('u2f64', 'a') */
   /* search773_0_0 -> 24 in the cache */
   /* search773_0 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* replace773_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('i2f64', ('i2i32', 'a@16')) => ('i2f64', 'a') */
   /* search774_0_0 -> 24 in the cache */
   /* search774_0 -> 2217 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2217 },
      -1,
   } },

   /* replace774_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search775_0_0 -> 24 in the cache */
   /* search775_0 -> 2225 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2225 },
      -1,
   } },

   /* replace775_0 -> 24 in the cache */
   /* replace775 -> 2232 in the cache */

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search776_0_0 -> 24 in the cache */
   /* search776_0 -> 2227 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2227 },
      -1,
   } },

   /* replace776_0 -> 24 in the cache */
   /* replace776 -> 2234 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search777_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2237 },
      -1,
   } },

   /* replace777 -> 29 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search778_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2239 },
      -1,
   } },

   /* replace778 -> 29 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search779_0_0 -> 29 in the cache */
   /* search779_0 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 2239 },
      -1,
   } },

   /* replace779_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search780_0_0 -> 29 in the cache */
   /* search780_0 -> 2237 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 2237 },
      -1,
   } },

   /* replace780_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search781_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2245 },
      -1,
   } },

   /* replace781_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search782_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2248 },
      -1,
   } },

   /* replace782_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search783_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 2251 },
      -1,
   } },

   /* replace783_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search784_0_0 -> 29 in the cache */
   /* search784_0 -> 2251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 2251 },
      -1,
   } },

   /* replace784_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search785_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2256 },
      -1,
   } },

   /* replace785_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search786_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2259 },
      -1,
   } },

   /* replace786_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search787_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2262 },
      -1,
   } },

   /* replace787_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search788_0_0 -> 29 in the cache */
   /* search788_0 -> 2262 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2262 },
      -1,
   } },

   /* replace788_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search789_0_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2267 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2268, 2269 },
      -1,
   } },

   /* replace789_0 -> 24 in the cache */
   /* replace789_1_0 -> 551 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffull /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 551, 2271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 24, 2272 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search790_0_0_0 -> 24 in the cache */
   /* search790_0_0_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 2269 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2274 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 2275 },
      -1,
   } },

   /* replace790_0 -> 24 in the cache */
   /* replace790_1_0 -> 551 in the cache */
   /* replace790_1_1 -> 2271 in the cache */
   /* replace790_1 -> 2272 in the cache */
   /* replace790 -> 2273 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search791_0_0_0_0 -> 24 in the cache */
   /* search791_0_0_0 -> 2267 in the cache */
   /* search791_0_0 -> 2268 in the cache */
   /* search791_0_1_0_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2277 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2268, 2278 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2279 },
      -1,
   } },

   /* replace791_0_0 -> 24 in the cache */
   /* replace791_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2281 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search792_0_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2283 },
      -1,
   } },
   /* search792_0_1_0_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2284, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2287 },
      -1,
   } },

   /* replace792_0_0 -> 29 in the cache */
   /* replace792_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2289 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search793_0_0 -> 0 in the cache */
   /* search793_0_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 911 },
      -1,
   } },
   /* search793_1_0 -> 153 in the cache */
   /* search793_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 153, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2291, 2292 },
      -1,
   } },

   /* replace793_0_0 -> 0 in the cache */
   /* replace793_0_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 153 },
      -1,
   } },
   /* replace793_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2294, 1 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search794_0_0 -> 0 in the cache */
   /* search794_0_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 911 },
      -1,
   } },
   /* search794_1_0 -> 153 in the cache */
   /* search794_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 153, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2296, 2297 },
      -1,
   } },

   /* replace794_0_0 -> 0 in the cache */
   /* replace794_0_1 -> 153 in the cache */
   /* replace794_0 -> 2294 in the cache */
   /* replace794_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2294, 1 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search795_0_0 -> 0 in the cache */
   /* search795_0_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 911 },
      -1,
   } },
   /* search795_1_0 -> 153 in the cache */
   /* search795_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 153, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2300, 2301 },
      -1,
   } },

   /* replace795_0_0 -> 0 in the cache */
   /* replace795_0_1 -> 153 in the cache */
   /* replace795_0 -> 2294 in the cache */
   /* replace795_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2294, 1 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search796_0_0 -> 0 in the cache */
   /* search796_0_1 -> 911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 911 },
      -1,
   } },
   /* search796_1_0 -> 153 in the cache */
   /* search796_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 153, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2304, 2305 },
      -1,
   } },

   /* replace796_0_0 -> 0 in the cache */
   /* replace796_0_1 -> 153 in the cache */
   /* replace796_0 -> 2294 in the cache */
   /* replace796_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2294, 1 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search797_0_0 -> 139 in the cache */
   /* search797_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 139, 45 },
      0,
   } },
   /* search797_1_0 -> 142 in the cache */
   /* search797_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 142, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2308, 2309 },
      -1,
   } },

   /* replace797_0_0 -> 139 in the cache */
   /* replace797_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 139, 142 },
      -1,
   } },
   /* replace797_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2311, 48 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search798_0_0 -> 139 in the cache */
   /* search798_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 139, 45 },
      0,
   } },
   /* search798_1_0 -> 142 in the cache */
   /* search798_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 142, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2313, 2314 },
      -1,
   } },

   /* replace798_0_0 -> 139 in the cache */
   /* replace798_0_1 -> 142 in the cache */
   /* replace798_0 -> 2311 in the cache */
   /* replace798_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2311, 48 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search799_0_0 -> 139 in the cache */
   /* search799_0_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 139, 45 },
      0,
   } },
   /* search799_1_0 -> 142 in the cache */
   /* search799_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 142, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2317, 2318 },
      -1,
   } },

   /* replace799_0_0 -> 139 in the cache */
   /* replace799_0_1 -> 142 in the cache */
   /* replace799_0 -> 2311 in the cache */
   /* replace799_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2311, 48 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search800_0_0_0_0 -> 24 in the cache */
   /* search800_0_0_0 -> 2267 in the cache */
   /* search800_0_0 -> 2268 in the cache */
   /* search800_0_1_0_0 -> 551 in the cache */
   /* search800_0_1_0 -> 2277 in the cache */
   /* search800_0_1 -> 2278 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2268, 2278 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2321 },
      -1,
   } },

   /* replace800_0_0 -> 24 in the cache */
   /* replace800_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 24, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2323 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search801_0_0_0_0 -> 29 in the cache */
   /* search801_0_0_0 -> 2283 in the cache */
   /* search801_0_0 -> 2284 in the cache */
   /* search801_0_1_0_0 -> 48 in the cache */
   /* search801_0_1_0 -> 2285 in the cache */
   /* search801_0_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2284, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2325 },
      -1,
   } },

   /* replace801_0_0 -> 29 in the cache */
   /* replace801_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2327 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search802_0_0 -> 0 in the cache */
   /* search802_0_1 -> 911 in the cache */
   /* search802_0 -> 2291 in the cache */
   /* search802_1_0 -> 153 in the cache */
   /* search802_1_1 -> 1 in the cache */
   /* search802_1 -> 2292 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2291, 2292 },
      -1,
   } },

   /* replace802_0_0 -> 0 in the cache */
   /* replace802_0_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 153 },
      -1,
   } },
   /* replace802_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2330, 1 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search803_0_0 -> 0 in the cache */
   /* search803_0_1 -> 911 in the cache */
   /* search803_0 -> 2296 in the cache */
   /* search803_1_0 -> 153 in the cache */
   /* search803_1_1 -> 1 in the cache */
   /* search803_1 -> 2297 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2296, 2297 },
      -1,
   } },

   /* replace803_0_0 -> 0 in the cache */
   /* replace803_0_1 -> 153 in the cache */
   /* replace803_0 -> 2330 in the cache */
   /* replace803_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2330, 1 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search804_0_0 -> 0 in the cache */
   /* search804_0_1 -> 911 in the cache */
   /* search804_0 -> 2300 in the cache */
   /* search804_1_0 -> 153 in the cache */
   /* search804_1_1 -> 1 in the cache */
   /* search804_1 -> 2301 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2300, 2301 },
      -1,
   } },

   /* replace804_0_0 -> 0 in the cache */
   /* replace804_0_1 -> 153 in the cache */
   /* replace804_0 -> 2330 in the cache */
   /* replace804_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2330, 1 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search805_0_0 -> 0 in the cache */
   /* search805_0_1 -> 911 in the cache */
   /* search805_0 -> 2304 in the cache */
   /* search805_1_0 -> 153 in the cache */
   /* search805_1_1 -> 1 in the cache */
   /* search805_1 -> 2305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2304, 2305 },
      -1,
   } },

   /* replace805_0_0 -> 0 in the cache */
   /* replace805_0_1 -> 153 in the cache */
   /* replace805_0 -> 2330 in the cache */
   /* replace805_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2330, 1 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search806_0_0 -> 139 in the cache */
   /* search806_0_1 -> 45 in the cache */
   /* search806_0 -> 2308 in the cache */
   /* search806_1_0 -> 142 in the cache */
   /* search806_1_1 -> 48 in the cache */
   /* search806_1 -> 2309 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2308, 2309 },
      -1,
   } },

   /* replace806_0_0 -> 139 in the cache */
   /* replace806_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 139, 142 },
      -1,
   } },
   /* replace806_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2339, 48 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search807_0_0 -> 139 in the cache */
   /* search807_0_1 -> 45 in the cache */
   /* search807_0 -> 2313 in the cache */
   /* search807_1_0 -> 142 in the cache */
   /* search807_1_1 -> 48 in the cache */
   /* search807_1 -> 2314 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2313, 2314 },
      -1,
   } },

   /* replace807_0_0 -> 139 in the cache */
   /* replace807_0_1 -> 142 in the cache */
   /* replace807_0 -> 2339 in the cache */
   /* replace807_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2339, 48 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search808_0_0 -> 139 in the cache */
   /* search808_0_1 -> 45 in the cache */
   /* search808_0 -> 2317 in the cache */
   /* search808_1_0 -> 142 in the cache */
   /* search808_1_1 -> 48 in the cache */
   /* search808_1 -> 2318 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2317, 2318 },
      -1,
   } },

   /* replace808_0_0 -> 139 in the cache */
   /* replace808_0_1 -> 142 in the cache */
   /* replace808_0 -> 2339 in the cache */
   /* replace808_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2339, 48 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search809_0_0_0_0 -> 24 in the cache */
   /* search809_0_0_0 -> 2267 in the cache */
   /* search809_0_0 -> 2268 in the cache */
   /* search809_0_1_0_0 -> 551 in the cache */
   /* search809_0_1_0 -> 2277 in the cache */
   /* search809_0_1 -> 2278 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2268, 2278 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2345 },
      -1,
   } },

   /* replace809_0_0 -> 24 in the cache */
   /* replace809_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 24, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2347 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search810_0_0_0_0 -> 29 in the cache */
   /* search810_0_0_0 -> 2283 in the cache */
   /* search810_0_0 -> 2284 in the cache */
   /* search810_0_1_0_0 -> 48 in the cache */
   /* search810_0_1_0 -> 2285 in the cache */
   /* search810_0_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2284, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2349 },
      -1,
   } },

   /* replace810_0_0 -> 29 in the cache */
   /* replace810_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2351 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search811_0_0 -> 0 in the cache */
   /* search811_0_1 -> 911 in the cache */
   /* search811_0 -> 2291 in the cache */
   /* search811_1_0 -> 153 in the cache */
   /* search811_1_1 -> 1 in the cache */
   /* search811_1 -> 2292 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2291, 2292 },
      -1,
   } },

   /* replace811_0_0 -> 0 in the cache */
   /* replace811_0_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 153 },
      -1,
   } },
   /* replace811_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2354, 1 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search812_0_0 -> 0 in the cache */
   /* search812_0_1 -> 911 in the cache */
   /* search812_0 -> 2296 in the cache */
   /* search812_1_0 -> 153 in the cache */
   /* search812_1_1 -> 1 in the cache */
   /* search812_1 -> 2297 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2296, 2297 },
      -1,
   } },

   /* replace812_0_0 -> 0 in the cache */
   /* replace812_0_1 -> 153 in the cache */
   /* replace812_0 -> 2354 in the cache */
   /* replace812_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2354, 1 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search813_0_0 -> 0 in the cache */
   /* search813_0_1 -> 911 in the cache */
   /* search813_0 -> 2300 in the cache */
   /* search813_1_0 -> 153 in the cache */
   /* search813_1_1 -> 1 in the cache */
   /* search813_1 -> 2301 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2300, 2301 },
      -1,
   } },

   /* replace813_0_0 -> 0 in the cache */
   /* replace813_0_1 -> 153 in the cache */
   /* replace813_0 -> 2354 in the cache */
   /* replace813_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2354, 1 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search814_0_0 -> 0 in the cache */
   /* search814_0_1 -> 911 in the cache */
   /* search814_0 -> 2304 in the cache */
   /* search814_1_0 -> 153 in the cache */
   /* search814_1_1 -> 1 in the cache */
   /* search814_1 -> 2305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2304, 2305 },
      -1,
   } },

   /* replace814_0_0 -> 0 in the cache */
   /* replace814_0_1 -> 153 in the cache */
   /* replace814_0 -> 2354 in the cache */
   /* replace814_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2354, 1 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search815_0_0 -> 139 in the cache */
   /* search815_0_1 -> 45 in the cache */
   /* search815_0 -> 2308 in the cache */
   /* search815_1_0 -> 142 in the cache */
   /* search815_1_1 -> 48 in the cache */
   /* search815_1 -> 2309 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2308, 2309 },
      -1,
   } },

   /* replace815_0_0 -> 139 in the cache */
   /* replace815_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 139, 142 },
      -1,
   } },
   /* replace815_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2363, 48 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search816_0_0 -> 139 in the cache */
   /* search816_0_1 -> 45 in the cache */
   /* search816_0 -> 2313 in the cache */
   /* search816_1_0 -> 142 in the cache */
   /* search816_1_1 -> 48 in the cache */
   /* search816_1 -> 2314 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2313, 2314 },
      -1,
   } },

   /* replace816_0_0 -> 139 in the cache */
   /* replace816_0_1 -> 142 in the cache */
   /* replace816_0 -> 2363 in the cache */
   /* replace816_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2363, 48 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search817_0_0 -> 139 in the cache */
   /* search817_0_1 -> 45 in the cache */
   /* search817_0 -> 2317 in the cache */
   /* search817_1_0 -> 142 in the cache */
   /* search817_1_1 -> 48 in the cache */
   /* search817_1 -> 2318 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2317, 2318 },
      -1,
   } },

   /* replace817_0_0 -> 139 in the cache */
   /* replace817_0_1 -> 142 in the cache */
   /* replace817_0 -> 2363 in the cache */
   /* replace817_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2363, 48 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search818_0_0 -> 19 in the cache */
   /* search818_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 925 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search818_1_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2370, 925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2369, 2371 },
      -1,
   } },

   /* replace818_0_0 -> 19 in the cache */
   /* replace818_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 19, 2370 },
      -1,
   } },
   /* replace818_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2373, 925 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search819_0_0 -> 19 in the cache */
   /* search819_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 925 },
      -1,
   } },
   /* search819_1_0 -> 2370 in the cache */
   /* search819_1_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2370, 925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2375, 2376 },
      -1,
   } },

   /* replace819_0_0 -> 19 in the cache */
   /* replace819_0_1 -> 2370 in the cache */
   /* replace819_0 -> 2373 in the cache */
   /* replace819_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2373, 925 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search820_0_0 -> 19 in the cache */
   /* search820_0_1 -> 925 in the cache */
   /* search820_0 -> 2369 in the cache */
   /* search820_1_0 -> 2370 in the cache */
   /* search820_1_1 -> 925 in the cache */
   /* search820_1 -> 2371 in the cache */
   /* search820 -> 2372 in the cache */

   /* replace820_0_0 -> 19 in the cache */
   /* replace820_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 19, 2370 },
      -1,
   } },
   /* replace820_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2379, 925 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search821_0_0 -> 19 in the cache */
   /* search821_0_1 -> 925 in the cache */
   /* search821_0 -> 2369 in the cache */
   /* search821_1_0 -> 2370 in the cache */
   /* search821_1_1 -> 925 in the cache */
   /* search821_1 -> 2371 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2369, 2371 },
      -1,
   } },

   /* replace821_0_0 -> 19 in the cache */
   /* replace821_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 19, 2370 },
      -1,
   } },
   /* replace821_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2382, 925 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search822_0_0 -> 19 in the cache */
   /* search822_0_1 -> 925 in the cache */
   /* search822_0 -> 2375 in the cache */
   /* search822_1_0 -> 2370 in the cache */
   /* search822_1_1 -> 925 in the cache */
   /* search822_1 -> 2376 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2375, 2376 },
      -1,
   } },

   /* replace822_0_0 -> 19 in the cache */
   /* replace822_0_1 -> 2370 in the cache */
   /* replace822_0 -> 2382 in the cache */
   /* replace822_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2382, 925 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search823_0_0 -> 19 in the cache */
   /* search823_0_1 -> 925 in the cache */
   /* search823_0 -> 2375 in the cache */
   /* search823_1_0 -> 2370 in the cache */
   /* search823_1_1 -> 925 in the cache */
   /* search823_1 -> 2376 in the cache */
   /* search823 -> 2377 in the cache */

   /* replace823_0_0 -> 19 in the cache */
   /* replace823_0_1 -> 2370 in the cache */
   /* replace823_0 -> 2379 in the cache */
   /* replace823_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2379, 925 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b@8', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2387, 2388 },
      -1,
   } },
   /* search824_1 -> 2387 in the cache */
   /* search824_2 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2389, 2387, 2388 },
      -1,
   } },

   /* replace824_0 -> 2388 in the cache */
   /* replace824_1 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2388, 2387 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a@8', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search825_0_0 -> 19 in the cache */
   /* search825_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 2370 },
      -1,
   } },
   /* search825_1 -> 2370 in the cache */
   /* search825_2 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2392, 2370, 19 },
      -1,
   } },

   /* replace825_0 -> 19 in the cache */
   /* replace825_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 19, 2370 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a@8', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search826_0_0 -> 19 in the cache */
   /* search826_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 19, 2370 },
      -1,
   } },
   /* search826_1 -> 2370 in the cache */
   /* search826_2 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2395, 2370, 19 },
      -1,
   } },

   /* replace826_0 -> 19 in the cache */
   /* replace826_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 19, 2370 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b@8', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search827_0_0 -> 2387 in the cache */
   /* search827_0_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2387, 2388 },
      -1,
   } },
   /* search827_1 -> 2387 in the cache */
   /* search827_2 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2398, 2387, 2388 },
      -1,
   } },

   /* replace827_0 -> 2388 in the cache */
   /* replace827_1 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2388, 2387 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b@8', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search828_0_0 -> 2387 in the cache */
   /* search828_0_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2387, 2388 },
      -1,
   } },
   /* search828_1 -> 2387 in the cache */
   /* search828_2 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2401, 2387, 2388 },
      -1,
   } },

   /* replace828_0 -> 2388 in the cache */
   /* replace828_1 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2388, 2387 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@8', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search829_0_0 -> 19 in the cache */
   /* search829_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 2370 },
      -1,
   } },
   /* search829_1 -> 2370 in the cache */
   /* search829_2 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2404, 2370, 19 },
      -1,
   } },

   /* replace829_0 -> 19 in the cache */
   /* replace829_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 19, 2370 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@8', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search830_0_0 -> 19 in the cache */
   /* search830_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 19, 2370 },
      -1,
   } },
   /* search830_1 -> 2370 in the cache */
   /* search830_2 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2407, 2370, 19 },
      -1,
   } },

   /* replace830_0 -> 19 in the cache */
   /* replace830_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 19, 2370 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b@8', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search831_0_0 -> 2387 in the cache */
   /* search831_0_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2387, 2388 },
      -1,
   } },
   /* search831_1 -> 2387 in the cache */
   /* search831_2 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2410, 2387, 2388 },
      -1,
   } },

   /* replace831_0 -> 2388 in the cache */
   /* replace831_1 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2388, 2387 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search832_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2413 },
      -1,
   } },

   /* replace832 -> 19 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search833_0 -> 19 in the cache */
   /* search833_1_0 -> 22 in the cache */
   /* search833_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 22, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 19, 2415 },
      -1,
   } },

   /* replace833_0 -> 19 in the cache */
   /* replace833_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 19, 48 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search834_0 -> 19 in the cache */
   /* search834_1_0 -> 22 in the cache */
   /* search834_1_1 -> 48 in the cache */
   /* search834_1 -> 2415 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 19, 2415 },
      -1,
   } },

   /* replace834_0 -> 19 in the cache */
   /* replace834_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 19, 48 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search835_0 -> 19 in the cache */
   /* search835_1_0 -> 22 in the cache */
   /* search835_1_1 -> 48 in the cache */
   /* search835_1 -> 2415 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 19, 2415 },
      -1,
   } },

   /* replace835_0 -> 19 in the cache */
   /* replace835_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 19, 48 },
      -1,
   } },

   /* ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2)) */
   /* search836_0 -> 19 in the cache */
   /* search836_1_0_0 -> 48 in the cache */
   /* search836_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 48, 486 },
      -1,
   } },
   /* search836_1_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2422, 491 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 19, 2423 },
      -1,
   } },

   /* replace836_0 -> 19 in the cache */
   /* replace836_1_0 -> 48 in the cache */
   /* replace836_1_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 48, 491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 19, 2425 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search837_0_0 -> 24 in the cache */
   /* search837_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 24, 946 },
      -1,
   } },
   /* search837_1_0 -> 551 in the cache */
   /* search837_1_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 551, 946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2427, 2428 },
      -1,
   } },

   /* replace837_0_0 -> 24 in the cache */
   /* replace837_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 24, 551 },
      -1,
   } },
   /* replace837_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2430, 946 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search838_0_0 -> 24 in the cache */
   /* search838_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 24, 946 },
      -1,
   } },
   /* search838_1_0 -> 551 in the cache */
   /* search838_1_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 551, 946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2432, 2433 },
      -1,
   } },

   /* replace838_0_0 -> 24 in the cache */
   /* replace838_0_1 -> 551 in the cache */
   /* replace838_0 -> 2430 in the cache */
   /* replace838_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2430, 946 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search839_0_0 -> 24 in the cache */
   /* search839_0_1 -> 946 in the cache */
   /* search839_0 -> 2427 in the cache */
   /* search839_1_0 -> 551 in the cache */
   /* search839_1_1 -> 946 in the cache */
   /* search839_1 -> 2428 in the cache */
   /* search839 -> 2429 in the cache */

   /* replace839_0_0 -> 24 in the cache */
   /* replace839_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 24, 551 },
      -1,
   } },
   /* replace839_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2436, 946 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search840_0_0 -> 24 in the cache */
   /* search840_0_1 -> 946 in the cache */
   /* search840_0 -> 2427 in the cache */
   /* search840_1_0 -> 551 in the cache */
   /* search840_1_1 -> 946 in the cache */
   /* search840_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2427, 2428 },
      -1,
   } },

   /* replace840_0_0 -> 24 in the cache */
   /* replace840_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 24, 551 },
      -1,
   } },
   /* replace840_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2439, 946 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search841_0_0 -> 24 in the cache */
   /* search841_0_1 -> 946 in the cache */
   /* search841_0 -> 2432 in the cache */
   /* search841_1_0 -> 551 in the cache */
   /* search841_1_1 -> 946 in the cache */
   /* search841_1 -> 2433 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2432, 2433 },
      -1,
   } },

   /* replace841_0_0 -> 24 in the cache */
   /* replace841_0_1 -> 551 in the cache */
   /* replace841_0 -> 2439 in the cache */
   /* replace841_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2439, 946 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search842_0_0 -> 24 in the cache */
   /* search842_0_1 -> 946 in the cache */
   /* search842_0 -> 2432 in the cache */
   /* search842_1_0 -> 551 in the cache */
   /* search842_1_1 -> 946 in the cache */
   /* search842_1 -> 2433 in the cache */
   /* search842 -> 2434 in the cache */

   /* replace842_0_0 -> 24 in the cache */
   /* replace842_0_1 -> 551 in the cache */
   /* replace842_0 -> 2436 in the cache */
   /* replace842_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2436, 946 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b@16', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search843_0_0 -> 603 in the cache */
   /* search843_0_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 603, 614 },
      -1,
   } },
   /* search843_1 -> 603 in the cache */
   /* search843_2 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2444, 603, 614 },
      -1,
   } },

   /* replace843_0 -> 614 in the cache */
   /* replace843_1 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 614, 603 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a@16', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search844_0_0 -> 24 in the cache */
   /* search844_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* search844_1 -> 551 in the cache */
   /* search844_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2447, 551, 24 },
      -1,
   } },

   /* replace844_0 -> 24 in the cache */
   /* replace844_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a@16', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search845_0_0 -> 24 in the cache */
   /* search845_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* search845_1 -> 551 in the cache */
   /* search845_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2450, 551, 24 },
      -1,
   } },

   /* replace845_0 -> 24 in the cache */
   /* replace845_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b@16', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search846_0_0 -> 603 in the cache */
   /* search846_0_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 603, 614 },
      -1,
   } },
   /* search846_1 -> 603 in the cache */
   /* search846_2 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2453, 603, 614 },
      -1,
   } },

   /* replace846_0 -> 614 in the cache */
   /* replace846_1 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 614, 603 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b@16', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search847_0_0 -> 603 in the cache */
   /* search847_0_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 603, 614 },
      -1,
   } },
   /* search847_1 -> 603 in the cache */
   /* search847_2 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2456, 603, 614 },
      -1,
   } },

   /* replace847_0 -> 614 in the cache */
   /* replace847_1 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 614, 603 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@16', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search848_0_0 -> 24 in the cache */
   /* search848_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* search848_1 -> 551 in the cache */
   /* search848_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2459, 551, 24 },
      -1,
   } },

   /* replace848_0 -> 24 in the cache */
   /* replace848_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@16', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search849_0_0 -> 24 in the cache */
   /* search849_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* search849_1 -> 551 in the cache */
   /* search849_2 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2462, 551, 24 },
      -1,
   } },

   /* replace849_0 -> 24 in the cache */
   /* replace849_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b@16', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search850_0_0 -> 603 in the cache */
   /* search850_0_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 603, 614 },
      -1,
   } },
   /* search850_1 -> 603 in the cache */
   /* search850_2 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2465, 603, 614 },
      -1,
   } },

   /* replace850_0 -> 614 in the cache */
   /* replace850_1 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 614, 603 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search851_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2468 },
      -1,
   } },

   /* replace851 -> 24 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search852_0 -> 24 in the cache */
   /* search852_1_0 -> 27 in the cache */
   /* search852_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 27, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 24, 2470 },
      -1,
   } },

   /* replace852_0 -> 24 in the cache */
   /* replace852_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 24, 48 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search853_0 -> 24 in the cache */
   /* search853_1_0 -> 27 in the cache */
   /* search853_1_1 -> 48 in the cache */
   /* search853_1 -> 2470 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 24, 2470 },
      -1,
   } },

   /* replace853_0 -> 24 in the cache */
   /* replace853_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 24, 48 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search854_0 -> 24 in the cache */
   /* search854_1_0 -> 27 in the cache */
   /* search854_1_1 -> 48 in the cache */
   /* search854_1 -> 2470 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 24, 2470 },
      -1,
   } },

   /* replace854_0 -> 24 in the cache */
   /* replace854_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 24, 48 },
      -1,
   } },

   /* ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3)) */
   /* search855_0 -> 24 in the cache */
   /* search855_1_0_0 -> 48 in the cache */
   /* search855_1_0_1 -> 486 in the cache */
   /* search855_1_0 -> 2422 in the cache */
   /* search855_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2422, 495 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 24, 2477 },
      -1,
   } },

   /* replace855_0 -> 24 in the cache */
   /* replace855_1_0 -> 48 in the cache */
   /* replace855_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 48, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 24, 2479 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search856_0_0 -> 29 in the cache */
   /* search856_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 29, 135 },
      -1,
   } },
   /* search856_1_0 -> 48 in the cache */
   /* search856_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2481, 2482 },
      -1,
   } },

   /* replace856_0_0 -> 29 in the cache */
   /* replace856_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace856_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2484, 135 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search857_0_0 -> 29 in the cache */
   /* search857_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 29, 135 },
      -1,
   } },
   /* search857_1_0 -> 48 in the cache */
   /* search857_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2486, 2487 },
      -1,
   } },

   /* replace857_0_0 -> 29 in the cache */
   /* replace857_0_1 -> 48 in the cache */
   /* replace857_0 -> 2484 in the cache */
   /* replace857_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2484, 135 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search858_0_0 -> 29 in the cache */
   /* search858_0_1 -> 135 in the cache */
   /* search858_0 -> 2481 in the cache */
   /* search858_1_0 -> 48 in the cache */
   /* search858_1_1 -> 135 in the cache */
   /* search858_1 -> 2482 in the cache */
   /* search858 -> 2483 in the cache */

   /* replace858_0_0 -> 29 in the cache */
   /* replace858_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace858_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2490, 135 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search859_0_0 -> 29 in the cache */
   /* search859_0_1 -> 135 in the cache */
   /* search859_0 -> 2481 in the cache */
   /* search859_1_0 -> 48 in the cache */
   /* search859_1_1 -> 135 in the cache */
   /* search859_1 -> 2482 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2481, 2482 },
      -1,
   } },

   /* replace859_0_0 -> 29 in the cache */
   /* replace859_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace859_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2493, 135 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search860_0_0 -> 29 in the cache */
   /* search860_0_1 -> 135 in the cache */
   /* search860_0 -> 2486 in the cache */
   /* search860_1_0 -> 48 in the cache */
   /* search860_1_1 -> 135 in the cache */
   /* search860_1 -> 2487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2486, 2487 },
      -1,
   } },

   /* replace860_0_0 -> 29 in the cache */
   /* replace860_0_1 -> 48 in the cache */
   /* replace860_0 -> 2493 in the cache */
   /* replace860_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2493, 135 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search861_0_0 -> 29 in the cache */
   /* search861_0_1 -> 135 in the cache */
   /* search861_0 -> 2486 in the cache */
   /* search861_1_0 -> 48 in the cache */
   /* search861_1_1 -> 135 in the cache */
   /* search861_1 -> 2487 in the cache */
   /* search861 -> 2488 in the cache */

   /* replace861_0_0 -> 29 in the cache */
   /* replace861_0_1 -> 48 in the cache */
   /* replace861_0 -> 2490 in the cache */
   /* replace861_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2490, 135 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b@32', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search862_0_0 -> 386 in the cache */
   /* search862_0_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 386, 196 },
      -1,
   } },
   /* search862_1 -> 386 in the cache */
   /* search862_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2498, 386, 196 },
      -1,
   } },

   /* replace862_0 -> 196 in the cache */
   /* replace862_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 196, 386 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a@32', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search863_0_0 -> 29 in the cache */
   /* search863_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   /* search863_1 -> 48 in the cache */
   /* search863_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2501, 48, 29 },
      -1,
   } },

   /* replace863_0 -> 29 in the cache */
   /* replace863_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a@32', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search864_0_0 -> 29 in the cache */
   /* search864_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   /* search864_1 -> 48 in the cache */
   /* search864_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2504, 48, 29 },
      -1,
   } },

   /* replace864_0 -> 29 in the cache */
   /* replace864_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b@32', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search865_0_0 -> 386 in the cache */
   /* search865_0_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 386, 196 },
      -1,
   } },
   /* search865_1 -> 386 in the cache */
   /* search865_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2507, 386, 196 },
      -1,
   } },

   /* replace865_0 -> 196 in the cache */
   /* replace865_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 196, 386 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b@32', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search866_0_0 -> 386 in the cache */
   /* search866_0_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 386, 196 },
      -1,
   } },
   /* search866_1 -> 386 in the cache */
   /* search866_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2510, 386, 196 },
      -1,
   } },

   /* replace866_0 -> 196 in the cache */
   /* replace866_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 196, 386 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search867_0_0 -> 29 in the cache */
   /* search867_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   /* search867_1 -> 48 in the cache */
   /* search867_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2513, 48, 29 },
      -1,
   } },

   /* replace867_0 -> 29 in the cache */
   /* replace867_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search868_0_0 -> 29 in the cache */
   /* search868_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   /* search868_1 -> 48 in the cache */
   /* search868_2 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2516, 48, 29 },
      -1,
   } },

   /* replace868_0 -> 29 in the cache */
   /* replace868_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b@32', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search869_0_0 -> 386 in the cache */
   /* search869_0_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 386, 196 },
      -1,
   } },
   /* search869_1 -> 386 in the cache */
   /* search869_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2519, 386, 196 },
      -1,
   } },

   /* replace869_0 -> 196 in the cache */
   /* replace869_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 196, 386 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search870_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2522 },
      -1,
   } },

   /* replace870 -> 29 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search871_0 -> 29 in the cache */
   /* search871_1_0 -> 32 in the cache */
   /* search871_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 29, 2524 },
      -1,
   } },

   /* replace871_0 -> 29 in the cache */
   /* replace871_1 -> 48 in the cache */
   /* replace871 -> 1036 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search872_0 -> 29 in the cache */
   /* search872_1_0 -> 32 in the cache */
   /* search872_1_1 -> 48 in the cache */
   /* search872_1 -> 2524 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 29, 2524 },
      -1,
   } },

   /* replace872_0 -> 29 in the cache */
   /* replace872_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search873_0 -> 29 in the cache */
   /* search873_1_0 -> 32 in the cache */
   /* search873_1_1 -> 48 in the cache */
   /* search873_1 -> 2524 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 29, 2524 },
      -1,
   } },

   /* replace873_0 -> 29 in the cache */
   /* replace873_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4)) */
   /* search874_0 -> 29 in the cache */
   /* search874_1_0_0 -> 48 in the cache */
   /* search874_1_0_1 -> 486 in the cache */
   /* search874_1_0 -> 2422 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4ull /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2422, 2530 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 29, 2531 },
      -1,
   } },

   /* replace874_0 -> 29 in the cache */
   /* replace874_1_0 -> 48 in the cache */
   /* replace874_1_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 48, 2530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 2533 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search875_0_0 -> 34 in the cache */
   /* search875_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 34, 987 },
      -1,
   } },
   /* search875_1_0 -> 53 in the cache */
   /* search875_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 53, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2535, 2536 },
      -1,
   } },

   /* replace875_0_0 -> 34 in the cache */
   /* replace875_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* replace875_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2538, 987 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search876_0_0 -> 34 in the cache */
   /* search876_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 34, 987 },
      -1,
   } },
   /* search876_1_0 -> 53 in the cache */
   /* search876_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 53, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2540, 2541 },
      -1,
   } },

   /* replace876_0_0 -> 34 in the cache */
   /* replace876_0_1 -> 53 in the cache */
   /* replace876_0 -> 2538 in the cache */
   /* replace876_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2538, 987 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search877_0_0 -> 34 in the cache */
   /* search877_0_1 -> 987 in the cache */
   /* search877_0 -> 2535 in the cache */
   /* search877_1_0 -> 53 in the cache */
   /* search877_1_1 -> 987 in the cache */
   /* search877_1 -> 2536 in the cache */
   /* search877 -> 2537 in the cache */

   /* replace877_0_0 -> 34 in the cache */
   /* replace877_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* replace877_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2544, 987 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search878_0_0 -> 34 in the cache */
   /* search878_0_1 -> 987 in the cache */
   /* search878_0 -> 2535 in the cache */
   /* search878_1_0 -> 53 in the cache */
   /* search878_1_1 -> 987 in the cache */
   /* search878_1 -> 2536 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2535, 2536 },
      -1,
   } },

   /* replace878_0_0 -> 34 in the cache */
   /* replace878_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* replace878_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2547, 987 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search879_0_0 -> 34 in the cache */
   /* search879_0_1 -> 987 in the cache */
   /* search879_0 -> 2540 in the cache */
   /* search879_1_0 -> 53 in the cache */
   /* search879_1_1 -> 987 in the cache */
   /* search879_1 -> 2541 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2540, 2541 },
      -1,
   } },

   /* replace879_0_0 -> 34 in the cache */
   /* replace879_0_1 -> 53 in the cache */
   /* replace879_0 -> 2547 in the cache */
   /* replace879_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2547, 987 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search880_0_0 -> 34 in the cache */
   /* search880_0_1 -> 987 in the cache */
   /* search880_0 -> 2540 in the cache */
   /* search880_1_0 -> 53 in the cache */
   /* search880_1_1 -> 987 in the cache */
   /* search880_1 -> 2541 in the cache */
   /* search880 -> 2542 in the cache */

   /* replace880_0_0 -> 34 in the cache */
   /* replace880_0_1 -> 53 in the cache */
   /* replace880_0 -> 2544 in the cache */
   /* replace880_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2544, 987 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b@64', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search881_0_0 -> 742 in the cache */
   /* search881_0_1 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 742, 752 },
      -1,
   } },
   /* search881_1 -> 742 in the cache */
   /* search881_2 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2552, 742, 752 },
      -1,
   } },

   /* replace881_0 -> 752 in the cache */
   /* replace881_1 -> 742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 752, 742 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a@64', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search882_0_0 -> 34 in the cache */
   /* search882_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 34, 53 },
      -1,
   } },
   /* search882_1 -> 53 in the cache */
   /* search882_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2555, 53, 34 },
      -1,
   } },

   /* replace882_0 -> 34 in the cache */
   /* replace882_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a@64', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search883_0_0 -> 34 in the cache */
   /* search883_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 34, 53 },
      -1,
   } },
   /* search883_1 -> 53 in the cache */
   /* search883_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2558, 53, 34 },
      -1,
   } },

   /* replace883_0 -> 34 in the cache */
   /* replace883_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b@64', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search884_0_0 -> 742 in the cache */
   /* search884_0_1 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 742, 752 },
      -1,
   } },
   /* search884_1 -> 742 in the cache */
   /* search884_2 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2561, 742, 752 },
      -1,
   } },

   /* replace884_0 -> 752 in the cache */
   /* replace884_1 -> 742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 752, 742 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b@64', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search885_0_0 -> 742 in the cache */
   /* search885_0_1 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 742, 752 },
      -1,
   } },
   /* search885_1 -> 742 in the cache */
   /* search885_2 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2564, 742, 752 },
      -1,
   } },

   /* replace885_0 -> 752 in the cache */
   /* replace885_1 -> 742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 752, 742 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@64', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search886_0_0 -> 34 in the cache */
   /* search886_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 53 },
      -1,
   } },
   /* search886_1 -> 53 in the cache */
   /* search886_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2567, 53, 34 },
      -1,
   } },

   /* replace886_0 -> 34 in the cache */
   /* replace886_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@64', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search887_0_0 -> 34 in the cache */
   /* search887_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 53 },
      -1,
   } },
   /* search887_1 -> 53 in the cache */
   /* search887_2 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2570, 53, 34 },
      -1,
   } },

   /* replace887_0 -> 34 in the cache */
   /* replace887_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b@64', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search888_0_0 -> 742 in the cache */
   /* search888_0_1 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 742, 752 },
      -1,
   } },
   /* search888_1 -> 742 in the cache */
   /* search888_2 -> 752 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2573, 742, 752 },
      -1,
   } },

   /* replace888_0 -> 752 in the cache */
   /* replace888_1 -> 742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 752, 742 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search889_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2576 },
      -1,
   } },

   /* replace889 -> 34 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search890_0 -> 34 in the cache */
   /* search890_1_0 -> 37 in the cache */
   /* search890_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 37, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 34, 2578 },
      -1,
   } },

   /* replace890_0 -> 34 in the cache */
   /* replace890_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 48 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search891_0 -> 34 in the cache */
   /* search891_1_0 -> 37 in the cache */
   /* search891_1_1 -> 48 in the cache */
   /* search891_1 -> 2578 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 34, 2578 },
      -1,
   } },

   /* replace891_0 -> 34 in the cache */
   /* replace891_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 48 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search892_0 -> 34 in the cache */
   /* search892_1_0 -> 37 in the cache */
   /* search892_1_1 -> 48 in the cache */
   /* search892_1 -> 2578 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 34, 2578 },
      -1,
   } },

   /* replace892_0 -> 34 in the cache */
   /* replace892_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 48 },
      -1,
   } },

   /* ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5)) */
   /* search893_0 -> 34 in the cache */
   /* search893_1_0_0 -> 48 in the cache */
   /* search893_1_0_1 -> 486 in the cache */
   /* search893_1_0 -> 2422 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x5ull /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2422, 2585 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 34, 2586 },
      -1,
   } },

   /* replace893_0 -> 34 in the cache */
   /* replace893_1_0 -> 48 in the cache */
   /* replace893_1_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 48, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 2588 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search894_0_0 -> 9 in the cache */
   /* search894_0_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 9, 73 },
      -1,
   } },
   /* search894_1_0 -> 9 in the cache */
   /* search894_1_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 9, 47 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2590, 2591 },
      -1,
   } },

   /* replace894_0 -> 47 in the cache */
   /* replace894_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 47, 9 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search895_0_0 -> 47 in the cache */
   /* search895_0_1 -> 9 in the cache */
   /* search895_0 -> 2593 in the cache */
   /* search895_1_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2ull /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 9, 2594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2593, 2595 },
      -1,
   } },

   /* replace895_0 -> 2594 in the cache */
   /* replace895_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2594, 9 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search896_0_0 -> 2594 in the cache */
   /* search896_0_1 -> 9 in the cache */
   /* search896_0 -> 2597 in the cache */
   /* search896_1_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3ull /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 9, 2598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2597, 2599 },
      -1,
   } },

   /* replace896_0 -> 2598 in the cache */
   /* replace896_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2598, 9 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search897_0 -> 847 in the cache */
   /* search897_1_0 -> 847 in the cache */
   /* search897_1_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 847, 1165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 847, 2602 },
      -1,
   } },

   /* replace897 -> 1350 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search898_0_0_0 -> 847 in the cache */
   /* search898_0_0 -> 1345 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1345 },
      -1,
   } },
   /* search898_1_0_0 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2605 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace898_0 -> 847 in the cache */
   /* replace898_1 -> 1251 in the cache */
   /* replace898 -> 1495 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search899_0_0 -> 847 in the cache */
   /* search899_0_1 -> 1251 in the cache */
   /* search899_0 -> 1495 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1495 },
      -1,
   } },

   /* replace899_0_0 -> 847 in the cache */
   /* replace899_0_1 -> 1251 in the cache */
   /* replace899_0 -> 1268 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1268 },
      -1,
   } },

   /* ('ishl', ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)), '#c') => ('bcsel', ('ige', ('iand', 'c', 31), ('find_lsb', 'b')), ('ishl', ('iand', 'a', 'b'), ('iadd', ('iand', 'c', 31), ('ineg', ('find_lsb', 'b')))), ('ushr', ('iand', 'a', 'b'), ('iadd', ('ineg', ('iand', 'c', 31)), ('find_lsb', 'b')))) */
   /* search900_0_0_0_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 2610 },
      -1,
   } },
   /* search900_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2611, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 2,
      { 2612 },
      -1,
   } },
   /* search900_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 2613, 322 },
      -1,
   } },

   /* replace900_0_0_0 -> 148 in the cache */
   /* replace900_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 32 },
      -1,
   } },
   /* replace900_0_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2615, 2616 },
      -1,
   } },
   /* replace900_1_0_0 -> 29 in the cache */
   /* replace900_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace900_1_1_0_0 -> 148 in the cache */
   /* replace900_1_1_0_1 -> 32 in the cache */
   /* replace900_1_1_0 -> 975 in the cache */
   /* replace900_1_1_1_0_0 -> 48 in the cache */
   /* replace900_1_1_1_0 -> 2616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 2,
      { 975, 2619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 2618, 2620 },
      -1,
   } },
   /* replace900_2_0_0 -> 29 in the cache */
   /* replace900_2_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      4, 1,
      { 29, 48 },
      -1,
   } },
   /* replace900_2_1_0_0_0 -> 148 in the cache */
   /* replace900_2_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      6, 1,
      { 148, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2623 },
      -1,
   } },
   /* replace900_2_1_1_0 -> 48 in the cache */
   /* replace900_2_1_1 -> 2616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 2,
      { 2624, 2616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 3,
      { 2622, 2625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 2617, 2621, 2626 },
      -1,
   } },

   /* ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)) => ('ushr', ('iand', 'a', 'b'), ('find_lsb', 'b')) */
   /* search901_0_0_0 -> 29 in the cache */
   /* search901_0_0_1 -> 2610 in the cache */
   /* search901_0_0 -> 2611 in the cache */
   /* search901_0_1 -> 135 in the cache */
   /* search901_0 -> 2612 in the cache */
   /* search901 -> 2613 in the cache */

   /* replace901_0_0 -> 29 in the cache */
   /* replace901_0_1 -> 48 in the cache */
   /* replace901_0 -> 2289 in the cache */
   /* replace901_1_0 -> 48 in the cache */
   /* replace901_1 -> 2616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2289, 2616 },
      -1,
   } },

   /* ('ior', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('ior', ('b2i', 'a'), 'b'), 1) */
   /* search902_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search902_1_0 -> 1 in the cache */
   /* search902_1_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1, 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2629, 2630 },
      -1,
   } },

   /* replace902_0_0_0 -> 9 in the cache */
   /* replace902_0_0 -> 2629 in the cache */
   /* replace902_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 2629, 1 },
      -1,
   } },
   /* replace902_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2632, 91 },
      -1,
   } },

   /* ('iand', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('b2i', 'a'), 'b') */
   /* search903_0_0 -> 9 in the cache */
   /* search903_0 -> 2629 in the cache */
   /* search903_1_0 -> 1 in the cache */
   /* search903_1_1 -> 91 in the cache */
   /* search903_1 -> 2630 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2629, 2630 },
      -1,
   } },

   /* replace903_0_0 -> 9 in the cache */
   /* replace903_0 -> 2629 in the cache */
   /* replace903_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2629, 1 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search904_0_0_0_0_0 -> 9 in the cache */
   /* search904_0_0_0_0_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 9, 73 },
      -1,
   } },
   /* search904_0_0_0_1 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2636, 1251 },
      -1,
   } },
   /* search904_0_0_1 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2637, 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2638 },
      -1,
   } },
   /* search904_1_0 -> 9 in the cache */
   /* search904_1_1 -> 73 in the cache */
   /* search904_1 -> 1370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2639, 1370 },
      -1,
   } },

   /* replace904_0_0_0 -> 1251 in the cache */
   /* replace904_0_0_1 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1251, 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2641 },
      -1,
   } },
   /* replace904_1_0 -> 9 in the cache */
   /* replace904_1_1 -> 73 in the cache */
   /* replace904_1 -> 1370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2642, 1370 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search905_0_0_0_0_0 -> 0 in the cache */
   /* search905_0_0_0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 1 },
      -1,
   } },
   /* search905_0_0_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2644, 98 },
      -1,
   } },
   /* search905_0_0_1 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2645, 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2646 },
      -1,
   } },
   /* search905_1_0 -> 0 in the cache */
   /* search905_1_1 -> 98 in the cache */
   /* search905_1 -> 102 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2647, 102 },
      -1,
   } },

   /* replace905_0_0_0_0 -> 1 in the cache */
   /* replace905_0_0_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 1, 98 },
      -1,
   } },
   /* replace905_0_0_1 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2649, 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2650 },
      -1,
   } },
   /* replace905_1_0 -> 0 in the cache */
   /* replace905_1_1 -> 98 in the cache */
   /* replace905_1 -> 102 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2651, 102 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search906_0 -> 9 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search906_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 9, 2654 },
      -1,
   } },

   /* replace906_0 -> 9 in the cache */
   /* replace906_1 -> 2653 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 2653 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search907_0_0 -> 0 in the cache */
   /* search907_0_1 -> 1 in the cache */
   /* search907_0 -> 1403 in the cache */
   /* search907_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1403, 0 },
      -1,
   } },

   /* replace907_0 -> 1 in the cache */
   /* replace907_1 -> 0 in the cache */
   /* replace907 -> 1166 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search908_0 -> 9 in the cache */
   /* search908_1_0 -> 2653 in the cache */
   /* search908_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 9, 2658 },
      -1,
   } },

   /* replace908 -> 1350 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search909_0_0 -> 0 in the cache */
   /* search909_0_1 -> 1 in the cache */
   /* search909_0 -> 1401 in the cache */
   /* search909_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1401, 0 },
      -1,
   } },

   /* replace909 -> 1350 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search910_0 -> 9 in the cache */
   /* search910_1_0 -> 2653 in the cache */
   /* search910_1_1 -> 9 in the cache */
   /* search910_1 -> 2658 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 9, 2658 },
      -1,
   } },

   /* replace910 -> 1165 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search911_0_0 -> 0 in the cache */
   /* search911_0_1 -> 1 in the cache */
   /* search911_0 -> 1401 in the cache */
   /* search911_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1401, 0 },
      -1,
   } },

   /* replace911 -> 1165 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search912_0 -> 9 in the cache */
   /* search912_1_0 -> 2653 in the cache */
   /* search912_1_1 -> 9 in the cache */
   /* search912_1 -> 2654 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 9, 2654 },
      -1,
   } },

   /* replace912_0 -> 9 in the cache */
   /* replace912_1 -> 2653 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 2653 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search913_0_0 -> 0 in the cache */
   /* search913_0_1 -> 1 in the cache */
   /* search913_0 -> 1403 in the cache */
   /* search913_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1403, 0 },
      -1,
   } },

   /* replace913_0 -> 1 in the cache */
   /* replace913_1 -> 0 in the cache */
   /* replace913 -> 1178 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search914_0 -> 9 in the cache */
   /* search914_1_0 -> 2653 in the cache */
   /* search914_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 9, 2666 },
      -1,
   } },

   /* replace914_0 -> 9 in the cache */
   /* replace914_1 -> 2653 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 9, 2653 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search915_0_0 -> 0 in the cache */
   /* search915_0_1 -> 1 in the cache */
   /* search915_0 -> 1460 in the cache */
   /* search915_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1460, 0 },
      -1,
   } },

   /* replace915_0 -> 1 in the cache */
   /* replace915_1 -> 0 in the cache */
   /* replace915 -> 1171 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search916_0 -> 9 in the cache */
   /* search916_1_0 -> 2653 in the cache */
   /* search916_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 9, 2670 },
      -1,
   } },

   /* replace916 -> 1350 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search917_0_0 -> 0 in the cache */
   /* search917_0_1 -> 1 in the cache */
   /* search917_0 -> 1452 in the cache */
   /* search917_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1452, 0 },
      -1,
   } },

   /* replace917 -> 1350 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search918_0 -> 9 in the cache */
   /* search918_1_0 -> 2653 in the cache */
   /* search918_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 9, 2673 },
      -1,
   } },

   /* replace918_0 -> 9 in the cache */
   /* replace918_1 -> 2653 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 9, 2653 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search919_0_0 -> 0 in the cache */
   /* search919_0_1 -> 1 in the cache */
   /* search919_0 -> 1457 in the cache */
   /* search919_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1457, 0 },
      -1,
   } },

   /* replace919_0 -> 1 in the cache */
   /* replace919_1 -> 0 in the cache */
   /* replace919 -> 1173 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search920_0 -> 9 in the cache */
   /* search920_1_0 -> 2653 in the cache */
   /* search920_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 9, 2677 },
      -1,
   } },

   /* replace920 -> 1350 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search921_0_0 -> 0 in the cache */
   /* search921_0_1 -> 1 in the cache */
   /* search921_0 -> 1449 in the cache */
   /* search921_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1449, 0 },
      -1,
   } },

   /* replace921 -> 1350 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search922_0 -> 9 in the cache */
   /* search922_1_0 -> 2653 in the cache */
   /* search922_1_1 -> 9 in the cache */
   /* search922_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 9, 2670 },
      -1,
   } },

   /* replace922 -> 1165 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search923_0_0 -> 0 in the cache */
   /* search923_0_1 -> 1 in the cache */
   /* search923_0 -> 1452 in the cache */
   /* search923_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1452, 0 },
      -1,
   } },

   /* replace923 -> 1165 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search924_0 -> 9 in the cache */
   /* search924_1_0 -> 2653 in the cache */
   /* search924_1_1 -> 9 in the cache */
   /* search924_1 -> 2666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 9, 2666 },
      -1,
   } },

   /* replace924_0 -> 9 in the cache */
   /* replace924_1 -> 2653 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 9, 2653 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search925_0_0 -> 0 in the cache */
   /* search925_0_1 -> 1 in the cache */
   /* search925_0 -> 1460 in the cache */
   /* search925_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1460, 0 },
      -1,
   } },

   /* replace925_0 -> 1 in the cache */
   /* replace925_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search926_0 -> 9 in the cache */
   /* search926_1_0 -> 2653 in the cache */
   /* search926_1_1 -> 9 in the cache */
   /* search926_1 -> 2677 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 9, 2677 },
      -1,
   } },

   /* replace926 -> 1165 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search927_0_0 -> 0 in the cache */
   /* search927_0_1 -> 1 in the cache */
   /* search927_0 -> 1449 in the cache */
   /* search927_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1449, 0 },
      -1,
   } },

   /* replace927 -> 1165 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search928_0 -> 9 in the cache */
   /* search928_1_0 -> 2653 in the cache */
   /* search928_1_1 -> 9 in the cache */
   /* search928_1 -> 2673 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 9, 2673 },
      -1,
   } },

   /* replace928_0 -> 9 in the cache */
   /* replace928_1 -> 2653 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 9, 2653 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search929_0_0 -> 0 in the cache */
   /* search929_0_1 -> 1 in the cache */
   /* search929_0 -> 1457 in the cache */
   /* search929_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1457, 0 },
      -1,
   } },

   /* replace929_0 -> 1 in the cache */
   /* replace929_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search930_0 -> 9 in the cache */
   /* search930_1_0 -> 2653 in the cache */
   /* search930_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 9, 2692 },
      -1,
   } },

   /* replace930 -> 1165 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search931_0_0 -> 0 in the cache */
   /* search931_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 1 },
      -1,
   } },
   /* search931_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2694, 0 },
      -1,
   } },

   /* replace931 -> 1165 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search932_0 -> 9 in the cache */
   /* search932_1_0 -> 2653 in the cache */
   /* search932_1_1 -> 9 in the cache */
   /* search932_1 -> 2692 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 9, 2692 },
      -1,
   } },

   /* replace932 -> 1350 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search933_0_0 -> 0 in the cache */
   /* search933_0_1 -> 1 in the cache */
   /* search933_0 -> 2694 in the cache */
   /* search933_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2694, 0 },
      -1,
   } },

   /* replace933 -> 1350 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search934_0 -> 295 in the cache */
   /* search934_1_0 -> 296 in the cache */
   /* search934_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 296, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 295, 2698 },
      -1,
   } },

   /* replace934_0_0 -> 139 in the cache */
   /* replace934_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 139, 140 },
      -1,
   } },
   /* replace934_1_0 -> 139 in the cache */
   /* replace934_1_1 -> 142 in the cache */
   /* replace934_1 -> 1762 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2700, 1762 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search935_0_0 -> 295 in the cache */
   /* search935_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 295, 140 },
      -1,
   } },
   /* search935_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2702, 904 },
      -1,
   } },

   /* replace935_0_0 -> 139 in the cache */
   /* replace935_0_1 -> 142 in the cache */
   /* replace935_0 -> 1762 in the cache */
   /* replace935_1_0 -> 140 in the cache */
   /* replace935_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1762, 2704 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search936_0 -> 295 in the cache */
   /* search936_1_0 -> 296 in the cache */
   /* search936_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 296, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 295, 2706 },
      -1,
   } },

   /* replace936_0_0 -> 139 in the cache */
   /* replace936_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 139, 140 },
      -1,
   } },
   /* replace936_1_0 -> 139 in the cache */
   /* replace936_1_1 -> 142 in the cache */
   /* replace936_1 -> 1772 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2708, 1772 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search937_0_0 -> 295 in the cache */
   /* search937_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 295, 140 },
      -1,
   } },
   /* search937_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2710, 904 },
      -1,
   } },

   /* replace937_0_0 -> 139 in the cache */
   /* replace937_0_1 -> 142 in the cache */
   /* replace937_0 -> 1772 in the cache */
   /* replace937_1_0 -> 140 in the cache */
   /* replace937_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1772, 2712 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search938_0 -> 295 in the cache */
   /* search938_1_0 -> 296 in the cache */
   /* search938_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 296, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 295, 2714 },
      -1,
   } },

   /* replace938_0_0 -> 139 in the cache */
   /* replace938_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 139, 140 },
      -1,
   } },
   /* replace938_1_0 -> 139 in the cache */
   /* replace938_1_1 -> 142 in the cache */
   /* replace938_1 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2716, 1782 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search939_0_0 -> 295 in the cache */
   /* search939_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 295, 140 },
      -1,
   } },
   /* search939_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2718, 904 },
      -1,
   } },

   /* replace939_0_0 -> 139 in the cache */
   /* replace939_0_1 -> 142 in the cache */
   /* replace939_0 -> 1782 in the cache */
   /* replace939_1_0 -> 140 in the cache */
   /* replace939_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1782, 2720 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search940_0 -> 295 in the cache */
   /* search940_1_0 -> 296 in the cache */
   /* search940_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 296, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 295, 2722 },
      -1,
   } },

   /* replace940_0_0 -> 139 in the cache */
   /* replace940_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 139, 140 },
      -1,
   } },
   /* replace940_1_0 -> 139 in the cache */
   /* replace940_1_1 -> 142 in the cache */
   /* replace940_1 -> 1792 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2724, 1792 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search941_0_0 -> 295 in the cache */
   /* search941_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 295, 140 },
      -1,
   } },
   /* search941_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2726, 904 },
      -1,
   } },

   /* replace941_0_0 -> 139 in the cache */
   /* replace941_0_1 -> 142 in the cache */
   /* replace941_0 -> 1792 in the cache */
   /* replace941_1_0 -> 140 in the cache */
   /* replace941_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 140, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1792, 2728 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search942_0 -> 295 in the cache */
   /* search942_1_0 -> 296 in the cache */
   /* search942_1_1 -> 142 in the cache */
   /* search942_1 -> 2706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 295, 2706 },
      -1,
   } },

   /* replace942_0_0 -> 139 in the cache */
   /* replace942_0_1 -> 140 in the cache */
   /* replace942_0 -> 2700 in the cache */
   /* replace942_1_0 -> 139 in the cache */
   /* replace942_1_1 -> 142 in the cache */
   /* replace942_1 -> 1762 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2700, 1762 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search943_0_0 -> 295 in the cache */
   /* search943_0_1 -> 140 in the cache */
   /* search943_0 -> 2710 in the cache */
   /* search943_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2710, 904 },
      -1,
   } },

   /* replace943_0_0 -> 139 in the cache */
   /* replace943_0_1 -> 142 in the cache */
   /* replace943_0 -> 1762 in the cache */
   /* replace943_1_0 -> 140 in the cache */
   /* replace943_1_1 -> 142 in the cache */
   /* replace943_1 -> 2704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1762, 2704 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search944_0 -> 295 in the cache */
   /* search944_1_0 -> 296 in the cache */
   /* search944_1_1 -> 142 in the cache */
   /* search944_1 -> 2698 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 295, 2698 },
      -1,
   } },

   /* replace944_0_0 -> 139 in the cache */
   /* replace944_0_1 -> 140 in the cache */
   /* replace944_0 -> 2708 in the cache */
   /* replace944_1_0 -> 139 in the cache */
   /* replace944_1_1 -> 142 in the cache */
   /* replace944_1 -> 1772 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2708, 1772 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search945_0_0 -> 295 in the cache */
   /* search945_0_1 -> 140 in the cache */
   /* search945_0 -> 2702 in the cache */
   /* search945_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2702, 904 },
      -1,
   } },

   /* replace945_0_0 -> 139 in the cache */
   /* replace945_0_1 -> 142 in the cache */
   /* replace945_0 -> 1772 in the cache */
   /* replace945_1_0 -> 140 in the cache */
   /* replace945_1_1 -> 142 in the cache */
   /* replace945_1 -> 2712 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1772, 2712 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search946_0 -> 295 in the cache */
   /* search946_1_0 -> 296 in the cache */
   /* search946_1_1 -> 142 in the cache */
   /* search946_1 -> 2722 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 295, 2722 },
      -1,
   } },

   /* replace946_0_0 -> 139 in the cache */
   /* replace946_0_1 -> 140 in the cache */
   /* replace946_0 -> 2716 in the cache */
   /* replace946_1_0 -> 139 in the cache */
   /* replace946_1_1 -> 142 in the cache */
   /* replace946_1 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2716, 1782 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search947_0_0 -> 295 in the cache */
   /* search947_0_1 -> 140 in the cache */
   /* search947_0 -> 2726 in the cache */
   /* search947_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2726, 904 },
      -1,
   } },

   /* replace947_0_0 -> 139 in the cache */
   /* replace947_0_1 -> 142 in the cache */
   /* replace947_0 -> 1782 in the cache */
   /* replace947_1_0 -> 140 in the cache */
   /* replace947_1_1 -> 142 in the cache */
   /* replace947_1 -> 2720 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1782, 2720 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search948_0 -> 295 in the cache */
   /* search948_1_0 -> 296 in the cache */
   /* search948_1_1 -> 142 in the cache */
   /* search948_1 -> 2714 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 295, 2714 },
      -1,
   } },

   /* replace948_0_0 -> 139 in the cache */
   /* replace948_0_1 -> 140 in the cache */
   /* replace948_0 -> 2724 in the cache */
   /* replace948_1_0 -> 139 in the cache */
   /* replace948_1_1 -> 142 in the cache */
   /* replace948_1 -> 1792 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2724, 1792 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search949_0_0 -> 295 in the cache */
   /* search949_0_1 -> 140 in the cache */
   /* search949_0 -> 2718 in the cache */
   /* search949_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2718, 904 },
      -1,
   } },

   /* replace949_0_0 -> 139 in the cache */
   /* replace949_0_1 -> 142 in the cache */
   /* replace949_0 -> 1792 in the cache */
   /* replace949_1_0 -> 140 in the cache */
   /* replace949_1_1 -> 142 in the cache */
   /* replace949_1 -> 2728 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1792, 2728 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search950_0_0 -> 9 in the cache */
   /* search950_0_1 -> 73 in the cache */
   /* search950_0 -> 1370 in the cache */
   /* search950_1_0_0 -> 9 in the cache */
   /* search950_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 9, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2746 },
      -1,
   } },
   /* search950_2_0 -> 9 in the cache */
   /* search950_2_1 -> 48 in the cache */
   /* search950_2 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1370, 2747, 2746 },
      -1,
   } },

   /* replace950_0_0 -> 9 in the cache */
   /* replace950_0_1 -> 48 in the cache */
   /* replace950_0 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2746 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search951_0_0_0 -> 9 in the cache */
   /* search951_0_0 -> 125 in the cache */
   /* search951_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 125, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2750 },
      -1,
   } },

   /* replace951_0_0 -> 9 in the cache */
   /* replace951_0 -> 125 in the cache */
   /* replace951_1 -> 48 in the cache */
   /* replace951 -> 2750 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search952_0_0 -> 0 in the cache */
   /* search952_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2752 },
      -1,
   } },

   /* replace952_0 -> 0 in the cache */
   /* replace952_1 -> 1 in the cache */
   /* replace952 -> 2752 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search953_0_0 -> 0 in the cache */
   /* search953_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2754 },
      -1,
   } },

   /* replace953_0 -> 0 in the cache */
   /* replace953_1 -> 1 in the cache */
   /* replace953 -> 2754 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search954_0_0 -> 0 in the cache */
   /* search954_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2756 },
      -1,
   } },

   /* replace954_0 -> 0 in the cache */
   /* replace954_1 -> 1 in the cache */
   /* replace954 -> 2756 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search955_0_0 -> 0 in the cache */
   /* search955_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2758 },
      -1,
   } },

   /* replace955_0 -> 0 in the cache */
   /* replace955_1 -> 1 in the cache */
   /* replace955 -> 2758 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search956_0 -> 0 in the cache */
   /* search956_1 -> 1 in the cache */
   /* search956 -> 2752 in the cache */

   /* replace956_0_0 -> 0 in the cache */
   /* replace956_0_1 -> 1 in the cache */
   /* replace956_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 3 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search957_0 -> 0 in the cache */
   /* search957_1 -> 1 in the cache */
   /* search957 -> 2754 in the cache */

   /* replace957_0_0 -> 0 in the cache */
   /* replace957_0_1 -> 1 in the cache */
   /* replace957_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search958_0 -> 0 in the cache */
   /* search958_1 -> 1 in the cache */
   /* search958 -> 2756 in the cache */

   /* replace958_0_0 -> 0 in the cache */
   /* replace958_0_1 -> 1 in the cache */
   /* replace958_0 -> 1143 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1143 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search959_0 -> 0 in the cache */
   /* search959_1 -> 1 in the cache */
   /* search959 -> 2758 in the cache */

   /* replace959_0_0 -> 0 in the cache */
   /* replace959_0_1 -> 1 in the cache */
   /* replace959_0 -> 1140 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1140 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search960_0_0 -> 0 in the cache */
   /* search960_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search960_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2764, 283 },
      -1,
   } },

   /* replace960_0 -> 0 in the cache */
   /* replace960_1 -> 1 in the cache */
   /* replace960 -> 2756 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search961_0_0 -> 0 in the cache */
   /* search961_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search961_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2766, 283 },
      -1,
   } },

   /* replace961_0 -> 0 in the cache */
   /* replace961_1 -> 1 in the cache */
   /* replace961 -> 2758 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search962_0_0 -> 0 in the cache */
   /* search962_0_1 -> 1 in the cache */
   /* search962_0 -> 2752 in the cache */
   /* search962_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2752, 283 },
      -1,
   } },

   /* replace962_0 -> 0 in the cache */
   /* replace962_1 -> 1 in the cache */
   /* replace962 -> 2752 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search963_0_0 -> 0 in the cache */
   /* search963_0_1 -> 1 in the cache */
   /* search963_0 -> 2754 in the cache */
   /* search963_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2754, 283 },
      -1,
   } },

   /* replace963_0 -> 0 in the cache */
   /* replace963_1 -> 1 in the cache */
   /* replace963 -> 2754 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search964_0_0 -> 0 in the cache */
   /* search964_0_1 -> 1 in the cache */
   /* search964_0 -> 2764 in the cache */
   /* search964_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2764, 273 },
      -1,
   } },

   /* replace964_0 -> 0 in the cache */
   /* replace964_1 -> 1 in the cache */
   /* replace964 -> 2756 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search965_0_0 -> 0 in the cache */
   /* search965_0_1 -> 1 in the cache */
   /* search965_0 -> 2766 in the cache */
   /* search965_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2766, 273 },
      -1,
   } },

   /* replace965_0 -> 0 in the cache */
   /* replace965_1 -> 1 in the cache */
   /* replace965 -> 2758 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search966_0_0 -> 0 in the cache */
   /* search966_0_1 -> 1 in the cache */
   /* search966_0 -> 2752 in the cache */
   /* search966_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2752, 273 },
      -1,
   } },

   /* replace966_0 -> 0 in the cache */
   /* replace966_1 -> 1 in the cache */
   /* replace966 -> 2752 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search967_0_0 -> 0 in the cache */
   /* search967_0_1 -> 1 in the cache */
   /* search967_0 -> 2754 in the cache */
   /* search967_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2754, 273 },
      -1,
   } },

   /* replace967_0 -> 0 in the cache */
   /* replace967_1 -> 1 in the cache */
   /* replace967 -> 2754 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search968_0_0 -> 0 in the cache */
   /* search968_0_1 -> 1 in the cache */
   /* search968_0 -> 2764 in the cache */
   /* search968_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2764, 273 },
      -1,
   } },

   /* replace968_0 -> 0 in the cache */
   /* replace968_1 -> 1 in the cache */
   /* replace968 -> 2758 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search969_0_0 -> 0 in the cache */
   /* search969_0_1 -> 1 in the cache */
   /* search969_0 -> 2766 in the cache */
   /* search969_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2766, 273 },
      -1,
   } },

   /* replace969_0 -> 0 in the cache */
   /* replace969_1 -> 1 in the cache */
   /* replace969 -> 2756 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search970_0_0 -> 0 in the cache */
   /* search970_0_1 -> 1 in the cache */
   /* search970_0 -> 2752 in the cache */
   /* search970_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2752, 273 },
      -1,
   } },

   /* replace970_0 -> 0 in the cache */
   /* replace970_1 -> 1 in the cache */
   /* replace970 -> 2754 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search971_0_0 -> 0 in the cache */
   /* search971_0_1 -> 1 in the cache */
   /* search971_0 -> 2754 in the cache */
   /* search971_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2754, 273 },
      -1,
   } },

   /* replace971_0 -> 0 in the cache */
   /* replace971_1 -> 1 in the cache */
   /* replace971 -> 2752 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search972_0_0 -> 0 in the cache */
   /* search972_0_1 -> 1 in the cache */
   /* search972_0 -> 2764 in the cache */
   /* search972_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2764, 283 },
      -1,
   } },

   /* replace972_0 -> 0 in the cache */
   /* replace972_1 -> 1 in the cache */
   /* replace972 -> 2758 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search973_0_0 -> 0 in the cache */
   /* search973_0_1 -> 1 in the cache */
   /* search973_0 -> 2766 in the cache */
   /* search973_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2766, 283 },
      -1,
   } },

   /* replace973_0 -> 0 in the cache */
   /* replace973_1 -> 1 in the cache */
   /* replace973 -> 2756 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search974_0_0 -> 0 in the cache */
   /* search974_0_1 -> 1 in the cache */
   /* search974_0 -> 2752 in the cache */
   /* search974_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2752, 283 },
      -1,
   } },

   /* replace974_0 -> 0 in the cache */
   /* replace974_1 -> 1 in the cache */
   /* replace974 -> 2754 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search975_0_0 -> 0 in the cache */
   /* search975_0_1 -> 1 in the cache */
   /* search975_0 -> 2754 in the cache */
   /* search975_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2754, 283 },
      -1,
   } },

   /* replace975_0 -> 0 in the cache */
   /* replace975_1 -> 1 in the cache */
   /* replace975 -> 2752 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search976_0 -> 29 in the cache */
   /* search976_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 29, 48 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2783, 2784 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2786, 2787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2785, 2788 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search977_0 -> 29 in the cache */
   /* search977_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace977_0_0 -> 29 in the cache */
   /* replace977_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace977_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2791, 241 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search978_0 -> 29 in the cache */
   /* search978_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace978_0_0 -> 29 in the cache */
   /* replace978_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace978_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2794, 241 },
      -1,
   } },

   /* ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0) */
   /* search979_0 -> 29 in the cache */
   /* search979_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fall_equal8,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace979_0_0 -> 29 in the cache */
   /* replace979_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal8,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace979_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2797, 241 },
      -1,
   } },

   /* ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0) */
   /* search980_0 -> 29 in the cache */
   /* search980_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fall_equal16,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace980_0_0 -> 29 in the cache */
   /* replace980_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal16,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace980_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2800, 241 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search981_0 -> 29 in the cache */
   /* search981_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace981_0_0 -> 2783 in the cache */
   /* replace981_0_1 -> 2784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2783, 2784 },
      -1,
   } },
   /* replace981_1_0 -> 2786 in the cache */
   /* replace981_1_1 -> 2787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2786, 2787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2803, 2804 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search982_0 -> 29 in the cache */
   /* search982_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace982_0_0_0 -> 29 in the cache */
   /* replace982_0_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 29, 48 },
      -1,
   } },
   /* replace982_0_1_0 -> 29 in the cache */
   /* replace982_0_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2807, 2808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2809 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search983_0 -> 29 in the cache */
   /* search983_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace983_0_0_0 -> 29 in the cache */
   /* replace983_0_0_1 -> 48 in the cache */
   /* replace983_0_0 -> 2807 in the cache */
   /* replace983_0_1_0 -> 29 in the cache */
   /* replace983_0_1_1 -> 48 in the cache */
   /* replace983_0_1 -> 2808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2807, 2808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2812 },
      -1,
   } },

   /* ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search984_0 -> 29 in the cache */
   /* search984_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal8,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace984_0_0_0 -> 29 in the cache */
   /* replace984_0_0_1 -> 48 in the cache */
   /* replace984_0_0 -> 2807 in the cache */
   /* replace984_0_1_0 -> 29 in the cache */
   /* replace984_0_1_1 -> 48 in the cache */
   /* replace984_0_1 -> 2808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot8,
      -1, 2,
      { 2807, 2808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2815 },
      -1,
   } },

   /* ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search985_0 -> 29 in the cache */
   /* search985_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fany_nequal16,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace985_0_0_0 -> 29 in the cache */
   /* replace985_0_0_1 -> 48 in the cache */
   /* replace985_0_0 -> 2807 in the cache */
   /* replace985_0_1_0 -> 29 in the cache */
   /* replace985_0_1_1 -> 48 in the cache */
   /* replace985_0_1 -> 2808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot16,
      -1, 2,
      { 2807, 2808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2818 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search986_0 -> 0 in the cache */
   /* search986_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace986_0_0 -> 856 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace986_1_0 -> 857 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 857, 2823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2822, 2824 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z'))) */
   /* search987_0 -> 0 in the cache */
   /* search987_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace987_0_0 -> 856 in the cache */
   /* replace987_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace987_1_0_0 -> 857 in the cache */
   /* replace987_1_0_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 857, 2823 },
      -1,
   } },
   /* replace987_1_1_0 -> 858 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 858, 2829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2828, 2830 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2827, 2831 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search988_0 -> 0 in the cache */
   /* search988_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace988_0_0_0 -> 856 in the cache */
   /* replace988_0_0_1 -> 2821 in the cache */
   /* replace988_0_0 -> 2822 in the cache */
   /* replace988_0_1_0 -> 857 in the cache */
   /* replace988_0_1_1 -> 2823 in the cache */
   /* replace988_0_1 -> 2824 in the cache */
   /* replace988_0 -> 2825 in the cache */
   /* replace988_1_0_0 -> 858 in the cache */
   /* replace988_1_0_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 858, 2829 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2835, 2836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2834, 2837 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2825, 2838 },
      -1,
   } },

   /* ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))) */
   /* search989_0 -> 0 in the cache */
   /* search989_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace989_0_0_0_0 -> 856 in the cache */
   /* replace989_0_0_0_1 -> 2821 in the cache */
   /* replace989_0_0_0 -> 2822 in the cache */
   /* replace989_0_0_1_0 -> 857 in the cache */
   /* replace989_0_0_1_1 -> 2823 in the cache */
   /* replace989_0_0_1 -> 2824 in the cache */
   /* replace989_0_0 -> 2825 in the cache */
   /* replace989_0_1_0_0 -> 858 in the cache */
   /* replace989_0_1_0_1 -> 2829 in the cache */
   /* replace989_0_1_0 -> 2834 in the cache */
   /* replace989_0_1_1_0 -> 2835 in the cache */
   /* replace989_0_1_1_1 -> 2836 in the cache */
   /* replace989_0_1_1 -> 2837 in the cache */
   /* replace989_0_1 -> 2838 in the cache */
   /* replace989_0 -> 2839 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      4, 1,
      { 2841, 2842 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      5, 1,
      { 2844, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2843, 2846 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      6, 1,
      { 2848, 2849 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      7, 1,
      { 2851, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2850, 2853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2847, 2854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2839, 2855 },
      -1,
   } },

   /* ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p'))))) */
   /* search990_0 -> 0 in the cache */
   /* search990_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace990_0_0_0_0_0 -> 856 in the cache */
   /* replace990_0_0_0_0_1 -> 2821 in the cache */
   /* replace990_0_0_0_0 -> 2822 in the cache */
   /* replace990_0_0_0_1_0 -> 857 in the cache */
   /* replace990_0_0_0_1_1 -> 2823 in the cache */
   /* replace990_0_0_0_1 -> 2824 in the cache */
   /* replace990_0_0_0 -> 2825 in the cache */
   /* replace990_0_0_1_0_0 -> 858 in the cache */
   /* replace990_0_0_1_0_1 -> 2829 in the cache */
   /* replace990_0_0_1_0 -> 2834 in the cache */
   /* replace990_0_0_1_1_0 -> 2835 in the cache */
   /* replace990_0_0_1_1_1 -> 2836 in the cache */
   /* replace990_0_0_1_1 -> 2837 in the cache */
   /* replace990_0_0_1 -> 2838 in the cache */
   /* replace990_0_0 -> 2839 in the cache */
   /* replace990_0_1_0_0_0 -> 2841 in the cache */
   /* replace990_0_1_0_0_1 -> 2842 in the cache */
   /* replace990_0_1_0_0 -> 2843 in the cache */
   /* replace990_0_1_0_1_0 -> 2844 in the cache */
   /* replace990_0_1_0_1_1 -> 2845 in the cache */
   /* replace990_0_1_0_1 -> 2846 in the cache */
   /* replace990_0_1_0 -> 2847 in the cache */
   /* replace990_0_1_1_0_0 -> 2848 in the cache */
   /* replace990_0_1_1_0_1 -> 2849 in the cache */
   /* replace990_0_1_1_0 -> 2850 in the cache */
   /* replace990_0_1_1_1_0 -> 2851 in the cache */
   /* replace990_0_1_1_1_1 -> 2852 in the cache */
   /* replace990_0_1_1_1 -> 2853 in the cache */
   /* replace990_0_1_1 -> 2854 in the cache */
   /* replace990_0_1 -> 2855 in the cache */
   /* replace990_0 -> 2856 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      8, 1,
      { 2858, 2859 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      9, 1,
      { 2861, 2862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2860, 2863 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      10, 1,
      { 2865, 2866 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      11, 1,
      { 2868, 2869 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2867, 2870 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2864, 2871 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      12, 1,
      { 2873, 2874 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      13, 1,
      { 2876, 2877 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2875, 2878 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      14, 1,
      { 2880, 2881 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      15, 1,
      { 2883, 2884 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2882, 2885 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2879, 2886 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2872, 2887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2856, 2888 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search991_0 -> 0 in the cache */
   /* search991_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace991_0_0 -> 856 in the cache */
   /* replace991_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace991_1_0 -> 857 in the cache */
   /* replace991_1_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 857, 2823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2891, 2892 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z'))) */
   /* search992_0 -> 0 in the cache */
   /* search992_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace992_0_0 -> 856 in the cache */
   /* replace992_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace992_1_0_0 -> 857 in the cache */
   /* replace992_1_0_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 857, 2823 },
      -1,
   } },
   /* replace992_1_1_0 -> 858 in the cache */
   /* replace992_1_1_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 858, 2829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2896, 2897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2895, 2898 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search993_0 -> 0 in the cache */
   /* search993_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace993_0_0_0 -> 856 in the cache */
   /* replace993_0_0_1 -> 2821 in the cache */
   /* replace993_0_0 -> 2891 in the cache */
   /* replace993_0_1_0 -> 857 in the cache */
   /* replace993_0_1_1 -> 2823 in the cache */
   /* replace993_0_1 -> 2892 in the cache */
   /* replace993_0 -> 2893 in the cache */
   /* replace993_1_0_0 -> 858 in the cache */
   /* replace993_1_0_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 858, 2829 },
      -1,
   } },
   /* replace993_1_1_0 -> 2835 in the cache */
   /* replace993_1_1_1 -> 2836 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2835, 2836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2901, 2902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2893, 2903 },
      -1,
   } },

   /* ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))) */
   /* search994_0 -> 0 in the cache */
   /* search994_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace994_0_0_0_0 -> 856 in the cache */
   /* replace994_0_0_0_1 -> 2821 in the cache */
   /* replace994_0_0_0 -> 2891 in the cache */
   /* replace994_0_0_1_0 -> 857 in the cache */
   /* replace994_0_0_1_1 -> 2823 in the cache */
   /* replace994_0_0_1 -> 2892 in the cache */
   /* replace994_0_0 -> 2893 in the cache */
   /* replace994_0_1_0_0 -> 858 in the cache */
   /* replace994_0_1_0_1 -> 2829 in the cache */
   /* replace994_0_1_0 -> 2901 in the cache */
   /* replace994_0_1_1_0 -> 2835 in the cache */
   /* replace994_0_1_1_1 -> 2836 in the cache */
   /* replace994_0_1_1 -> 2902 in the cache */
   /* replace994_0_1 -> 2903 in the cache */
   /* replace994_0 -> 2904 in the cache */
   /* replace994_1_0_0_0 -> 2841 in the cache */
   /* replace994_1_0_0_1 -> 2842 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      4, 1,
      { 2841, 2842 },
      -1,
   } },
   /* replace994_1_0_1_0 -> 2844 in the cache */
   /* replace994_1_0_1_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      5, 1,
      { 2844, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2906, 2907 },
      -1,
   } },
   /* replace994_1_1_0_0 -> 2848 in the cache */
   /* replace994_1_1_0_1 -> 2849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      6, 1,
      { 2848, 2849 },
      -1,
   } },
   /* replace994_1_1_1_0 -> 2851 in the cache */
   /* replace994_1_1_1_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      7, 1,
      { 2851, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2909, 2910 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2908, 2911 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2904, 2912 },
      -1,
   } },

   /* ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p'))))) */
   /* search995_0 -> 0 in the cache */
   /* search995_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace995_0_0_0_0_0 -> 856 in the cache */
   /* replace995_0_0_0_0_1 -> 2821 in the cache */
   /* replace995_0_0_0_0 -> 2891 in the cache */
   /* replace995_0_0_0_1_0 -> 857 in the cache */
   /* replace995_0_0_0_1_1 -> 2823 in the cache */
   /* replace995_0_0_0_1 -> 2892 in the cache */
   /* replace995_0_0_0 -> 2893 in the cache */
   /* replace995_0_0_1_0_0 -> 858 in the cache */
   /* replace995_0_0_1_0_1 -> 2829 in the cache */
   /* replace995_0_0_1_0 -> 2901 in the cache */
   /* replace995_0_0_1_1_0 -> 2835 in the cache */
   /* replace995_0_0_1_1_1 -> 2836 in the cache */
   /* replace995_0_0_1_1 -> 2902 in the cache */
   /* replace995_0_0_1 -> 2903 in the cache */
   /* replace995_0_0 -> 2904 in the cache */
   /* replace995_0_1_0_0_0 -> 2841 in the cache */
   /* replace995_0_1_0_0_1 -> 2842 in the cache */
   /* replace995_0_1_0_0 -> 2906 in the cache */
   /* replace995_0_1_0_1_0 -> 2844 in the cache */
   /* replace995_0_1_0_1_1 -> 2845 in the cache */
   /* replace995_0_1_0_1 -> 2907 in the cache */
   /* replace995_0_1_0 -> 2908 in the cache */
   /* replace995_0_1_1_0_0 -> 2848 in the cache */
   /* replace995_0_1_1_0_1 -> 2849 in the cache */
   /* replace995_0_1_1_0 -> 2909 in the cache */
   /* replace995_0_1_1_1_0 -> 2851 in the cache */
   /* replace995_0_1_1_1_1 -> 2852 in the cache */
   /* replace995_0_1_1_1 -> 2910 in the cache */
   /* replace995_0_1_1 -> 2911 in the cache */
   /* replace995_0_1 -> 2912 in the cache */
   /* replace995_0 -> 2913 in the cache */
   /* replace995_1_0_0_0_0 -> 2858 in the cache */
   /* replace995_1_0_0_0_1 -> 2859 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      8, 1,
      { 2858, 2859 },
      -1,
   } },
   /* replace995_1_0_0_1_0 -> 2861 in the cache */
   /* replace995_1_0_0_1_1 -> 2862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      9, 1,
      { 2861, 2862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2915, 2916 },
      -1,
   } },
   /* replace995_1_0_1_0_0 -> 2865 in the cache */
   /* replace995_1_0_1_0_1 -> 2866 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      10, 1,
      { 2865, 2866 },
      -1,
   } },
   /* replace995_1_0_1_1_0 -> 2868 in the cache */
   /* replace995_1_0_1_1_1 -> 2869 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      11, 1,
      { 2868, 2869 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2918, 2919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2917, 2920 },
      -1,
   } },
   /* replace995_1_1_0_0_0 -> 2873 in the cache */
   /* replace995_1_1_0_0_1 -> 2874 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      12, 1,
      { 2873, 2874 },
      -1,
   } },
   /* replace995_1_1_0_1_0 -> 2876 in the cache */
   /* replace995_1_1_0_1_1 -> 2877 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      13, 1,
      { 2876, 2877 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2922, 2923 },
      -1,
   } },
   /* replace995_1_1_1_0_0 -> 2880 in the cache */
   /* replace995_1_1_1_0_1 -> 2881 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      14, 1,
      { 2880, 2881 },
      -1,
   } },
   /* replace995_1_1_1_1_0 -> 2883 in the cache */
   /* replace995_1_1_1_1_1 -> 2884 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      15, 1,
      { 2883, 2884 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2925, 2926 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2924, 2927 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2921, 2928 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2913, 2929 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search996_0 -> 0 in the cache */
   /* search996_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace996_0_0 -> 856 in the cache */
   /* replace996_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace996_1_0 -> 857 in the cache */
   /* replace996_1_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 857, 2823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2932, 2933 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z'))) */
   /* search997_0 -> 0 in the cache */
   /* search997_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace997_0_0 -> 856 in the cache */
   /* replace997_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace997_1_0_0 -> 857 in the cache */
   /* replace997_1_0_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 857, 2823 },
      -1,
   } },
   /* replace997_1_1_0 -> 858 in the cache */
   /* replace997_1_1_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 858, 2829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2937, 2938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2936, 2939 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search998_0 -> 0 in the cache */
   /* search998_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace998_0_0_0 -> 856 in the cache */
   /* replace998_0_0_1 -> 2821 in the cache */
   /* replace998_0_0 -> 2932 in the cache */
   /* replace998_0_1_0 -> 857 in the cache */
   /* replace998_0_1_1 -> 2823 in the cache */
   /* replace998_0_1 -> 2933 in the cache */
   /* replace998_0 -> 2934 in the cache */
   /* replace998_1_0_0 -> 858 in the cache */
   /* replace998_1_0_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 858, 2829 },
      -1,
   } },
   /* replace998_1_1_0 -> 2835 in the cache */
   /* replace998_1_1_1 -> 2836 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2835, 2836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2942, 2943 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2934, 2944 },
      -1,
   } },

   /* ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))) */
   /* search999_0 -> 0 in the cache */
   /* search999_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace999_0_0_0_0 -> 856 in the cache */
   /* replace999_0_0_0_1 -> 2821 in the cache */
   /* replace999_0_0_0 -> 2932 in the cache */
   /* replace999_0_0_1_0 -> 857 in the cache */
   /* replace999_0_0_1_1 -> 2823 in the cache */
   /* replace999_0_0_1 -> 2933 in the cache */
   /* replace999_0_0 -> 2934 in the cache */
   /* replace999_0_1_0_0 -> 858 in the cache */
   /* replace999_0_1_0_1 -> 2829 in the cache */
   /* replace999_0_1_0 -> 2942 in the cache */
   /* replace999_0_1_1_0 -> 2835 in the cache */
   /* replace999_0_1_1_1 -> 2836 in the cache */
   /* replace999_0_1_1 -> 2943 in the cache */
   /* replace999_0_1 -> 2944 in the cache */
   /* replace999_0 -> 2945 in the cache */
   /* replace999_1_0_0_0 -> 2841 in the cache */
   /* replace999_1_0_0_1 -> 2842 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      4, 1,
      { 2841, 2842 },
      -1,
   } },
   /* replace999_1_0_1_0 -> 2844 in the cache */
   /* replace999_1_0_1_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      5, 1,
      { 2844, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2947, 2948 },
      -1,
   } },
   /* replace999_1_1_0_0 -> 2848 in the cache */
   /* replace999_1_1_0_1 -> 2849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      6, 1,
      { 2848, 2849 },
      -1,
   } },
   /* replace999_1_1_1_0 -> 2851 in the cache */
   /* replace999_1_1_1_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      7, 1,
      { 2851, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2950, 2951 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2949, 2952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2945, 2953 },
      -1,
   } },

   /* ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p'))))) */
   /* search1000_0 -> 0 in the cache */
   /* search1000_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1000_0_0_0_0_0 -> 856 in the cache */
   /* replace1000_0_0_0_0_1 -> 2821 in the cache */
   /* replace1000_0_0_0_0 -> 2932 in the cache */
   /* replace1000_0_0_0_1_0 -> 857 in the cache */
   /* replace1000_0_0_0_1_1 -> 2823 in the cache */
   /* replace1000_0_0_0_1 -> 2933 in the cache */
   /* replace1000_0_0_0 -> 2934 in the cache */
   /* replace1000_0_0_1_0_0 -> 858 in the cache */
   /* replace1000_0_0_1_0_1 -> 2829 in the cache */
   /* replace1000_0_0_1_0 -> 2942 in the cache */
   /* replace1000_0_0_1_1_0 -> 2835 in the cache */
   /* replace1000_0_0_1_1_1 -> 2836 in the cache */
   /* replace1000_0_0_1_1 -> 2943 in the cache */
   /* replace1000_0_0_1 -> 2944 in the cache */
   /* replace1000_0_0 -> 2945 in the cache */
   /* replace1000_0_1_0_0_0 -> 2841 in the cache */
   /* replace1000_0_1_0_0_1 -> 2842 in the cache */
   /* replace1000_0_1_0_0 -> 2947 in the cache */
   /* replace1000_0_1_0_1_0 -> 2844 in the cache */
   /* replace1000_0_1_0_1_1 -> 2845 in the cache */
   /* replace1000_0_1_0_1 -> 2948 in the cache */
   /* replace1000_0_1_0 -> 2949 in the cache */
   /* replace1000_0_1_1_0_0 -> 2848 in the cache */
   /* replace1000_0_1_1_0_1 -> 2849 in the cache */
   /* replace1000_0_1_1_0 -> 2950 in the cache */
   /* replace1000_0_1_1_1_0 -> 2851 in the cache */
   /* replace1000_0_1_1_1_1 -> 2852 in the cache */
   /* replace1000_0_1_1_1 -> 2951 in the cache */
   /* replace1000_0_1_1 -> 2952 in the cache */
   /* replace1000_0_1 -> 2953 in the cache */
   /* replace1000_0 -> 2954 in the cache */
   /* replace1000_1_0_0_0_0 -> 2858 in the cache */
   /* replace1000_1_0_0_0_1 -> 2859 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      8, 1,
      { 2858, 2859 },
      -1,
   } },
   /* replace1000_1_0_0_1_0 -> 2861 in the cache */
   /* replace1000_1_0_0_1_1 -> 2862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      9, 1,
      { 2861, 2862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2956, 2957 },
      -1,
   } },
   /* replace1000_1_0_1_0_0 -> 2865 in the cache */
   /* replace1000_1_0_1_0_1 -> 2866 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      10, 1,
      { 2865, 2866 },
      -1,
   } },
   /* replace1000_1_0_1_1_0 -> 2868 in the cache */
   /* replace1000_1_0_1_1_1 -> 2869 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      11, 1,
      { 2868, 2869 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2959, 2960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2958, 2961 },
      -1,
   } },
   /* replace1000_1_1_0_0_0 -> 2873 in the cache */
   /* replace1000_1_1_0_0_1 -> 2874 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      12, 1,
      { 2873, 2874 },
      -1,
   } },
   /* replace1000_1_1_0_1_0 -> 2876 in the cache */
   /* replace1000_1_1_0_1_1 -> 2877 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      13, 1,
      { 2876, 2877 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2963, 2964 },
      -1,
   } },
   /* replace1000_1_1_1_0_0 -> 2880 in the cache */
   /* replace1000_1_1_1_0_1 -> 2881 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      14, 1,
      { 2880, 2881 },
      -1,
   } },
   /* replace1000_1_1_1_1_0 -> 2883 in the cache */
   /* replace1000_1_1_1_1_1 -> 2884 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      15, 1,
      { 2883, 2884 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2966, 2967 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2965, 2968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2962, 2969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2954, 2970 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search1001_0 -> 0 in the cache */
   /* search1001_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1001_0_0 -> 856 in the cache */
   /* replace1001_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace1001_1_0 -> 857 in the cache */
   /* replace1001_1_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 857, 2823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2973, 2974 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z'))) */
   /* search1002_0 -> 0 in the cache */
   /* search1002_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1002_0_0 -> 856 in the cache */
   /* replace1002_0_1 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 856, 2821 },
      -1,
   } },
   /* replace1002_1_0_0 -> 857 in the cache */
   /* replace1002_1_0_1 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 857, 2823 },
      -1,
   } },
   /* replace1002_1_1_0 -> 858 in the cache */
   /* replace1002_1_1_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 858, 2829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2978, 2979 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2977, 2980 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search1003_0 -> 0 in the cache */
   /* search1003_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1003_0_0_0 -> 856 in the cache */
   /* replace1003_0_0_1 -> 2821 in the cache */
   /* replace1003_0_0 -> 2973 in the cache */
   /* replace1003_0_1_0 -> 857 in the cache */
   /* replace1003_0_1_1 -> 2823 in the cache */
   /* replace1003_0_1 -> 2974 in the cache */
   /* replace1003_0 -> 2975 in the cache */
   /* replace1003_1_0_0 -> 858 in the cache */
   /* replace1003_1_0_1 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 858, 2829 },
      -1,
   } },
   /* replace1003_1_1_0 -> 2835 in the cache */
   /* replace1003_1_1_1 -> 2836 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2835, 2836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2983, 2984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2975, 2985 },
      -1,
   } },

   /* ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))) */
   /* search1004_0 -> 0 in the cache */
   /* search1004_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1004_0_0_0_0 -> 856 in the cache */
   /* replace1004_0_0_0_1 -> 2821 in the cache */
   /* replace1004_0_0_0 -> 2973 in the cache */
   /* replace1004_0_0_1_0 -> 857 in the cache */
   /* replace1004_0_0_1_1 -> 2823 in the cache */
   /* replace1004_0_0_1 -> 2974 in the cache */
   /* replace1004_0_0 -> 2975 in the cache */
   /* replace1004_0_1_0_0 -> 858 in the cache */
   /* replace1004_0_1_0_1 -> 2829 in the cache */
   /* replace1004_0_1_0 -> 2983 in the cache */
   /* replace1004_0_1_1_0 -> 2835 in the cache */
   /* replace1004_0_1_1_1 -> 2836 in the cache */
   /* replace1004_0_1_1 -> 2984 in the cache */
   /* replace1004_0_1 -> 2985 in the cache */
   /* replace1004_0 -> 2986 in the cache */
   /* replace1004_1_0_0_0 -> 2841 in the cache */
   /* replace1004_1_0_0_1 -> 2842 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      4, 1,
      { 2841, 2842 },
      -1,
   } },
   /* replace1004_1_0_1_0 -> 2844 in the cache */
   /* replace1004_1_0_1_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      5, 1,
      { 2844, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2988, 2989 },
      -1,
   } },
   /* replace1004_1_1_0_0 -> 2848 in the cache */
   /* replace1004_1_1_0_1 -> 2849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      6, 1,
      { 2848, 2849 },
      -1,
   } },
   /* replace1004_1_1_1_0 -> 2851 in the cache */
   /* replace1004_1_1_1_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      7, 1,
      { 2851, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2991, 2992 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2990, 2993 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2986, 2994 },
      -1,
   } },

   /* ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p'))))) */
   /* search1005_0 -> 0 in the cache */
   /* search1005_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1005_0_0_0_0_0 -> 856 in the cache */
   /* replace1005_0_0_0_0_1 -> 2821 in the cache */
   /* replace1005_0_0_0_0 -> 2973 in the cache */
   /* replace1005_0_0_0_1_0 -> 857 in the cache */
   /* replace1005_0_0_0_1_1 -> 2823 in the cache */
   /* replace1005_0_0_0_1 -> 2974 in the cache */
   /* replace1005_0_0_0 -> 2975 in the cache */
   /* replace1005_0_0_1_0_0 -> 858 in the cache */
   /* replace1005_0_0_1_0_1 -> 2829 in the cache */
   /* replace1005_0_0_1_0 -> 2983 in the cache */
   /* replace1005_0_0_1_1_0 -> 2835 in the cache */
   /* replace1005_0_0_1_1_1 -> 2836 in the cache */
   /* replace1005_0_0_1_1 -> 2984 in the cache */
   /* replace1005_0_0_1 -> 2985 in the cache */
   /* replace1005_0_0 -> 2986 in the cache */
   /* replace1005_0_1_0_0_0 -> 2841 in the cache */
   /* replace1005_0_1_0_0_1 -> 2842 in the cache */
   /* replace1005_0_1_0_0 -> 2988 in the cache */
   /* replace1005_0_1_0_1_0 -> 2844 in the cache */
   /* replace1005_0_1_0_1_1 -> 2845 in the cache */
   /* replace1005_0_1_0_1 -> 2989 in the cache */
   /* replace1005_0_1_0 -> 2990 in the cache */
   /* replace1005_0_1_1_0_0 -> 2848 in the cache */
   /* replace1005_0_1_1_0_1 -> 2849 in the cache */
   /* replace1005_0_1_1_0 -> 2991 in the cache */
   /* replace1005_0_1_1_1_0 -> 2851 in the cache */
   /* replace1005_0_1_1_1_1 -> 2852 in the cache */
   /* replace1005_0_1_1_1 -> 2992 in the cache */
   /* replace1005_0_1_1 -> 2993 in the cache */
   /* replace1005_0_1 -> 2994 in the cache */
   /* replace1005_0 -> 2995 in the cache */
   /* replace1005_1_0_0_0_0 -> 2858 in the cache */
   /* replace1005_1_0_0_0_1 -> 2859 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      8, 1,
      { 2858, 2859 },
      -1,
   } },
   /* replace1005_1_0_0_1_0 -> 2861 in the cache */
   /* replace1005_1_0_0_1_1 -> 2862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      9, 1,
      { 2861, 2862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2997, 2998 },
      -1,
   } },
   /* replace1005_1_0_1_0_0 -> 2865 in the cache */
   /* replace1005_1_0_1_0_1 -> 2866 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      10, 1,
      { 2865, 2866 },
      -1,
   } },
   /* replace1005_1_0_1_1_0 -> 2868 in the cache */
   /* replace1005_1_0_1_1_1 -> 2869 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      11, 1,
      { 2868, 2869 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 3000, 3001 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2999, 3002 },
      -1,
   } },
   /* replace1005_1_1_0_0_0 -> 2873 in the cache */
   /* replace1005_1_1_0_0_1 -> 2874 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      12, 1,
      { 2873, 2874 },
      -1,
   } },
   /* replace1005_1_1_0_1_0 -> 2876 in the cache */
   /* replace1005_1_1_0_1_1 -> 2877 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      13, 1,
      { 2876, 2877 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 3004, 3005 },
      -1,
   } },
   /* replace1005_1_1_1_0_0 -> 2880 in the cache */
   /* replace1005_1_1_1_0_1 -> 2881 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      14, 1,
      { 2880, 2881 },
      -1,
   } },
   /* replace1005_1_1_1_1_0 -> 2883 in the cache */
   /* replace1005_1_1_1_1_1 -> 2884 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      15, 1,
      { 2883, 2884 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 3007, 3008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 3006, 3009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 3003, 3010 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2995, 3011 },
      -1,
   } },

   /* ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search1006_0_0 -> 0 in the cache */
   /* search1006_0_1 -> 1 in the cache */
   /* search1006_0 -> 2764 in the cache */
   /* search1006_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2764, 283 },
      -1,
   } },

   /* replace1006_0 -> 0 in the cache */
   /* replace1006_1 -> 1 in the cache */
   /* replace1006 -> 1143 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search1007_0_0 -> 0 in the cache */
   /* search1007_0_1 -> 1 in the cache */
   /* search1007_0 -> 2766 in the cache */
   /* search1007_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2766, 283 },
      -1,
   } },

   /* replace1007_0 -> 0 in the cache */
   /* replace1007_1 -> 1 in the cache */
   /* replace1007 -> 1140 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search1008_0_0 -> 0 in the cache */
   /* search1008_0_1 -> 1 in the cache */
   /* search1008_0 -> 2752 in the cache */
   /* search1008_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2752, 283 },
      -1,
   } },

   /* replace1008_0 -> 0 in the cache */
   /* replace1008_1 -> 1 in the cache */
   /* replace1008 -> 3 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search1009_0_0 -> 0 in the cache */
   /* search1009_0_1 -> 1 in the cache */
   /* search1009_0 -> 2754 in the cache */
   /* search1009_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2754, 283 },
      -1,
   } },

   /* replace1009_0 -> 0 in the cache */
   /* replace1009_1 -> 1 in the cache */
   /* replace1009 -> 6 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search1010_0_0 -> 0 in the cache */
   /* search1010_0_1 -> 1 in the cache */
   /* search1010_0 -> 2764 in the cache */
   /* search1010_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2764, 273 },
      -1,
   } },

   /* replace1010_0 -> 0 in the cache */
   /* replace1010_1 -> 1 in the cache */
   /* replace1010 -> 1143 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search1011_0_0 -> 0 in the cache */
   /* search1011_0_1 -> 1 in the cache */
   /* search1011_0 -> 2766 in the cache */
   /* search1011_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2766, 273 },
      -1,
   } },

   /* replace1011_0 -> 0 in the cache */
   /* replace1011_1 -> 1 in the cache */
   /* replace1011 -> 1140 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search1012_0_0 -> 0 in the cache */
   /* search1012_0_1 -> 1 in the cache */
   /* search1012_0 -> 2752 in the cache */
   /* search1012_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2752, 273 },
      -1,
   } },

   /* replace1012_0 -> 0 in the cache */
   /* replace1012_1 -> 1 in the cache */
   /* replace1012 -> 3 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search1013_0_0 -> 0 in the cache */
   /* search1013_0_1 -> 1 in the cache */
   /* search1013_0 -> 2754 in the cache */
   /* search1013_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2754, 273 },
      -1,
   } },

   /* replace1013_0 -> 0 in the cache */
   /* replace1013_1 -> 1 in the cache */
   /* replace1013 -> 6 in the cache */

   /* ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search1014_0_0 -> 0 in the cache */
   /* search1014_0_1 -> 1 in the cache */
   /* search1014_0 -> 2764 in the cache */
   /* search1014_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2764, 273 },
      -1,
   } },

   /* replace1014_0 -> 0 in the cache */
   /* replace1014_1 -> 1 in the cache */
   /* replace1014 -> 1140 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search1015_0_0 -> 0 in the cache */
   /* search1015_0_1 -> 1 in the cache */
   /* search1015_0 -> 2766 in the cache */
   /* search1015_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2766, 273 },
      -1,
   } },

   /* replace1015_0 -> 0 in the cache */
   /* replace1015_1 -> 1 in the cache */
   /* replace1015 -> 1143 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search1016_0_0 -> 0 in the cache */
   /* search1016_0_1 -> 1 in the cache */
   /* search1016_0 -> 2752 in the cache */
   /* search1016_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2752, 273 },
      -1,
   } },

   /* replace1016_0 -> 0 in the cache */
   /* replace1016_1 -> 1 in the cache */
   /* replace1016 -> 6 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search1017_0_0 -> 0 in the cache */
   /* search1017_0_1 -> 1 in the cache */
   /* search1017_0 -> 2754 in the cache */
   /* search1017_1 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2754, 273 },
      -1,
   } },

   /* replace1017_0 -> 0 in the cache */
   /* replace1017_1 -> 1 in the cache */
   /* replace1017 -> 3 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search1018_0_0 -> 0 in the cache */
   /* search1018_0_1 -> 1 in the cache */
   /* search1018_0 -> 2764 in the cache */
   /* search1018_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2764, 283 },
      -1,
   } },

   /* replace1018_0 -> 0 in the cache */
   /* replace1018_1 -> 1 in the cache */
   /* replace1018 -> 1140 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search1019_0_0 -> 0 in the cache */
   /* search1019_0_1 -> 1 in the cache */
   /* search1019_0 -> 2766 in the cache */
   /* search1019_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2766, 283 },
      -1,
   } },

   /* replace1019_0 -> 0 in the cache */
   /* replace1019_1 -> 1 in the cache */
   /* replace1019 -> 1143 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search1020_0_0 -> 0 in the cache */
   /* search1020_0_1 -> 1 in the cache */
   /* search1020_0 -> 2752 in the cache */
   /* search1020_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2752, 283 },
      -1,
   } },

   /* replace1020_0 -> 0 in the cache */
   /* replace1020_1 -> 1 in the cache */
   /* replace1020 -> 6 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search1021_0_0 -> 0 in the cache */
   /* search1021_0_1 -> 1 in the cache */
   /* search1021_0 -> 2754 in the cache */
   /* search1021_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2754, 283 },
      -1,
   } },

   /* replace1021_0 -> 0 in the cache */
   /* replace1021_1 -> 1 in the cache */
   /* replace1021 -> 3 in the cache */

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search1022_0_0 -> 9 in the cache */
   /* search1022_0 -> 118 in the cache */
   /* search1022_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 118, 9 },
      -1,
   } },

   /* replace1022_0 -> 9 in the cache */
   /* replace1022_1 -> 8 in the cache */
   /* replace1022 -> 1224 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search1023_0_0 -> 9 in the cache */
   /* search1023_0 -> 118 in the cache */
   /* search1023_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 118, 9 },
      -1,
   } },

   /* replace1023_0 -> 9 in the cache */
   /* replace1023_1 -> 8 in the cache */
   /* replace1023 -> 1226 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search1024_0_0 -> 847 in the cache */
   /* search1024_0 -> 1345 in the cache */
   /* search1024_1_0 -> 1251 in the cache */
   /* search1024_1 -> 2605 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1345, 2605 },
      -1,
   } },

   /* replace1024_0_0 -> 847 in the cache */
   /* replace1024_0_1 -> 1251 in the cache */
   /* replace1024_0 -> 1263 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1263 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search1025_0_0 -> 847 in the cache */
   /* search1025_0 -> 1345 in the cache */
   /* search1025_1_0 -> 1251 in the cache */
   /* search1025_1 -> 2605 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1345, 2605 },
      -1,
   } },

   /* replace1025_0_0 -> 847 in the cache */
   /* replace1025_0_1 -> 1251 in the cache */
   /* replace1025_0 -> 1263 in the cache */
   /* replace1025 -> 3032 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search1026_0_0 -> 847 in the cache */
   /* search1026_0 -> 1345 in the cache */
   /* search1026_1_0 -> 1251 in the cache */
   /* search1026_1 -> 2605 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1345, 2605 },
      -1,
   } },

   /* replace1026_0_0 -> 847 in the cache */
   /* replace1026_0_1 -> 1251 in the cache */
   /* replace1026_0 -> 1255 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1255 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search1027_0_0 -> 847 in the cache */
   /* search1027_0 -> 1246 in the cache */
   /* search1027_1_0 -> 1251 in the cache */
   /* search1027_1 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1246, 1252 },
      -1,
   } },

   /* replace1027_0_0 -> 847 in the cache */
   /* replace1027_0_1 -> 1251 in the cache */
   /* replace1027_0 -> 1263 in the cache */
   /* replace1027 -> 1386 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search1028_0_0_0 -> 847 in the cache */
   /* search1028_0_0 -> 1246 in the cache */
   /* search1028_0_1_0 -> 1251 in the cache */
   /* search1028_0_1 -> 1252 in the cache */
   /* search1028_0 -> 1282 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1282 },
      -1,
   } },

   /* replace1028_0_0 -> 847 in the cache */
   /* replace1028_0_1 -> 1251 in the cache */
   /* replace1028_0 -> 1255 in the cache */
   /* replace1028 -> 1383 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1029_1 -> 569 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3038, 569 },
      -1,
   } },

   /* replace1029_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1030_1 -> 261 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3041, 261 },
      -1,
   } },

   /* replace1030_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search1031_0_0_0 -> 847 in the cache */
   /* search1031_0_0 -> 1246 in the cache */
   /* search1031_0 -> 1249 in the cache */
   /* search1031_1 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1249, 1346 },
      -1,
   } },

   /* replace1031 -> 847 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search1032_0 -> 9 in the cache */
   /* search1032_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1032 -> 1165 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search1033_0 -> 9 in the cache */
   /* search1033_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1033 -> 1350 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search1034_0 -> 9 in the cache */
   /* search1034_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1034 -> 1350 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search1035_0 -> 9 in the cache */
   /* search1035_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1035 -> 1165 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search1036_0 -> 9 in the cache */
   /* search1036_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1036 -> 1165 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search1037_0 -> 9 in the cache */
   /* search1037_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1037 -> 1350 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search1038_0 -> 9 in the cache */
   /* search1038_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1038 -> 1165 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1039_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3052, 9 },
      -1,
   } },

   /* replace1039 -> 1350 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search1040_0 -> 3052 in the cache */
   /* search1040_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 3052, 9 },
      -1,
   } },

   /* replace1040 -> 1350 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search1041_0 -> 3052 in the cache */
   /* search1041_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 3052, 9 },
      -1,
   } },

   /* replace1041 -> 1165 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search1042_0 -> 9 in the cache */
   /* search1042_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1042 -> 9 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search1043_0 -> 9 in the cache */
   /* search1043_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace1043 -> 73 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search1044_0 -> 9 in the cache */
   /* search1044_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 75 },
      -1,
   } },

   /* replace1044 -> 9 in the cache */

   /* ('iand', 'a', ('inot', 'a')) => 0 */
   /* search1045_0 -> 9 in the cache */
   /* search1045_1_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 3059 },
      -1,
   } },

   /* replace1045 -> 73 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search1046_0 -> 9 in the cache */
   /* search1046_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1046 -> 9 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search1047_0 -> 9 in the cache */
   /* search1047_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace1047 -> 9 in the cache */

   /* ('ior', 'a', -1) => -1 */
   /* search1048_0 -> 9 in the cache */
   /* search1048_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 9, 75 },
      -1,
   } },

   /* replace1048 -> 75 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search1049_0 -> 9 in the cache */
   /* search1049_1_0 -> 9 in the cache */
   /* search1049_1 -> 3059 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 9, 3059 },
      -1,
   } },

   /* replace1049 -> 75 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search1050_0 -> 9 in the cache */
   /* search1050_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 9, 9 },
      -1,
   } },

   /* replace1050 -> 73 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search1051_0 -> 9 in the cache */
   /* search1051_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 9, 73 },
      -1,
   } },

   /* replace1051 -> 9 in the cache */

   /* ('ixor', 'a', ('ixor', 'a', 'b')) => b */
   /* search1052_0 -> 0 in the cache */
   /* search1052_1_0 -> 0 in the cache */
   /* search1052_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 0, 3067 },
      -1,
   } },

   /* replace1052 -> 1 in the cache */

   /* ('ixor', 'a', -1) => ('inot', 'a') */
   /* search1053_0 -> 9 in the cache */
   /* search1053_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 9, 75 },
      -1,
   } },

   /* replace1053_0 -> 9 in the cache */
   /* replace1053 -> 3059 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search1054_0_0 -> 9 in the cache */
   /* search1054_0 -> 3059 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3059 },
      -1,
   } },

   /* replace1054 -> 9 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search1055_0_0 -> 0 in the cache */
   /* search1055_0_1 -> 1 in the cache */
   /* search1055_0 -> 214 in the cache */
   /* search1055_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 214, 1 },
      -1,
   } },

   /* replace1055 -> 1 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search1056_0_0 -> 0 in the cache */
   /* search1056_0_1 -> 1 in the cache */
   /* search1056_0 -> 96 in the cache */
   /* search1056_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 96, 1 },
      -1,
   } },

   /* replace1056_0 -> 0 in the cache */
   /* replace1056_1 -> 1 in the cache */
   /* replace1056 -> 2694 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search1057_0_0 -> 0 in the cache */
   /* search1057_0_1 -> 1 in the cache */
   /* search1057_0 -> 96 in the cache */
   /* search1057_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 96, 1 },
      -1,
   } },

   /* replace1057 -> 1 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search1058_0_0 -> 0 in the cache */
   /* search1058_0_1 -> 1 in the cache */
   /* search1058_0 -> 214 in the cache */
   /* search1058_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 214, 1 },
      -1,
   } },

   /* replace1058_0 -> 0 in the cache */
   /* replace1058_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('iand(is_used_once)', 'a', 'b'), ('iand(is_used_once)', 'a', 'c')) => ('iand', 'a', ('iand', 'b', 'c')) */
   /* search1059_0_0 -> 139 in the cache */
   /* search1059_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 139, 140 },
      0,
   } },
   /* search1059_1_0 -> 139 in the cache */
   /* search1059_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 139, 142 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3076, 3077 },
      -1,
   } },

   /* replace1059_0 -> 139 in the cache */
   /* replace1059_1_0 -> 140 in the cache */
   /* replace1059_1_1 -> 142 in the cache */
   /* replace1059_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 139, 205 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', 0, ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search1060_0 -> 34 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 3080 },
      -1,
   } },

   /* replace1060_0 -> 135 in the cache */
   /* replace1060_1_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1060_1_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3082, 3083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 135, 3084 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), 0) */
   /* search1061_0 -> 34 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 3086 },
      -1,
   } },

   /* replace1061_0_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1061_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3088, 3089 },
      -1,
   } },
   /* replace1061_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3090, 135 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search1062_0 -> 34 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 3092 },
      -1,
   } },

   /* replace1062_0_0 -> 34 in the cache */
   /* replace1062_0 -> 3088 in the cache */
   /* replace1062_1_0_0 -> 34 in the cache */
   /* replace1062_1_0 -> 3082 in the cache */
   /* replace1062_1_1_0 -> 53 in the cache */
   /* replace1062_1_1 -> 3083 in the cache */
   /* replace1062_1 -> 3084 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3088, 3084 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a')) */
   /* search1063_0 -> 34 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 3095 },
      -1,
   } },

   /* replace1063_0_0_0 -> 34 in the cache */
   /* replace1063_0_0 -> 3088 in the cache */
   /* replace1063_0_1_0 -> 53 in the cache */
   /* replace1063_0_1 -> 3089 in the cache */
   /* replace1063_0 -> 3090 in the cache */
   /* replace1063_1_0 -> 34 in the cache */
   /* replace1063_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3090, 3082 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search1064_0 -> 34 in the cache */
   /* search1064_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 34, 3080 },
      -1,
   } },

   /* replace1064_0_0 -> 34 in the cache */
   /* replace1064_0 -> 3088 in the cache */
   /* replace1064_1_0_0 -> 34 in the cache */
   /* replace1064_1_0 -> 3082 in the cache */
   /* replace1064_1_1_0 -> 53 in the cache */
   /* replace1064_1_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3082, 3083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3088, 3099 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a')) */
   /* search1065_0 -> 34 in the cache */
   /* search1065_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 34, 3086 },
      -1,
   } },

   /* replace1065_0_0_0 -> 34 in the cache */
   /* replace1065_0_0 -> 3088 in the cache */
   /* replace1065_0_1_0 -> 53 in the cache */
   /* replace1065_0_1 -> 3089 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3088, 3089 },
      -1,
   } },
   /* replace1065_1_0 -> 34 in the cache */
   /* replace1065_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3102, 3082 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', -1, ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search1066_0 -> 34 in the cache */
   /* search1066_1 -> 3092 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 34, 3092 },
      -1,
   } },

   /* replace1066_0 -> 137 in the cache */
   /* replace1066_1_0_0 -> 34 in the cache */
   /* replace1066_1_0 -> 3082 in the cache */
   /* replace1066_1_1_0 -> 53 in the cache */
   /* replace1066_1_1 -> 3083 in the cache */
   /* replace1066_1 -> 3099 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 137, 3099 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), -1) */
   /* search1067_0 -> 34 in the cache */
   /* search1067_1 -> 3095 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 34, 3095 },
      -1,
   } },

   /* replace1067_0_0_0 -> 34 in the cache */
   /* replace1067_0_0 -> 3088 in the cache */
   /* replace1067_0_1_0 -> 53 in the cache */
   /* replace1067_0_1 -> 3089 in the cache */
   /* replace1067_0 -> 3102 in the cache */
   /* replace1067_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3102, 137 },
      -1,
   } },

   /* ('ixor@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ixor', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search1068_0 -> 34 in the cache */
   /* search1068_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 34, 3080 },
      -1,
   } },

   /* replace1068_0_0 -> 34 in the cache */
   /* replace1068_0 -> 3088 in the cache */
   /* replace1068_1_0_0 -> 34 in the cache */
   /* replace1068_1_0 -> 3082 in the cache */
   /* replace1068_1_1_0 -> 53 in the cache */
   /* replace1068_1_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3082, 3083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3088, 3109 },
      -1,
   } },

   /* ('ixor@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ixor', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a')) */
   /* search1069_0 -> 34 in the cache */
   /* search1069_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 34, 3086 },
      -1,
   } },

   /* replace1069_0_0_0 -> 34 in the cache */
   /* replace1069_0_0 -> 3088 in the cache */
   /* replace1069_0_1_0 -> 53 in the cache */
   /* replace1069_0_1 -> 3089 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3088, 3089 },
      -1,
   } },
   /* replace1069_1_0 -> 34 in the cache */
   /* replace1069_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 3112, 3082 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search1070_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search1070_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3114, 3115 },
      -1,
   } },

   /* replace1070_0_0 -> 0 in the cache */
   /* replace1070_0_1 -> 1 in the cache */
   /* replace1070_0 -> 2694 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2694 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search1071_0_0 -> 0 in the cache */
   /* search1071_0 -> 3114 in the cache */
   /* search1071_1_0 -> 1 in the cache */
   /* search1071_1 -> 3115 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3114, 3115 },
      -1,
   } },

   /* replace1071_0_0 -> 0 in the cache */
   /* replace1071_0_1 -> 1 in the cache */
   /* replace1071_0 -> 3075 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 3075 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search1072_0 -> 1346 in the cache */
   /* search1072_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1346, 29 },
      -1,
   } },

   /* replace1072 -> 1346 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search1073_0 -> 9 in the cache */
   /* search1073_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 9, 135 },
      -1,
   } },

   /* replace1073 -> 9 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search1074_0 -> 1346 in the cache */
   /* search1074_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1346, 29 },
      -1,
   } },

   /* replace1074 -> 1346 in the cache */

   /* ('ishr', -1, 'a') => -1 */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   /* search1075_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3123, 29 },
      -1,
   } },

   /* replace1075 -> 3123 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search1076_0 -> 9 in the cache */
   /* search1076_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 9, 135 },
      -1,
   } },

   /* replace1076 -> 9 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search1077_0 -> 1346 in the cache */
   /* search1077_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1346, 29 },
      -1,
   } },

   /* replace1077 -> 1346 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search1078_0 -> 9 in the cache */
   /* search1078_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 9, 135 },
      -1,
   } },

   /* replace1078 -> 9 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search1079_0_0 -> 24 in the cache */
   /* search1079_0_1 -> 48 in the cache */
   /* search1079_0 -> 2472 in the cache */
   /* search1079_1_0 -> 24 in the cache */
   /* search1079_1_1_0 -> 943 in the cache */
   /* search1079_1_1_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 943, 3128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 24, 3129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2472, 3130 },
      -1,
   } },

   /* replace1079_0 -> 24 in the cache */
   /* replace1079_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 24, 48 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search1080_0_0 -> 24 in the cache */
   /* search1080_0_1 -> 48 in the cache */
   /* search1080_0 -> 2472 in the cache */
   /* search1080_1_0 -> 24 in the cache */
   /* search1080_1_1_0 -> 943 in the cache */
   /* search1080_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 943, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 24, 3133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2472, 3134 },
      -1,
   } },

   /* replace1080_0 -> 24 in the cache */
   /* replace1080_1 -> 48 in the cache */
   /* replace1080 -> 3132 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search1081_0_0 -> 29 in the cache */
   /* search1081_0_1 -> 48 in the cache */
   /* search1081_0 -> 1036 in the cache */
   /* search1081_1_0 -> 29 in the cache */
   /* search1081_1_1_0 -> 964 in the cache */
   /* search1081_1_1_1_0 -> 48 in the cache */
   /* search1081_1_1_1 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 964, 3128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 29, 3136 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1036, 3137 },
      -1,
   } },

   /* replace1081_0 -> 29 in the cache */
   /* replace1081_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search1082_0_0 -> 29 in the cache */
   /* search1082_0_1 -> 48 in the cache */
   /* search1082_0 -> 1036 in the cache */
   /* search1082_1_0 -> 29 in the cache */
   /* search1082_1_1_0 -> 964 in the cache */
   /* search1082_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 964, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 3140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1036, 3141 },
      -1,
   } },

   /* replace1082_0 -> 29 in the cache */
   /* replace1082_1 -> 48 in the cache */
   /* replace1082 -> 3139 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search1083_0_0 -> 24 in the cache */
   /* search1083_0_1 -> 48 in the cache */
   /* search1083_0 -> 2476 in the cache */
   /* search1083_1_0 -> 24 in the cache */
   /* search1083_1_1_0 -> 943 in the cache */
   /* search1083_1_1_1_0 -> 48 in the cache */
   /* search1083_1_1_1 -> 3128 in the cache */
   /* search1083_1_1 -> 3129 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 24, 3129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2476, 3143 },
      -1,
   } },

   /* replace1083_0 -> 24 in the cache */
   /* replace1083_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 24, 48 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search1084_0_0 -> 24 in the cache */
   /* search1084_0_1 -> 48 in the cache */
   /* search1084_0 -> 2476 in the cache */
   /* search1084_1_0 -> 24 in the cache */
   /* search1084_1_1_0 -> 943 in the cache */
   /* search1084_1_1_1 -> 48 in the cache */
   /* search1084_1_1 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 24, 3133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2476, 3146 },
      -1,
   } },

   /* replace1084_0 -> 24 in the cache */
   /* replace1084_1 -> 48 in the cache */
   /* replace1084 -> 3145 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search1085_0_0 -> 29 in the cache */
   /* search1085_0_1 -> 48 in the cache */
   /* search1085_0 -> 2529 in the cache */
   /* search1085_1_0 -> 29 in the cache */
   /* search1085_1_1_0 -> 964 in the cache */
   /* search1085_1_1_1_0 -> 48 in the cache */
   /* search1085_1_1_1 -> 3128 in the cache */
   /* search1085_1_1 -> 3136 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 29, 3136 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2529, 3148 },
      -1,
   } },

   /* replace1085_0 -> 29 in the cache */
   /* replace1085_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search1086_0_0 -> 29 in the cache */
   /* search1086_0_1 -> 48 in the cache */
   /* search1086_0 -> 2529 in the cache */
   /* search1086_1_0 -> 29 in the cache */
   /* search1086_1_1_0 -> 964 in the cache */
   /* search1086_1_1_1 -> 48 in the cache */
   /* search1086_1_1 -> 3140 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 3140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2529, 3151 },
      -1,
   } },

   /* replace1086_0 -> 29 in the cache */
   /* replace1086_1 -> 48 in the cache */
   /* replace1086 -> 3150 in the cache */

   /* ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b'))) */
   /* search1087_0 -> 19 in the cache */
   /* search1087_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 19, 48 },
      -1,
   } },

   /* replace1087_0_0 -> 19 in the cache */
   /* replace1087_0_1 -> 48 in the cache */
   /* replace1087_0 -> 2417 in the cache */
   /* replace1087_1_0 -> 19 in the cache */
   /* replace1087_1_1_0 -> 921 in the cache */
   /* replace1087_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 921, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 19, 3154 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2417, 3155 },
      -1,
   } },

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search1088_0 -> 24 in the cache */
   /* search1088_1 -> 48 in the cache */
   /* search1088 -> 3132 in the cache */

   /* replace1088_0_0 -> 24 in the cache */
   /* replace1088_0_1 -> 48 in the cache */
   /* replace1088_0 -> 2472 in the cache */
   /* replace1088_1_0 -> 24 in the cache */
   /* replace1088_1_1_0 -> 943 in the cache */
   /* replace1088_1_1_1 -> 48 in the cache */
   /* replace1088_1_1 -> 3133 in the cache */
   /* replace1088_1 -> 3134 in the cache */
   /* replace1088 -> 3135 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search1089_0 -> 29 in the cache */
   /* search1089_1 -> 48 in the cache */
   /* search1089 -> 3139 in the cache */

   /* replace1089_0_0 -> 29 in the cache */
   /* replace1089_0_1 -> 48 in the cache */
   /* replace1089_0 -> 1036 in the cache */
   /* replace1089_1_0 -> 29 in the cache */
   /* replace1089_1_1_0 -> 964 in the cache */
   /* replace1089_1_1_1 -> 48 in the cache */
   /* replace1089_1_1 -> 3140 in the cache */
   /* replace1089_1 -> 3141 in the cache */
   /* replace1089 -> 3142 in the cache */

   /* ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b'))) */
   /* search1090_0 -> 34 in the cache */
   /* search1090_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 34, 48 },
      -1,
   } },

   /* replace1090_0_0 -> 34 in the cache */
   /* replace1090_0_1 -> 48 in the cache */
   /* replace1090_0 -> 2580 in the cache */
   /* replace1090_1_0 -> 34 in the cache */
   /* replace1090_1_1_0 -> 984 in the cache */
   /* replace1090_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 984, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 3158 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2580, 3159 },
      -1,
   } },

   /* ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b'))) */
   /* search1091_0 -> 19 in the cache */
   /* search1091_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 19, 48 },
      -1,
   } },

   /* replace1091_0_0 -> 19 in the cache */
   /* replace1091_0_1 -> 48 in the cache */
   /* replace1091_0 -> 2421 in the cache */
   /* replace1091_1_0 -> 19 in the cache */
   /* replace1091_1_1_0 -> 921 in the cache */
   /* replace1091_1_1_1 -> 48 in the cache */
   /* replace1091_1_1 -> 3154 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 19, 3154 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2421, 3162 },
      -1,
   } },

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search1092_0 -> 24 in the cache */
   /* search1092_1 -> 48 in the cache */
   /* search1092 -> 3145 in the cache */

   /* replace1092_0_0 -> 24 in the cache */
   /* replace1092_0_1 -> 48 in the cache */
   /* replace1092_0 -> 2476 in the cache */
   /* replace1092_1_0 -> 24 in the cache */
   /* replace1092_1_1_0 -> 943 in the cache */
   /* replace1092_1_1_1 -> 48 in the cache */
   /* replace1092_1_1 -> 3133 in the cache */
   /* replace1092_1 -> 3146 in the cache */
   /* replace1092 -> 3147 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search1093_0 -> 29 in the cache */
   /* search1093_1 -> 48 in the cache */
   /* search1093 -> 3150 in the cache */

   /* replace1093_0_0 -> 29 in the cache */
   /* replace1093_0_1 -> 48 in the cache */
   /* replace1093_0 -> 2529 in the cache */
   /* replace1093_1_0 -> 29 in the cache */
   /* replace1093_1_1_0 -> 964 in the cache */
   /* replace1093_1_1_1 -> 48 in the cache */
   /* replace1093_1_1 -> 3140 in the cache */
   /* replace1093_1 -> 3151 in the cache */
   /* replace1093 -> 3152 in the cache */

   /* ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b'))) */
   /* search1094_0 -> 34 in the cache */
   /* search1094_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 34, 48 },
      -1,
   } },

   /* replace1094_0_0 -> 34 in the cache */
   /* replace1094_0_1 -> 48 in the cache */
   /* replace1094_0 -> 2584 in the cache */
   /* replace1094_1_0 -> 34 in the cache */
   /* replace1094_1_1_0 -> 984 in the cache */
   /* replace1094_1_1_1 -> 48 in the cache */
   /* replace1094_1_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 3158 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2584, 3165 },
      -1,
   } },

   /* ('bitfield_select', 4278190080, ('ishl', 'b@32', 24), ('ushr', 'a', 8)) => ('shfr', 'b', 'a', 8) */
   /* search1095_0 -> 1105 in the cache */
   /* search1095_1_0 -> 386 in the cache */
   /* search1095_1_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 386, 1102 },
      -1,
   } },
   /* search1095_2_0 -> 196 in the cache */
   /* search1095_2_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 196, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 1105, 3167, 3168 },
      -1,
   } },

   /* replace1095_0 -> 386 in the cache */
   /* replace1095_1 -> 196 in the cache */
   /* replace1095_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_shfr,
      -1, 0,
      { 386, 196, 921 },
      -1,
   } },

   /* ('bitfield_select', 4294901760, ('ishl', 'b@32', 16), ('extract_u16', 'a', 1)) => ('shfr', 'b', 'a', 16) */
   /* search1096_0 -> 1096 in the cache */
   /* search1096_1_0 -> 386 in the cache */
   /* search1096_1_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 386, 943 },
      -1,
   } },
   /* search1096_2_0 -> 196 in the cache */
   /* search1096_2_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 196, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 1096, 3171, 3172 },
      -1,
   } },

   /* replace1096_0 -> 386 in the cache */
   /* replace1096_1 -> 196 in the cache */
   /* replace1096_2 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_shfr,
      -1, 0,
      { 386, 196, 943 },
      -1,
   } },

   /* ('bitfield_select', 4294967040, ('ishl', 'b@32', 8), ('extract_u8', 'a', 3)) => ('shfr', 'b', 'a', 24) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff00ull /* 4294967040 */ },
   } },
   /* search1097_1_0 -> 386 in the cache */
   /* search1097_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 386, 921 },
      -1,
   } },
   /* search1097_2_0 -> 196 in the cache */
   /* search1097_2_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 196, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3175, 3176, 3177 },
      -1,
   } },

   /* replace1097_0 -> 386 in the cache */
   /* replace1097_1 -> 196 in the cache */
   /* replace1097_2 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_shfr,
      -1, 0,
      { 386, 196, 1102 },
      -1,
   } },

   /* ('ior', ('ishl', 'b@32', 24), ('ushr', 'a', 8)) => ('shfr', 'b', 'a', 8) */
   /* search1098_0_0 -> 386 in the cache */
   /* search1098_0_1 -> 1102 in the cache */
   /* search1098_0 -> 3167 in the cache */
   /* search1098_1_0 -> 196 in the cache */
   /* search1098_1_1 -> 921 in the cache */
   /* search1098_1 -> 3168 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3167, 3168 },
      -1,
   } },

   /* replace1098_0 -> 386 in the cache */
   /* replace1098_1 -> 196 in the cache */
   /* replace1098_2 -> 921 in the cache */
   /* replace1098 -> 3170 in the cache */

   /* ('ior', ('ishl', 'b@32', 16), ('extract_u16', 'a', 1)) => ('shfr', 'b', 'a', 16) */
   /* search1099_0_0 -> 386 in the cache */
   /* search1099_0_1 -> 943 in the cache */
   /* search1099_0 -> 3171 in the cache */
   /* search1099_1_0 -> 196 in the cache */
   /* search1099_1_1 -> 486 in the cache */
   /* search1099_1 -> 3172 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3171, 3172 },
      -1,
   } },

   /* replace1099_0 -> 386 in the cache */
   /* replace1099_1 -> 196 in the cache */
   /* replace1099_2 -> 943 in the cache */
   /* replace1099 -> 3174 in the cache */

   /* ('ior', ('ishl', 'b@32', 8), ('extract_u8', 'a', 3)) => ('shfr', 'b', 'a', 24) */
   /* search1100_0_0 -> 386 in the cache */
   /* search1100_0_1 -> 921 in the cache */
   /* search1100_0 -> 3176 in the cache */
   /* search1100_1_0 -> 196 in the cache */
   /* search1100_1_1 -> 495 in the cache */
   /* search1100_1 -> 3177 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3176, 3177 },
      -1,
   } },

   /* replace1100_0 -> 386 in the cache */
   /* replace1100_1 -> 196 in the cache */
   /* replace1100_2 -> 1102 in the cache */
   /* replace1100 -> 3179 in the cache */

   /* ('ior', ('ishl', 'b@32', ('iadd', 32, ('ineg', 'c'))), ('ushr@32', 'a', 'c')) => ('shfr', 'b', 'a', 'c') */
   /* search1101_0_0 -> 386 in the cache */
   /* search1101_0_1_0 -> 964 in the cache */
   /* search1101_0_1_1_0 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 964, 3183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 386, 3184 },
      -1,
   } },
   /* search1101_1_0 -> 672 in the cache */
   /* search1101_1_1 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 672, 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3185, 3186 },
      -1,
   } },

   /* replace1101_0 -> 386 in the cache */
   /* replace1101_1 -> 672 in the cache */
   /* replace1101_2 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_shfr,
      -1, 0,
      { 386, 672, 643 },
      -1,
   } },

   /* ('bfi', 4294967295, 'a', 'b') => a */
   /* search1102_0 -> 1017 in the cache */
   /* search1102_1 -> 29 in the cache */
   /* search1102_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 1017, 29, 48 },
      -1,
   } },

   /* replace1102 -> 29 in the cache */

   /* ('bfi', 0, 'a', 'b') => b */
   /* search1103_0 -> 135 in the cache */
   /* search1103_1 -> 29 in the cache */
   /* search1103_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 135, 29, 48 },
      -1,
   } },

   /* replace1103 -> 48 in the cache */

   /* ('bfi', ('ineg', ('b2i', 'a@1')), 'b', 'c') => ('bcsel', 'a', 'b', 'c') */
   /* search1104_0_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3191 },
      -1,
   } },
   /* search1104_1 -> 48 in the cache */
   /* search1104_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3192, 48, 148 },
      -1,
   } },

   /* replace1104_0 -> 847 in the cache */
   /* replace1104_1 -> 48 in the cache */
   /* replace1104_2 -> 148 in the cache */
   /* replace1104 -> 2009 in the cache */

   /* ('bfi', '#a(is_odd)', 'a', 'b') => ('ior', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1105_1 -> 29 in the cache */
   /* search1105_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3194, 29, 48 },
      -1,
   } },

   /* replace1105_0 -> 29 in the cache */
   /* replace1105_1 -> 48 in the cache */
   /* replace1105 -> 2327 in the cache */

   /* ('bfi', '#a(is_odd)', 'b', 0) => ('iand', 'a', 'b') */
   /* search1106_0 -> 3194 in the cache */
   /* search1106_1 -> 48 in the cache */
   /* search1106_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3194, 48, 135 },
      -1,
   } },

   /* replace1106_0 -> 29 in the cache */
   /* replace1106_1 -> 48 in the cache */
   /* replace1106 -> 2289 in the cache */

   /* ('u2f32', ('bfi', '#a(is_pos_power_of_two)', 'b', 0)) => ('bcsel', ('ieq', ('iand', 'b', 1), 0), ('iand', 'b', 1), ('u2f', 'a')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1107_0_1 -> 48 in the cache */
   /* search1107_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3197, 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3198 },
      -1,
   } },

   /* replace1107_0_0_0 -> 48 in the cache */
   /* replace1107_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 486 },
      -1,
   } },
   /* replace1107_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3200, 135 },
      -1,
   } },
   /* replace1107_1_0 -> 48 in the cache */
   /* replace1107_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 48, 486 },
      -1,
   } },
   /* replace1107_2_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3201, 3202, 3203 },
      -1,
   } },

   /* ('u2f', ('bfi', '#a(is_pos_power_of_two)', 'b', 0)) => ('bcsel', ('ieq', ('iand', 'b', 1), 0), 0, ('u2f', 'a')) */
   /* search1108_0_0 -> 3197 in the cache */
   /* search1108_0_1 -> 48 in the cache */
   /* search1108_0_2 -> 135 in the cache */
   /* search1108_0 -> 3198 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 3198 },
      -1,
   } },

   /* replace1108_0_0_0 -> 48 in the cache */
   /* replace1108_0_0_1 -> 486 in the cache */
   /* replace1108_0_0 -> 3200 in the cache */
   /* replace1108_0_1 -> 135 in the cache */
   /* replace1108_0 -> 3201 in the cache */
   /* replace1108_1 -> 1346 in the cache */
   /* replace1108_2_0 -> 29 in the cache */
   /* replace1108_2 -> 2015 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3201, 1346, 2015 },
      -1,
   } },

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search1109_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3207 },
      -1,
   } },

   /* replace1109 -> 9 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search1110_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 3209 },
      -1,
   } },

   /* replace1110 -> 9 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search1111_0 -> 0 in the cache */
   /* search1111_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1111_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace1111_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3212, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3213 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search1112_0_0_0 -> 0 in the cache */
   /* search1112_0_0 -> 3212 in the cache */
   /* search1112_0_1 -> 1 in the cache */
   /* search1112_0 -> 3213 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3213 },
      -1,
   } },

   /* replace1112_0 -> 0 in the cache */
   /* replace1112_1 -> 1 in the cache */
   /* replace1112 -> 3211 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search1113_0_0_0_0 -> 162 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 162 },
      -1,
   } },
   /* search1113_0_0_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3216, 163 },
      -1,
   } },
   /* search1113_0_1_0_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 165 },
      -1,
   } },
   /* search1113_0_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 3218, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 3217, 3219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 3220 },
      -1,
   } },

   /* replace1113_0_0 -> 162 in the cache */
   /* replace1113_0_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 162, 163 },
      -1,
   } },
   /* replace1113_1_0 -> 165 in the cache */
   /* replace1113_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3222, 3223 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search1114_0_0_0 -> 9 in the cache */
   /* search1114_0_0 -> 3207 in the cache */
   /* search1114_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3225 },
      -1,
   } },

   /* replace1114_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search1115_0_0_0 -> 9 in the cache */
   /* search1115_0_0 -> 3207 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000ull /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 3228 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3229 },
      -1,
   } },

   /* replace1115_0 -> 9 in the cache */
   /* replace1115_1 -> 9 in the cache */
   /* replace1115 -> 268 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 3.0)) => ('fmul', ('fmul', 'a', 'a'), 'a') */
   /* search1116_0_0_0 -> 9 in the cache */
   /* search1116_0_0 -> 3207 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4008000000000000ull /* 3.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 3231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3232 },
      -1,
   } },

   /* replace1116_0_0 -> 9 in the cache */
   /* replace1116_0_1 -> 9 in the cache */
   /* replace1116_0 -> 268 in the cache */
   /* replace1116_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 268, 9 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search1117_0_0_0 -> 9 in the cache */
   /* search1117_0_0 -> 3207 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000ull /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3236 },
      -1,
   } },

   /* replace1117_0_0 -> 9 in the cache */
   /* replace1117_0_1 -> 9 in the cache */
   /* replace1117_0 -> 268 in the cache */
   /* replace1117_1_0 -> 9 in the cache */
   /* replace1117_1_1 -> 9 in the cache */
   /* replace1117_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 268, 268 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 5.0)) => ('fmul', ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')), 'a') */
   /* search1118_0_0_0 -> 9 in the cache */
   /* search1118_0_0 -> 3207 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4014000000000000ull /* 5.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 3239 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3240 },
      -1,
   } },

   /* replace1118_0_0_0 -> 9 in the cache */
   /* replace1118_0_0_1 -> 9 in the cache */
   /* replace1118_0_0 -> 268 in the cache */
   /* replace1118_0_1_0 -> 9 in the cache */
   /* replace1118_0_1_1 -> 9 in the cache */
   /* replace1118_0_1 -> 268 in the cache */
   /* replace1118_0 -> 3238 in the cache */
   /* replace1118_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3238, 9 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 6.0)) => ('fmul', ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')), ('fmul', 'a', 'a')) */
   /* search1119_0_0_0 -> 9 in the cache */
   /* search1119_0_0 -> 3207 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4018000000000000ull /* 6.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 3243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3244 },
      -1,
   } },

   /* replace1119_0_0_0 -> 9 in the cache */
   /* replace1119_0_0_1 -> 9 in the cache */
   /* replace1119_0_0 -> 268 in the cache */
   /* replace1119_0_1_0 -> 9 in the cache */
   /* replace1119_0_1_1 -> 9 in the cache */
   /* replace1119_0_1 -> 268 in the cache */
   /* replace1119_0 -> 3238 in the cache */
   /* replace1119_1_0 -> 9 in the cache */
   /* replace1119_1_1 -> 9 in the cache */
   /* replace1119_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3238, 268 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 8.0)) => ('fmul', ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')), ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))) */
   /* search1120_0_0_0 -> 9 in the cache */
   /* search1120_0_0 -> 3207 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4020000000000000ull /* 8.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3207, 3247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3248 },
      -1,
   } },

   /* replace1120_0_0_0 -> 9 in the cache */
   /* replace1120_0_0_1 -> 9 in the cache */
   /* replace1120_0_0 -> 268 in the cache */
   /* replace1120_0_1_0 -> 9 in the cache */
   /* replace1120_0_1_1 -> 9 in the cache */
   /* replace1120_0_1 -> 268 in the cache */
   /* replace1120_0 -> 3238 in the cache */
   /* replace1120_1_0_0 -> 9 in the cache */
   /* replace1120_1_0_1 -> 9 in the cache */
   /* replace1120_1_0 -> 268 in the cache */
   /* replace1120_1_1_0 -> 9 in the cache */
   /* replace1120_1_1_1 -> 9 in the cache */
   /* replace1120_1_1 -> 268 in the cache */
   /* replace1120_1 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 3238, 3238 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search1121_0 -> 9 in the cache */
   /* search1121_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 9, 259 },
      -1,
   } },

   /* replace1121 -> 9 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search1122_0 -> 9 in the cache */
   /* search1122_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 9, 3228 },
      -1,
   } },

   /* replace1122_0 -> 9 in the cache */
   /* replace1122_1 -> 9 in the cache */
   /* replace1122 -> 268 in the cache */

   /* ('~fpow', 'a', 3.0) => ('fmul', ('fmul', 'a', 'a'), 'a') */
   /* search1123_0 -> 9 in the cache */
   /* search1123_1 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 9, 3231 },
      -1,
   } },

   /* replace1123_0_0 -> 9 in the cache */
   /* replace1123_0_1 -> 9 in the cache */
   /* replace1123_0 -> 268 in the cache */
   /* replace1123_1 -> 9 in the cache */
   /* replace1123 -> 3234 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search1124_0 -> 9 in the cache */
   /* search1124_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 9, 3235 },
      -1,
   } },

   /* replace1124_0_0 -> 9 in the cache */
   /* replace1124_0_1 -> 9 in the cache */
   /* replace1124_0 -> 268 in the cache */
   /* replace1124_1_0 -> 9 in the cache */
   /* replace1124_1_1 -> 9 in the cache */
   /* replace1124_1 -> 268 in the cache */
   /* replace1124 -> 3238 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search1125_0 -> 3228 in the cache */
   /* search1125_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 3228, 9 },
      -1,
   } },

   /* replace1125_0 -> 9 in the cache */
   /* replace1125 -> 3209 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search1126_0_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999aull /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 9, 3256 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48ull /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 3257, 3258 },
      -1,
   } },

   /* replace1126 -> 9 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search1127_0_0_0 -> 9 in the cache */
   /* search1127_0_0_1 -> 3256 in the cache */
   /* search1127_0_0 -> 3257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3257 },
      -1,
   } },
   /* search1127_1 -> 3258 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 3260, 3258 },
      -1,
   } },

   /* replace1127_0 -> 9 in the cache */
   /* replace1127 -> 11 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search1128_0_0 -> 9 in the cache */
   /* search1128_0 -> 3209 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 3209 },
      -1,
   } },

   /* replace1128_0_0 -> 111 in the cache */
   /* replace1128_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 111, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3263 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search1129_0_0 -> 9 in the cache */
   /* search1129_0 -> 3209 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3209 },
      -1,
   } },

   /* replace1129_0_0 -> 9 in the cache */
   /* replace1129_0 -> 118 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 118 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search1130_0_0 -> 9 in the cache */
   /* search1130_0 -> 3209 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 3209 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000ull /* -0.5 */ },
   } },
   /* replace1130_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3268, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 3269 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search1131_0_0 -> 9 in the cache */
   /* search1131_0 -> 3227 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 3227 },
      -1,
   } },

   /* replace1131_0 -> 111 in the cache */
   /* replace1131_1_0 -> 9 in the cache */
   /* replace1131_1 -> 3207 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 111, 3207 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search1132_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 3273 },
      -1,
   } },

   /* replace1132_0_0 -> 9 in the cache */
   /* replace1132_0 -> 3207 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3207 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search1133_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 3276 },
      -1,
   } },

   /* replace1133_0 -> 3268 in the cache */
   /* replace1133_1_0 -> 9 in the cache */
   /* replace1133_1 -> 3207 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3268, 3207 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search1134_0_0 -> 0 in the cache */
   /* search1134_0_1 -> 1 in the cache */
   /* search1134_0 -> 3211 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 3211 },
      -1,
   } },

   /* replace1134_0 -> 1 in the cache */
   /* replace1134_1_0 -> 0 in the cache */
   /* replace1134_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3212 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search1135_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search1135_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3281, 3282 },
      -1,
   } },

   /* replace1135_0_0 -> 0 in the cache */
   /* replace1135_0_1 -> 1 in the cache */
   /* replace1135_0 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 285 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search1136_0_0 -> 9 in the cache */
   /* search1136_0_1 -> 8 in the cache */
   /* search1136_0 -> 1289 in the cache */
   /* search1136_1 -> 8 in the cache */
   /* search1136_2_0 -> 9 in the cache */
   /* search1136_2 -> 3227 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1289, 8, 3227 },
      -1,
   } },

   /* replace1136_0_0 -> 9 in the cache */
   /* replace1136_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 9, 8 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 3286 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search1137_0_0 -> 9 in the cache */
   /* search1137_0 -> 3227 in the cache */
   /* search1137_1_0 -> 9 in the cache */
   /* search1137_1 -> 3227 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 3227, 3227 },
      -1,
   } },

   /* replace1137_0 -> 9 in the cache */
   /* replace1137 -> 11 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search1138_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 29 },
      -1,
   } },
   /* search1138_1_0 -> 29 in the cache */
   /* search1138_1 -> 3289 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 3289, 3289 },
      -1,
   } },

   /* replace1138_0 -> 29 in the cache */
   /* replace1138 -> 423 in the cache */

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search1139_0 -> 259 in the cache */
   /* search1139_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 259, 9 },
      -1,
   } },

   /* replace1139_0 -> 9 in the cache */
   /* replace1139 -> 3273 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search1140_0 -> 0 in the cache */
   /* search1140_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1140_0 -> 0 in the cache */
   /* replace1140_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3293 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search1141_0_0 -> 9 in the cache */
   /* search1141_0 -> 3273 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3273 },
      -1,
   } },

   /* replace1141 -> 9 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search1142_0_0 -> 9 in the cache */
   /* search1142_0 -> 3227 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3227 },
      -1,
   } },

   /* replace1142_0 -> 9 in the cache */
   /* replace1142 -> 3276 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search1143_0 -> 9 in the cache */
   /* search1143 -> 3227 in the cache */

   /* replace1143_0_0 -> 9 in the cache */
   /* replace1143_0 -> 3276 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3276 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search1144_0_0 -> 9 in the cache */
   /* search1144_0 -> 3276 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3276 },
      -1,
   } },

   /* replace1144_0 -> 9 in the cache */
   /* replace1144 -> 3227 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search1145_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace1145_0_0_0_0_0_0 -> 3228 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883ull /* 0.15915494309189535 */ },
   } },
   /* replace1145_0_0_0_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_0_0_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 3301, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 3228, 3303 },
      -1,
   } },
   /* replace1145_0_0_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3304, 259 },
      -1,
   } },
   /* replace1145_0_0_0_1_0_0_0 -> 3228 in the cache */
   /* replace1145_0_0_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_0_0_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_0_0_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 3306, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3307 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 3228, 3308 },
      -1,
   } },
   /* replace1145_0_0_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3309, 259 },
      -1,
   } },
   /* replace1145_0_0_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1145_0_0_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_0_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_0_0_1_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 3311, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 3228, 3313 },
      -1,
   } },
   /* replace1145_0_0_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3314, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3315 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 3310, 3316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3305, 3317 },
      -1,
   } },
   /* replace1145_0_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 3318, 3235 },
      -1,
   } },
   /* replace1145_0_1_0_0_0_0_0 -> 3228 in the cache */
   /* replace1145_0_1_0_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_1_0_0_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_1_0_0_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 3320, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 3228, 3322 },
      -1,
   } },
   /* replace1145_0_1_0_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3323, 259 },
      -1,
   } },
   /* replace1145_0_1_0_0_1_0_0_0 -> 3228 in the cache */
   /* replace1145_0_1_0_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_1_0_0_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_1_0_0_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 3325, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3326 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 3228, 3327 },
      -1,
   } },
   /* replace1145_0_1_0_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3328, 259 },
      -1,
   } },
   /* replace1145_0_1_0_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1145_0_1_0_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_1_0_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_1_0_0_1_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 3330, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 3228, 3332 },
      -1,
   } },
   /* replace1145_0_1_0_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3333, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3334 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 3329, 3335 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3324, 3336 },
      -1,
   } },
   /* replace1145_0_1_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 3337, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 3338 },
      -1,
   } },
   /* replace1145_0_2_0_0_0_0_0 -> 3228 in the cache */
   /* replace1145_0_2_0_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_2_0_0_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_2_0_0_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 3340, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3341 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 3228, 3342 },
      -1,
   } },
   /* replace1145_0_2_0_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3343, 259 },
      -1,
   } },
   /* replace1145_0_2_0_0_1_0_0_0 -> 3228 in the cache */
   /* replace1145_0_2_0_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_2_0_0_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_2_0_0_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 3345, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3346 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 3228, 3347 },
      -1,
   } },
   /* replace1145_0_2_0_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3348, 259 },
      -1,
   } },
   /* replace1145_0_2_0_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1145_0_2_0_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_0_2_0_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_0_2_0_0_1_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 3350, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3351 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 3228, 3352 },
      -1,
   } },
   /* replace1145_0_2_0_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3353, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 3349, 3355 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3344, 3356 },
      -1,
   } },
   /* replace1145_0_2_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 3357, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 3358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 3319, 3339, 3359 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccdull /* 0.225 */ },
   } },
   /* replace1145_2_0_0_0_0 -> 3228 in the cache */
   /* replace1145_2_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_2_0_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_2_0_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 3362, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3363 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 3228, 3364 },
      -1,
   } },
   /* replace1145_2_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3365, 259 },
      -1,
   } },
   /* replace1145_2_0_1_0_0_0 -> 3228 in the cache */
   /* replace1145_2_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_2_0_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_2_0_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 3367, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 3228, 3369 },
      -1,
   } },
   /* replace1145_2_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3370, 259 },
      -1,
   } },
   /* replace1145_2_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1145_2_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1145_2_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 3300, 9 },
      -1,
   } },
   /* replace1145_2_0_1_1_0_0_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 3372, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3373 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 3228, 3374 },
      -1,
   } },
   /* replace1145_2_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3375, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3376 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 3371, 3377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3366, 3378 },
      -1,
   } },
   /* replace1145_2_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 3379, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 3360, 3361, 3380 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search1146_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace1146_0_0_0_0_0_0 -> 3228 in the cache */
   /* replace1146_0_0_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_0_0_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_0_0_0_0_1_0_0 -> 3301 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000ull /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 3301, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 3228, 3385 },
      -1,
   } },
   /* replace1146_0_0_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3386, 259 },
      -1,
   } },
   /* replace1146_0_0_0_1_0_0_0 -> 3228 in the cache */
   /* replace1146_0_0_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_0_0_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_0_0_1_0_0_1_0_0 -> 3306 in the cache */
   /* replace1146_0_0_0_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 3306, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 3228, 3389 },
      -1,
   } },
   /* replace1146_0_0_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3390, 259 },
      -1,
   } },
   /* replace1146_0_0_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1146_0_0_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_0_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_0_0_1_1_0_0_1_0_0 -> 3311 in the cache */
   /* replace1146_0_0_0_1_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 3311, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3392 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 3228, 3393 },
      -1,
   } },
   /* replace1146_0_0_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3394, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3395 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 3391, 3396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3387, 3397 },
      -1,
   } },
   /* replace1146_0_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 3398, 3235 },
      -1,
   } },
   /* replace1146_0_1_0_0_0_0_0 -> 3228 in the cache */
   /* replace1146_0_1_0_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_1_0_0_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_1_0_0_0_0_1_0_0 -> 3320 in the cache */
   /* replace1146_0_1_0_0_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 3320, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 3228, 3401 },
      -1,
   } },
   /* replace1146_0_1_0_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3402, 259 },
      -1,
   } },
   /* replace1146_0_1_0_0_1_0_0_0 -> 3228 in the cache */
   /* replace1146_0_1_0_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_1_0_0_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_1_0_0_1_0_0_1_0_0 -> 3325 in the cache */
   /* replace1146_0_1_0_0_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 3325, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 3228, 3405 },
      -1,
   } },
   /* replace1146_0_1_0_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3406, 259 },
      -1,
   } },
   /* replace1146_0_1_0_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1146_0_1_0_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_1_0_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_1_0_0_1_1_0_0_1_0_0 -> 3330 in the cache */
   /* replace1146_0_1_0_0_1_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 3330, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3408 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 3228, 3409 },
      -1,
   } },
   /* replace1146_0_1_0_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3410, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3411 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 3407, 3412 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3403, 3413 },
      -1,
   } },
   /* replace1146_0_1_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 3414, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 3415 },
      -1,
   } },
   /* replace1146_0_2_0_0_0_0_0 -> 3228 in the cache */
   /* replace1146_0_2_0_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_2_0_0_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_2_0_0_0_0_1_0_0 -> 3340 in the cache */
   /* replace1146_0_2_0_0_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 3340, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 3228, 3418 },
      -1,
   } },
   /* replace1146_0_2_0_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3419, 259 },
      -1,
   } },
   /* replace1146_0_2_0_0_1_0_0_0 -> 3228 in the cache */
   /* replace1146_0_2_0_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_2_0_0_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_2_0_0_1_0_0_1_0_0 -> 3345 in the cache */
   /* replace1146_0_2_0_0_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 3345, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 3228, 3422 },
      -1,
   } },
   /* replace1146_0_2_0_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3423, 259 },
      -1,
   } },
   /* replace1146_0_2_0_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1146_0_2_0_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_0_2_0_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_0_2_0_0_1_1_0_0_1_0_0 -> 3350 in the cache */
   /* replace1146_0_2_0_0_1_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 3350, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3425 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 3228, 3426 },
      -1,
   } },
   /* replace1146_0_2_0_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3427, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 3424, 3429 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3420, 3430 },
      -1,
   } },
   /* replace1146_0_2_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 3431, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 3432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 3399, 3416, 3433 },
      -1,
   } },
   /* replace1146_1 -> 3361 in the cache */
   /* replace1146_2_0_0_0_0 -> 3228 in the cache */
   /* replace1146_2_0_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_2_0_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_2_0_0_0_1_0_0 -> 3362 in the cache */
   /* replace1146_2_0_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 3362, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 3228, 3436 },
      -1,
   } },
   /* replace1146_2_0_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3437, 259 },
      -1,
   } },
   /* replace1146_2_0_1_0_0_0 -> 3228 in the cache */
   /* replace1146_2_0_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_2_0_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_2_0_1_0_0_1_0_0 -> 3367 in the cache */
   /* replace1146_2_0_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 3367, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3439 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 3228, 3440 },
      -1,
   } },
   /* replace1146_2_0_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3441, 259 },
      -1,
   } },
   /* replace1146_2_0_1_1_0_0_0 -> 3228 in the cache */
   /* replace1146_2_0_1_1_0_0_1_0_0_0 -> 3300 in the cache */
   /* replace1146_2_0_1_1_0_0_1_0_0_1 -> 9 in the cache */
   /* replace1146_2_0_1_1_0_0_1_0_0 -> 3372 in the cache */
   /* replace1146_2_0_1_1_0_0_1_0_1 -> 3383 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 3372, 3383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3443 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 3228, 3444 },
      -1,
   } },
   /* replace1146_2_0_1_1_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3445, 259 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 3442, 3447 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3438, 3448 },
      -1,
   } },
   /* replace1146_2_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 3449, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 3434, 3361, 3450 },
      -1,
   } },

   /* ('ieq', 'a', True) => a */
   /* search1147_0 -> 847 in the cache */
   /* search1147_1 -> 1350 in the cache */
   /* search1147 -> 1351 in the cache */

   /* replace1147 -> 847 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search1148_0 -> 847 in the cache */
   /* search1148_1 -> 1350 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 847, 1350 },
      2,
   } },

   /* replace1148_0 -> 847 in the cache */
   /* replace1148 -> 1248 in the cache */

   /* ('ine', 'a', False) => a */
   /* search1149_0 -> 847 in the cache */
   /* search1149_1 -> 1165 in the cache */
   /* search1149 -> 1352 in the cache */

   /* replace1149 -> 847 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search1150_0 -> 847 in the cache */
   /* search1150_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 847, 1165 },
      2,
   } },

   /* replace1150_0 -> 847 in the cache */
   /* replace1150 -> 1248 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search1151_0 -> 847 in the cache */
   /* search1151_1 -> 1350 in the cache */
   /* search1151_2 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1350, 1165 },
      -1,
   } },

   /* replace1151 -> 847 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search1152_0 -> 847 in the cache */
   /* search1152_1 -> 1165 in the cache */
   /* search1152_2 -> 1350 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1165, 1350 },
      -1,
   } },

   /* replace1152_0 -> 847 in the cache */
   /* replace1152 -> 1248 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search1153_0 -> 1350 in the cache */
   /* search1153_1 -> 1192 in the cache */
   /* search1153_2 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1350, 1192, 771 },
      -1,
   } },

   /* replace1153 -> 1192 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search1154_0 -> 1165 in the cache */
   /* search1154_1 -> 1192 in the cache */
   /* search1154_2 -> 771 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1165, 1192, 771 },
      -1,
   } },

   /* replace1154 -> 771 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search1155_0 -> 847 in the cache */
   /* search1155_1 -> 569 in the cache */
   /* search1155_2 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 569, 776 },
      -1,
   } },

   /* replace1155_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search1156_0 -> 847 in the cache */
   /* search1156_1 -> 776 in the cache */
   /* search1156_2 -> 569 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 776, 569 },
      -1,
   } },

   /* replace1156_0_0 -> 847 in the cache */
   /* replace1156_0 -> 1248 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1248 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search1157_0 -> 847 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000ull /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3462, 3463 },
      -1,
   } },

   /* replace1157_0_0 -> 847 in the cache */
   /* replace1157_0 -> 3459 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3459 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search1158_0 -> 847 in the cache */
   /* search1158_1 -> 3463 in the cache */
   /* search1158_2 -> 3462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3463, 3462 },
      -1,
   } },

   /* replace1158_0_0_0 -> 847 in the cache */
   /* replace1158_0_0 -> 1248 in the cache */
   /* replace1158_0 -> 3461 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3461 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search1159_0 -> 847 in the cache */
   /* search1159_1 -> 261 in the cache */
   /* search1159_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 261, 241 },
      -1,
   } },

   /* replace1159_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search1160_0 -> 847 in the cache */
   /* search1160_1 -> 241 in the cache */
   /* search1160_2 -> 261 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 241, 261 },
      -1,
   } },

   /* replace1160_0_0 -> 847 in the cache */
   /* replace1160_0 -> 1248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1248 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search1161_0 -> 847 in the cache */
   /* search1161_1 -> 291 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000ull /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 291, 3472 },
      -1,
   } },

   /* replace1161_0_0 -> 847 in the cache */
   /* replace1161_0 -> 3469 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3469 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search1162_0 -> 847 in the cache */
   /* search1162_1 -> 3472 in the cache */
   /* search1162_2 -> 291 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3472, 291 },
      -1,
   } },

   /* replace1162_0_0_0 -> 847 in the cache */
   /* replace1162_0_0 -> 1248 in the cache */
   /* replace1162_0 -> 3471 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3471 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search1163_0 -> 847 in the cache */
   /* search1163_1 -> 709 in the cache */
   /* search1163_2 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 709, 788 },
      -1,
   } },

   /* replace1163_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 847 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search1164_0 -> 847 in the cache */
   /* search1164_1 -> 788 in the cache */
   /* search1164_2 -> 709 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 788, 709 },
      -1,
   } },

   /* replace1164_0_0 -> 847 in the cache */
   /* replace1164_0 -> 1248 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1248 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search1165_0 -> 847 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000ull /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3481, 3482 },
      -1,
   } },

   /* replace1165_0_0 -> 847 in the cache */
   /* replace1165_0 -> 3478 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3478 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search1166_0 -> 847 in the cache */
   /* search1166_1 -> 3482 in the cache */
   /* search1166_2 -> 3481 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3482, 3481 },
      -1,
   } },

   /* replace1166_0_0_0 -> 847 in the cache */
   /* replace1166_0_0 -> 1248 in the cache */
   /* replace1166_0 -> 3480 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3480 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search1167_0 -> 847 in the cache */
   /* search1167_1 -> 1 in the cache */
   /* search1167_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1, 1 },
      -1,
   } },

   /* replace1167 -> 1 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search1168_0 -> 29 in the cache */
   /* search1168_1 -> 48 in the cache */
   /* search1168_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 29, 48, 48 },
      -1,
   } },

   /* replace1168 -> 48 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search1169_0 -> 847 in the cache */
   /* search1169_1 -> 3123 in the cache */
   /* search1169_2 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3123, 1346 },
      -1,
   } },

   /* replace1169_0_0 -> 847 in the cache */
   /* replace1169_0 -> 1345 in the cache */
   /* replace1169 -> 2604 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search1170_0 -> 847 in the cache */
   /* search1170_1 -> 1346 in the cache */
   /* search1170_2 -> 3123 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1346, 3123 },
      -1,
   } },

   /* replace1170_0_0_0 -> 847 in the cache */
   /* replace1170_0_0 -> 1248 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1248 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3491 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search1171_0 -> 847 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   /* search1171_2 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 3493, 1346 },
      -1,
   } },

   /* replace1171_0 -> 847 in the cache */
   /* replace1171 -> 1345 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search1172_0 -> 847 in the cache */
   /* search1172_1 -> 1346 in the cache */
   /* search1172_2 -> 3493 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1346, 3493 },
      -1,
   } },

   /* replace1172_0_0 -> 847 in the cache */
   /* replace1172_0 -> 1248 in the cache */
   /* replace1172 -> 3491 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search1173_0_0_0 -> 847 in the cache */
   /* search1173_0_0 -> 1345 in the cache */
   /* search1173_0 -> 2604 in the cache */
   /* search1173_1_0_0 -> 1251 in the cache */
   /* search1173_1_0 -> 2605 in the cache */
   /* search1173_1 -> 2606 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace1173_0_0_0 -> 847 in the cache */
   /* replace1173_0_0_1 -> 1251 in the cache */
   /* replace1173_0_0 -> 1263 in the cache */
   /* replace1173_0 -> 3032 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 3032 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search1174_0_0_0 -> 847 in the cache */
   /* search1174_0_0 -> 1345 in the cache */
   /* search1174_0 -> 2604 in the cache */
   /* search1174_1_0_0 -> 1251 in the cache */
   /* search1174_1_0 -> 2605 in the cache */
   /* search1174_1 -> 2606 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace1174_0_0_0 -> 847 in the cache */
   /* replace1174_0_0_1 -> 1251 in the cache */
   /* replace1174_0_0 -> 1255 in the cache */
   /* replace1174_0 -> 3035 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 3035 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search1175_0_0_0 -> 847 in the cache */
   /* search1175_0_0 -> 1345 in the cache */
   /* search1175_0 -> 2604 in the cache */
   /* search1175_1 -> 3123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2604, 3123 },
      -1,
   } },

   /* replace1175 -> 847 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search1176_0_0_0 -> 847 in the cache */
   /* search1176_0_0 -> 1345 in the cache */
   /* search1176_0 -> 2604 in the cache */
   /* search1176_1 -> 3123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2604, 3123 },
      -1,
   } },

   /* replace1176_0 -> 847 in the cache */
   /* replace1176 -> 1248 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search1177_0_0_0 -> 847 in the cache */
   /* search1177_0_0 -> 1345 in the cache */
   /* search1177_0 -> 2604 in the cache */
   /* search1177_1 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2604, 1346 },
      -1,
   } },

   /* replace1177_0 -> 847 in the cache */
   /* replace1177 -> 1248 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search1178_0_0_0 -> 847 in the cache */
   /* search1178_0_0 -> 1345 in the cache */
   /* search1178_0 -> 2604 in the cache */
   /* search1178_1 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2604, 1346 },
      -1,
   } },

   /* replace1178 -> 847 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search1179_0 -> 1346 in the cache */
   /* search1179_1_0_0 -> 847 in the cache */
   /* search1179_1_0 -> 1345 in the cache */
   /* search1179_1 -> 2604 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1346, 2604 },
      -1,
   } },

   /* replace1179 -> 847 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search1180_0_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3505 },
      -1,
   } },
   /* search1180_1 -> 1256 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3506, 1256 },
      -1,
   } },

   /* replace1180_0 -> 9 in the cache */
   /* replace1180 -> 1632 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search1181_0_0_0 -> 9 in the cache */
   /* search1181_0_0 -> 3505 in the cache */
   /* search1181_0 -> 3506 in the cache */
   /* search1181_1 -> 3493 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3506, 3493 },
      -1,
   } },

   /* replace1181_0 -> 9 in the cache */
   /* replace1181 -> 3505 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search1182_0_0_0 -> 847 in the cache */
   /* search1182_0_0 -> 1345 in the cache */
   /* search1182_0 -> 2604 in the cache */
   /* search1182_1_0_0 -> 1251 in the cache */
   /* search1182_1_0 -> 2605 in the cache */
   /* search1182_1 -> 2606 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace1182_0_0_0 -> 847 in the cache */
   /* replace1182_0_0_1 -> 1251 in the cache */
   /* replace1182_0_0 -> 1263 in the cache */
   /* replace1182_0 -> 3032 in the cache */
   /* replace1182 -> 3497 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search1183_0_0_0 -> 847 in the cache */
   /* search1183_0_0 -> 1345 in the cache */
   /* search1183_0 -> 2604 in the cache */
   /* search1183_1_0_0 -> 1251 in the cache */
   /* search1183_1_0 -> 2605 in the cache */
   /* search1183_1 -> 2606 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace1183_0_0_0 -> 847 in the cache */
   /* replace1183_0_0_1 -> 1251 in the cache */
   /* replace1183_0_0 -> 1255 in the cache */
   /* replace1183_0 -> 3035 in the cache */
   /* replace1183 -> 3499 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search1184_0_0_0 -> 847 in the cache */
   /* search1184_0_0 -> 1345 in the cache */
   /* search1184_0 -> 2604 in the cache */
   /* search1184_1_0_0 -> 1251 in the cache */
   /* search1184_1_0 -> 2605 in the cache */
   /* search1184_1 -> 2606 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace1184_0_0_0 -> 847 in the cache */
   /* replace1184_0_0_1 -> 1251 in the cache */
   /* replace1184_0_0 -> 1255 in the cache */
   /* replace1184_0 -> 3035 in the cache */
   /* replace1184 -> 3499 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search1185_0_0_0 -> 847 in the cache */
   /* search1185_0_0 -> 1345 in the cache */
   /* search1185_0 -> 2604 in the cache */
   /* search1185_1_0_0 -> 1251 in the cache */
   /* search1185_1_0 -> 2605 in the cache */
   /* search1185_1 -> 2606 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2604, 2606 },
      -1,
   } },

   /* replace1185_0_0_0 -> 847 in the cache */
   /* replace1185_0_0_1 -> 1251 in the cache */
   /* replace1185_0_0 -> 1263 in the cache */
   /* replace1185_0 -> 3032 in the cache */
   /* replace1185 -> 3497 in the cache */

   /* ('umax', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search1186_0_0 -> 847 in the cache */
   /* search1186_0 -> 1345 in the cache */
   /* search1186_1_0 -> 1251 in the cache */
   /* search1186_1 -> 2605 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 1345, 2605 },
      -1,
   } },

   /* replace1186_0_0 -> 847 in the cache */
   /* replace1186_0_1 -> 1251 in the cache */
   /* replace1186_0 -> 1255 in the cache */
   /* replace1186 -> 3035 in the cache */

   /* ('umin', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search1187_0_0 -> 847 in the cache */
   /* search1187_0 -> 1345 in the cache */
   /* search1187_1_0 -> 1251 in the cache */
   /* search1187_1 -> 2605 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 1345, 2605 },
      -1,
   } },

   /* replace1187_0_0 -> 847 in the cache */
   /* replace1187_0_1 -> 1251 in the cache */
   /* replace1187_0 -> 1263 in the cache */
   /* replace1187 -> 3032 in the cache */

   /* ('iand', ('b2i', 'a'), 1) => ('b2i', 'a') */
   /* search1188_0_0 -> 9 in the cache */
   /* search1188_0 -> 3505 in the cache */
   /* search1188_1 -> 3493 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3505, 3493 },
      -1,
   } },

   /* replace1188_0 -> 9 in the cache */
   /* replace1188 -> 3505 in the cache */

   /* ('ine', ('umin', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('iand', 'a', ('ine', 'b', 0)) */
   /* search1189_0_0_0_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3516 },
      -1,
   } },
   /* search1189_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 3517, 1 },
      -1,
   } },
   /* search1189_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3518, 98 },
      -1,
   } },

   /* replace1189_0 -> 847 in the cache */
   /* replace1189_1_0 -> 1 in the cache */
   /* replace1189_1_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 1, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 847, 3520 },
      -1,
   } },

   /* ('ine', ('umax', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('ior', 'a', ('ine', 'b', 0)) */
   /* search1190_0_0_0_0 -> 847 in the cache */
   /* search1190_0_0_0 -> 3516 in the cache */
   /* search1190_0_0 -> 3517 in the cache */
   /* search1190_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 3517, 1 },
      -1,
   } },
   /* search1190_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3522, 98 },
      -1,
   } },

   /* replace1190_0 -> 847 in the cache */
   /* replace1190_1_0 -> 1 in the cache */
   /* replace1190_1_1 -> 98 in the cache */
   /* replace1190_1 -> 3520 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 847, 3520 },
      -1,
   } },

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search1191_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 3525 },
      -1,
   } },

   /* replace1191_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search1192_0_0 -> 9 in the cache */
   /* search1192_0 -> 3525 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 3525 },
      -1,
   } },

   /* replace1192_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search1193_0_0 -> 24 in the cache */
   /* search1193_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace1193 -> 24 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search1194_0_0 -> 24 in the cache */
   /* search1194_0 -> 2217 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2217 },
      -1,
   } },

   /* replace1194 -> 24 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search1195_0_0 -> 24 in the cache */
   /* search1195_0 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* replace1195 -> 24 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search1196_0_0 -> 24 in the cache */
   /* search1196_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace1196_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search1197_0_0 -> 24 in the cache */
   /* search1197_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace1197_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search1198_0_0 -> 24 in the cache */
   /* search1198_0 -> 2217 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 2217 },
      -1,
   } },

   /* replace1198_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search1199_0_0 -> 24 in the cache */
   /* search1199_0 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* replace1199_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search1200_0_0 -> 847 in the cache */
   /* search1200_0 -> 1512 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1512 },
      -1,
   } },

   /* replace1200_0 -> 847 in the cache */
   /* replace1200 -> 1508 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1201_0_0 -> 847 in the cache */
   /* search1201_0 -> 1500 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1500 },
      -1,
   } },

   /* replace1201_0 -> 847 in the cache */
   /* replace1201 -> 1496 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1202_0_0 -> 847 in the cache */
   /* search1202_0 -> 1500 in the cache */
   /* search1202 -> 3542 in the cache */

   /* replace1202_0 -> 847 in the cache */
   /* replace1202 -> 1496 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1203_0_0 -> 847 in the cache */
   /* search1203_0 -> 1512 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1512 },
      -1,
   } },

   /* replace1203_0 -> 847 in the cache */
   /* replace1203 -> 1496 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1204_0_0 -> 847 in the cache */
   /* search1204_0 -> 1512 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1512 },
      -1,
   } },

   /* replace1204_0 -> 847 in the cache */
   /* replace1204 -> 1496 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1205_0_0 -> 847 in the cache */
   /* search1205_0 -> 1500 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1500 },
      -1,
   } },

   /* replace1205_0 -> 847 in the cache */
   /* replace1205 -> 1508 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1206_0_0 -> 847 in the cache */
   /* search1206_0 -> 1500 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1500 },
      -1,
   } },

   /* replace1206_0 -> 847 in the cache */
   /* replace1206 -> 1508 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search1207_0_0 -> 29 in the cache */
   /* search1207_0 -> 2251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2251 },
      -1,
   } },

   /* replace1207 -> 29 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search1208_0_0 -> 29 in the cache */
   /* search1208_0 -> 2262 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2262 },
      -1,
   } },

   /* replace1208 -> 29 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search1209_0_0 -> 29 in the cache */
   /* search1209_0 -> 2262 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2262 },
      -1,
   } },

   /* replace1209 -> 29 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search1210_0_0 -> 29 in the cache */
   /* search1210_0 -> 2261 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2261 },
      -1,
   } },

   /* replace1210_0 -> 29 in the cache */
   /* replace1210 -> 2259 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search1211_0_0 -> 29 in the cache */
   /* search1211_0 -> 2258 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2258 },
      -1,
   } },

   /* replace1211_0 -> 29 in the cache */
   /* replace1211 -> 2256 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search1212_0_0 -> 29 in the cache */
   /* search1212_0 -> 2250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2250 },
      -1,
   } },

   /* replace1212_0 -> 29 in the cache */
   /* replace1212 -> 2248 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search1213_0_0 -> 29 in the cache */
   /* search1213_0 -> 2247 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2247 },
      -1,
   } },

   /* replace1213_0 -> 29 in the cache */
   /* replace1213 -> 2245 in the cache */

   /* ('f2i32', ('f2fmp', 'a@32')) => ('f2i32', 'a') */
   /* search1214_0_0 -> 29 in the cache */
   /* search1214_0 -> 2251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 2251 },
      -1,
   } },

   /* replace1214_0 -> 29 in the cache */
   /* replace1214 -> 2259 in the cache */

   /* ('f2u32', ('f2fmp', 'a@32')) => ('f2u32', 'a') */
   /* search1215_0_0 -> 29 in the cache */
   /* search1215_0 -> 2251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 2251 },
      -1,
   } },

   /* replace1215_0 -> 29 in the cache */
   /* replace1215 -> 2256 in the cache */

   /* ('i2f32', ('i2imp', 'a@32')) => ('i2f32', 'a') */
   /* search1216_0_0 -> 29 in the cache */
   /* search1216_0 -> 2262 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 2262 },
      -1,
   } },

   /* replace1216_0 -> 29 in the cache */
   /* replace1216 -> 2248 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 3557 },
      -1,
   } },

   /* replace1217 -> 9 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search1218_0 -> 3557 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 3557 },
      -1,
   } },

   /* replace1218 -> 9 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search1219_0 -> 3557 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 3557 },
      -1,
   } },

   /* replace1219 -> 9 in the cache */

   /* ('fround_even', 'a(is_integral)') => a */
   /* search1220_0 -> 3557 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 3557 },
      -1,
   } },

   /* replace1220 -> 9 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search1221_0 -> 3557 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 3557 },
      -1,
   } },

   /* replace1221 -> 8 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3563 },
      -1,
   } },

   /* replace1222 -> 9 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search1223_0 -> 3563 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3563 },
      -1,
   } },

   /* replace1223 -> 9 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3566 },
      -1,
   } },

   /* replace1224 -> 8 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search1225_0 -> 3563 in the cache */
   /* search1225_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3563, 259 },
      -1,
   } },

   /* replace1225_0 -> 9 in the cache */
   /* replace1225 -> 235 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1226_0_0_0_0 -> 9 in the cache */
   /* search1226_0_0_0 -> 235 in the cache */
   /* search1226_0_0_1_0_0 -> 9 in the cache */
   /* search1226_0_0_1_0 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 235, 3569 },
      -1,
   } },
   /* search1226_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3570, 259 },
      -1,
   } },
   /* search1226_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 3571, 8 },
      -1,
   } },

   /* replace1226 -> 1165 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1227_0_0_0_0_0 -> 9 in the cache */
   /* search1227_0_0_0_0 -> 235 in the cache */
   /* search1227_0_0_0_1_0 -> 9 in the cache */
   /* search1227_0_0_0_1 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 235, 235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3573 },
      -1,
   } },
   /* search1227_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 3574, 259 },
      -1,
   } },
   /* search1227_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3575, 8 },
      -1,
   } },

   /* replace1227 -> 1165 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search1228_0_0_0_0 -> 9 in the cache */
   /* search1228_0_0_0 -> 235 in the cache */
   /* search1228_0_0_1_0_0 -> 9 in the cache */
   /* search1228_0_0_1_0 -> 235 in the cache */
   /* search1228_0_0_1 -> 3569 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 235, 3569 },
      -1,
   } },
   /* search1228_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 3577, 259 },
      -1,
   } },
   /* search1228_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 3578, 8 },
      -1,
   } },

   /* replace1228_0_0_0 -> 9 in the cache */
   /* replace1228_0_0 -> 235 in the cache */
   /* replace1228_0_1_0_0 -> 9 in the cache */
   /* replace1228_0_1_0 -> 235 in the cache */
   /* replace1228_0_1 -> 3569 in the cache */
   /* replace1228_0 -> 3570 in the cache */
   /* replace1228_1 -> 259 in the cache */
   /* replace1228 -> 3571 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search1229_0_0_0_0_0 -> 9 in the cache */
   /* search1229_0_0_0_0 -> 235 in the cache */
   /* search1229_0_0_0_1_0 -> 9 in the cache */
   /* search1229_0_0_0_1 -> 235 in the cache */
   /* search1229_0_0_0 -> 3573 in the cache */
   /* search1229_0_0 -> 3574 in the cache */
   /* search1229_0_1 -> 259 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3574, 259 },
      -1,
   } },
   /* search1229_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 3580, 8 },
      -1,
   } },

   /* replace1229_0_0_0_0 -> 9 in the cache */
   /* replace1229_0_0_0 -> 235 in the cache */
   /* replace1229_0_0_1_0 -> 9 in the cache */
   /* replace1229_0_0_1 -> 235 in the cache */
   /* replace1229_0_0 -> 3573 in the cache */
   /* replace1229_0 -> 3574 in the cache */
   /* replace1229_1 -> 259 in the cache */
   /* replace1229 -> 3575 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1230_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3582, 8 },
      -1,
   } },

   /* replace1230 -> 1350 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search1231_0 -> 3582 in the cache */
   /* search1231_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3582, 8 },
      -1,
   } },

   /* replace1231 -> 1165 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3585, 3586 },
      -1,
   } },

   /* replace1232 -> 1350 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3588, 3589 },
      -1,
   } },

   /* replace1233 -> 1165 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      32,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3591, 3592 },
      -1,
   } },

   /* replace1234 -> 1165 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1235_0 -> 1689 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1689, 3594 },
      -1,
   } },

   /* replace1235 -> 1165 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      33,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3596, 3597 },
      -1,
   } },

   /* replace1236 -> 1350 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      34,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3599, 3600 },
      -1,
   } },

   /* replace1237 -> 1350 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search1238_0 -> 3582 in the cache */
   /* search1238_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3582, 73 },
      -1,
   } },

   /* replace1238 -> 1350 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search1239_0 -> 3582 in the cache */
   /* search1239_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3582, 73 },
      -1,
   } },

   /* replace1239 -> 1165 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search1240_0 -> 1689 in the cache */
   /* search1240_1 -> 3594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1689, 3594 },
      -1,
   } },

   /* replace1240 -> 1350 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search1241_0 -> 3588 in the cache */
   /* search1241_1 -> 3589 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3588, 3589 },
      -1,
   } },

   /* replace1241 -> 1165 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search1242_0 -> 3591 in the cache */
   /* search1242_1 -> 3592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3591, 3592 },
      -1,
   } },

   /* replace1242 -> 1165 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1243_0 -> 1689 in the cache */
   /* search1243_1 -> 3594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1689, 3594 },
      -1,
   } },

   /* replace1243 -> 1165 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search1244_0 -> 3588 in the cache */
   /* search1244_1 -> 3589 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3588, 3589 },
      -1,
   } },

   /* replace1244 -> 1350 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search1245_0 -> 3591 in the cache */
   /* search1245_1 -> 3592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3591, 3592 },
      -1,
   } },

   /* replace1245 -> 1350 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search1246_0 -> 73 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 73, 3610 },
      -1,
   } },

   /* replace1246 -> 1350 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search1247_0 -> 9 in the cache */
   /* search1247_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* replace1247 -> 1165 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search1248_0_0 -> 29 in the cache */
   /* search1248_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1248 -> 29 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search1249_0_0 -> 29 in the cache */
   /* search1249_0_1 -> 48 in the cache */
   /* search1249_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1249 -> 48 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x */
   /* search1250_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3616 },
      -1,
   } },

   /* replace1250 -> 2783 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y */
   /* search1251_0_0 -> 29 in the cache */
   /* search1251_0 -> 3616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3616 },
      -1,
   } },

   /* replace1251 -> 2786 in the cache */

   /* ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a */
   /* search1252_0_0 -> 29 in the cache */
   /* search1252_0 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 2239 },
      -1,
   } },

   /* replace1252 -> 29 in the cache */

   /* ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0 */
   /* search1253_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1253 -> 135 in the cache */

   /* ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a */
   /* search1254_0_0 -> 29 in the cache */
   /* search1254_0 -> 2237 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 2237 },
      -1,
   } },

   /* replace1254 -> 29 in the cache */

   /* ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31) */
   /* search1255_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 29 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3623 },
      -1,
   } },

   /* replace1255_0 -> 29 in the cache */
   /* replace1255_1 -> 32 in the cache */
   /* replace1255 -> 1564 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search1256_0_0 -> 29 in the cache */
   /* search1256_0_1 -> 48 in the cache */
   /* search1256_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1256_0 -> 29 in the cache */
   /* replace1256_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search1257_0_0 -> 29 in the cache */
   /* search1257_0 -> 3616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3616 },
      -1,
   } },

   /* replace1257 -> 29 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search1258_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 3628 },
      -1,
   } },

   /* replace1258 -> 29 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search1259_0_0 -> 34 in the cache */
   /* search1259_0 -> 3088 in the cache */
   /* search1259_1_0 -> 34 in the cache */
   /* search1259_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 3088, 3082 },
      -1,
   } },

   /* replace1259 -> 34 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1260_0_0_0 -> 34 in the cache */
   /* search1260_0_0 -> 3088 in the cache */
   /* search1260_0_1_0 -> 34 in the cache */
   /* search1260_0_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3088, 3082 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3631 },
      -1,
   } },

   /* replace1260 -> 34 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1261_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3633 },
      -1,
   } },

   /* replace1261 -> 34 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1262_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 3635 },
      -1,
   } },

   /* replace1262 -> 34 in the cache */

   /* ('unpack_64_4x16', ('pack_64_4x16', 'a')) => a */
   /* search1263_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_4x16,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_4x16,
      -1, 0,
      { 3637 },
      -1,
   } },

   /* replace1263 -> 24 in the cache */

   /* ('unpack_64_4x16', ('pack_64_2x32', ('vec2', ('pack_32_2x16_split', 'a', 'b'), ('pack_32_2x16_split', 'c', 'd')))) => ('vec4', 'a', 'b', 'c', 'd') */
   /* search1264_0_0_0_0 -> 24 in the cache */
   /* search1264_0_0_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* search1264_0_0_1_0 -> 557 in the cache */
   /* search1264_0_0_1_1 -> 563 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 557, 563 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3639, 3640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3641 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_4x16,
      -1, 0,
      { 3642 },
      -1,
   } },

   /* replace1264_0 -> 24 in the cache */
   /* replace1264_1 -> 551 in the cache */
   /* replace1264_2 -> 557 in the cache */
   /* replace1264_3 -> 563 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 24, 551, 557, 563 },
      -1,
   } },

   /* ('unpack_64_4x16', ('pack_64_2x32_split', ('pack_32_2x16_split', 'a', 'b'), ('pack_32_2x16_split', 'c', 'd'))) => ('vec4', 'a', 'b', 'c', 'd') */
   /* search1265_0_0_0 -> 24 in the cache */
   /* search1265_0_0_1 -> 551 in the cache */
   /* search1265_0_0 -> 3639 in the cache */
   /* search1265_0_1_0 -> 557 in the cache */
   /* search1265_0_1_1 -> 563 in the cache */
   /* search1265_0_1 -> 3640 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 3639, 3640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_4x16,
      -1, 0,
      { 3645 },
      -1,
   } },

   /* replace1265_0 -> 24 in the cache */
   /* replace1265_1 -> 551 in the cache */
   /* replace1265_2 -> 557 in the cache */
   /* replace1265_3 -> 563 in the cache */
   /* replace1265 -> 3644 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1266_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 29 },
      -1,
   } },
   /* search1266_0_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3647, 2269 },
      -1,
   } },
   /* search1266_1_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 29 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3649, 3650 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3648, 3651 },
      -1,
   } },

   /* replace1266_0 -> 29 in the cache */
   /* replace1266_1_0 -> 551 in the cache */
   /* replace1266_1_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 551, 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 3653 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1267_0 -> 24 in the cache */
   /* search1267_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 24, 921 },
      -1,
   } },

   /* replace1267_0 -> 24 in the cache */
   /* replace1267_1 -> 1556 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 24, 1556 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1268_0 -> 29 in the cache */
   /* search1268_1 -> 1102 in the cache */
   /* search1268 -> 1107 in the cache */

   /* replace1268_0 -> 29 in the cache */
   /* replace1268_1 -> 495 in the cache */
   /* replace1268 -> 512 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1269_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38ull /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 3657 },
      -1,
   } },

   /* replace1269_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7ull /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 3659 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1270_0 -> 24 in the cache */
   /* search1270_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 24, 921 },
      -1,
   } },

   /* replace1270_0 -> 24 in the cache */
   /* replace1270_1 -> 1556 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 24, 1556 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1271_0 -> 29 in the cache */
   /* search1271_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 29, 1102 },
      -1,
   } },

   /* replace1271_0 -> 29 in the cache */
   /* replace1271_1 -> 495 in the cache */
   /* replace1271 -> 496 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1272_0 -> 34 in the cache */
   /* search1272_1 -> 3657 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 3657 },
      -1,
   } },

   /* replace1272_0 -> 34 in the cache */
   /* replace1272_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 3659 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1273_0 -> 1695 in the cache */
   /* search1273_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1695, 9 },
      -1,
   } },

   /* replace1273_0 -> 9 in the cache */
   /* replace1273_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* ('ishr', ('iand', 'a', 65280), 8) => ('extract_u8', 'a', 1) */
   /* search1274_0_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff00ull /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 3668 },
      -1,
   } },
   /* search1274_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3669, 921 },
      -1,
   } },

   /* replace1274_0 -> 9 in the cache */
   /* replace1274_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   /* ('ishr', ('iand', 'a', 16711680), 16) => ('extract_u8', 'a', 2) */
   /* search1275_0_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff0000ull /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 3672 },
      -1,
   } },
   /* search1275_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3673, 943 },
      -1,
   } },

   /* replace1275_0 -> 9 in the cache */
   /* replace1275_1 -> 2594 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 9, 2594 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1276_0_0 -> 9 in the cache */
   /* search1276_0_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 9, 47 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3676 },
      -1,
   } },

   /* replace1276_0_0 -> 9 in the cache */
   /* replace1276_0_1 -> 2594 in the cache */
   /* replace1276_0 -> 3675 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3675 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1277_0_0 -> 9 in the cache */
   /* search1277_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 9, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3679 },
      -1,
   } },

   /* replace1277_0_0 -> 9 in the cache */
   /* replace1277_0_1 -> 47 in the cache */
   /* replace1277_0 -> 3671 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3671 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1278_0_0_0 -> 0 in the cache */
   /* search1278_0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3682 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3683 },
      -1,
   } },

   /* replace1278_0_0 -> 0 in the cache */
   /* replace1278_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3685 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1279_0_0_0 -> 0 in the cache */
   /* search1279_0_0_1 -> 1 in the cache */
   /* search1279_0_0 -> 3682 in the cache */
   /* search1279_0 -> 3683 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3683 },
      -1,
   } },

   /* replace1279_0_0 -> 0 in the cache */
   /* replace1279_0_1 -> 1 in the cache */
   /* replace1279_0 -> 3682 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3682 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1280_0 -> 29 in the cache */
   /* search1280_1 -> 135 in the cache */
   /* search1280_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 135, 921 },
      -1,
   } },

   /* replace1280_0 -> 29 in the cache */
   /* replace1280_1 -> 135 in the cache */
   /* replace1280 -> 502 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1281_0 -> 29 in the cache */
   /* search1281_1 -> 921 in the cache */
   /* search1281_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 921, 921 },
      -1,
   } },

   /* replace1281_0 -> 29 in the cache */
   /* replace1281_1 -> 486 in the cache */
   /* replace1281 -> 505 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1282_0 -> 29 in the cache */
   /* search1282_1 -> 943 in the cache */
   /* search1282_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 943, 921 },
      -1,
   } },

   /* replace1282_0 -> 29 in the cache */
   /* replace1282_1 -> 491 in the cache */
   /* replace1282 -> 509 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1283_0 -> 29 in the cache */
   /* search1283_1 -> 1102 in the cache */
   /* search1283_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 1102, 921 },
      -1,
   } },

   /* replace1283_0 -> 29 in the cache */
   /* replace1283_1 -> 495 in the cache */
   /* replace1283 -> 512 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1284_0 -> 29 in the cache */
   /* search1284_1 -> 135 in the cache */
   /* search1284_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 135, 921 },
      -1,
   } },

   /* replace1284_0 -> 29 in the cache */
   /* replace1284_1 -> 135 in the cache */
   /* replace1284 -> 483 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1285_0 -> 29 in the cache */
   /* search1285_1 -> 921 in the cache */
   /* search1285_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 921, 921 },
      -1,
   } },

   /* replace1285_0 -> 29 in the cache */
   /* replace1285_1 -> 486 in the cache */
   /* replace1285 -> 487 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1286_0 -> 29 in the cache */
   /* search1286_1 -> 943 in the cache */
   /* search1286_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 943, 921 },
      -1,
   } },

   /* replace1286_0 -> 29 in the cache */
   /* replace1286_1 -> 491 in the cache */
   /* replace1286 -> 492 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1287_0 -> 29 in the cache */
   /* search1287_1 -> 1102 in the cache */
   /* search1287_2 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 1102, 921 },
      -1,
   } },

   /* replace1287_0 -> 29 in the cache */
   /* replace1287_1 -> 495 in the cache */
   /* replace1287 -> 496 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1288_0_0 -> 0 in the cache */
   /* search1288_0_1 -> 1 in the cache */
   /* search1288_0 -> 3685 in the cache */
   /* search1288_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3685, 98 },
      -1,
   } },

   /* replace1288_0 -> 0 in the cache */
   /* replace1288_1 -> 1 in the cache */
   /* replace1288 -> 3682 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1289_0_0 -> 0 in the cache */
   /* search1289_0_1 -> 1 in the cache */
   /* search1289_0 -> 3682 in the cache */
   /* search1289_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3682, 98 },
      -1,
   } },

   /* replace1289_0 -> 0 in the cache */
   /* replace1289_1 -> 1 in the cache */
   /* replace1289 -> 3682 in the cache */

   /* ('extract_i8', ('iand', 'a', 65280), 1) => ('extract_i8', 'a', 1) */
   /* search1290_0_0 -> 9 in the cache */
   /* search1290_0_1 -> 3668 in the cache */
   /* search1290_0 -> 3669 in the cache */
   /* search1290_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 3669, 47 },
      -1,
   } },

   /* replace1290_0 -> 9 in the cache */
   /* replace1290_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 9, 47 },
      -1,
   } },

   /* ('extract_i8', ('iand', 'a', 16711680), 2) => ('extract_i8', 'a', 2) */
   /* search1291_0_0 -> 9 in the cache */
   /* search1291_0_1 -> 3672 in the cache */
   /* search1291_0 -> 3673 in the cache */
   /* search1291_1 -> 2594 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 3673, 2594 },
      -1,
   } },

   /* replace1291_0 -> 9 in the cache */
   /* replace1291_1 -> 2594 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 9, 2594 },
      -1,
   } },

   /* ('extract_i8', ('iand', 'a', 4278190080), 3) => ('extract_i8', 'a', 3) */
   /* search1292_0_0 -> 9 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff000000ull /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 3703 },
      -1,
   } },
   /* search1292_1 -> 2598 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 3704, 2598 },
      -1,
   } },

   /* replace1292_0 -> 9 in the cache */
   /* replace1292_1 -> 2598 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 9, 2598 },
      -1,
   } },

   /* ('extract_u8', ('iand', 'a', 65280), 1) => ('extract_u8', 'a', 1) */
   /* search1293_0_0 -> 9 in the cache */
   /* search1293_0_1 -> 3668 in the cache */
   /* search1293_0 -> 3669 in the cache */
   /* search1293_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 3669, 47 },
      -1,
   } },

   /* replace1293_0 -> 9 in the cache */
   /* replace1293_1 -> 47 in the cache */
   /* replace1293 -> 3671 in the cache */

   /* ('extract_u8', ('iand', 'a', 16711680), 2) => ('extract_u8', 'a', 2) */
   /* search1294_0_0 -> 9 in the cache */
   /* search1294_0_1 -> 3672 in the cache */
   /* search1294_0 -> 3673 in the cache */
   /* search1294_1 -> 2594 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 3673, 2594 },
      -1,
   } },

   /* replace1294_0 -> 9 in the cache */
   /* replace1294_1 -> 2594 in the cache */
   /* replace1294 -> 3675 in the cache */

   /* ('extract_u8', ('iand', 'a', 4278190080), 3) => ('extract_u8', 'a', 3) */
   /* search1295_0_0 -> 9 in the cache */
   /* search1295_0_1 -> 3703 in the cache */
   /* search1295_0 -> 3704 in the cache */
   /* search1295_1 -> 2598 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 3704, 2598 },
      -1,
   } },

   /* replace1295_0 -> 9 in the cache */
   /* replace1295_1 -> 2598 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 9, 2598 },
      -1,
   } },

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1296_0_0 -> 29 in the cache */
   /* search1296_0_1 -> 943 in the cache */
   /* search1296_0 -> 1095 in the cache */
   /* search1296_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1095, 943 },
      -1,
   } },

   /* replace1296_0 -> 29 in the cache */
   /* replace1296_1 -> 135 in the cache */
   /* replace1296 -> 534 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1297_0 -> 29 in the cache */
   /* search1297_1 -> 943 in the cache */
   /* search1297 -> 1098 in the cache */

   /* replace1297_0 -> 29 in the cache */
   /* replace1297_1 -> 486 in the cache */
   /* replace1297 -> 537 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1298_0_0 -> 29 in the cache */
   /* search1298_0_1 -> 943 in the cache */
   /* search1298_0 -> 1095 in the cache */
   /* search1298_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1095, 943 },
      -1,
   } },

   /* replace1298_0 -> 29 in the cache */
   /* replace1298_1 -> 135 in the cache */
   /* replace1298 -> 526 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1299_0 -> 29 in the cache */
   /* search1299_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 29, 943 },
      -1,
   } },

   /* replace1299_0 -> 29 in the cache */
   /* replace1299_1 -> 486 in the cache */
   /* replace1299 -> 529 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffffull /* 65535 */ },
   } },
   /* search1300_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3714, 9 },
      -1,
   } },

   /* replace1300_0 -> 9 in the cache */
   /* replace1300_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 9, 73 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1301_0 -> 29 in the cache */
   /* search1301_1 -> 135 in the cache */
   /* search1301_2 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 135, 943 },
      -1,
   } },

   /* replace1301_0 -> 29 in the cache */
   /* replace1301_1 -> 135 in the cache */
   /* replace1301 -> 534 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1302_0 -> 29 in the cache */
   /* search1302_1 -> 943 in the cache */
   /* search1302_2 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 943, 943 },
      -1,
   } },

   /* replace1302_0 -> 29 in the cache */
   /* replace1302_1 -> 486 in the cache */
   /* replace1302 -> 537 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1303_0 -> 29 in the cache */
   /* search1303_1 -> 135 in the cache */
   /* search1303_2 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 135, 943 },
      -1,
   } },

   /* replace1303_0 -> 29 in the cache */
   /* replace1303_1 -> 135 in the cache */
   /* replace1303 -> 526 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1304_0 -> 29 in the cache */
   /* search1304_1 -> 943 in the cache */
   /* search1304_2 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 943, 943 },
      -1,
   } },

   /* replace1304_0 -> 29 in the cache */
   /* replace1304_1 -> 486 in the cache */
   /* replace1304 -> 529 in the cache */

   /* ('unpack_32_4x8', ('pack_32_4x8', 'a')) => a */
   /* search1305_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_4x8,
      -1, 0,
      { 3721 },
      -1,
   } },

   /* replace1305 -> 19 in the cache */

   /* ('unpack_32_2x16', ('pack_32_2x16', 'a')) => a */
   /* search1306_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_2x16,
      -1, 0,
      { 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16,
      -1, 0,
      { 3723 },
      -1,
   } },

   /* replace1306 -> 24 in the cache */

   /* ('unpack_64_4x16', ('pack_64_4x16', 'a')) => a */
   /* search1307_0_0 -> 24 in the cache */
   /* search1307_0 -> 3637 in the cache */
   /* search1307 -> 3638 in the cache */

   /* replace1307 -> 24 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search1308_0_0 -> 29 in the cache */
   /* search1308_0 -> 3616 in the cache */
   /* search1308 -> 3627 in the cache */

   /* replace1308 -> 29 in the cache */

   /* ('pack_32_4x8', ('unpack_32_4x8', 'a')) => a */
   /* search1309_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_4x8,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 3725 },
      -1,
   } },

   /* replace1309 -> 29 in the cache */

   /* ('pack_32_2x16', ('unpack_32_2x16', 'a')) => a */
   /* search1310_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_2x16,
      -1, 0,
      { 3727 },
      -1,
   } },

   /* replace1310 -> 29 in the cache */

   /* ('pack_64_4x16', ('unpack_64_4x16', 'a')) => a */
   /* search1311_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_4x16,
      -1, 0,
      { 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_4x16,
      -1, 0,
      { 3729 },
      -1,
   } },

   /* replace1311 -> 34 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1312_0_0 -> 34 in the cache */
   /* search1312_0 -> 3633 in the cache */
   /* search1312 -> 3634 in the cache */

   /* replace1312 -> 34 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1313_0_0_0 -> 19 in the cache */
   /* search1313_0_0 -> 2189 in the cache */
   /* search1313_0_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2189, 1102 },
      -1,
   } },
   /* search1313_1_0_0_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2370 },
      -1,
   } },
   /* search1313_1_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3732, 943 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3734 },
      -1,
   } },
   /* search1313_1_1_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3735, 921 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3737 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 3736, 3738 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 3733, 3739 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3731, 3740 },
      -1,
   } },

   /* replace1313_0_0 -> 3737 in the cache */
   /* replace1313_0_1 -> 3734 in the cache */
   /* replace1313_0_2 -> 2370 in the cache */
   /* replace1313_0_3 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3737, 3734, 2370, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 3742 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1314_0_0 -> 0 in the cache */
   /* search1314_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search1314_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3744, 98 },
      -1,
   } },

   /* replace1314_0 -> 0 in the cache */
   /* replace1314_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1315_0_0 -> 0 in the cache */
   /* search1315_0_1 -> 1 in the cache */
   /* search1315_0 -> 3746 in the cache */
   /* search1315_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3746, 98 },
      -1,
   } },

   /* replace1315_0 -> 0 in the cache */
   /* replace1315_1 -> 1 in the cache */
   /* replace1315 -> 3746 in the cache */

   /* ('extract_i16', ('iand', 'a', 16711680), 1) => ('extract_u8', 'a', 2) */
   /* search1316_0_0 -> 9 in the cache */
   /* search1316_0_1 -> 3672 in the cache */
   /* search1316_0 -> 3673 in the cache */
   /* search1316_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 3673, 47 },
      -1,
   } },

   /* replace1316_0 -> 9 in the cache */
   /* replace1316_1 -> 2594 in the cache */
   /* replace1316 -> 3675 in the cache */

   /* ('extract_u16', ('iand', 'a', 16711680), 1) => ('extract_u8', 'a', 2) */
   /* search1317_0_0 -> 9 in the cache */
   /* search1317_0_1 -> 3672 in the cache */
   /* search1317_0 -> 3673 in the cache */
   /* search1317_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 3673, 47 },
      -1,
   } },

   /* replace1317_0 -> 9 in the cache */
   /* replace1317_1 -> 2594 in the cache */
   /* replace1317 -> 3675 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1318_0 -> 29 in the cache */
   /* search1318_1 -> 48 in the cache */
   /* search1318 -> 3613 in the cache */

   /* replace1318_0_0 -> 29 in the cache */
   /* replace1318_0 -> 2239 in the cache */
   /* replace1318_1_0_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 48 },
      -1,
   } },
   /* replace1318_1_1 -> 964 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3750, 964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2239, 3751 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1319_0 -> 24 in the cache */
   /* search1319_1 -> 551 in the cache */
   /* search1319 -> 3639 in the cache */

   /* replace1319_0_0 -> 24 in the cache */
   /* replace1319_0 -> 2219 in the cache */
   /* replace1319_1_0_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 551 },
      -1,
   } },
   /* replace1319_1_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3753, 943 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2219, 3754 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a', 'b') => ('pack_half_2x16_rtz_split', 'a', 'b') */
   /* search1320_0 -> 29 in the cache */
   /* search1320_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1320_0 -> 29 in the cache */
   /* replace1320_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1321_0 -> 34 in the cache */
   /* search1321 -> 3088 in the cache */

   /* replace1321_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 34 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1322_0 -> 34 in the cache */
   /* search1322 -> 3082 in the cache */

   /* replace1322_0_0 -> 34 in the cache */
   /* replace1322_0_1 -> 964 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3759 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1323_0 -> 29 in the cache */
   /* search1323 -> 3647 in the cache */

   /* replace1323_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1324_0 -> 29 in the cache */
   /* search1324 -> 3649 in the cache */

   /* replace1324_0_0 -> 29 in the cache */
   /* replace1324_0_1 -> 943 in the cache */
   /* replace1324_0 -> 1098 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1098 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('ushr', 'a', 32)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1325_0_0 -> 34 in the cache */
   /* search1325_0_1 -> 964 in the cache */
   /* search1325_0 -> 3759 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3759 },
      -1,
   } },

   /* replace1325_0 -> 34 in the cache */
   /* replace1325 -> 3082 in the cache */

   /* ('u2u32', ('ushr', 'a@64', 32)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1326_0_0 -> 34 in the cache */
   /* search1326_0_1 -> 964 in the cache */
   /* search1326_0 -> 3759 in the cache */
   /* search1326 -> 3760 in the cache */

   /* replace1326_0 -> 34 in the cache */
   /* replace1326 -> 3082 in the cache */

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1327_0_0 -> 29 in the cache */
   /* search1327_0_1 -> 1092 in the cache */
   /* search1327_0 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 1093 },
      -1,
   } },

   /* replace1327_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1328_0_0 -> 29 in the cache */
   /* search1328_0_1 -> 1092 in the cache */
   /* search1328_0 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 1093 },
      -1,
   } },

   /* replace1328_0 -> 29 in the cache */
   /* replace1328 -> 3647 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1329_0_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffull /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 3767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 3768 },
      -1,
   } },

   /* replace1329_0 -> 34 in the cache */
   /* replace1329 -> 3088 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1330_0_0 -> 29 in the cache */
   /* search1330_0_1 -> 1096 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 1096 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 3770 },
      -1,
   } },

   /* replace1330_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1331_0_0 -> 29 in the cache */
   /* search1331_0_1 -> 1096 in the cache */
   /* search1331_0 -> 3770 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 3770 },
      -1,
   } },

   /* replace1331_0 -> 29 in the cache */
   /* replace1331 -> 3649 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1332_0_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000ull /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 3774 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 3775 },
      -1,
   } },

   /* replace1332_0 -> 34 in the cache */
   /* replace1332 -> 3082 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1333_0_0 -> 29 in the cache */
   /* search1333_0_1 -> 135 in the cache */
   /* search1333_0 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 534 },
      -1,
   } },

   /* replace1333_0 -> 29 in the cache */
   /* replace1333 -> 3765 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1334_0_0 -> 29 in the cache */
   /* search1334_0_1 -> 486 in the cache */
   /* search1334_0 -> 537 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 537 },
      -1,
   } },

   /* replace1334_0 -> 29 in the cache */
   /* replace1334 -> 3772 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1335_0_0 -> 29 in the cache */
   /* search1335_0_1 -> 943 in the cache */
   /* search1335_0 -> 1098 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 1098 },
      -1,
   } },

   /* replace1335_0 -> 29 in the cache */
   /* replace1335 -> 3772 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1336_0_0 -> 29 in the cache */
   /* search1336_0_1 -> 135 in the cache */
   /* search1336_0 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 534 },
      -1,
   } },

   /* replace1336_0 -> 29 in the cache */
   /* replace1336 -> 3647 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1337_0_0 -> 29 in the cache */
   /* search1337_0_1 -> 486 in the cache */
   /* search1337_0 -> 537 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 537 },
      -1,
   } },

   /* replace1337_0 -> 29 in the cache */
   /* replace1337 -> 3649 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1338_0_0_0 -> 29 in the cache */
   /* search1338_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3782 },
      -1,
   } },
   /* search1338_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3783, 943 },
      -1,
   } },

   /* replace1338_0_0 -> 135 in the cache */
   /* replace1338_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 135, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3785 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1339_0_0_0 -> 135 in the cache */
   /* search1339_0_0_1 -> 29 in the cache */
   /* search1339_0_0 -> 3785 in the cache */
   /* search1339_0 -> 3786 in the cache */
   /* search1339_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3786, 943 },
      -1,
   } },

   /* replace1339_0_0 -> 29 in the cache */
   /* replace1339_0_1 -> 135 in the cache */
   /* replace1339_0 -> 3782 in the cache */
   /* replace1339 -> 3783 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1340_0_0_0 -> 29 in the cache */
   /* search1340_0_0_1 -> 135 in the cache */
   /* search1340_0_0 -> 3782 in the cache */
   /* search1340_0 -> 3783 in the cache */
   /* search1340_1_0_0 -> 135 in the cache */
   /* search1340_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 135, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3783, 3789 },
      -1,
   } },

   /* replace1340_0_0 -> 29 in the cache */
   /* replace1340_0_1 -> 48 in the cache */
   /* replace1340_0 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3626 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1341_0_0_0 -> 29 in the cache */
   /* search1341_0_0_1 -> 135 in the cache */
   /* search1341_0_0 -> 3782 in the cache */
   /* search1341_0 -> 3783 in the cache */
   /* search1341_1_0_0 -> 135 in the cache */
   /* search1341_1_0_1 -> 48 in the cache */
   /* search1341_1_0 -> 3788 in the cache */
   /* search1341_1 -> 3789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3783, 3789 },
      -1,
   } },

   /* replace1341_0_0 -> 29 in the cache */
   /* replace1341_0_1 -> 48 in the cache */
   /* replace1341_0 -> 3626 in the cache */
   /* replace1341 -> 3791 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1342_0_0 -> 29 in the cache */
   /* search1342_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* search1342_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3793, 943 },
      -1,
   } },

   /* replace1342_0 -> 135 in the cache */
   /* replace1342_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 135, 29 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1343_0_0 -> 135 in the cache */
   /* search1343_0_1 -> 29 in the cache */
   /* search1343_0 -> 3795 in the cache */
   /* search1343_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3795, 943 },
      -1,
   } },

   /* replace1343_0 -> 29 in the cache */
   /* replace1343_1 -> 135 in the cache */
   /* replace1343 -> 3793 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1344_0_0 -> 135 in the cache */
   /* search1344_0_1 -> 29 in the cache */
   /* search1344_0 -> 3795 in the cache */
   /* search1344_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3795, 486 },
      -1,
   } },

   /* replace1344_0 -> 29 in the cache */
   /* replace1344_1 -> 135 in the cache */
   /* replace1344 -> 3793 in the cache */

   /* ('ishl', ('pack_half_2x16_rtz_split', 'a', 0), 16) => ('pack_half_2x16_rtz_split', 0, 'a') */
   /* search1345_0_0 -> 29 in the cache */
   /* search1345_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* search1345_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3798, 943 },
      -1,
   } },

   /* replace1345_0 -> 135 in the cache */
   /* replace1345_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 135, 29 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_rtz_split', 0, 'a'), 16) => ('pack_half_2x16_rtz_split', 'a', 0) */
   /* search1346_0_0 -> 135 in the cache */
   /* search1346_0_1 -> 29 in the cache */
   /* search1346_0 -> 3800 in the cache */
   /* search1346_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3800, 943 },
      -1,
   } },

   /* replace1346_0 -> 29 in the cache */
   /* replace1346_1 -> 135 in the cache */
   /* replace1346 -> 3798 in the cache */

   /* ('extract_u16', ('pack_half_2x16_rtz_split', 0, 'a'), 1) => ('pack_half_2x16_rtz_split', 'a', 0) */
   /* search1347_0_0 -> 135 in the cache */
   /* search1347_0_1 -> 29 in the cache */
   /* search1347_0 -> 3800 in the cache */
   /* search1347_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3800, 486 },
      -1,
   } },

   /* replace1347_0 -> 29 in the cache */
   /* replace1347_1 -> 135 in the cache */
   /* replace1347 -> 3798 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1348_0_0 -> 29 in the cache */
   /* search1348_0_1 -> 135 in the cache */
   /* search1348_0 -> 3793 in the cache */
   /* search1348_1_0 -> 135 in the cache */
   /* search1348_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 135, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3793, 3803 },
      -1,
   } },

   /* replace1348_0 -> 29 in the cache */
   /* replace1348_1 -> 48 in the cache */
   /* replace1348 -> 3756 in the cache */

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1349_0_0 -> 29 in the cache */
   /* search1349_0_1 -> 135 in the cache */
   /* search1349_0 -> 3793 in the cache */
   /* search1349_1_0 -> 135 in the cache */
   /* search1349_1_1 -> 48 in the cache */
   /* search1349_1 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3793, 3803 },
      -1,
   } },

   /* replace1349_0 -> 29 in the cache */
   /* replace1349_1 -> 48 in the cache */
   /* replace1349 -> 3756 in the cache */

   /* ('iadd', ('pack_half_2x16_rtz_split', 'a', 0), ('pack_half_2x16_rtz_split', 0, 'b')) => ('pack_half_2x16_rtz_split', 'a', 'b') */
   /* search1350_0_0 -> 29 in the cache */
   /* search1350_0_1 -> 135 in the cache */
   /* search1350_0 -> 3798 in the cache */
   /* search1350_1_0 -> 135 in the cache */
   /* search1350_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 135, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3798, 3806 },
      -1,
   } },

   /* replace1350_0 -> 29 in the cache */
   /* replace1350_1 -> 48 in the cache */
   /* replace1350 -> 3757 in the cache */

   /* ('ior', ('pack_half_2x16_rtz_split', 'a', 0), ('pack_half_2x16_rtz_split', 0, 'b')) => ('pack_half_2x16_rtz_split', 'a', 'b') */
   /* search1351_0_0 -> 29 in the cache */
   /* search1351_0_1 -> 135 in the cache */
   /* search1351_0 -> 3798 in the cache */
   /* search1351_1_0 -> 135 in the cache */
   /* search1351_1_1 -> 48 in the cache */
   /* search1351_1 -> 3806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3798, 3806 },
      -1,
   } },

   /* replace1351_0 -> 29 in the cache */
   /* replace1351_1 -> 48 in the cache */
   /* replace1351 -> 3757 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1352_0_0 -> 19 in the cache */
   /* search1352_0_1 -> 2370 in the cache */
   /* search1352_0_2 -> 3734 in the cache */
   /* search1352_0_3 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 19, 2370, 3734, 3737 },
      -1,
   } },
   /* search1352_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3809, 135 },
      -1,
   } },

   /* replace1352_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1353_0_0 -> 19 in the cache */
   /* search1353_0_1 -> 2370 in the cache */
   /* search1353_0_2 -> 3734 in the cache */
   /* search1353_0_3 -> 3737 in the cache */
   /* search1353_0 -> 3809 in the cache */
   /* search1353_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3809, 486 },
      -1,
   } },

   /* replace1353_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2370 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1354_0_0 -> 19 in the cache */
   /* search1354_0_1 -> 2370 in the cache */
   /* search1354_0_2 -> 3734 in the cache */
   /* search1354_0_3 -> 3737 in the cache */
   /* search1354_0 -> 3809 in the cache */
   /* search1354_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3809, 491 },
      -1,
   } },

   /* replace1354_0 -> 3734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3734 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1355_0_0 -> 19 in the cache */
   /* search1355_0_1 -> 2370 in the cache */
   /* search1355_0_2 -> 3734 in the cache */
   /* search1355_0_3 -> 3737 in the cache */
   /* search1355_0 -> 3809 in the cache */
   /* search1355_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3809, 495 },
      -1,
   } },

   /* replace1355_0 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3737 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1356_0_0 -> 19 in the cache */
   /* search1356_0_1 -> 2370 in the cache */
   /* search1356_0_2 -> 3734 in the cache */
   /* search1356_0_3 -> 3737 in the cache */
   /* search1356_0 -> 3809 in the cache */
   /* search1356_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3809, 135 },
      -1,
   } },

   /* replace1356_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 19 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1357_0_0 -> 19 in the cache */
   /* search1357_0_1 -> 2370 in the cache */
   /* search1357_0_2 -> 3734 in the cache */
   /* search1357_0_3 -> 3737 in the cache */
   /* search1357_0 -> 3809 in the cache */
   /* search1357_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3809, 486 },
      -1,
   } },

   /* replace1357_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2370 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1358_0_0 -> 19 in the cache */
   /* search1358_0_1 -> 2370 in the cache */
   /* search1358_0_2 -> 3734 in the cache */
   /* search1358_0_3 -> 3737 in the cache */
   /* search1358_0 -> 3809 in the cache */
   /* search1358_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3809, 491 },
      -1,
   } },

   /* replace1358_0 -> 3734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3734 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1359_0_0 -> 19 in the cache */
   /* search1359_0_1 -> 2370 in the cache */
   /* search1359_0_2 -> 3734 in the cache */
   /* search1359_0_3 -> 3737 in the cache */
   /* search1359_0 -> 3809 in the cache */
   /* search1359_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3809, 495 },
      -1,
   } },

   /* replace1359_0 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3737 },
      -1,
   } },

   /* ('u2u32', ('iadd(is_used_once)', 'a@64', 'b')) => ('iadd', ('u2u32', 'a'), ('u2u32', 'b')) */
   /* search1360_0_0 -> 34 in the cache */
   /* search1360_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 34, 53 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 1,
      { 3826 },
      -1,
   } },

   /* replace1360_0_0 -> 34 in the cache */
   /* replace1360_0 -> 3758 in the cache */
   /* replace1360_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3758, 3828 },
      -1,
   } },

   /* ('u2u32', ('ushr', ('ior', ('ishl', 'a', 32), ('u2u64', 'b')), 32)) => ('u2u32', 'a') */
   /* search1361_0_0_0_0 -> 34 in the cache */
   /* search1361_0_0_0_1 -> 964 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 964 },
      -1,
   } },
   /* search1361_0_0_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3830, 3831 },
      -1,
   } },
   /* search1361_0_1 -> 964 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3832, 964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 1,
      { 3833 },
      -1,
   } },

   /* replace1361_0 -> 34 in the cache */
   /* replace1361 -> 3758 in the cache */

   /* ('u2u16', ('ushr', ('ior', ('ishl', 'a', 16), ('u2u32', 'b')), 16)) => ('u2u16', 'a') */
   /* search1362_0_0_0_0 -> 29 in the cache */
   /* search1362_0_0_0_1 -> 943 in the cache */
   /* search1362_0_0_0 -> 1095 in the cache */
   /* search1362_0_0_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1095, 3835 },
      -1,
   } },
   /* search1362_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3836, 943 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 3837 },
      -1,
   } },

   /* replace1362_0 -> 29 in the cache */
   /* replace1362 -> 3761 in the cache */

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1363_0_0 -> 24 in the cache */
   /* search1363_0_1 -> 921 in the cache */
   /* search1363_0 -> 3655 in the cache */
   /* search1363_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3655, 946 },
      -1,
   } },

   /* replace1363_0 -> 24 in the cache */
   /* replace1363_1 -> 1556 in the cache */
   /* replace1363 -> 3656 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1364_0_0 -> 29 in the cache */
   /* search1364_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 29, 921 },
      -1,
   } },
   /* search1364_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3840, 135 },
      -1,
   } },

   /* replace1364_0 -> 29 in the cache */
   /* replace1364_1 -> 486 in the cache */
   /* replace1364 -> 505 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1365_0_0 -> 29 in the cache */
   /* search1365_0_1 -> 943 in the cache */
   /* search1365_0 -> 1098 in the cache */
   /* search1365_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1098, 135 },
      -1,
   } },

   /* replace1365_0 -> 29 in the cache */
   /* replace1365_1 -> 491 in the cache */
   /* replace1365 -> 509 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1366_0_0 -> 29 in the cache */
   /* search1366_0_1 -> 1102 in the cache */
   /* search1366_0 -> 1107 in the cache */
   /* search1366_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1107, 135 },
      -1,
   } },

   /* replace1366_0 -> 29 in the cache */
   /* replace1366_1 -> 495 in the cache */
   /* replace1366 -> 512 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1367_0_0 -> 34 in the cache */
   /* search1367_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 921 },
      -1,
   } },
   /* search1367_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3844, 987 },
      -1,
   } },

   /* replace1367_0 -> 34 in the cache */
   /* replace1367_1 -> 1598 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 1598 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1368_0_0 -> 34 in the cache */
   /* search1368_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 943 },
      -1,
   } },
   /* search1368_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3847, 987 },
      -1,
   } },

   /* replace1368_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2ull /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 3849 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1369_0_0 -> 34 in the cache */
   /* search1369_0_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 1102 },
      -1,
   } },
   /* search1369_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3851, 987 },
      -1,
   } },

   /* replace1369_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3ull /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 3853 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1370_0_0 -> 34 in the cache */
   /* search1370_0_1 -> 964 in the cache */
   /* search1370_0 -> 3759 in the cache */
   /* search1370_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3759, 987 },
      -1,
   } },

   /* replace1370_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4ull /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 3856 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1371_0_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28ull /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 3858 },
      -1,
   } },
   /* search1371_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3859, 987 },
      -1,
   } },

   /* replace1371_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5ull /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 3861 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1372_0_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30ull /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 34, 3863 },
      -1,
   } },
   /* search1372_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3864, 987 },
      -1,
   } },

   /* replace1372_0 -> 34 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6ull /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 3866 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1373_0_0 -> 34 in the cache */
   /* search1373_0_1 -> 3657 in the cache */
   /* search1373_0 -> 3658 in the cache */
   /* search1373_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3658, 987 },
      -1,
   } },

   /* replace1373_0 -> 34 in the cache */
   /* replace1373_1 -> 3659 in the cache */
   /* replace1373 -> 3660 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1374_0_0 -> 24 in the cache */
   /* search1374_0_1 -> 921 in the cache */
   /* search1374_0 -> 3661 in the cache */
   /* search1374_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3661, 946 },
      -1,
   } },

   /* replace1374_0 -> 24 in the cache */
   /* replace1374_1 -> 1556 in the cache */
   /* replace1374 -> 3656 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1375_0_0 -> 29 in the cache */
   /* search1375_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 29, 921 },
      -1,
   } },
   /* search1375_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3870, 135 },
      -1,
   } },

   /* replace1375_0 -> 29 in the cache */
   /* replace1375_1 -> 486 in the cache */
   /* replace1375 -> 505 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1376_0_0 -> 29 in the cache */
   /* search1376_0_1 -> 943 in the cache */
   /* search1376_0 -> 3713 in the cache */
   /* search1376_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3713, 135 },
      -1,
   } },

   /* replace1376_0 -> 29 in the cache */
   /* replace1376_1 -> 491 in the cache */
   /* replace1376 -> 509 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1377_0_0 -> 29 in the cache */
   /* search1377_0_1 -> 1102 in the cache */
   /* search1377_0 -> 3663 in the cache */
   /* search1377_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3663, 135 },
      -1,
   } },

   /* replace1377_0 -> 29 in the cache */
   /* replace1377_1 -> 495 in the cache */
   /* replace1377 -> 512 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1378_0_0 -> 34 in the cache */
   /* search1378_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 921 },
      -1,
   } },
   /* search1378_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3874, 987 },
      -1,
   } },

   /* replace1378_0 -> 34 in the cache */
   /* replace1378_1 -> 1598 in the cache */
   /* replace1378 -> 3846 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1379_0_0 -> 34 in the cache */
   /* search1379_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 943 },
      -1,
   } },
   /* search1379_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3876, 987 },
      -1,
   } },

   /* replace1379_0 -> 34 in the cache */
   /* replace1379_1 -> 3849 in the cache */
   /* replace1379 -> 3850 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1380_0_0 -> 34 in the cache */
   /* search1380_0_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 1102 },
      -1,
   } },
   /* search1380_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3878, 987 },
      -1,
   } },

   /* replace1380_0 -> 34 in the cache */
   /* replace1380_1 -> 3853 in the cache */
   /* replace1380 -> 3854 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1381_0_0 -> 34 in the cache */
   /* search1381_0_1 -> 964 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 964 },
      -1,
   } },
   /* search1381_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3880, 987 },
      -1,
   } },

   /* replace1381_0 -> 34 in the cache */
   /* replace1381_1 -> 3856 in the cache */
   /* replace1381 -> 3857 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1382_0_0 -> 34 in the cache */
   /* search1382_0_1 -> 3858 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 3858 },
      -1,
   } },
   /* search1382_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3882, 987 },
      -1,
   } },

   /* replace1382_0 -> 34 in the cache */
   /* replace1382_1 -> 3861 in the cache */
   /* replace1382 -> 3862 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1383_0_0 -> 34 in the cache */
   /* search1383_0_1 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 34, 3863 },
      -1,
   } },
   /* search1383_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3884, 987 },
      -1,
   } },

   /* replace1383_0 -> 34 in the cache */
   /* replace1383_1 -> 3866 in the cache */
   /* replace1383 -> 3867 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1384_0_0 -> 34 in the cache */
   /* search1384_0_1 -> 3657 in the cache */
   /* search1384_0 -> 3664 in the cache */
   /* search1384_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3664, 987 },
      -1,
   } },

   /* replace1384_0 -> 34 in the cache */
   /* replace1384_1 -> 3659 in the cache */
   /* replace1384 -> 3660 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1385_0_0 -> 9 in the cache */
   /* search1385_0_1 -> 47 in the cache */
   /* search1385_0 -> 3676 in the cache */
   /* search1385_1 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3676, 73 },
      -1,
   } },

   /* replace1385_0 -> 9 in the cache */
   /* replace1385_1 -> 2594 in the cache */
   /* replace1385 -> 3675 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1386_0_0 -> 24 in the cache */
   /* search1386_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 24, 921 },
      -1,
   } },
   /* search1386_1 -> 1556 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3888, 1556 },
      -1,
   } },

   /* replace1386_0 -> 24 in the cache */
   /* replace1386_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 24, 946 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1387_0_0 -> 29 in the cache */
   /* search1387_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 921 },
      -1,
   } },
   /* search1387_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3891, 495 },
      -1,
   } },

   /* replace1387_0 -> 29 in the cache */
   /* replace1387_1 -> 491 in the cache */
   /* replace1387 -> 509 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1388_0_0 -> 29 in the cache */
   /* search1388_0_1 -> 943 in the cache */
   /* search1388_0 -> 1095 in the cache */
   /* search1388_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1095, 495 },
      -1,
   } },

   /* replace1388_0 -> 29 in the cache */
   /* replace1388_1 -> 486 in the cache */
   /* replace1388 -> 505 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1389_0_0 -> 29 in the cache */
   /* search1389_0_1 -> 1102 in the cache */
   /* search1389_0 -> 1104 in the cache */
   /* search1389_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1104, 495 },
      -1,
   } },

   /* replace1389_0 -> 29 in the cache */
   /* replace1389_1 -> 135 in the cache */
   /* replace1389 -> 502 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1390_0_0 -> 34 in the cache */
   /* search1390_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 921 },
      -1,
   } },
   /* search1390_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3895, 3659 },
      -1,
   } },

   /* replace1390_0 -> 34 in the cache */
   /* replace1390_1 -> 3866 in the cache */
   /* replace1390 -> 3867 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1391_0_0 -> 34 in the cache */
   /* search1391_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 943 },
      -1,
   } },
   /* search1391_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3897, 3659 },
      -1,
   } },

   /* replace1391_0 -> 34 in the cache */
   /* replace1391_1 -> 3861 in the cache */
   /* replace1391 -> 3862 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1392_0_0 -> 34 in the cache */
   /* search1392_0_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 1102 },
      -1,
   } },
   /* search1392_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3899, 3659 },
      -1,
   } },

   /* replace1392_0 -> 34 in the cache */
   /* replace1392_1 -> 3856 in the cache */
   /* replace1392 -> 3857 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1393_0_0 -> 34 in the cache */
   /* search1393_0_1 -> 964 in the cache */
   /* search1393_0 -> 3830 in the cache */
   /* search1393_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3830, 3659 },
      -1,
   } },

   /* replace1393_0 -> 34 in the cache */
   /* replace1393_1 -> 3853 in the cache */
   /* replace1393 -> 3854 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1394_0_0 -> 34 in the cache */
   /* search1394_0_1 -> 3858 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 3858 },
      -1,
   } },
   /* search1394_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3902, 3659 },
      -1,
   } },

   /* replace1394_0 -> 34 in the cache */
   /* replace1394_1 -> 3849 in the cache */
   /* replace1394 -> 3850 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1395_0_0 -> 34 in the cache */
   /* search1395_0_1 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 3863 },
      -1,
   } },
   /* search1395_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3904, 3659 },
      -1,
   } },

   /* replace1395_0 -> 34 in the cache */
   /* replace1395_1 -> 1598 in the cache */
   /* replace1395 -> 3846 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1396_0_0 -> 34 in the cache */
   /* search1396_0_1 -> 3657 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 3657 },
      -1,
   } },
   /* search1396_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3906, 3659 },
      -1,
   } },

   /* replace1396_0 -> 34 in the cache */
   /* replace1396_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 34, 987 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1397_0_0 -> 24 in the cache */
   /* search1397_0_1 -> 921 in the cache */
   /* search1397_0 -> 3888 in the cache */
   /* search1397_1 -> 1556 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3888, 1556 },
      -1,
   } },

   /* replace1397_0 -> 24 in the cache */
   /* replace1397_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 24, 946 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1398_0_0 -> 29 in the cache */
   /* search1398_0_1 -> 921 in the cache */
   /* search1398_0 -> 3891 in the cache */
   /* search1398_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3891, 495 },
      -1,
   } },

   /* replace1398_0 -> 29 in the cache */
   /* replace1398_1 -> 491 in the cache */
   /* replace1398 -> 492 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1399_0_0 -> 29 in the cache */
   /* search1399_0_1 -> 943 in the cache */
   /* search1399_0 -> 1095 in the cache */
   /* search1399_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 1095, 495 },
      -1,
   } },

   /* replace1399_0 -> 29 in the cache */
   /* replace1399_1 -> 486 in the cache */
   /* replace1399 -> 487 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1400_0_0 -> 29 in the cache */
   /* search1400_0_1 -> 1102 in the cache */
   /* search1400_0 -> 1104 in the cache */
   /* search1400_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 1104, 495 },
      -1,
   } },

   /* replace1400_0 -> 29 in the cache */
   /* replace1400_1 -> 135 in the cache */
   /* replace1400 -> 483 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1401_0_0 -> 34 in the cache */
   /* search1401_0_1 -> 921 in the cache */
   /* search1401_0 -> 3895 in the cache */
   /* search1401_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3895, 3659 },
      -1,
   } },

   /* replace1401_0 -> 34 in the cache */
   /* replace1401_1 -> 3866 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 3866 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1402_0_0 -> 34 in the cache */
   /* search1402_0_1 -> 943 in the cache */
   /* search1402_0 -> 3897 in the cache */
   /* search1402_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3897, 3659 },
      -1,
   } },

   /* replace1402_0 -> 34 in the cache */
   /* replace1402_1 -> 3861 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 3861 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1403_0_0 -> 34 in the cache */
   /* search1403_0_1 -> 1102 in the cache */
   /* search1403_0 -> 3899 in the cache */
   /* search1403_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3899, 3659 },
      -1,
   } },

   /* replace1403_0 -> 34 in the cache */
   /* replace1403_1 -> 3856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 3856 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1404_0_0 -> 34 in the cache */
   /* search1404_0_1 -> 964 in the cache */
   /* search1404_0 -> 3830 in the cache */
   /* search1404_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3830, 3659 },
      -1,
   } },

   /* replace1404_0 -> 34 in the cache */
   /* replace1404_1 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 3853 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1405_0_0 -> 34 in the cache */
   /* search1405_0_1 -> 3858 in the cache */
   /* search1405_0 -> 3902 in the cache */
   /* search1405_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3902, 3659 },
      -1,
   } },

   /* replace1405_0 -> 34 in the cache */
   /* replace1405_1 -> 3849 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 3849 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1406_0_0 -> 34 in the cache */
   /* search1406_0_1 -> 3863 in the cache */
   /* search1406_0 -> 3904 in the cache */
   /* search1406_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3904, 3659 },
      -1,
   } },

   /* replace1406_0 -> 34 in the cache */
   /* replace1406_1 -> 1598 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 1598 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1407_0_0 -> 34 in the cache */
   /* search1407_0_1 -> 3657 in the cache */
   /* search1407_0 -> 3906 in the cache */
   /* search1407_1 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3906, 3659 },
      -1,
   } },

   /* replace1407_0 -> 34 in the cache */
   /* replace1407_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 34, 987 },
      -1,
   } },

   /* ('ieq', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ieq', 'a', 'b') */
   /* search1408_0_0 -> 29 in the cache */
   /* search1408_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* search1408_1_0 -> 48 in the cache */
   /* search1408_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 48, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3928, 3929 },
      -1,
   } },

   /* replace1408_0 -> 29 in the cache */
   /* replace1408_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('ieq', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ieq', 'a', ('unpack_64_2x32_split_x', 'b')) */
   /* search1409_0_0 -> 29 in the cache */
   /* search1409_0_1 -> 135 in the cache */
   /* search1409_0 -> 3928 in the cache */
   /* search1409_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3928, 3086 },
      -1,
   } },

   /* replace1409_0 -> 29 in the cache */
   /* replace1409_1_0 -> 53 in the cache */
   /* replace1409_1 -> 3089 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 3089 },
      -1,
   } },

   /* ('ieq', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ieq', ('unpack_64_2x32_split_x', 'a'), 'b') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1410_1_0 -> 48 in the cache */
   /* search1410_1_1 -> 135 in the cache */
   /* search1410_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3934, 3929 },
      -1,
   } },

   /* replace1410_0_0 -> 34 in the cache */
   /* replace1410_0 -> 3088 in the cache */
   /* replace1410_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3088, 48 },
      -1,
   } },

   /* ('ieq', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ieq', 'a', 'b') */
   /* search1411_0_0 -> 135 in the cache */
   /* search1411_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 135, 29 },
      -1,
   } },
   /* search1411_1_0 -> 135 in the cache */
   /* search1411_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 135, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3937, 3938 },
      -1,
   } },

   /* replace1411_0 -> 29 in the cache */
   /* replace1411_1 -> 48 in the cache */
   /* replace1411 -> 3931 in the cache */

   /* ('ieq', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ieq', 'a', ('unpack_64_2x32_split_y', 'b')) */
   /* search1412_0_0 -> 135 in the cache */
   /* search1412_0_1 -> 29 in the cache */
   /* search1412_0 -> 3937 in the cache */
   /* search1412_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3937, 3080 },
      -1,
   } },

   /* replace1412_0 -> 29 in the cache */
   /* replace1412_1_0 -> 53 in the cache */
   /* replace1412_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 3083 },
      -1,
   } },

   /* ('ieq', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ieq', ('unpack_64_2x32_split_y', 'a'), 'b') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1413_1_0 -> 135 in the cache */
   /* search1413_1_1 -> 48 in the cache */
   /* search1413_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3942, 3938 },
      -1,
   } },

   /* replace1413_0_0 -> 34 in the cache */
   /* replace1413_0 -> 3082 in the cache */
   /* replace1413_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3082, 48 },
      -1,
   } },

   /* ('ine', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ine', 'a', 'b') */
   /* search1414_0_0 -> 29 in the cache */
   /* search1414_0_1 -> 135 in the cache */
   /* search1414_0 -> 3928 in the cache */
   /* search1414_1_0 -> 48 in the cache */
   /* search1414_1_1 -> 135 in the cache */
   /* search1414_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3928, 3929 },
      -1,
   } },

   /* replace1414_0 -> 29 in the cache */
   /* replace1414_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('ine', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ine', 'a', ('unpack_64_2x32_split_x', 'b')) */
   /* search1415_0_0 -> 29 in the cache */
   /* search1415_0_1 -> 135 in the cache */
   /* search1415_0 -> 3928 in the cache */
   /* search1415_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3928, 3086 },
      -1,
   } },

   /* replace1415_0 -> 29 in the cache */
   /* replace1415_1_0 -> 53 in the cache */
   /* replace1415_1 -> 3089 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 3089 },
      -1,
   } },

   /* ('ine', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ine', ('unpack_64_2x32_split_x', 'a'), 'b') */
   /* search1416_0 -> 3934 in the cache */
   /* search1416_1_0 -> 48 in the cache */
   /* search1416_1_1 -> 135 in the cache */
   /* search1416_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3934, 3929 },
      -1,
   } },

   /* replace1416_0_0 -> 34 in the cache */
   /* replace1416_0 -> 3088 in the cache */
   /* replace1416_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3088, 48 },
      -1,
   } },

   /* ('ine', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ine', 'a', 'b') */
   /* search1417_0_0 -> 135 in the cache */
   /* search1417_0_1 -> 29 in the cache */
   /* search1417_0 -> 3937 in the cache */
   /* search1417_1_0 -> 135 in the cache */
   /* search1417_1_1 -> 48 in the cache */
   /* search1417_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3937, 3938 },
      -1,
   } },

   /* replace1417_0 -> 29 in the cache */
   /* replace1417_1 -> 48 in the cache */
   /* replace1417 -> 3946 in the cache */

   /* ('ine', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ine', 'a', ('unpack_64_2x32_split_y', 'b')) */
   /* search1418_0_0 -> 135 in the cache */
   /* search1418_0_1 -> 29 in the cache */
   /* search1418_0 -> 3937 in the cache */
   /* search1418_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3937, 3080 },
      -1,
   } },

   /* replace1418_0 -> 29 in the cache */
   /* replace1418_1_0 -> 53 in the cache */
   /* replace1418_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 3083 },
      -1,
   } },

   /* ('ine', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ine', ('unpack_64_2x32_split_y', 'a'), 'b') */
   /* search1419_0 -> 3942 in the cache */
   /* search1419_1_0 -> 135 in the cache */
   /* search1419_1_1 -> 48 in the cache */
   /* search1419_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3942, 3938 },
      -1,
   } },

   /* replace1419_0_0 -> 34 in the cache */
   /* replace1419_0 -> 3082 in the cache */
   /* replace1419_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3082, 48 },
      -1,
   } },

   /* ('ult', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ult', 'a', 'b') */
   /* search1420_0_0 -> 29 in the cache */
   /* search1420_0_1 -> 135 in the cache */
   /* search1420_0 -> 3928 in the cache */
   /* search1420_1_0 -> 48 in the cache */
   /* search1420_1_1 -> 135 in the cache */
   /* search1420_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3928, 3929 },
      -1,
   } },

   /* replace1420_0 -> 29 in the cache */
   /* replace1420_1 -> 48 in the cache */
   /* replace1420 -> 2501 in the cache */

   /* ('ult', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ult', 'a', ('unpack_64_2x32_split_x', 'b')) */
   /* search1421_0_0 -> 29 in the cache */
   /* search1421_0_1 -> 135 in the cache */
   /* search1421_0 -> 3928 in the cache */
   /* search1421_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3928, 3086 },
      -1,
   } },

   /* replace1421_0 -> 29 in the cache */
   /* replace1421_1_0 -> 53 in the cache */
   /* replace1421_1 -> 3089 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 3089 },
      -1,
   } },

   /* ('ult', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ult', ('unpack_64_2x32_split_x', 'a'), 'b') */
   /* search1422_0 -> 3934 in the cache */
   /* search1422_1_0 -> 48 in the cache */
   /* search1422_1_1 -> 135 in the cache */
   /* search1422_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3934, 3929 },
      -1,
   } },

   /* replace1422_0_0 -> 34 in the cache */
   /* replace1422_0 -> 3088 in the cache */
   /* replace1422_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3088, 48 },
      -1,
   } },

   /* ('ult', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ult', 'a', 'b') */
   /* search1423_0_0 -> 135 in the cache */
   /* search1423_0_1 -> 29 in the cache */
   /* search1423_0 -> 3937 in the cache */
   /* search1423_1_0 -> 135 in the cache */
   /* search1423_1_1 -> 48 in the cache */
   /* search1423_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3937, 3938 },
      -1,
   } },

   /* replace1423_0 -> 29 in the cache */
   /* replace1423_1 -> 48 in the cache */
   /* replace1423 -> 2501 in the cache */

   /* ('ult', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ult', 'a', ('unpack_64_2x32_split_y', 'b')) */
   /* search1424_0_0 -> 135 in the cache */
   /* search1424_0_1 -> 29 in the cache */
   /* search1424_0 -> 3937 in the cache */
   /* search1424_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3937, 3080 },
      -1,
   } },

   /* replace1424_0 -> 29 in the cache */
   /* replace1424_1_0 -> 53 in the cache */
   /* replace1424_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 3083 },
      -1,
   } },

   /* ('ult', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ult', ('unpack_64_2x32_split_y', 'a'), 'b') */
   /* search1425_0 -> 3942 in the cache */
   /* search1425_1_0 -> 135 in the cache */
   /* search1425_1_1 -> 48 in the cache */
   /* search1425_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3942, 3938 },
      -1,
   } },

   /* replace1425_0_0 -> 34 in the cache */
   /* replace1425_0 -> 3082 in the cache */
   /* replace1425_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3082, 48 },
      -1,
   } },

   /* ('ilt', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('ult', 'a', 'b') */
   /* search1426_0_0 -> 29 in the cache */
   /* search1426_0_1 -> 135 in the cache */
   /* search1426_0 -> 3928 in the cache */
   /* search1426_1_0 -> 48 in the cache */
   /* search1426_1_1 -> 135 in the cache */
   /* search1426_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3928, 3929 },
      -1,
   } },

   /* replace1426_0 -> 29 in the cache */
   /* replace1426_1 -> 48 in the cache */
   /* replace1426 -> 2501 in the cache */

   /* ('ilt', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('ult', 'a', ('unpack_64_2x32_split_x', 'b')) */
   /* search1427_0_0 -> 29 in the cache */
   /* search1427_0_1 -> 135 in the cache */
   /* search1427_0 -> 3928 in the cache */
   /* search1427_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3928, 3086 },
      -1,
   } },

   /* replace1427_0 -> 29 in the cache */
   /* replace1427_1_0 -> 53 in the cache */
   /* replace1427_1 -> 3089 in the cache */
   /* replace1427 -> 3958 in the cache */

   /* ('ilt', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('ult', ('unpack_64_2x32_split_x', 'a'), 'b') */
   /* search1428_0 -> 3934 in the cache */
   /* search1428_1_0 -> 48 in the cache */
   /* search1428_1_1 -> 135 in the cache */
   /* search1428_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3934, 3929 },
      -1,
   } },

   /* replace1428_0_0 -> 34 in the cache */
   /* replace1428_0 -> 3088 in the cache */
   /* replace1428_1 -> 48 in the cache */
   /* replace1428 -> 3960 in the cache */

   /* ('ilt', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ilt', 'a', 'b') */
   /* search1429_0_0 -> 135 in the cache */
   /* search1429_0_1 -> 29 in the cache */
   /* search1429_0 -> 3937 in the cache */
   /* search1429_1_0 -> 135 in the cache */
   /* search1429_1_1 -> 48 in the cache */
   /* search1429_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3937, 3938 },
      -1,
   } },

   /* replace1429_0 -> 29 in the cache */
   /* replace1429_1 -> 48 in the cache */
   /* replace1429 -> 2513 in the cache */

   /* ('ilt', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ilt', 'a', ('unpack_64_2x32_split_y', 'b')) */
   /* search1430_0_0 -> 135 in the cache */
   /* search1430_0_1 -> 29 in the cache */
   /* search1430_0 -> 3937 in the cache */
   /* search1430_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3937, 3080 },
      -1,
   } },

   /* replace1430_0 -> 29 in the cache */
   /* replace1430_1_0 -> 53 in the cache */
   /* replace1430_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 3083 },
      -1,
   } },

   /* ('ilt', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 'b') */
   /* search1431_0 -> 3942 in the cache */
   /* search1431_1_0 -> 135 in the cache */
   /* search1431_1_1 -> 48 in the cache */
   /* search1431_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3942, 3938 },
      -1,
   } },

   /* replace1431_0_0 -> 34 in the cache */
   /* replace1431_0 -> 3082 in the cache */
   /* replace1431_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3082, 48 },
      -1,
   } },

   /* ('uge', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('uge', 'a', 'b') */
   /* search1432_0_0 -> 29 in the cache */
   /* search1432_0_1 -> 135 in the cache */
   /* search1432_0 -> 3928 in the cache */
   /* search1432_1_0 -> 48 in the cache */
   /* search1432_1_1 -> 135 in the cache */
   /* search1432_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3928, 3929 },
      -1,
   } },

   /* replace1432_0 -> 29 in the cache */
   /* replace1432_1 -> 48 in the cache */
   /* replace1432 -> 2504 in the cache */

   /* ('uge', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('uge', 'a', ('unpack_64_2x32_split_x', 'b')) */
   /* search1433_0_0 -> 29 in the cache */
   /* search1433_0_1 -> 135 in the cache */
   /* search1433_0 -> 3928 in the cache */
   /* search1433_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3928, 3086 },
      -1,
   } },

   /* replace1433_0 -> 29 in the cache */
   /* replace1433_1_0 -> 53 in the cache */
   /* replace1433_1 -> 3089 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 3089 },
      -1,
   } },

   /* ('uge', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('uge', ('unpack_64_2x32_split_x', 'a'), 'b') */
   /* search1434_0 -> 3934 in the cache */
   /* search1434_1_0 -> 48 in the cache */
   /* search1434_1_1 -> 135 in the cache */
   /* search1434_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3934, 3929 },
      -1,
   } },

   /* replace1434_0_0 -> 34 in the cache */
   /* replace1434_0 -> 3088 in the cache */
   /* replace1434_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3088, 48 },
      -1,
   } },

   /* ('uge', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('uge', 'a', 'b') */
   /* search1435_0_0 -> 135 in the cache */
   /* search1435_0_1 -> 29 in the cache */
   /* search1435_0 -> 3937 in the cache */
   /* search1435_1_0 -> 135 in the cache */
   /* search1435_1_1 -> 48 in the cache */
   /* search1435_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3937, 3938 },
      -1,
   } },

   /* replace1435_0 -> 29 in the cache */
   /* replace1435_1 -> 48 in the cache */
   /* replace1435 -> 2504 in the cache */

   /* ('uge', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('uge', 'a', ('unpack_64_2x32_split_y', 'b')) */
   /* search1436_0_0 -> 135 in the cache */
   /* search1436_0_1 -> 29 in the cache */
   /* search1436_0 -> 3937 in the cache */
   /* search1436_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3937, 3080 },
      -1,
   } },

   /* replace1436_0 -> 29 in the cache */
   /* replace1436_1_0 -> 53 in the cache */
   /* replace1436_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 3083 },
      -1,
   } },

   /* ('uge', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('uge', ('unpack_64_2x32_split_y', 'a'), 'b') */
   /* search1437_0 -> 3942 in the cache */
   /* search1437_1_0 -> 135 in the cache */
   /* search1437_1_1 -> 48 in the cache */
   /* search1437_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3942, 3938 },
      -1,
   } },

   /* replace1437_0_0 -> 34 in the cache */
   /* replace1437_0 -> 3082 in the cache */
   /* replace1437_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3082, 48 },
      -1,
   } },

   /* ('ige', ('pack_64_2x32_split', 'a', 0), ('pack_64_2x32_split', 'b', 0)) => ('uge', 'a', 'b') */
   /* search1438_0_0 -> 29 in the cache */
   /* search1438_0_1 -> 135 in the cache */
   /* search1438_0 -> 3928 in the cache */
   /* search1438_1_0 -> 48 in the cache */
   /* search1438_1_1 -> 135 in the cache */
   /* search1438_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3928, 3929 },
      -1,
   } },

   /* replace1438_0 -> 29 in the cache */
   /* replace1438_1 -> 48 in the cache */
   /* replace1438 -> 2504 in the cache */

   /* ('ige', ('pack_64_2x32_split', 'a', 0), '#b(is_upper_half_zero)') => ('uge', 'a', ('unpack_64_2x32_split_x', 'b')) */
   /* search1439_0_0 -> 29 in the cache */
   /* search1439_0_1 -> 135 in the cache */
   /* search1439_0 -> 3928 in the cache */
   /* search1439_1 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3928, 3086 },
      -1,
   } },

   /* replace1439_0 -> 29 in the cache */
   /* replace1439_1_0 -> 53 in the cache */
   /* replace1439_1 -> 3089 in the cache */
   /* replace1439 -> 3976 in the cache */

   /* ('ige', '#a(is_upper_half_zero)', ('pack_64_2x32_split', 'b', 0)) => ('uge', ('unpack_64_2x32_split_x', 'a'), 'b') */
   /* search1440_0 -> 3934 in the cache */
   /* search1440_1_0 -> 48 in the cache */
   /* search1440_1_1 -> 135 in the cache */
   /* search1440_1 -> 3929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3934, 3929 },
      -1,
   } },

   /* replace1440_0_0 -> 34 in the cache */
   /* replace1440_0 -> 3088 in the cache */
   /* replace1440_1 -> 48 in the cache */
   /* replace1440 -> 3978 in the cache */

   /* ('ige', ('pack_64_2x32_split', 0, 'a'), ('pack_64_2x32_split', 0, 'b')) => ('ige', 'a', 'b') */
   /* search1441_0_0 -> 135 in the cache */
   /* search1441_0_1 -> 29 in the cache */
   /* search1441_0 -> 3937 in the cache */
   /* search1441_1_0 -> 135 in the cache */
   /* search1441_1_1 -> 48 in the cache */
   /* search1441_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3937, 3938 },
      -1,
   } },

   /* replace1441_0 -> 29 in the cache */
   /* replace1441_1 -> 48 in the cache */
   /* replace1441 -> 2516 in the cache */

   /* ('ige', ('pack_64_2x32_split', 0, 'a'), '#b(is_lower_half_zero)') => ('ige', 'a', ('unpack_64_2x32_split_y', 'b')) */
   /* search1442_0_0 -> 135 in the cache */
   /* search1442_0_1 -> 29 in the cache */
   /* search1442_0 -> 3937 in the cache */
   /* search1442_1 -> 3080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3937, 3080 },
      -1,
   } },

   /* replace1442_0 -> 29 in the cache */
   /* replace1442_1_0 -> 53 in the cache */
   /* replace1442_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 3083 },
      -1,
   } },

   /* ('ige', '#a(is_lower_half_zero)', ('pack_64_2x32_split', 0, 'b')) => ('ige', ('unpack_64_2x32_split_y', 'a'), 'b') */
   /* search1443_0 -> 3942 in the cache */
   /* search1443_1_0 -> 135 in the cache */
   /* search1443_1_1 -> 48 in the cache */
   /* search1443_1 -> 3938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3942, 3938 },
      -1,
   } },

   /* replace1443_0_0 -> 34 in the cache */
   /* replace1443_0 -> 3082 in the cache */
   /* replace1443_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3082, 48 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1444_0 -> 29 in the cache */
   /* search1444_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 29, 135 },
      -1,
   } },

   /* replace1444 -> 29 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1445_0 -> 29 in the cache */
   /* search1445_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 29, 137 },
      -1,
   } },

   /* replace1445 -> 135 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1446_0 -> 0 in the cache */
   /* search1446_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1446_0 -> 0 in the cache */
   /* replace1446_1_0 -> 1 in the cache */
   /* replace1446_1 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1175 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1447_0 -> 0 in the cache */
   /* search1447_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1447_0 -> 0 in the cache */
   /* replace1447_1_0 -> 1 in the cache */
   /* replace1447_1 -> 105 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 105 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1448_0 -> 0 in the cache */
   /* search1448_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1448_0_0 -> 0 in the cache */
   /* replace1448_0_1 -> 1 in the cache */
   /* replace1448_0 -> 1155 in the cache */
   /* replace1448_1_0_0 -> 0 in the cache */
   /* replace1448_1_0_1 -> 1 in the cache */
   /* replace1448_1_0 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3996 },
      -1,
   } },
   /* replace1448_2_0 -> 0 in the cache */
   /* replace1448_2_1 -> 1 in the cache */
   /* replace1448_2 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1155, 3999, 3996 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1449_0 -> 0 in the cache */
   /* search1449_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1449_0_0 -> 0 in the cache */
   /* replace1449_0_1 -> 1 in the cache */
   /* replace1449_0 -> 1152 in the cache */
   /* replace1449_1_0_0 -> 0 in the cache */
   /* replace1449_1_0_1 -> 1 in the cache */
   /* replace1449_1_0 -> 3996 in the cache */
   /* replace1449_1 -> 3999 in the cache */
   /* replace1449_2_0 -> 0 in the cache */
   /* replace1449_2_1 -> 1 in the cache */
   /* replace1449_2 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1152, 3999, 3996 },
      -1,
   } },

   /* ('bitz', 'a', 'b') => ('inot', ('bitnz', 'a', 'b')) */
   /* search1450_0 -> 9 in the cache */
   /* search1450_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 9, 48 },
      -1,
   } },

   /* replace1450_0_0 -> 9 in the cache */
   /* replace1450_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 9, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 4004 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1451_0_0 -> 0 in the cache */
   /* search1451_0 -> 230 in the cache */
   /* search1451_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 230, 1 },
      3,
   } },

   /* replace1451_0_0 -> 0 in the cache */
   /* replace1451_0_1 -> 1 in the cache */
   /* replace1451_0 -> 279 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 279 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat,nsz)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1452_0_0 -> 29 in the cache */
   /* search1452_0 -> 293 in the cache */
   /* search1452_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 293, 48 },
      3,
   } },

   /* replace1452_0_0 -> 29 in the cache */
   /* replace1452_0_1 -> 48 in the cache */
   /* replace1452_0 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 282 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1453_0_0 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 139 },
      -1,
   } },
   /* search1453_1_0 -> 140 in the cache */
   /* search1453_1 -> 1314 in the cache */
   /* search1453_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 4010, 1314, 142 },
      -1,
   } },

   /* replace1453_0 -> 139 in the cache */
   /* replace1453_1 -> 140 in the cache */
   /* replace1453_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 139, 140, 142 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1454_0_0 -> 29 in the cache */
   /* search1454_0 -> 293 in the cache */
   /* search1454_1_0 -> 48 in the cache */
   /* search1454_1 -> 687 in the cache */
   /* search1454_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 293, 687, 148 },
      -1,
   } },

   /* replace1454_0 -> 29 in the cache */
   /* replace1454_1 -> 48 in the cache */
   /* replace1454_2 -> 148 in the cache */
   /* replace1454 -> 462 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1455_0_0 -> 0 in the cache */
   /* search1455_0 -> 225 in the cache */
   /* search1455_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 225, 1 },
      -1,
   } },

   /* replace1455_0_0 -> 0 in the cache */
   /* replace1455_0_1 -> 1 in the cache */
   /* replace1455_0 -> 1041 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 1041 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 4016, 4017 },
      0,
   } },
   /* search1456_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 4018, 904 },
      0,
   } },

   /* replace1456_0_0 -> 139 in the cache */
   /* replace1456_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace1456_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 4020, 140 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1457_0_0 -> 341 in the cache */
   /* search1457_0_1 -> 351 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 341, 351 },
      0,
   } },
   /* search1457_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 4022, 322 },
      0,
   } },

   /* replace1457_0_0 -> 29 in the cache */
   /* replace1457_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 29, 148 },
      -1,
   } },
   /* replace1457_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 4024, 48 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1458_0_0 -> 341 in the cache */
   /* search1458_0_1 -> 351 in the cache */
   /* search1458_0 -> 4022 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 4022, 4026 },
      0,
   } },

   /* replace1458_0_0 -> 29 in the cache */
   /* replace1458_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 29, 148 },
      -1,
   } },
   /* replace1458_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 4028, 48 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1459_0_0 -> 4016 in the cache */
   /* search1459_0_1 -> 4017 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 4016, 4017 },
      0,
   } },
   /* search1459_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 4030, 904 },
      0,
   } },

   /* replace1459_0_0 -> 139 in the cache */
   /* replace1459_0_1 -> 142 in the cache */
   /* replace1459_0 -> 1115 in the cache */
   /* replace1459_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1115, 140 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 4033, 4034 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1460_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 4035, 4036, 166 },
      -1,
   } },

   /* replace1460_0_0 -> 162 in the cache */
   /* replace1460_0_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 162, 165 },
      -1,
   } },
   /* replace1460_1 -> 163 in the cache */
   /* replace1460_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 4038, 163, 166 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1461_0_0 -> 341 in the cache */
   /* search1461_0_1 -> 351 in the cache */
   /* search1461_0 -> 4022 in the cache */
   /* search1461_1 -> 322 in the cache */
   /* search1461_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 4022, 322, 176 },
      -1,
   } },

   /* replace1461_0_0 -> 29 in the cache */
   /* replace1461_0_1 -> 148 in the cache */
   /* replace1461_0 -> 4024 in the cache */
   /* replace1461_1 -> 48 in the cache */
   /* replace1461_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 4024, 48, 176 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1462_0_0 -> 341 in the cache */
   /* search1462_0_1 -> 351 in the cache */
   /* search1462_0 -> 4022 in the cache */
   /* search1462_1 -> 4026 in the cache */
   /* search1462_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 4022, 4026, 176 },
      -1,
   } },

   /* replace1462_0_0 -> 29 in the cache */
   /* replace1462_0_1 -> 148 in the cache */
   /* replace1462_0 -> 4028 in the cache */
   /* replace1462_1 -> 48 in the cache */
   /* replace1462_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 4028, 48, 176 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1463_0_0 -> 4016 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      35,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 4016, 4044 },
      0,
   } },
   /* search1463_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4045, 904 },
      0,
   } },

   /* replace1463_0_0 -> 139 in the cache */
   /* replace1463_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace1463_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4047, 140 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1464_0_0 -> 4016 in the cache */
   /* search1464_0_1 -> 4017 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 4016, 4017 },
      0,
   } },
   /* search1464_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4049, 904 },
      0,
   } },

   /* replace1464_0_0 -> 139 in the cache */
   /* replace1464_0_1 -> 142 in the cache */
   /* replace1464_0 -> 4047 in the cache */
   /* replace1464_1 -> 140 in the cache */
   /* replace1464 -> 4048 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1465_0_0 -> 4033 in the cache */
   /* search1465_0_1 -> 163 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 4033, 163, 4051 },
      0,
   } },
   /* search1465_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4052, 1121 },
      0,
   } },

   /* replace1465_0_0 -> 162 in the cache */
   /* replace1465_0_1 -> 163 in the cache */
   /* replace1465_0_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 162, 163, 166 },
      -1,
   } },
   /* replace1465_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4054, 165 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1466_0_0 -> 341 in the cache */
   /* search1466_0_1 -> 48 in the cache */
   /* search1466_0_2 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 341, 48, 360 },
      0,
   } },
   /* search1466_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4056, 324 },
      0,
   } },

   /* replace1466_0_0 -> 29 in the cache */
   /* replace1466_0_1 -> 48 in the cache */
   /* replace1466_0_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 29, 48, 176 },
      -1,
   } },
   /* replace1466_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4058, 148 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1467_0_0 -> 4016 in the cache */
   /* search1467_0_1 -> 4017 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 4016, 4017 },
      0,
   } },
   /* search1467_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 4060, 904 },
      0,
   } },

   /* replace1467_0_0 -> 139 in the cache */
   /* replace1467_0_1 -> 142 in the cache */
   /* replace1467_0 -> 1129 in the cache */
   /* replace1467_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1129, 140 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1468_0 -> 295 in the cache */
   /* search1468_1_0 -> 4017 in the cache */
   /* search1468_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 295, 4063 },
      -1,
   } },

   /* replace1468_0_0 -> 139 in the cache */
   /* replace1468_0_1 -> 142 in the cache */
   /* replace1468_0 -> 4020 in the cache */
   /* replace1468_1 -> 140 in the cache */
   /* replace1468 -> 4021 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1469_0 -> 299 in the cache */
   /* search1469_1_0 -> 351 in the cache */
   /* search1469_1_1 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 351, 322 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 299, 4065 },
      -1,
   } },

   /* replace1469_0_0 -> 29 in the cache */
   /* replace1469_0_1 -> 148 in the cache */
   /* replace1469_0 -> 4024 in the cache */
   /* replace1469_1 -> 48 in the cache */
   /* replace1469 -> 4025 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1470_1_0 -> 351 in the cache */
   /* search1470_1_1 -> 322 in the cache */
   /* search1470_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 4067, 4065 },
      -1,
   } },

   /* replace1470_0_0 -> 29 in the cache */
   /* replace1470_0_1 -> 148 in the cache */
   /* replace1470_0 -> 4028 in the cache */
   /* replace1470_1 -> 48 in the cache */
   /* replace1470 -> 4029 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1471_1_0 -> 4034 in the cache */
   /* search1471_1_1 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 4034, 4036 },
      -1,
   } },
   /* search1471_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 4069, 4070, 166 },
      -1,
   } },

   /* replace1471_0_0 -> 162 in the cache */
   /* replace1471_0_1 -> 165 in the cache */
   /* replace1471_0 -> 4038 in the cache */
   /* replace1471_1 -> 163 in the cache */
   /* replace1471_2 -> 166 in the cache */
   /* replace1471 -> 4039 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1472_0 -> 299 in the cache */
   /* search1472_1_0 -> 351 in the cache */
   /* search1472_1_1 -> 322 in the cache */
   /* search1472_1 -> 4065 in the cache */
   /* search1472_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 299, 4065, 176 },
      -1,
   } },

   /* replace1472_0_0 -> 29 in the cache */
   /* replace1472_0_1 -> 148 in the cache */
   /* replace1472_0 -> 4024 in the cache */
   /* replace1472_1 -> 48 in the cache */
   /* replace1472_2 -> 176 in the cache */
   /* replace1472 -> 4041 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1473_0 -> 4067 in the cache */
   /* search1473_1_0 -> 351 in the cache */
   /* search1473_1_1 -> 322 in the cache */
   /* search1473_1 -> 4065 in the cache */
   /* search1473_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 4067, 4065, 176 },
      -1,
   } },

   /* replace1473_0_0 -> 29 in the cache */
   /* replace1473_0_1 -> 148 in the cache */
   /* replace1473_0 -> 4028 in the cache */
   /* replace1473_1 -> 48 in the cache */
   /* replace1473_2 -> 176 in the cache */
   /* replace1473 -> 4043 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1474_0 -> 295 in the cache */
   /* search1474_1_0 -> 4017 in the cache */
   /* search1474_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 295, 4074 },
      -1,
   } },

   /* replace1474_0_0 -> 139 in the cache */
   /* replace1474_0_1 -> 142 in the cache */
   /* replace1474_0 -> 1115 in the cache */
   /* replace1474_1 -> 140 in the cache */
   /* replace1474 -> 4032 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1475_0 -> 295 in the cache */
   /* search1475_1_0 -> 4017 in the cache */
   /* search1475_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 295, 4076 },
      -1,
   } },

   /* replace1475_0_0 -> 139 in the cache */
   /* replace1475_0_1 -> 142 in the cache */
   /* replace1475_0 -> 4047 in the cache */
   /* replace1475_1 -> 140 in the cache */
   /* replace1475 -> 4048 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1476_0 -> 295 in the cache */
   /* search1476_1_0_0 -> 4017 in the cache */
   /* search1476_1_0_1 -> 904 in the cache */
   /* search1476_1_0 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 4076 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 295, 4078 },
      -1,
   } },

   /* replace1476_0_0 -> 139 in the cache */
   /* replace1476_0_1_0 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 4080 },
      -1,
   } },
   /* replace1476_1_0 -> 140 in the cache */
   /* replace1476_1 -> 1314 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4081, 1314 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1477_0 -> 4069 in the cache */
   /* search1477_1_0 -> 4034 in the cache */
   /* search1477_1_1 -> 4051 in the cache */
   /* search1477_1_2 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 4034, 4051, 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4069, 4083 },
      -1,
   } },

   /* replace1477_0 -> 163 in the cache */
   /* replace1477_1 -> 165 in the cache */
   /* replace1477_2_0 -> 162 in the cache */
   /* replace1477_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 162, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 163, 165, 4085 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1478_0 -> 4069 in the cache */
   /* search1478_1_0_0 -> 4034 in the cache */
   /* search1478_1_0_1 -> 4051 in the cache */
   /* search1478_1_0_2 -> 1121 in the cache */
   /* search1478_1_0 -> 4083 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 4083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4069, 4087 },
      -1,
   } },

   /* replace1478_0_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 163 },
      -1,
   } },
   /* replace1478_1 -> 165 in the cache */
   /* replace1478_2_0 -> 162 in the cache */
   /* replace1478_2_1_0 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 162, 4090 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 4089, 165, 4091 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1479_0 -> 299 in the cache */
   /* search1479_1_0 -> 351 in the cache */
   /* search1479_1_1 -> 360 in the cache */
   /* search1479_1_2 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 351, 360, 324 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 299, 4093 },
      -1,
   } },

   /* replace1479_0 -> 48 in the cache */
   /* replace1479_1 -> 148 in the cache */
   /* replace1479_2_0 -> 29 in the cache */
   /* replace1479_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 29, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 48, 148, 4095 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1480_0 -> 299 in the cache */
   /* search1480_1_0_0 -> 351 in the cache */
   /* search1480_1_0_1 -> 360 in the cache */
   /* search1480_1_0_2 -> 324 in the cache */
   /* search1480_1_0 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 4093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 299, 4097 },
      -1,
   } },

   /* replace1480_0_0 -> 48 in the cache */
   /* replace1480_0 -> 687 in the cache */
   /* replace1480_1 -> 148 in the cache */
   /* replace1480_2_0 -> 29 in the cache */
   /* replace1480_2_1_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 29, 4099 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 687, 148, 4100 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1481_0 -> 295 in the cache */
   /* search1481_1_0 -> 4017 in the cache */
   /* search1481_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 295, 4102 },
      -1,
   } },

   /* replace1481_0_0 -> 139 in the cache */
   /* replace1481_0_1 -> 142 in the cache */
   /* replace1481_0 -> 1129 in the cache */
   /* replace1481_1 -> 140 in the cache */
   /* replace1481 -> 4062 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1482_0 -> 295 in the cache */
   /* search1482_1_0 -> 4017 in the cache */
   /* search1482_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 295, 4104 },
      -1,
   } },

   /* replace1482_0_0 -> 139 in the cache */
   /* replace1482_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace1482_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4106, 140 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1483_0 -> 295 in the cache */
   /* search1483_1_0 -> 4017 in the cache */
   /* search1483_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 295, 4108 },
      -1,
   } },

   /* replace1483_0_0 -> 139 in the cache */
   /* replace1483_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace1483_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 4110, 140 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1484_0 -> 295 in the cache */
   /* search1484_1_0 -> 4017 in the cache */
   /* search1484_1_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 4017, 904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 295, 4112 },
      -1,
   } },

   /* replace1484_0_0 -> 139 in the cache */
   /* replace1484_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 139, 142 },
      -1,
   } },
   /* replace1484_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 4114, 140 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      35,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1485_0_1 -> 4044 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 4116, 4044 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 4117, 4118 },
      -1,
   } },

   /* replace1485_0_0 -> 139 in the cache */
   /* replace1485_0_1 -> 142 in the cache */
   /* replace1485_0 -> 4047 in the cache */
   /* replace1485_1 -> 140 in the cache */
   /* replace1485 -> 4048 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1486_0_0 -> 0 in the cache */
   /* search1486_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      4,
   } },
   /* search1486_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 4120, 1 },
      -1,
   } },

   /* replace1486 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1487_0_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search1487_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4122, 135 },
      -1,
   } },
   /* search1487_1_0 -> 9 in the cache */
   /* search1487_1 -> 4122 in the cache */
   /* search1487_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4123, 4122, 137 },
      -1,
   } },

   /* replace1487_0 -> 9 in the cache */
   /* replace1487 -> 4122 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1488_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 29 },
      -1,
   } },
   /* search1488_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4125, 135 },
      -1,
   } },
   /* search1488_1_0 -> 29 in the cache */
   /* search1488_1 -> 4125 in the cache */
   /* search1488_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4126, 4125, 137 },
      -1,
   } },

   /* replace1488_0 -> 29 in the cache */
   /* replace1488 -> 4125 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1489_0_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search1489_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4128, 135 },
      -1,
   } },
   /* search1489_1_0 -> 9 in the cache */
   /* search1489_1 -> 4128 in the cache */
   /* search1489_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4129, 4128, 137 },
      -1,
   } },

   /* replace1489_0 -> 9 in the cache */
   /* replace1489 -> 4128 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1490_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 29 },
      -1,
   } },
   /* search1490_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4131, 135 },
      -1,
   } },
   /* search1490_1_0 -> 29 in the cache */
   /* search1490_1 -> 4131 in the cache */
   /* search1490_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4132, 4131, 137 },
      -1,
   } },

   /* replace1490_0 -> 29 in the cache */
   /* replace1490 -> 4131 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1491_0_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 9 },
      -1,
   } },
   /* search1491_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4134, 135 },
      -1,
   } },
   /* search1491_1_0 -> 9 in the cache */
   /* search1491_1 -> 4134 in the cache */
   /* search1491_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4135, 4134, 137 },
      -1,
   } },

   /* replace1491_0 -> 9 in the cache */
   /* replace1491 -> 4134 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1492_0_0 -> 9 in the cache */
   /* search1492_0_1 -> 73 in the cache */
   /* search1492_0 -> 1220 in the cache */
   /* search1492_1_0 -> 9 in the cache */
   /* search1492_1 -> 4122 in the cache */
   /* search1492_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 4122, 137 },
      -1,
   } },

   /* replace1492_0 -> 9 in the cache */
   /* replace1492 -> 4122 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1493_0_0 -> 29 in the cache */
   /* search1493_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 135 },
      -1,
   } },
   /* search1493_1_0 -> 29 in the cache */
   /* search1493_1 -> 4125 in the cache */
   /* search1493_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4138, 4125, 137 },
      -1,
   } },

   /* replace1493_0 -> 29 in the cache */
   /* replace1493 -> 4125 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1494_0_0 -> 9 in the cache */
   /* search1494_0_1 -> 73 in the cache */
   /* search1494_0 -> 1220 in the cache */
   /* search1494_1_0 -> 9 in the cache */
   /* search1494_1 -> 4128 in the cache */
   /* search1494_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 4128, 137 },
      -1,
   } },

   /* replace1494_0 -> 9 in the cache */
   /* replace1494 -> 4128 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1495_0_0 -> 29 in the cache */
   /* search1495_0_1 -> 135 in the cache */
   /* search1495_0 -> 4138 in the cache */
   /* search1495_1_0 -> 29 in the cache */
   /* search1495_1 -> 4131 in the cache */
   /* search1495_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4138, 4131, 137 },
      -1,
   } },

   /* replace1495_0 -> 29 in the cache */
   /* replace1495 -> 4131 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1496_0_0 -> 9 in the cache */
   /* search1496_0_1 -> 73 in the cache */
   /* search1496_0 -> 1220 in the cache */
   /* search1496_1_0 -> 9 in the cache */
   /* search1496_1 -> 4134 in the cache */
   /* search1496_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 4134, 137 },
      -1,
   } },

   /* replace1496_0 -> 9 in the cache */
   /* replace1496 -> 4134 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1497_0_0 -> 29 in the cache */
   /* search1497_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 137 },
      -1,
   } },
   /* search1497_1_0 -> 29 in the cache */
   /* search1497_1 -> 4125 in the cache */
   /* search1497_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4143, 4125, 137 },
      -1,
   } },

   /* replace1497_0 -> 29 in the cache */
   /* replace1497 -> 4125 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1498_0_0 -> 29 in the cache */
   /* search1498_0_1 -> 137 in the cache */
   /* search1498_0 -> 4143 in the cache */
   /* search1498_1_0 -> 29 in the cache */
   /* search1498_1 -> 4131 in the cache */
   /* search1498_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4143, 4131, 137 },
      -1,
   } },

   /* replace1498_0 -> 29 in the cache */
   /* replace1498 -> 4131 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a') */
   /* search1499_0_0_0 -> 29 in the cache */
   /* search1499_0_0 -> 4125 in the cache */
   /* search1499_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4125, 137 },
      -1,
   } },
   /* search1499_1_0 -> 32 in the cache */
   /* search1499_1_1_0_0 -> 29 in the cache */
   /* search1499_1_1_0 -> 4125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 32, 4147 },
      -1,
   } },
   /* search1499_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4146, 4148, 137 },
      -1,
   } },

   /* replace1499_0 -> 29 in the cache */
   /* replace1499 -> 4131 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1500_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 29 },
      -1,
   } },
   /* search1500_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4150, 137 },
      -1,
   } },
   /* search1500_1_0 -> 32 in the cache */
   /* search1500_1_1_0_0 -> 29 in the cache */
   /* search1500_1_1_0 -> 4150 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 32, 4152 },
      -1,
   } },
   /* search1500_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4151, 4153, 137 },
      -1,
   } },

   /* replace1500_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1501_0_0_0 -> 29 in the cache */
   /* search1501_0_0 -> 4125 in the cache */
   /* search1501_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4125, 137 },
      -1,
   } },
   /* search1501_1 -> 137 in the cache */
   /* search1501_2_0 -> 32 in the cache */
   /* search1501_2_1_0_0 -> 29 in the cache */
   /* search1501_2_1_0 -> 4125 in the cache */
   /* search1501_2_1 -> 4147 in the cache */
   /* search1501_2 -> 4148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4156, 137, 4148 },
      -1,
   } },

   /* replace1501_0 -> 29 in the cache */
   /* replace1501 -> 4131 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1502_0_0_0 -> 29 in the cache */
   /* search1502_0_0 -> 4150 in the cache */
   /* search1502_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4150, 137 },
      -1,
   } },
   /* search1502_1 -> 137 in the cache */
   /* search1502_2_0 -> 32 in the cache */
   /* search1502_2_1_0_0 -> 29 in the cache */
   /* search1502_2_1_0 -> 4150 in the cache */
   /* search1502_2_1 -> 4152 in the cache */
   /* search1502_2 -> 4153 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4158, 137, 4153 },
      -1,
   } },

   /* replace1502_0 -> 29 in the cache */
   /* replace1502 -> 4155 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a') */
   /* search1503_0_0_0 -> 29 in the cache */
   /* search1503_0_0 -> 4125 in the cache */
   /* search1503_0_1 -> 137 in the cache */
   /* search1503_0 -> 4146 in the cache */
   /* search1503_1_0 -> 32 in the cache */
   /* search1503_1_1_0_0 -> 29 in the cache */
   /* search1503_1_1_0 -> 4125 in the cache */
   /* search1503_1_1 -> 4147 in the cache */
   /* search1503_1 -> 4148 in the cache */
   /* search1503_2_0 -> 29 in the cache */
   /* search1503_2 -> 4125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4146, 4148, 4125 },
      -1,
   } },

   /* replace1503_0 -> 29 in the cache */
   /* replace1503 -> 4131 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1504_0_0_0 -> 29 in the cache */
   /* search1504_0_0 -> 4150 in the cache */
   /* search1504_0_1 -> 137 in the cache */
   /* search1504_0 -> 4151 in the cache */
   /* search1504_1_0 -> 32 in the cache */
   /* search1504_1_1_0_0 -> 29 in the cache */
   /* search1504_1_1_0 -> 4150 in the cache */
   /* search1504_1_1 -> 4152 in the cache */
   /* search1504_1 -> 4153 in the cache */
   /* search1504_2_0 -> 29 in the cache */
   /* search1504_2 -> 4150 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4151, 4153, 4150 },
      -1,
   } },

   /* replace1504_0 -> 29 in the cache */
   /* replace1504 -> 4155 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1505_0_0_0 -> 29 in the cache */
   /* search1505_0_0 -> 4125 in the cache */
   /* search1505_0_1 -> 137 in the cache */
   /* search1505_0 -> 4156 in the cache */
   /* search1505_1_0 -> 29 in the cache */
   /* search1505_1 -> 4125 in the cache */
   /* search1505_2_0 -> 32 in the cache */
   /* search1505_2_1_0_0 -> 29 in the cache */
   /* search1505_2_1_0 -> 4125 in the cache */
   /* search1505_2_1 -> 4147 in the cache */
   /* search1505_2 -> 4148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4156, 4125, 4148 },
      -1,
   } },

   /* replace1505_0 -> 29 in the cache */
   /* replace1505 -> 4131 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1506_0_0_0 -> 29 in the cache */
   /* search1506_0_0 -> 4150 in the cache */
   /* search1506_0_1 -> 137 in the cache */
   /* search1506_0 -> 4158 in the cache */
   /* search1506_1_0 -> 29 in the cache */
   /* search1506_1 -> 4150 in the cache */
   /* search1506_2_0 -> 32 in the cache */
   /* search1506_2_1_0_0 -> 29 in the cache */
   /* search1506_2_1_0 -> 4150 in the cache */
   /* search1506_2_1 -> 4152 in the cache */
   /* search1506_2 -> 4153 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4158, 4150, 4153 },
      -1,
   } },

   /* replace1506_0 -> 29 in the cache */
   /* replace1506 -> 4155 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1507_0_0 -> 29 in the cache */
   /* search1507_0_1 -> 135 in the cache */
   /* search1507_0 -> 4138 in the cache */
   /* search1507_1_0 -> 32 in the cache */
   /* search1507_1_1_0_0 -> 29 in the cache */
   /* search1507_1_1_0 -> 4150 in the cache */
   /* search1507_1_1 -> 4152 in the cache */
   /* search1507_1 -> 4153 in the cache */
   /* search1507_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4138, 4153, 137 },
      -1,
   } },

   /* replace1507_0 -> 29 in the cache */
   /* replace1507 -> 4155 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1508_0_0 -> 29 in the cache */
   /* search1508_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 135 },
      -1,
   } },
   /* search1508_1 -> 137 in the cache */
   /* search1508_2_0 -> 32 in the cache */
   /* search1508_2_1_0_0 -> 29 in the cache */
   /* search1508_2_1_0 -> 4150 in the cache */
   /* search1508_2_1 -> 4152 in the cache */
   /* search1508_2 -> 4153 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4165, 137, 4153 },
      -1,
   } },

   /* replace1508_0 -> 29 in the cache */
   /* replace1508 -> 4155 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1509_0_0 -> 29 in the cache */
   /* search1509_0_1 -> 135 in the cache */
   /* search1509_0 -> 4138 in the cache */
   /* search1509_1_0 -> 32 in the cache */
   /* search1509_1_1_0_0 -> 29 in the cache */
   /* search1509_1_1_0 -> 4150 in the cache */
   /* search1509_1_1 -> 4152 in the cache */
   /* search1509_1 -> 4153 in the cache */
   /* search1509_2_0 -> 29 in the cache */
   /* search1509_2 -> 4150 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4138, 4153, 4150 },
      -1,
   } },

   /* replace1509_0 -> 29 in the cache */
   /* replace1509 -> 4155 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1510_0_0 -> 29 in the cache */
   /* search1510_0_1 -> 135 in the cache */
   /* search1510_0 -> 4165 in the cache */
   /* search1510_1_0 -> 29 in the cache */
   /* search1510_1 -> 4150 in the cache */
   /* search1510_2_0 -> 32 in the cache */
   /* search1510_2_1_0_0 -> 29 in the cache */
   /* search1510_2_1_0 -> 4150 in the cache */
   /* search1510_2_1 -> 4152 in the cache */
   /* search1510_2 -> 4153 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4165, 4150, 4153 },
      -1,
   } },

   /* replace1510_0 -> 29 in the cache */
   /* replace1510 -> 4155 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a') */
   /* search1511_0_0_0 -> 29 in the cache */
   /* search1511_0_0 -> 4131 in the cache */
   /* search1511_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4131, 137 },
      -1,
   } },
   /* search1511_1_0 -> 32 in the cache */
   /* search1511_1_1_0_0 -> 29 in the cache */
   /* search1511_1_1_0 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 32, 4170 },
      -1,
   } },
   /* search1511_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4169, 4171, 137 },
      -1,
   } },

   /* replace1511_0 -> 29 in the cache */
   /* replace1511 -> 4125 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1512_0_0_0 -> 29 in the cache */
   /* search1512_0_0 -> 4155 in the cache */
   /* search1512_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4155, 137 },
      -1,
   } },
   /* search1512_1_0 -> 32 in the cache */
   /* search1512_1_1_0_0 -> 29 in the cache */
   /* search1512_1_1_0 -> 4155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 32, 4174 },
      -1,
   } },
   /* search1512_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4173, 4175, 137 },
      -1,
   } },

   /* replace1512_0 -> 29 in the cache */
   /* replace1512 -> 4150 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1513_0_0_0 -> 29 in the cache */
   /* search1513_0_0 -> 4131 in the cache */
   /* search1513_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4131, 137 },
      -1,
   } },
   /* search1513_1 -> 137 in the cache */
   /* search1513_2_0 -> 32 in the cache */
   /* search1513_2_1_0_0 -> 29 in the cache */
   /* search1513_2_1_0 -> 4131 in the cache */
   /* search1513_2_1 -> 4170 in the cache */
   /* search1513_2 -> 4171 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4177, 137, 4171 },
      -1,
   } },

   /* replace1513_0 -> 29 in the cache */
   /* replace1513 -> 4125 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1514_0_0_0 -> 29 in the cache */
   /* search1514_0_0 -> 4155 in the cache */
   /* search1514_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4155, 137 },
      -1,
   } },
   /* search1514_1 -> 137 in the cache */
   /* search1514_2_0 -> 32 in the cache */
   /* search1514_2_1_0_0 -> 29 in the cache */
   /* search1514_2_1_0 -> 4155 in the cache */
   /* search1514_2_1 -> 4174 in the cache */
   /* search1514_2 -> 4175 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4179, 137, 4175 },
      -1,
   } },

   /* replace1514_0 -> 29 in the cache */
   /* replace1514 -> 4150 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a') */
   /* search1515_0_0_0 -> 29 in the cache */
   /* search1515_0_0 -> 4131 in the cache */
   /* search1515_0_1 -> 137 in the cache */
   /* search1515_0 -> 4169 in the cache */
   /* search1515_1_0 -> 32 in the cache */
   /* search1515_1_1_0_0 -> 29 in the cache */
   /* search1515_1_1_0 -> 4131 in the cache */
   /* search1515_1_1 -> 4170 in the cache */
   /* search1515_1 -> 4171 in the cache */
   /* search1515_2_0 -> 29 in the cache */
   /* search1515_2 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4169, 4171, 4131 },
      -1,
   } },

   /* replace1515_0 -> 29 in the cache */
   /* replace1515 -> 4125 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1516_0_0_0 -> 29 in the cache */
   /* search1516_0_0 -> 4155 in the cache */
   /* search1516_0_1 -> 137 in the cache */
   /* search1516_0 -> 4173 in the cache */
   /* search1516_1_0 -> 32 in the cache */
   /* search1516_1_1_0_0 -> 29 in the cache */
   /* search1516_1_1_0 -> 4155 in the cache */
   /* search1516_1_1 -> 4174 in the cache */
   /* search1516_1 -> 4175 in the cache */
   /* search1516_2_0 -> 29 in the cache */
   /* search1516_2 -> 4155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4173, 4175, 4155 },
      -1,
   } },

   /* replace1516_0 -> 29 in the cache */
   /* replace1516 -> 4150 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1517_0_0_0 -> 29 in the cache */
   /* search1517_0_0 -> 4131 in the cache */
   /* search1517_0_1 -> 137 in the cache */
   /* search1517_0 -> 4177 in the cache */
   /* search1517_1_0 -> 29 in the cache */
   /* search1517_1 -> 4131 in the cache */
   /* search1517_2_0 -> 32 in the cache */
   /* search1517_2_1_0_0 -> 29 in the cache */
   /* search1517_2_1_0 -> 4131 in the cache */
   /* search1517_2_1 -> 4170 in the cache */
   /* search1517_2 -> 4171 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4177, 4131, 4171 },
      -1,
   } },

   /* replace1517_0 -> 29 in the cache */
   /* replace1517 -> 4125 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1518_0_0_0 -> 29 in the cache */
   /* search1518_0_0 -> 4155 in the cache */
   /* search1518_0_1 -> 137 in the cache */
   /* search1518_0 -> 4179 in the cache */
   /* search1518_1_0 -> 29 in the cache */
   /* search1518_1 -> 4155 in the cache */
   /* search1518_2_0 -> 32 in the cache */
   /* search1518_2_1_0_0 -> 29 in the cache */
   /* search1518_2_1_0 -> 4155 in the cache */
   /* search1518_2_1 -> 4174 in the cache */
   /* search1518_2 -> 4175 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4179, 4155, 4175 },
      -1,
   } },

   /* replace1518_0 -> 29 in the cache */
   /* replace1518 -> 4150 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1519_0_0 -> 29 in the cache */
   /* search1519_0_1 -> 135 in the cache */
   /* search1519_0 -> 4138 in the cache */
   /* search1519_1_0 -> 32 in the cache */
   /* search1519_1_1_0_0 -> 29 in the cache */
   /* search1519_1_1_0 -> 4155 in the cache */
   /* search1519_1_1 -> 4174 in the cache */
   /* search1519_1 -> 4175 in the cache */
   /* search1519_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4138, 4175, 137 },
      -1,
   } },

   /* replace1519_0 -> 29 in the cache */
   /* replace1519 -> 4150 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1520_0_0 -> 29 in the cache */
   /* search1520_0_1 -> 135 in the cache */
   /* search1520_0 -> 4165 in the cache */
   /* search1520_1 -> 137 in the cache */
   /* search1520_2_0 -> 32 in the cache */
   /* search1520_2_1_0_0 -> 29 in the cache */
   /* search1520_2_1_0 -> 4155 in the cache */
   /* search1520_2_1 -> 4174 in the cache */
   /* search1520_2 -> 4175 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4165, 137, 4175 },
      -1,
   } },

   /* replace1520_0 -> 29 in the cache */
   /* replace1520 -> 4150 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1521_0_0 -> 29 in the cache */
   /* search1521_0_1 -> 135 in the cache */
   /* search1521_0 -> 4138 in the cache */
   /* search1521_1_0 -> 32 in the cache */
   /* search1521_1_1_0_0 -> 29 in the cache */
   /* search1521_1_1_0 -> 4155 in the cache */
   /* search1521_1_1 -> 4174 in the cache */
   /* search1521_1 -> 4175 in the cache */
   /* search1521_2_0 -> 29 in the cache */
   /* search1521_2 -> 4155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4138, 4175, 4155 },
      -1,
   } },

   /* replace1521_0 -> 29 in the cache */
   /* replace1521 -> 4150 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1522_0_0 -> 29 in the cache */
   /* search1522_0_1 -> 135 in the cache */
   /* search1522_0 -> 4165 in the cache */
   /* search1522_1_0 -> 29 in the cache */
   /* search1522_1 -> 4155 in the cache */
   /* search1522_2_0 -> 32 in the cache */
   /* search1522_2_1_0_0 -> 29 in the cache */
   /* search1522_2_1_0 -> 4155 in the cache */
   /* search1522_2_1 -> 4174 in the cache */
   /* search1522_2 -> 4175 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4165, 4155, 4175 },
      -1,
   } },

   /* replace1522_0 -> 29 in the cache */
   /* replace1522 -> 4150 in the cache */

   /* ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1523_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 4189 },
      -1,
   } },

   /* replace1523_0 -> 29 in the cache */
   /* replace1523 -> 4155 in the cache */

   /* ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a') */
   /* search1524_0_0 -> 29 in the cache */
   /* search1524_0 -> 4189 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 4189 },
      -1,
   } },

   /* replace1524_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('ifind_msb', ('f2i32(is_used_once)', 'a')) => ('ufind_msb', ('f2i32', ('fabs', 'a'))) */
   /* search1525_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 9 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 4193 },
      -1,
   } },

   /* replace1525_0_0_0 -> 9 in the cache */
   /* replace1525_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 4195 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1526_0_0 -> 609 in the cache */
   /* search1526_0_1 -> 288 in the cache */
   /* search1526_0_2 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 288, 283 },
      0,
   } },
   /* search1526_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 4197, 1 },
      -1,
   } },

   /* replace1526_0 -> 609 in the cache */
   /* replace1526_1_0 -> 1 in the cache */
   /* replace1526_1 -> 1175 in the cache */
   /* replace1526_2 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 1175, 1 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1527_0_0 -> 609 in the cache */
   /* search1527_0_1 -> 283 in the cache */
   /* search1527_0_2 -> 288 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 283, 288 },
      0,
   } },
   /* search1527_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 4200, 1 },
      -1,
   } },

   /* replace1527_0 -> 609 in the cache */
   /* replace1527_1 -> 1 in the cache */
   /* replace1527_2_0 -> 1 in the cache */
   /* replace1527_2 -> 1175 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 1, 1175 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1528_0_0 -> 609 in the cache */
   /* search1528_0_1 -> 291 in the cache */
   /* search1528_0_2 -> 261 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 291, 261 },
      0,
   } },
   /* search1528_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 4203, 48 },
      -1,
   } },

   /* replace1528_0 -> 609 in the cache */
   /* replace1528_1_0 -> 48 in the cache */
   /* replace1528_1 -> 687 in the cache */
   /* replace1528_2 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 687, 48 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1529_0_0 -> 609 in the cache */
   /* search1529_0_1 -> 261 in the cache */
   /* search1529_0_2 -> 291 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 261, 291 },
      0,
   } },
   /* search1529_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 4206, 48 },
      -1,
   } },

   /* replace1529_0 -> 609 in the cache */
   /* replace1529_1 -> 48 in the cache */
   /* replace1529_2_0 -> 48 in the cache */
   /* replace1529_2 -> 687 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 48, 687 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1530_0_1_0 -> 1191 in the cache */
   /* search1530_0_1 -> 1682 in the cache */
   /* search1530_0_2 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4209, 1682, 1191 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 4210 },
      -1,
   } },

   /* replace1530_0 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1191 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a') */
   /* search1531_0_0 -> 4209 in the cache */
   /* search1531_0_1 -> 1191 in the cache */
   /* search1531_0_2_0 -> 1191 in the cache */
   /* search1531_0_2 -> 1682 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4209, 1191, 1682 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 4213 },
      -1,
   } },

   /* replace1531_0 -> 1191 in the cache */
   /* replace1531 -> 4212 in the cache */

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1532_0_0 -> 9 in the cache */
   /* search1532_0_1 -> 8 in the cache */
   /* search1532_0 -> 1289 in the cache */
   /* search1532_1_0 -> 9 in the cache */
   /* search1532_1 -> 118 in the cache */
   /* search1532_2 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1289, 118, 9 },
      -1,
   } },

   /* replace1532_0 -> 9 in the cache */
   /* replace1532 -> 11 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1533_0 -> 847 in the cache */
   /* search1533_1_0 -> 1251 in the cache */
   /* search1533_1_1 -> 165 in the cache */
   /* search1533_1_2 -> 166 in the cache */
   /* search1533_1 -> 1422 in the cache */
   /* search1533_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1422, 166 },
      -1,
   } },

   /* replace1533_0_0 -> 847 in the cache */
   /* replace1533_0_1 -> 1251 in the cache */
   /* replace1533_0 -> 1263 in the cache */
   /* replace1533_1 -> 165 in the cache */
   /* replace1533_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1263, 165, 166 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1534_0 -> 847 in the cache */
   /* search1534_1 -> 163 in the cache */
   /* search1534_2_0 -> 552 in the cache */
   /* search1534_2_1 -> 163 in the cache */
   /* search1534_2_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 552, 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 163, 4218 },
      -1,
   } },

   /* replace1534_0_0 -> 847 in the cache */
   /* replace1534_0_1 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 847, 552 },
      -1,
   } },
   /* replace1534_1 -> 163 in the cache */
   /* replace1534_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4220, 163, 166 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1535_0 -> 0 in the cache */
   /* search1535_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1535_0 -> 0 in the cache */
   /* replace1535_1_0 -> 1 in the cache */
   /* replace1535_1_1_0_0 -> 0 in the cache */
   /* replace1535_1_1_0_1 -> 1 in the cache */
   /* replace1535_1_1_0 -> 3292 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 3292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 4223 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 4224 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1536_0 -> 0 in the cache */
   /* search1536_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1536_0 -> 0 in the cache */
   /* replace1536_1_0 -> 1 in the cache */
   /* replace1536_1_1_0_0 -> 0 in the cache */
   /* replace1536_1_1_0_1 -> 1 in the cache */
   /* replace1536_1_1_0 -> 3292 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 3292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 4227 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 4228 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1537_0 -> 0 in the cache */
   /* search1537_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1537_0_0_0 -> 0 in the cache */
   /* replace1537_0_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 1 },
      -1,
   } },
   /* replace1537_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4231, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 4232 },
      -1,
   } },

   /* ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1538_0 -> 0 in the cache */
   /* search1538_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1538_0_0 -> 0 in the cache */
   /* replace1538_0_1 -> 1 in the cache */
   /* replace1538_0 -> 1155 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1155 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 4236, 4237, 4238, 4239 },
      -1,
   } },

   /* replace1539_0_0 -> 32 in the cache */
   /* replace1539_0_1 -> 4239 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 4239 },
      -1,
   } },
   /* replace1539_1 -> 4237 in the cache */
   /* replace1539_2_0_0 -> 4239 in the cache */
   /* replace1539_2_0_1 -> 4238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 4239, 4238 },
      -1,
   } },
   /* replace1539_2_1 -> 4237 in the cache */
   /* replace1539_2_2 -> 4236 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 4242, 4237, 4236 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4241, 4237, 4243 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1540_0 -> 0 in the cache */
   /* search1540_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1540_0_0 -> 0 in the cache */
   /* replace1540_0_1 -> 1 in the cache */
   /* replace1540_0 -> 214 in the cache */
   /* replace1540_1_0_0 -> 0 in the cache */
   /* replace1540_1_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 1 },
      -1,
   } },
   /* replace1540_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 4246, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 214, 4247 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1541_0 -> 0 in the cache */
   /* search1541_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1541_0_0 -> 0 in the cache */
   /* replace1541_0_1 -> 1 in the cache */
   /* replace1541_0 -> 214 in the cache */
   /* replace1541_1_0_0 -> 0 in the cache */
   /* replace1541_1_0_1 -> 1 in the cache */
   /* replace1541_1_0 -> 4246 in the cache */
   /* replace1541_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4246, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 214, 4250 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1542_0 -> 0 in the cache */
   /* search1542_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1542_0_0 -> 0 in the cache */
   /* replace1542_0_1 -> 1 in the cache */
   /* replace1542_0 -> 2694 in the cache */
   /* replace1542_1_0_0 -> 0 in the cache */
   /* replace1542_1_0_1 -> 1 in the cache */
   /* replace1542_1_0 -> 3067 in the cache */
   /* replace1542_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3067, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2694, 4253 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1543_0 -> 0 in the cache */
   /* search1543_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1543_0_0 -> 0 in the cache */
   /* replace1543_0_1 -> 1 in the cache */
   /* replace1543_0 -> 2694 in the cache */
   /* replace1543_1_0_0 -> 0 in the cache */
   /* replace1543_1_0_1 -> 1 in the cache */
   /* replace1543_1_0 -> 3067 in the cache */
   /* replace1543_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3067, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2694, 4256 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1544_0 -> 34 in the cache */
   /* search1544_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* replace1544_0_0 -> 34 in the cache */
   /* replace1544_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1544_1_0_0 -> 34 in the cache */
   /* replace1544_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1544_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 4260, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 4259, 4261 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1545_0 -> 34 in the cache */
   /* search1545_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* replace1545_0_0 -> 34 in the cache */
   /* replace1545_0_1 -> 53 in the cache */
   /* replace1545_0 -> 4259 in the cache */
   /* replace1545_1_0_0 -> 34 in the cache */
   /* replace1545_1_0_1 -> 53 in the cache */
   /* replace1545_1_0 -> 4260 in the cache */
   /* replace1545_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4260, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 4259, 4264 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1546_0 -> 34 in the cache */
   /* search1546_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* replace1546_0_0 -> 34 in the cache */
   /* replace1546_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1546_1_0_0 -> 34 in the cache */
   /* replace1546_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1546_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 4268, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 4267, 4269 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1547_0 -> 34 in the cache */
   /* search1547_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* replace1547_0_0 -> 34 in the cache */
   /* replace1547_0_1 -> 53 in the cache */
   /* replace1547_0 -> 4267 in the cache */
   /* replace1547_1_0_0 -> 34 in the cache */
   /* replace1547_1_0_1 -> 53 in the cache */
   /* replace1547_1_0 -> 4268 in the cache */
   /* replace1547_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4268, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 4267, 4272 },
      -1,
   } },

   /* ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0)) */
   /* search1548_0 -> 29 in the cache */
   /* search1548_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul_32x16,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1548_0 -> 29 in the cache */
   /* replace1548_1_0 -> 48 in the cache */
   /* replace1548_1_1 -> 135 in the cache */
   /* replace1548_1 -> 527 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 29, 527 },
      -1,
   } },

   /* ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0)) */
   /* search1549_0 -> 29 in the cache */
   /* search1549_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_32x16,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1549_0 -> 29 in the cache */
   /* replace1549_1_0 -> 48 in the cache */
   /* replace1549_1_1 -> 135 in the cache */
   /* replace1549_1 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 29, 535 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1550_0 -> 34 in the cache */
   /* search1550_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* replace1550_0_0_0 -> 34 in the cache */
   /* replace1550_0_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1550_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4279, 34 },
      -1,
   } },
   /* replace1550_1 -> 1603 in the cache */
   /* replace1550_2_0 -> 34 in the cache */
   /* replace1550_2_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 34, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4280, 1603, 4281 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1551_0 -> 0 in the cache */
   /* search1551_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1551_0_0_0 -> 0 in the cache */
   /* replace1551_0_0_1 -> 1 in the cache */
   /* replace1551_0_0 -> 4231 in the cache */
   /* replace1551_0_1 -> 0 in the cache */
   /* replace1551_0 -> 4232 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   /* replace1551_2_0 -> 0 in the cache */
   /* replace1551_2_1 -> 1 in the cache */
   /* replace1551_2 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4232, 4284, 226 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1552_0 -> 0 in the cache */
   /* search1552_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1552_0_0 -> 0 in the cache */
   /* replace1552_0_1 -> 1 in the cache */
   /* replace1552_0 -> 1155 in the cache */
   /* replace1552_1 -> 98 in the cache */
   /* replace1552_2_0 -> 0 in the cache */
   /* replace1552_2_1 -> 1 in the cache */
   /* replace1552_2 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1155, 98, 3996 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1553_0 -> 34 in the cache */
   /* search1553_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 34, 53 },
      -1,
   } },

   /* replace1553_0_0 -> 34 in the cache */
   /* replace1553_0_1 -> 53 in the cache */
   /* replace1553_0 -> 2555 in the cache */
   /* replace1553_1 -> 987 in the cache */
   /* replace1553_2_0 -> 34 in the cache */
   /* replace1553_2_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 34, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 2555, 987, 4289 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1554_0 -> 34 in the cache */
   /* search1554_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 34, 53 },
      -1,
   } },

   /* replace1554_0_0_0_0 -> 34 in the cache */
   /* replace1554_0_0_0_1 -> 987 in the cache */
   /* replace1554_0_0_0 -> 1593 in the cache */
   /* replace1554_0_0_1_0 -> 53 in the cache */
   /* replace1554_0_0_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 53, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1593, 4292 },
      -1,
   } },
   /* replace1554_0_1_0_0 -> 34 in the cache */
   /* replace1554_0_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1554_0_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 4294, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4293, 4295 },
      -1,
   } },
   /* replace1554_1 -> 35 in the cache */
   /* replace1554_2_0_0_0_0 -> 34 in the cache */
   /* replace1554_2_0_0_0_1 -> 987 in the cache */
   /* replace1554_2_0_0_0 -> 1593 in the cache */
   /* replace1554_2_0_0_1_0 -> 53 in the cache */
   /* replace1554_2_0_0_1_1 -> 987 in the cache */
   /* replace1554_2_0_0_1 -> 4292 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1593, 4292 },
      -1,
   } },
   /* replace1554_2_0_1_0_0 -> 34 in the cache */
   /* replace1554_2_0_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 34, 53 },
      -1,
   } },
   /* replace1554_2_0_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 4298, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 4297, 4299 },
      -1,
   } },
   /* replace1554_2_1_0 -> 34 in the cache */
   /* replace1554_2_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 34, 53 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffffull /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4300, 4301, 4302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 4296, 35, 4303 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1555_0 -> 34 in the cache */
   /* search1555_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 34, 53 },
      -1,
   } },

   /* replace1555_0_0_0_0 -> 34 in the cache */
   /* replace1555_0_0_0_1 -> 987 in the cache */
   /* replace1555_0_0_0 -> 1593 in the cache */
   /* replace1555_0_0_1_0 -> 53 in the cache */
   /* replace1555_0_0_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 53, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1593, 4306 },
      -1,
   } },
   /* replace1555_0_1_0_0 -> 34 in the cache */
   /* replace1555_0_1_0_1 -> 53 in the cache */
   /* replace1555_0_1_0 -> 4289 in the cache */
   /* replace1555_0_1_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4289, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4307, 4308 },
      -1,
   } },
   /* replace1555_1 -> 35 in the cache */
   /* replace1555_2_0_0_0_0 -> 34 in the cache */
   /* replace1555_2_0_0_0_1 -> 987 in the cache */
   /* replace1555_2_0_0_0 -> 1593 in the cache */
   /* replace1555_2_0_0_1_0 -> 53 in the cache */
   /* replace1555_2_0_0_1_1 -> 987 in the cache */
   /* replace1555_2_0_0_1 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1593, 4306 },
      -1,
   } },
   /* replace1555_2_0_1_0_0 -> 34 in the cache */
   /* replace1555_2_0_1_0_1 -> 53 in the cache */
   /* replace1555_2_0_1_0 -> 4289 in the cache */
   /* replace1555_2_0_1_1 -> 987 in the cache */
   /* replace1555_2_0_1 -> 4308 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 4310, 4308 },
      -1,
   } },
   /* replace1555_2_1_0 -> 34 in the cache */
   /* replace1555_2_1_1 -> 53 in the cache */
   /* replace1555_2_1 -> 4289 in the cache */
   /* replace1555_2_2 -> 4302 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4311, 4289, 4302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4309, 35, 4312 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1556_0_0 -> 34 in the cache */
   /* search1556_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 34, 53 },
      0,
   } },
   /* search1556_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4314, 987 },
      -1,
   } },

   /* replace1556_0_0_0 -> 34 in the cache */
   /* replace1556_0_0 -> 3082 in the cache */
   /* replace1556_0_1_0 -> 53 in the cache */
   /* replace1556_0_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 3082, 3083 },
      -1,
   } },
   /* replace1556_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4316, 135 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1557_0_0 -> 34 in the cache */
   /* search1557_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 34, 53 },
      0,
   } },
   /* search1557_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4318, 987 },
      -1,
   } },

   /* replace1557_0_0_0 -> 34 in the cache */
   /* replace1557_0_0 -> 3082 in the cache */
   /* replace1557_0_1_0 -> 53 in the cache */
   /* replace1557_0_1 -> 3083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 3082, 3083 },
      -1,
   } },
   /* replace1557_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4320, 135 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1558_0_0 -> 34 in the cache */
   /* search1558_0_1 -> 53 in the cache */
   /* search1558_0 -> 4314 in the cache */
   /* search1558_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 4314, 987 },
      -1,
   } },

   /* replace1558_0_0_0 -> 34 in the cache */
   /* replace1558_0_0 -> 3082 in the cache */
   /* replace1558_0_1_0 -> 53 in the cache */
   /* replace1558_0_1 -> 3083 in the cache */
   /* replace1558_0 -> 4316 in the cache */
   /* replace1558_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 4316, 135 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1559_0_0 -> 34 in the cache */
   /* search1559_0_1 -> 53 in the cache */
   /* search1559_0 -> 4318 in the cache */
   /* search1559_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 4318, 987 },
      -1,
   } },

   /* replace1559_0_0_0 -> 34 in the cache */
   /* replace1559_0_0 -> 3082 in the cache */
   /* replace1559_0_1_0 -> 53 in the cache */
   /* replace1559_0_1 -> 3083 in the cache */
   /* replace1559_0 -> 4320 in the cache */
   /* replace1559_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 4320, 135 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1560_0 -> 34 in the cache */
   /* search1560_1 -> 987 in the cache */
   /* search1560 -> 1593 in the cache */

   /* replace1560_0_0 -> 34 in the cache */
   /* replace1560_0 -> 3082 in the cache */
   /* replace1560_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3082, 135 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1561_0 -> 34 in the cache */
   /* search1561_1 -> 987 in the cache */
   /* search1561 -> 1590 in the cache */

   /* replace1561_0_0 -> 34 in the cache */
   /* replace1561_0 -> 3082 in the cache */
   /* replace1561_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3082, 135 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1562_0 -> 34 in the cache */
   /* search1562_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 34, 987 },
      -1,
   } },

   /* replace1562_0_0_0 -> 34 in the cache */
   /* replace1562_0_0 -> 3088 in the cache */
   /* replace1562_0_1_0 -> 34 in the cache */
   /* replace1562_0_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3088, 3082 },
      -1,
   } },
   /* replace1562_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4329, 135 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1563_0 -> 34 in the cache */
   /* search1563_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 34, 987 },
      -1,
   } },

   /* replace1563_0_0_0 -> 34 in the cache */
   /* replace1563_0_0 -> 3088 in the cache */
   /* replace1563_0_1_0 -> 34 in the cache */
   /* replace1563_0_1 -> 3082 in the cache */
   /* replace1563_0 -> 4329 in the cache */
   /* replace1563_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4329, 135 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1564_0 -> 987 in the cache */
   /* search1564_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 987, 34 },
      -1,
   } },

   /* replace1564_0_0_0 -> 34 in the cache */
   /* replace1564_0_0 -> 3088 in the cache */
   /* replace1564_0_1_0 -> 34 in the cache */
   /* replace1564_0_1 -> 3082 in the cache */
   /* replace1564_0 -> 4329 in the cache */
   /* replace1564_1 -> 135 in the cache */
   /* replace1564 -> 4330 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1565_0 -> 4236 in the cache */
   /* search1565_1 -> 4237 in the cache */
   /* search1565_2 -> 4238 in the cache */
   /* search1565_3 -> 4239 in the cache */
   /* search1565 -> 4240 in the cache */

   /* replace1565_0_0 -> 32 in the cache */
   /* replace1565_0_1 -> 4239 in the cache */
   /* replace1565_0 -> 4241 in the cache */
   /* replace1565_1 -> 4237 in the cache */
   /* replace1565_2_0_0 -> 4236 in the cache */
   /* replace1565_2_0_1_0_0_0_0 -> 486 in the cache */
   /* replace1565_2_0_1_0_0_0_1 -> 4239 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 486, 4239 },
      -1,
   } },
   /* replace1565_2_0_1_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 4334, 486 },
      -1,
   } },
   /* replace1565_2_0_1_0_1 -> 4238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4335, 4238 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 4336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 4236, 4337 },
      -1,
   } },
   /* replace1565_2_1_0_0 -> 4237 in the cache */
   /* replace1565_2_1_0_1 -> 4238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4237, 4238 },
      -1,
   } },
   /* replace1565_2_1_1_0_0_0 -> 486 in the cache */
   /* replace1565_2_1_1_0_0_1 -> 4239 in the cache */
   /* replace1565_2_1_1_0_0 -> 4334 in the cache */
   /* replace1565_2_1_1_0_1 -> 486 in the cache */
   /* replace1565_2_1_1_0 -> 4335 in the cache */
   /* replace1565_2_1_1_1 -> 4238 in the cache */
   /* replace1565_2_1_1 -> 4336 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 4339, 4336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4338, 4340 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4241, 4237, 4341 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1566_0 -> 4236 in the cache */
   /* search1566_1 -> 4237 in the cache */
   /* search1566_2 -> 4238 in the cache */
   /* search1566_3 -> 4239 in the cache */
   /* search1566 -> 4240 in the cache */

   /* replace1566_0_0 -> 32 in the cache */
   /* replace1566_0_1 -> 4239 in the cache */
   /* replace1566_0 -> 4241 in the cache */
   /* replace1566_1 -> 4237 in the cache */
   /* replace1566_2_0_0 -> 4239 in the cache */
   /* replace1566_2_0_1 -> 4238 in the cache */
   /* replace1566_2_0 -> 4242 in the cache */
   /* replace1566_2_1_0 -> 4237 in the cache */
   /* replace1566_2_1_1 -> 4238 in the cache */
   /* replace1566_2_1 -> 4339 in the cache */
   /* replace1566_2_2 -> 4236 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 4242, 4339, 4236 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4241, 4237, 4343 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 4345, 4346, 4347 },
      -1,
   } },

   /* replace1567_0_0 -> 32 in the cache */
   /* replace1567_0_1 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 4347 },
      -1,
   } },
   /* replace1567_1 -> 4345 in the cache */
   /* replace1567_2_0 -> 4345 in the cache */
   /* replace1567_2_1 -> 4346 in the cache */
   /* replace1567_2_2 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 4345, 4346, 4347 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4349, 4345, 4350 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1568_0 -> 4345 in the cache */
   /* search1568_1 -> 4346 in the cache */
   /* search1568_2 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 4345, 4346, 4347 },
      -1,
   } },

   /* replace1568_0_0 -> 32 in the cache */
   /* replace1568_0_1 -> 4347 in the cache */
   /* replace1568_0 -> 4349 in the cache */
   /* replace1568_1 -> 4345 in the cache */
   /* replace1568_2_0 -> 4345 in the cache */
   /* replace1568_2_1 -> 4346 in the cache */
   /* replace1568_2_2 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 4345, 4346, 4347 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4349, 4345, 4353 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1569_0 -> 0 in the cache */
   /* search1569_1 -> 1 in the cache */
   /* search1569_2 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 1, 98 },
      -1,
   } },

   /* replace1569_0 -> 0 in the cache */
   /* replace1569_1 -> 1 in the cache */
   /* replace1569 -> 3075 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1570_0 -> 139 in the cache */
   /* search1570_1_0 -> 139 in the cache */
   /* search1570_1_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 139, 140 },
      -1,
   } },
   /* search1570_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 139, 4356, 142 },
      -1,
   } },

   /* replace1570_0 -> 139 in the cache */
   /* replace1570_1 -> 140 in the cache */
   /* replace1570_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 139, 140, 142 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1571_0 -> 4345 in the cache */
   /* search1571_1 -> 4346 in the cache */
   /* search1571_2_0 -> 32 in the cache */
   /* search1571_2_1 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 4347 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 4345, 4346, 4359 },
      -1,
   } },

   /* replace1571_0 -> 4345 in the cache */
   /* replace1571_1 -> 4346 in the cache */
   /* replace1571_2 -> 4347 in the cache */
   /* replace1571 -> 4353 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1572_0 -> 4345 in the cache */
   /* search1572_1_0 -> 32 in the cache */
   /* search1572_1_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 4346 },
      -1,
   } },
   /* search1572_2 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 4345, 4361, 4347 },
      -1,
   } },

   /* replace1572_0 -> 4345 in the cache */
   /* replace1572_1 -> 4346 in the cache */
   /* replace1572_2 -> 4347 in the cache */
   /* replace1572 -> 4353 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1573_0 -> 4345 in the cache */
   /* search1573_1 -> 4346 in the cache */
   /* search1573_2_0 -> 32 in the cache */
   /* search1573_2_1 -> 4347 in the cache */
   /* search1573_2 -> 4359 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 4345, 4346, 4359 },
      -1,
   } },

   /* replace1573_0 -> 4345 in the cache */
   /* replace1573_1 -> 4346 in the cache */
   /* replace1573_2 -> 4347 in the cache */
   /* replace1573 -> 4350 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1574_0 -> 4345 in the cache */
   /* search1574_1_0 -> 32 in the cache */
   /* search1574_1_1 -> 4346 in the cache */
   /* search1574_1 -> 4361 in the cache */
   /* search1574_2 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 4345, 4361, 4347 },
      -1,
   } },

   /* replace1574_0 -> 4345 in the cache */
   /* replace1574_1 -> 4346 in the cache */
   /* replace1574_2 -> 4347 in the cache */
   /* replace1574 -> 4350 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1575_1_0 -> 32 in the cache */
   /* search1575_1_1 -> 4346 in the cache */
   /* search1575_1 -> 4361 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 4365, 4361 },
      -1,
   } },

   /* replace1575_0 -> 4365 in the cache */
   /* replace1575_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 4365, 4346 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1576_0_0 -> 32 in the cache */
   /* search1576_0_1 -> 4365 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 4365 },
      -1,
   } },
   /* search1576_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 4368, 4346 },
      -1,
   } },

   /* replace1576_0 -> 4365 in the cache */
   /* replace1576_1 -> 4346 in the cache */
   /* replace1576 -> 4367 in the cache */

   /* ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False */
   /* search1577_0 -> 139 in the cache */
   /* search1577_1_0_0 -> 139 in the cache */
   /* search1577_1_0_1 -> 140 in the cache */
   /* search1577_1_0 -> 207 in the cache */
   /* search1577_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 207, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 2,
      { 139, 4370 },
      -1,
   } },

   /* replace1577 -> 1165 in the cache */

   /* ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1full /* 31 */ },
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* bits */
      true,
      nir_type_invalid,
      36,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1578_1_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 4373, 1191 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4372, 4374 },
      -1,
   } },

   /* replace1578 -> 1165 in the cache */

   /* ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width') */
   /* search1579_0 -> 4345 in the cache */
   /* search1579_1 -> 4346 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1579_2_1_0 -> 964 in the cache */
   /* search1579_2_1_1_0_0 -> 32 in the cache */
   /* search1579_2_1_1_0_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 32, 4346 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 4377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 964, 4378 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 4376, 4379 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 3,
      { 4345, 4346, 4380 },
      -1,
   } },

   /* replace1579_0 -> 4345 in the cache */
   /* replace1579_1 -> 4346 in the cache */
   /* replace1579_2 -> 4376 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 4345, 4346, 4376 },
      -1,
   } },

   /* ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width') */
   /* search1580_0 -> 4345 in the cache */
   /* search1580_1 -> 4346 in the cache */
   /* search1580_2_0 -> 4376 in the cache */
   /* search1580_2_1_0 -> 964 in the cache */
   /* search1580_2_1_1_0_0 -> 32 in the cache */
   /* search1580_2_1_1_0_1 -> 4346 in the cache */
   /* search1580_2_1_1_0 -> 4377 in the cache */
   /* search1580_2_1_1 -> 4378 in the cache */
   /* search1580_2_1 -> 4379 in the cache */
   /* search1580_2 -> 4380 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 3,
      { 4345, 4346, 4380 },
      -1,
   } },

   /* replace1580_0 -> 4345 in the cache */
   /* replace1580_1 -> 4346 in the cache */
   /* replace1580_2 -> 4376 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 4345, 4346, 4376 },
      -1,
   } },

   /* ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1581_0_1_0 -> 964 in the cache */
   /* search1581_0_1_1_0_0 -> 32 in the cache */
   /* search1581_0_1_1_0_1 -> 4346 in the cache */
   /* search1581_0_1_1_0 -> 4377 in the cache */
   /* search1581_0_1_1 -> 4378 in the cache */
   /* search1581_0_1 -> 4379 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 4385, 4379 },
      -1,
   } },
   /* search1581_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 3,
      { 4386, 4346 },
      -1,
   } },

   /* replace1581_0 -> 4385 in the cache */
   /* replace1581_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 4385, 4346 },
      -1,
   } },

   /* ('iadd@32', ('ishl', 1, 'a'), -1) => ('bfm', 'a', 0) */
   /* search1582_0_0 -> 486 in the cache */
   /* search1582_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 486, 29 },
      -1,
   } },
   /* search1582_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4389, 137 },
      -1,
   } },

   /* replace1582_0 -> 29 in the cache */
   /* replace1582_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 29, 135 },
      -1,
   } },

   /* ('ishl', ('bfm', 'a', 0), 'b') => ('bfm', 'a', 'b') */
   /* search1583_0_0 -> 29 in the cache */
   /* search1583_0_1 -> 135 in the cache */
   /* search1583_0 -> 4391 in the cache */
   /* search1583_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4391, 48 },
      -1,
   } },

   /* replace1583_0 -> 29 in the cache */
   /* replace1583_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1584_0 -> 29 in the cache */
   /* search1584_1 -> 48 in the cache */
   /* search1584_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 48, 135 },
      -1,
   } },

   /* replace1584 -> 135 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1585_0 -> 29 in the cache */
   /* search1585_1 -> 48 in the cache */
   /* search1585_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 48, 135 },
      -1,
   } },

   /* replace1585 -> 135 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1586_0 -> 29 in the cache */
   /* search1586_1 -> 135 in the cache */
   /* search1586_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 135, 45 },
      -1,
   } },

   /* replace1586_0 -> 29 in the cache */
   /* replace1586_1_0 -> 1017 in the cache */
   /* replace1586_1_1_0 -> 48 in the cache */
   /* replace1586_1_1 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1017, 3128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 4397 },
      -1,
   } },

   /* ('b2i32', ('ine', ('ubfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1) */
   /* search1587_0_0_0 -> 29 in the cache */
   /* search1587_0_0_1 -> 48 in the cache */
   /* search1587_0_0_2 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 48, 486 },
      -1,
   } },
   /* search1587_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4399, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 1,
      { 4400 },
      -1,
   } },

   /* replace1587_0 -> 29 in the cache */
   /* replace1587_1 -> 48 in the cache */
   /* replace1587_2 -> 486 in the cache */
   /* replace1587 -> 4399 in the cache */

   /* ('b2i32', ('ine', ('ibfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1) */
   /* search1588_0_0_0 -> 29 in the cache */
   /* search1588_0_0_1 -> 48 in the cache */
   /* search1588_0_0_2 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 48, 486 },
      -1,
   } },
   /* search1588_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4402, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 1,
      { 4403 },
      -1,
   } },

   /* replace1588_0 -> 29 in the cache */
   /* replace1588_1 -> 48 in the cache */
   /* replace1588_2 -> 486 in the cache */
   /* replace1588 -> 4399 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1589_0_0 -> 29 in the cache */
   /* search1589_0_1 -> 45 in the cache */
   /* search1589_0_2 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 29, 45, 322 },
      0,
   } },
   /* search1589_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4405, 135 },
      -1,
   } },

   /* replace1589_0_0 -> 29 in the cache */
   /* replace1589_0_1_0_0 -> 1017 in the cache */
   /* replace1589_0_1_0_1_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1017, 4407 },
      -1,
   } },
   /* replace1589_0_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4408, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 4409 },
      -1,
   } },
   /* replace1589_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4410, 135 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1590_0_0 -> 29 in the cache */
   /* search1590_0_1 -> 45 in the cache */
   /* search1590_0_2 -> 322 in the cache */
   /* search1590_0 -> 4405 in the cache */
   /* search1590_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4405, 135 },
      -1,
   } },

   /* replace1590_0_0 -> 29 in the cache */
   /* replace1590_0_1_0_0 -> 1017 in the cache */
   /* replace1590_0_1_0_1_0 -> 148 in the cache */
   /* replace1590_0_1_0_1 -> 4407 in the cache */
   /* replace1590_0_1_0 -> 4408 in the cache */
   /* replace1590_0_1_1 -> 48 in the cache */
   /* replace1590_0_1 -> 4409 in the cache */
   /* replace1590_0 -> 4410 in the cache */
   /* replace1590_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4410, 135 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1591_0_0 -> 29 in the cache */
   /* search1591_0_1 -> 45 in the cache */
   /* search1591_0_2 -> 322 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 29, 45, 322 },
      0,
   } },
   /* search1591_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4414, 135 },
      -1,
   } },

   /* replace1591_0_0 -> 29 in the cache */
   /* replace1591_0_1_0_0 -> 1017 in the cache */
   /* replace1591_0_1_0_1_0 -> 148 in the cache */
   /* replace1591_0_1_0_1 -> 4407 in the cache */
   /* replace1591_0_1_0 -> 4408 in the cache */
   /* replace1591_0_1_1 -> 48 in the cache */
   /* replace1591_0_1 -> 4409 in the cache */
   /* replace1591_0 -> 4410 in the cache */
   /* replace1591_1 -> 135 in the cache */
   /* replace1591 -> 4411 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1592_0_0 -> 29 in the cache */
   /* search1592_0_1 -> 45 in the cache */
   /* search1592_0_2 -> 322 in the cache */
   /* search1592_0 -> 4414 in the cache */
   /* search1592_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4414, 135 },
      -1,
   } },

   /* replace1592_0_0 -> 29 in the cache */
   /* replace1592_0_1_0_0 -> 1017 in the cache */
   /* replace1592_0_1_0_1_0 -> 148 in the cache */
   /* replace1592_0_1_0_1 -> 4407 in the cache */
   /* replace1592_0_1_0 -> 4408 in the cache */
   /* replace1592_0_1_1 -> 48 in the cache */
   /* replace1592_0_1 -> 4409 in the cache */
   /* replace1592_0 -> 4410 in the cache */
   /* replace1592_1 -> 135 in the cache */
   /* replace1592 -> 4413 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1593_0 -> 4345 in the cache */
   /* search1593_1 -> 4346 in the cache */
   /* search1593_2 -> 4347 in the cache */
   /* search1593 -> 4348 in the cache */

   /* replace1593_0_0 -> 135 in the cache */
   /* replace1593_0_1 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 135, 4347 },
      -1,
   } },
   /* replace1593_1 -> 135 in the cache */
   /* replace1593_2_0_0 -> 4345 in the cache */
   /* replace1593_2_0_1_0_0 -> 964 in the cache */
   /* replace1593_2_0_1_0_1 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 964, 4347 },
      -1,
   } },
   /* replace1593_2_0_1_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 4418, 4346 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4345, 4419 },
      -1,
   } },
   /* replace1593_2_1_0 -> 964 in the cache */
   /* replace1593_2_1_1 -> 4347 in the cache */
   /* replace1593_2_1 -> 4418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 4420, 4418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4417, 135, 4421 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1594_0 -> 4345 in the cache */
   /* search1594_1 -> 4346 in the cache */
   /* search1594_2 -> 4347 in the cache */
   /* search1594 -> 4352 in the cache */

   /* replace1594_0_0 -> 4345 in the cache */
   /* replace1594_0_1 -> 4346 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 4345, 4346 },
      -1,
   } },
   /* replace1594_1_0_0 -> 4347 in the cache */
   /* replace1594_1_0_1 -> 964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 4347, 964 },
      -1,
   } },
   /* replace1594_1_1 -> 1017 in the cache */
   /* replace1594_1_2_0_0 -> 486 in the cache */
   /* replace1594_1_2_0_1 -> 4347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 486, 4347 },
      -1,
   } },
   /* replace1594_1_2_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 4425, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4424, 1017, 4426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4423, 4427 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1595_0 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 4345 },
      -1,
   } },

   /* replace1595_0_0_0 -> 4345 in the cache */
   /* replace1595_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4345, 135 },
      -1,
   } },
   /* replace1595_0_1_0 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 4345 },
      -1,
   } },
   /* replace1595_0_2 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4430, 4431, 4345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 4432 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1596_0 -> 4345 in the cache */
   /* search1596 -> 4429 in the cache */

   /* replace1596_0_0_0 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 4345 },
      -1,
   } },
   /* replace1596_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4434, 135 },
      -1,
   } },
   /* replace1596_1_0 -> 32 in the cache */
   /* replace1596_1_1_0 -> 4345 in the cache */
   /* replace1596_1_1 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 32, 4434 },
      -1,
   } },
   /* replace1596_2_0 -> 4345 in the cache */
   /* replace1596_2 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4435, 4436, 4434 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('isub', 31, ('uclz', ('ixor', 'value', ('ishr', 'value', 31)))) */
   /* search1597_0 -> 4345 in the cache */
   /* search1597 -> 4429 in the cache */

   /* replace1597_0 -> 32 in the cache */
   /* replace1597_1_0_0 -> 4345 in the cache */
   /* replace1597_1_0_1_0 -> 4345 in the cache */
   /* replace1597_1_0_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 4345, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4345, 4438 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uclz,
      -1, 1,
      { 4439 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 1,
      { 32, 4440 },
      -1,
   } },

   /* ('ufind_msb', 'value@32') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   /* search1598_0 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 4345 },
      -1,
   } },

   /* replace1598_0_0_0 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 4345 },
      -1,
   } },
   /* replace1598_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4443, 135 },
      -1,
   } },
   /* replace1598_1_0 -> 32 in the cache */
   /* replace1598_1_1_0 -> 4345 in the cache */
   /* replace1598_1_1 -> 4443 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 32, 4443 },
      -1,
   } },
   /* replace1598_2_0 -> 4345 in the cache */
   /* replace1598_2 -> 4443 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4444, 4445, 4443 },
      -1,
   } },

   /* ('ufind_msb', 'value@32') => ('isub', 31, ('uclz', 'value')) */
   /* search1599_0 -> 4345 in the cache */
   /* search1599 -> 4442 in the cache */

   /* replace1599_0 -> 32 in the cache */
   /* replace1599_1_0 -> 4345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uclz,
      -1, 0,
      { 4345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 32, 4447 },
      -1,
   } },

   /* ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a')) */
   /* search1600_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uclz,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace1600_0 -> 964 in the cache */
   /* replace1600_1_0 -> 29 in the cache */
   /* replace1600_1 -> 4155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 964, 4155 },
      -1,
   } },

   /* ('find_lsb', 'value@64') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 4451 },
      -1,
   } },

   /* replace1601_0_0 -> 4451 in the cache */
   /* replace1601_0_1_0 -> 4451 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4451, 4453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 4454 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('u2u32', ('iand', 'value', ('ineg', 'value')))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 4456 },
      -1,
   } },

   /* replace1602_0_0_0 -> 4456 in the cache */
   /* replace1602_0_0_1_0 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4456 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4456, 4458 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 1,
      { 4459 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 4460 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1603_0 -> 29 in the cache */
   /* search1603_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1603_0_0 -> 29 in the cache */
   /* replace1603_0_1_0_0 -> 495 in the cache */
   /* replace1603_0_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 495, 48 },
      -1,
   } },
   /* replace1603_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4463, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 29, 4464 },
      -1,
   } },
   /* replace1603_1 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 4465, 1102 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1604_0 -> 29 in the cache */
   /* search1604_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1604_0_0 -> 29 in the cache */
   /* replace1604_0_1_0 -> 48 in the cache */
   /* replace1604_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 48, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 29, 4468 },
      -1,
   } },
   /* replace1604_1 -> 1100 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4469, 1100 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1605_0 -> 29 in the cache */
   /* search1605_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1605_0_0 -> 29 in the cache */
   /* replace1605_0_1_0_0 -> 486 in the cache */
   /* replace1605_0_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 486, 48 },
      -1,
   } },
   /* replace1605_0_1_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4472, 943 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 29, 4473 },
      -1,
   } },
   /* replace1605_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 4474, 943 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1606_0 -> 29 in the cache */
   /* search1606_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1606_0_0 -> 29 in the cache */
   /* replace1606_0_1_0 -> 48 in the cache */
   /* replace1606_0_1_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 48, 943 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 29, 4477 },
      -1,
   } },
   /* replace1606_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4478, 1092 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 4480 },
      -1,
   } },

   /* replace1607_0_0_0_0_0 -> 4480 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 4480 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x40efffe000000000ull /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 4482, 4483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 4484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 4485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 4486 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 4488 },
      -1,
   } },

   /* replace1608_0_0_0_0_0 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 4488 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000ull /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 4490, 4491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 4492 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 4493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 4494 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_32_4x8', ('f2u8', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1609_0 -> 4488 in the cache */
   /* search1609 -> 4489 in the cache */

   /* replace1609_0_0_0_0_0 -> 4488 in the cache */
   /* replace1609_0_0_0_0 -> 4490 in the cache */
   /* replace1609_0_0_0_1 -> 4491 in the cache */
   /* replace1609_0_0_0 -> 4492 in the cache */
   /* replace1609_0_0 -> 4493 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u8,
      -1, 1,
      { 4493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 1,
      { 4496 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1610_0 -> 4480 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 4480 },
      -1,
   } },

   /* replace1610_0_0_0_0_0 -> 259 in the cache */
   /* replace1610_0_0_0_0_1_0 -> 265 in the cache */
   /* replace1610_0_0_0_0_1_1 -> 4480 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 265, 4480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 259, 4499 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x40dfffc000000000ull /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 4500, 4501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 4502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 4503 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 4504 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1611_0 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 4488 },
      -1,
   } },

   /* replace1611_0_0_0_0_0 -> 261 in the cache */
   /* replace1611_0_0_0_0_1_0 -> 291 in the cache */
   /* replace1611_0_0_0_0_1_1 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 291, 4488 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 261, 4507 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000ull /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 4508, 4509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 4510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 4511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 4512 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_32_4x8', ('f2i8', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1612_0 -> 4488 in the cache */
   /* search1612 -> 4506 in the cache */

   /* replace1612_0_0_0_0_0 -> 261 in the cache */
   /* replace1612_0_0_0_0_1_0 -> 291 in the cache */
   /* replace1612_0_0_0_0_1_1 -> 4488 in the cache */
   /* replace1612_0_0_0_0_1 -> 4507 in the cache */
   /* replace1612_0_0_0_0 -> 4508 in the cache */
   /* replace1612_0_0_0_1 -> 4509 in the cache */
   /* replace1612_0_0_0 -> 4510 in the cache */
   /* replace1612_0_0 -> 4511 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i8,
      -1, 3,
      { 4511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 3,
      { 4514 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1613_0 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 4488 },
      -1,
   } },

   /* replace1613_0_0_0_0 -> 4488 in the cache */
   /* replace1613_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 4488, 135 },
      -1,
   } },
   /* replace1613_0_0_1_0 -> 4488 in the cache */
   /* replace1613_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 4488, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4517, 4518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 4519 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000ull /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 4520, 4521 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1614_0 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 4488 },
      -1,
   } },

   /* replace1614_0_0_0_0 -> 4488 in the cache */
   /* replace1614_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 4488, 135 },
      -1,
   } },
   /* replace1614_0_0_1_0 -> 4488 in the cache */
   /* replace1614_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 4488, 486 },
      -1,
   } },
   /* replace1614_0_0_2_0 -> 4488 in the cache */
   /* replace1614_0_0_2_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 4488, 491 },
      -1,
   } },
   /* replace1614_0_0_3_0 -> 4488 in the cache */
   /* replace1614_0_0_3_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 4488, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4524, 4525, 4526, 4527 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 4528 },
      -1,
   } },
   /* replace1614_1 -> 4491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 4529, 4491 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1615_0 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 4488 },
      -1,
   } },

   /* replace1615_0 -> 261 in the cache */
   /* replace1615_1_0 -> 291 in the cache */
   /* replace1615_1_1_0_0_0_0 -> 4488 in the cache */
   /* replace1615_1_1_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 4488, 135 },
      -1,
   } },
   /* replace1615_1_1_0_0_1_0 -> 4488 in the cache */
   /* replace1615_1_1_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 4488, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4532, 4533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 4534 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000ull /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 4535, 4536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 291, 4537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 261, 4538 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1616_0 -> 4488 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 4488 },
      -1,
   } },

   /* replace1616_0 -> 261 in the cache */
   /* replace1616_1_0 -> 291 in the cache */
   /* replace1616_1_1_0_0_0_0 -> 4488 in the cache */
   /* replace1616_1_1_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 4488, 135 },
      -1,
   } },
   /* replace1616_1_1_0_0_1_0 -> 4488 in the cache */
   /* replace1616_1_1_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 4488, 486 },
      -1,
   } },
   /* replace1616_1_1_0_0_2_0 -> 4488 in the cache */
   /* replace1616_1_1_0_0_2_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 4488, 491 },
      -1,
   } },
   /* replace1616_1_1_0_0_3_0 -> 4488 in the cache */
   /* replace1616_1_1_0_0_3_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 4488, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4541, 4542, 4543, 4544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 4545 },
      -1,
   } },
   /* replace1616_1_1_1 -> 4509 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 4546, 4509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 291, 4547 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 261, 4548 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1617_0 -> 29 in the cache */
   /* search1617_1 -> 48 in the cache */
   /* search1617 -> 3756 in the cache */

   /* replace1617_0_0_0_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4550 },
      -1,
   } },
   /* replace1617_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4551, 943 },
      -1,
   } },
   /* replace1617_1_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4552, 4554 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1618_0 -> 29 in the cache */
   /* search1618 -> 3765 in the cache */

   /* replace1618_0_0 -> 29 in the cache */
   /* replace1618_0 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3761 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('fmul', 1.0, ('u2u16', 'a'))) */
   /* search1619_0 -> 29 in the cache */
   /* search1619 -> 3765 in the cache */

   /* replace1619_0_0 -> 569 in the cache */
   /* replace1619_0_1_0 -> 29 in the cache */
   /* replace1619_0_1 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 569, 3761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 4557 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1620_0 -> 29 in the cache */
   /* search1620 -> 3772 in the cache */

   /* replace1620_0_0_0 -> 29 in the cache */
   /* replace1620_0_0_1 -> 943 in the cache */
   /* replace1620_0_0 -> 1098 in the cache */
   /* replace1620_0 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3762 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('fmul', 1.0, ('u2u16', ('ushr', 'a', 16)))) */
   /* search1621_0 -> 29 in the cache */
   /* search1621 -> 3772 in the cache */

   /* replace1621_0_0 -> 569 in the cache */
   /* replace1621_0_1_0_0 -> 29 in the cache */
   /* replace1621_0_1_0_1 -> 943 in the cache */
   /* replace1621_0_1_0 -> 1098 in the cache */
   /* replace1621_0_1 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 569, 3762 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 4560 },
      -1,
   } },

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1622_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace1622_0_0 -> 9 in the cache */
   /* replace1622_0_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 9, 75 },
      -1,
   } },
   /* replace1622_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 4563, 47 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1623_0_0 -> 9 in the cache */
   /* search1623_0_1 -> 75 in the cache */
   /* search1623_0 -> 4563 in the cache */
   /* search1623_1 -> 47 in the cache */
   /* search1623 -> 4564 in the cache */

   /* replace1623_0 -> 9 in the cache */
   /* replace1623 -> 4562 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1624_0_0 -> 9 in the cache */
   /* search1624_0_1 -> 47 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 9, 47 },
      -1,
   } },
   /* search1624_1 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 4565, 75 },
      -1,
   } },

   /* replace1624_0 -> 9 in the cache */
   /* replace1624 -> 4562 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1625_0 -> 9 in the cache */
   /* search1625 -> 110 in the cache */

   /* replace1625_0_0_0 -> 8 in the cache */
   /* replace1625_0_0_1 -> 9 in the cache */
   /* replace1625_0_0 -> 1630 in the cache */
   /* replace1625_0 -> 1631 in the cache */
   /* replace1625_1_0_0 -> 9 in the cache */
   /* replace1625_1_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 8 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 4567 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1631, 4568 },
      -1,
   } },

   /* ('fsign', 'a@64') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1626_0 -> 34 in the cache */
   /* search1626 -> 2117 in the cache */

   /* replace1626_0_0_0 -> 788 in the cache */
   /* replace1626_0_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 788, 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 4570 },
      -1,
   } },
   /* replace1626_1_0_0 -> 34 in the cache */
   /* replace1626_1_0_1 -> 788 in the cache */
   /* replace1626_1_0 -> 2095 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 2095 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 4571, 4572 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1627_0 -> 0 in the cache */
   /* search1627_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1627_0 -> 0 in the cache */
   /* replace1627_1 -> 1 in the cache */
   /* replace1627 -> 1041 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1628_0 -> 29 in the cache */
   /* search1628_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace1628_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffull /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 29, 4576 },
      -1,
   } },
   /* replace1628_1_0 -> 48 in the cache */
   /* replace1628_1_1 -> 4576 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 48, 4576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 4577, 4578 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1629_0 -> 29 in the cache */
   /* search1629_1 -> 48 in the cache */
   /* search1629_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace1629_0_0_0 -> 29 in the cache */
   /* replace1629_0_0_1 -> 4576 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 29, 4576 },
      -1,
   } },
   /* replace1629_0_1_0 -> 48 in the cache */
   /* replace1629_0_1_1 -> 4576 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 48, 4576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 4581, 4582 },
      -1,
   } },
   /* replace1629_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 4583, 148 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1630_0 -> 29 in the cache */
   /* search1630_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace1630_0 -> 29 in the cache */
   /* replace1630_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1631_0 -> 29 in the cache */
   /* search1631_1 -> 48 in the cache */
   /* search1631 -> 4585 in the cache */

   /* replace1631_0 -> 29 in the cache */
   /* replace1631_1 -> 48 in the cache */
   /* replace1631 -> 61 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1632_0 -> 29 in the cache */
   /* search1632_1 -> 48 in the cache */
   /* search1632_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 29, 48, 148 },
      -1,
   } },

   /* replace1632_0 -> 29 in the cache */
   /* replace1632_1 -> 48 in the cache */
   /* replace1632_2 -> 148 in the cache */
   /* replace1632 -> 4580 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1633_0 -> 29 in the cache */
   /* search1633_1 -> 48 in the cache */
   /* search1633_2 -> 148 in the cache */
   /* search1633 -> 4587 in the cache */

   /* replace1633_0_0 -> 29 in the cache */
   /* replace1633_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace1633_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 4588, 148 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1634_0 -> 29 in the cache */
   /* search1634_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace1634_0 -> 29 in the cache */
   /* replace1634_1 -> 48 in the cache */
   /* replace1634 -> 4575 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1635_0 -> 29 in the cache */
   /* search1635_1 -> 48 in the cache */
   /* search1635 -> 4590 in the cache */

   /* replace1635_0 -> 29 in the cache */
   /* replace1635_1 -> 48 in the cache */
   /* replace1635 -> 61 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1636_0 -> 29 in the cache */
   /* search1636_1 -> 48 in the cache */
   /* search1636_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 29, 48, 135 },
      -1,
   } },

   /* replace1636_0 -> 29 in the cache */
   /* replace1636_1 -> 48 in the cache */
   /* replace1636 -> 4586 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1637_0 -> 29 in the cache */
   /* search1637_1 -> 135 in the cache */
   /* search1637_2 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 29, 135, 643 },
      -1,
   } },

   /* replace1637 -> 643 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1638_0 -> 29 in the cache */
   /* search1638_1 -> 486 in the cache */
   /* search1638_2 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 29, 486, 643 },
      -1,
   } },

   /* replace1638_0 -> 29 in the cache */
   /* replace1638_1 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 29, 643 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1639_0 -> 299 in the cache */
   /* search1639_1 -> 45 in the cache */
   /* search1639_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 299, 45, 148 },
      -1,
   } },

   /* replace1639_0_0 -> 29 in the cache */
   /* replace1639_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* replace1639_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 4596, 148 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1640_0 -> 29 in the cache */
   /* search1640_1 -> 2610 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 29, 2610 },
      -1,
   } },

   /* replace1640_0 -> 29 in the cache */
   /* replace1640_1_0 -> 48 in the cache */
   /* replace1640_1 -> 2616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 2616 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1641_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 29, 4600 },
      -1,
   } },

   /* replace1641_0_0 -> 29 in the cache */
   /* replace1641_0_1_0_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 4602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 4603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4604 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1642_0 -> 29 in the cache */
   /* search1642_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 29, 135 },
      -1,
   } },

   /* replace1642 -> 135 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1643_0_0_0 -> 19 in the cache */
   /* search1643_0_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 19, 2370 },
      -1,
   } },
   /* search1643_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4607, 19 },
      -1,
   } },
   /* search1643_1 -> 1539 in the cache */
   /* search1643_2_0 -> 19 in the cache */
   /* search1643_2_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4608, 1539, 4609 },
      -1,
   } },

   /* replace1643_0 -> 19 in the cache */
   /* replace1643_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 19, 2370 },
      -1,
   } },

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1644_0_0_0 -> 19 in the cache */
   /* search1644_0_0_1 -> 2370 in the cache */
   /* search1644_0_0 -> 4607 in the cache */
   /* search1644_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4607, 19 },
      -1,
   } },
   /* search1644_1_0 -> 19 in the cache */
   /* search1644_1_1 -> 2370 in the cache */
   /* search1644_1 -> 4609 in the cache */
   /* search1644_2 -> 1539 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4612, 4609, 1539 },
      -1,
   } },

   /* replace1644_0 -> 19 in the cache */
   /* replace1644_1 -> 2370 in the cache */
   /* replace1644 -> 4611 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1645_0_0_0 -> 19 in the cache */
   /* search1645_0_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 19, 2370 },
      -1,
   } },
   /* search1645_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4614, 925 },
      -1,
   } },
   /* search1645_1_0 -> 19 in the cache */
   /* search1645_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 19, 2370 },
      -1,
   } },
   /* search1645_2 -> 1539 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4615, 4616, 1539 },
      -1,
   } },

   /* replace1645_0 -> 19 in the cache */
   /* replace1645_1 -> 2370 in the cache */
   /* replace1645 -> 4611 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1646_0_0_0 -> 19 in the cache */
   /* search1646_0_0_1 -> 2370 in the cache */
   /* search1646_0_0 -> 4614 in the cache */
   /* search1646_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4614, 925 },
      -1,
   } },
   /* search1646_1 -> 1539 in the cache */
   /* search1646_2_0 -> 19 in the cache */
   /* search1646_2_1 -> 2370 in the cache */
   /* search1646_2 -> 4616 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4618, 1539, 4616 },
      -1,
   } },

   /* replace1646_0 -> 19 in the cache */
   /* replace1646_1 -> 2370 in the cache */
   /* replace1646 -> 4611 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1647_0_0_0 -> 24 in the cache */
   /* search1647_0_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 24, 551 },
      -1,
   } },
   /* search1647_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4620, 24 },
      -1,
   } },
   /* search1647_1 -> 1561 in the cache */
   /* search1647_2_0 -> 24 in the cache */
   /* search1647_2_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 24, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4621, 1561, 4622 },
      -1,
   } },

   /* replace1647_0 -> 24 in the cache */
   /* replace1647_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1648_0_0_0 -> 24 in the cache */
   /* search1648_0_0_1 -> 551 in the cache */
   /* search1648_0_0 -> 4620 in the cache */
   /* search1648_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4620, 24 },
      -1,
   } },
   /* search1648_1_0 -> 24 in the cache */
   /* search1648_1_1 -> 551 in the cache */
   /* search1648_1 -> 4622 in the cache */
   /* search1648_2 -> 1561 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4625, 4622, 1561 },
      -1,
   } },

   /* replace1648_0 -> 24 in the cache */
   /* replace1648_1 -> 551 in the cache */
   /* replace1648 -> 4624 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1649_0_0_0 -> 24 in the cache */
   /* search1649_0_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 24, 551 },
      -1,
   } },
   /* search1649_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4627, 946 },
      -1,
   } },
   /* search1649_1_0 -> 24 in the cache */
   /* search1649_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 24, 551 },
      -1,
   } },
   /* search1649_2 -> 1561 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4628, 4629, 1561 },
      -1,
   } },

   /* replace1649_0 -> 24 in the cache */
   /* replace1649_1 -> 551 in the cache */
   /* replace1649 -> 4624 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1650_0_0_0 -> 24 in the cache */
   /* search1650_0_0_1 -> 551 in the cache */
   /* search1650_0_0 -> 4627 in the cache */
   /* search1650_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4627, 946 },
      -1,
   } },
   /* search1650_1 -> 1561 in the cache */
   /* search1650_2_0 -> 24 in the cache */
   /* search1650_2_1 -> 551 in the cache */
   /* search1650_2 -> 4629 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4631, 1561, 4629 },
      -1,
   } },

   /* replace1650_0 -> 24 in the cache */
   /* replace1650_1 -> 551 in the cache */
   /* replace1650 -> 4624 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1651_0_0_0 -> 29 in the cache */
   /* search1651_0_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 29, 48 },
      -1,
   } },
   /* search1651_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4633, 29 },
      -1,
   } },
   /* search1651_1 -> 137 in the cache */
   /* search1651_2_0 -> 29 in the cache */
   /* search1651_2_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4634, 137, 4635 },
      -1,
   } },

   /* replace1651_0 -> 29 in the cache */
   /* replace1651_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1652_0_0_0 -> 29 in the cache */
   /* search1652_0_0_1 -> 48 in the cache */
   /* search1652_0_0 -> 4633 in the cache */
   /* search1652_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4633, 29 },
      -1,
   } },
   /* search1652_1_0 -> 29 in the cache */
   /* search1652_1_1 -> 48 in the cache */
   /* search1652_1 -> 4635 in the cache */
   /* search1652_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4638, 4635, 137 },
      -1,
   } },

   /* replace1652_0 -> 29 in the cache */
   /* replace1652_1 -> 48 in the cache */
   /* replace1652 -> 4637 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1653_0_0_0 -> 29 in the cache */
   /* search1653_0_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 29, 48 },
      -1,
   } },
   /* search1653_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4640, 135 },
      -1,
   } },
   /* search1653_1_0 -> 29 in the cache */
   /* search1653_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 29, 48 },
      -1,
   } },
   /* search1653_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4641, 4642, 137 },
      -1,
   } },

   /* replace1653_0 -> 29 in the cache */
   /* replace1653_1 -> 48 in the cache */
   /* replace1653 -> 4637 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1654_0_0_0 -> 29 in the cache */
   /* search1654_0_0_1 -> 48 in the cache */
   /* search1654_0_0 -> 4640 in the cache */
   /* search1654_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4640, 135 },
      -1,
   } },
   /* search1654_1 -> 137 in the cache */
   /* search1654_2_0 -> 29 in the cache */
   /* search1654_2_1 -> 48 in the cache */
   /* search1654_2 -> 4642 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4644, 137, 4642 },
      -1,
   } },

   /* replace1654_0 -> 29 in the cache */
   /* replace1654_1 -> 48 in the cache */
   /* replace1654 -> 4637 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1655_0_0_0 -> 34 in the cache */
   /* search1655_0_0_1 -> 53 in the cache */
   /* search1655_0_0 -> 4279 in the cache */
   /* search1655_0_1 -> 34 in the cache */
   /* search1655_0 -> 4280 in the cache */
   /* search1655_1 -> 1603 in the cache */
   /* search1655_2_0 -> 34 in the cache */
   /* search1655_2_1 -> 53 in the cache */
   /* search1655_2 -> 4281 in the cache */
   /* search1655 -> 4282 in the cache */

   /* replace1655_0 -> 34 in the cache */
   /* replace1655_1 -> 53 in the cache */
   /* replace1655 -> 4278 in the cache */

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1656_0_0_0 -> 34 in the cache */
   /* search1656_0_0_1 -> 53 in the cache */
   /* search1656_0_0 -> 4279 in the cache */
   /* search1656_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4279, 34 },
      -1,
   } },
   /* search1656_1_0 -> 34 in the cache */
   /* search1656_1_1 -> 53 in the cache */
   /* search1656_1 -> 4281 in the cache */
   /* search1656_2 -> 1603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4646, 4281, 1603 },
      -1,
   } },

   /* replace1656_0 -> 34 in the cache */
   /* replace1656_1 -> 53 in the cache */
   /* replace1656 -> 4278 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1657_0_0_0 -> 34 in the cache */
   /* search1657_0_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 34, 53 },
      -1,
   } },
   /* search1657_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4648, 987 },
      -1,
   } },
   /* search1657_1_0 -> 34 in the cache */
   /* search1657_1_1 -> 53 in the cache */
   /* search1657_1 -> 4294 in the cache */
   /* search1657_2 -> 1603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4649, 4294, 1603 },
      -1,
   } },

   /* replace1657_0 -> 34 in the cache */
   /* replace1657_1 -> 53 in the cache */
   /* replace1657 -> 4278 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1658_0_0_0 -> 34 in the cache */
   /* search1658_0_0_1 -> 53 in the cache */
   /* search1658_0_0 -> 4648 in the cache */
   /* search1658_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4648, 987 },
      -1,
   } },
   /* search1658_1 -> 1603 in the cache */
   /* search1658_2_0 -> 34 in the cache */
   /* search1658_2_1 -> 53 in the cache */
   /* search1658_2 -> 4294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4651, 1603, 4294 },
      -1,
   } },

   /* replace1658_0 -> 34 in the cache */
   /* replace1658_1 -> 53 in the cache */
   /* replace1658 -> 4278 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1659_0_0 -> 19 in the cache */
   /* search1659_0_1 -> 2370 in the cache */
   /* search1659_0 -> 2392 in the cache */
   /* search1659_1 -> 925 in the cache */
   /* search1659_2_0 -> 19 in the cache */
   /* search1659_2_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 19, 4653 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2392, 925, 4654 },
      -1,
   } },

   /* replace1659_0 -> 19 in the cache */
   /* replace1659_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 19, 2370 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1660_0_0 -> 19 in the cache */
   /* search1660_0_1 -> 2370 in the cache */
   /* search1660_0 -> 2395 in the cache */
   /* search1660_1_0 -> 19 in the cache */
   /* search1660_1_1_0 -> 2370 in the cache */
   /* search1660_1_1 -> 4653 in the cache */
   /* search1660_1 -> 4654 in the cache */
   /* search1660_2 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2395, 4654, 925 },
      -1,
   } },

   /* replace1660_0 -> 19 in the cache */
   /* replace1660_1 -> 2370 in the cache */
   /* replace1660 -> 4656 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1661_0_0_0 -> 19 in the cache */
   /* search1661_0_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 19, 2370 },
      -1,
   } },
   /* search1661_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4658, 925 },
      -1,
   } },
   /* search1661_1_0 -> 19 in the cache */
   /* search1661_1_1_0 -> 2370 in the cache */
   /* search1661_1_1 -> 4653 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 4653 },
      -1,
   } },
   /* search1661_2 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4659, 4660, 925 },
      -1,
   } },

   /* replace1661_0 -> 19 in the cache */
   /* replace1661_1 -> 2370 in the cache */
   /* replace1661 -> 4656 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1662_0_0_0 -> 19 in the cache */
   /* search1662_0_0_1 -> 2370 in the cache */
   /* search1662_0_0 -> 4658 in the cache */
   /* search1662_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4658, 925 },
      -1,
   } },
   /* search1662_1 -> 925 in the cache */
   /* search1662_2_0 -> 19 in the cache */
   /* search1662_2_1_0 -> 2370 in the cache */
   /* search1662_2_1 -> 4653 in the cache */
   /* search1662_2 -> 4660 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4662, 925, 4660 },
      -1,
   } },

   /* replace1662_0 -> 19 in the cache */
   /* replace1662_1 -> 2370 in the cache */
   /* replace1662 -> 4656 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1663_0_0 -> 24 in the cache */
   /* search1663_0_1 -> 551 in the cache */
   /* search1663_0 -> 2447 in the cache */
   /* search1663_1 -> 946 in the cache */
   /* search1663_2_0 -> 24 in the cache */
   /* search1663_2_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 24, 4664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2447, 946, 4665 },
      -1,
   } },

   /* replace1663_0 -> 24 in the cache */
   /* replace1663_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 24, 551 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1664_0_0 -> 24 in the cache */
   /* search1664_0_1 -> 551 in the cache */
   /* search1664_0 -> 2450 in the cache */
   /* search1664_1_0 -> 24 in the cache */
   /* search1664_1_1_0 -> 551 in the cache */
   /* search1664_1_1 -> 4664 in the cache */
   /* search1664_1 -> 4665 in the cache */
   /* search1664_2 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2450, 4665, 946 },
      -1,
   } },

   /* replace1664_0 -> 24 in the cache */
   /* replace1664_1 -> 551 in the cache */
   /* replace1664 -> 4667 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1665_0_0_0 -> 24 in the cache */
   /* search1665_0_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* search1665_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4669, 946 },
      -1,
   } },
   /* search1665_1_0 -> 24 in the cache */
   /* search1665_1_1_0 -> 551 in the cache */
   /* search1665_1_1 -> 4664 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 24, 4664 },
      -1,
   } },
   /* search1665_2 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4670, 4671, 946 },
      -1,
   } },

   /* replace1665_0 -> 24 in the cache */
   /* replace1665_1 -> 551 in the cache */
   /* replace1665 -> 4667 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1666_0_0_0 -> 24 in the cache */
   /* search1666_0_0_1 -> 551 in the cache */
   /* search1666_0_0 -> 4669 in the cache */
   /* search1666_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4669, 946 },
      -1,
   } },
   /* search1666_1 -> 946 in the cache */
   /* search1666_2_0 -> 24 in the cache */
   /* search1666_2_1_0 -> 551 in the cache */
   /* search1666_2_1 -> 4664 in the cache */
   /* search1666_2 -> 4671 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4673, 946, 4671 },
      -1,
   } },

   /* replace1666_0 -> 24 in the cache */
   /* replace1666_1 -> 551 in the cache */
   /* replace1666 -> 4667 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1667_0_0 -> 29 in the cache */
   /* search1667_0_1 -> 48 in the cache */
   /* search1667_0 -> 2501 in the cache */
   /* search1667_1 -> 135 in the cache */
   /* search1667_2_0 -> 29 in the cache */
   /* search1667_2_1_0 -> 48 in the cache */
   /* search1667_2_1 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 29, 3128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2501, 135, 4675 },
      -1,
   } },

   /* replace1667_0 -> 29 in the cache */
   /* replace1667_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1668_0_0 -> 29 in the cache */
   /* search1668_0_1 -> 48 in the cache */
   /* search1668_0 -> 2504 in the cache */
   /* search1668_1_0 -> 29 in the cache */
   /* search1668_1_1_0 -> 48 in the cache */
   /* search1668_1_1 -> 3128 in the cache */
   /* search1668_1 -> 4675 in the cache */
   /* search1668_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2504, 4675, 135 },
      -1,
   } },

   /* replace1668_0 -> 29 in the cache */
   /* replace1668_1 -> 48 in the cache */
   /* replace1668 -> 4677 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1669_0_0_0 -> 29 in the cache */
   /* search1669_0_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   /* search1669_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4679, 135 },
      -1,
   } },
   /* search1669_1_0 -> 29 in the cache */
   /* search1669_1_1_0 -> 48 in the cache */
   /* search1669_1_1 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 29, 3128 },
      -1,
   } },
   /* search1669_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4680, 4681, 135 },
      -1,
   } },

   /* replace1669_0 -> 29 in the cache */
   /* replace1669_1 -> 48 in the cache */
   /* replace1669 -> 4677 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1670_0_0_0 -> 29 in the cache */
   /* search1670_0_0_1 -> 48 in the cache */
   /* search1670_0_0 -> 4679 in the cache */
   /* search1670_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4679, 135 },
      -1,
   } },
   /* search1670_1 -> 135 in the cache */
   /* search1670_2_0 -> 29 in the cache */
   /* search1670_2_1_0 -> 48 in the cache */
   /* search1670_2_1 -> 3128 in the cache */
   /* search1670_2 -> 4681 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4683, 135, 4681 },
      -1,
   } },

   /* replace1670_0 -> 29 in the cache */
   /* replace1670_1 -> 48 in the cache */
   /* replace1670 -> 4677 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1671_0_0 -> 34 in the cache */
   /* search1671_0_1 -> 53 in the cache */
   /* search1671_0 -> 2555 in the cache */
   /* search1671_1 -> 987 in the cache */
   /* search1671_2_0 -> 34 in the cache */
   /* search1671_2_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 34, 4685 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2555, 987, 4686 },
      -1,
   } },

   /* replace1671_0 -> 34 in the cache */
   /* replace1671_1 -> 53 in the cache */
   /* replace1671 -> 4288 in the cache */

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1672_0_0 -> 34 in the cache */
   /* search1672_0_1 -> 53 in the cache */
   /* search1672_0 -> 2558 in the cache */
   /* search1672_1_0 -> 34 in the cache */
   /* search1672_1_1_0 -> 53 in the cache */
   /* search1672_1_1 -> 4685 in the cache */
   /* search1672_1 -> 4686 in the cache */
   /* search1672_2 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 2558, 4686, 987 },
      -1,
   } },

   /* replace1672_0 -> 34 in the cache */
   /* replace1672_1 -> 53 in the cache */
   /* replace1672 -> 4288 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1673_0_0_0 -> 34 in the cache */
   /* search1673_0_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 34, 53 },
      -1,
   } },
   /* search1673_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4689, 987 },
      -1,
   } },
   /* search1673_1_0 -> 34 in the cache */
   /* search1673_1_1_0 -> 53 in the cache */
   /* search1673_1_1 -> 4685 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 34, 4685 },
      -1,
   } },
   /* search1673_2 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4690, 4691, 987 },
      -1,
   } },

   /* replace1673_0 -> 34 in the cache */
   /* replace1673_1 -> 53 in the cache */
   /* replace1673 -> 4288 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1674_0_0_0 -> 34 in the cache */
   /* search1674_0_0_1 -> 53 in the cache */
   /* search1674_0_0 -> 4689 in the cache */
   /* search1674_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4689, 987 },
      -1,
   } },
   /* search1674_1 -> 987 in the cache */
   /* search1674_2_0 -> 34 in the cache */
   /* search1674_2_1_0 -> 53 in the cache */
   /* search1674_2_1 -> 4685 in the cache */
   /* search1674_2 -> 4691 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4693, 987, 4691 },
      -1,
   } },

   /* replace1674_0 -> 34 in the cache */
   /* replace1674_1 -> 53 in the cache */
   /* replace1674 -> 4288 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1675_0 -> 19 in the cache */
   /* search1675_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 19, 2370 },
      -1,
   } },

   /* replace1675_0_0 -> 2370 in the cache */
   /* replace1675_0_1 -> 1534 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2370, 1534 },
      -1,
   } },
   /* replace1675_1_0_0_0 -> 19 in the cache */
   /* replace1675_1_0_0_1 -> 2370 in the cache */
   /* replace1675_1_0_0 -> 4607 in the cache */
   /* replace1675_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4607, 19 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7full /* 127 */ },
   } },
   /* replace1675_1_2_0 -> 19 in the cache */
   /* replace1675_1_2_1 -> 2370 in the cache */
   /* replace1675_1_2 -> 4609 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4697, 4698, 4609 },
      -1,
   } },
   /* replace1675_2_0_0 -> 19 in the cache */
   /* replace1675_2_0_1_0 -> 19 in the cache */
   /* replace1675_2_0_1_1 -> 2370 in the cache */
   /* replace1675_2_0_1 -> 4616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 19, 4616 },
      -1,
   } },
   /* replace1675_2_1 -> 20 in the cache */
   /* replace1675_2_2_0 -> 19 in the cache */
   /* replace1675_2_2_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 19, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4700, 20, 4701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4696, 4699, 4702 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1676_0 -> 19 in the cache */
   /* search1676_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 19, 2370 },
      -1,
   } },

   /* replace1676_0_0 -> 2370 in the cache */
   /* replace1676_0_1 -> 925 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2370, 925 },
      -1,
   } },
   /* replace1676_1_0_0_0 -> 19 in the cache */
   /* replace1676_1_0_0_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 2370 },
      -1,
   } },
   /* replace1676_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4706, 19 },
      -1,
   } },
   /* replace1676_1_1 -> 4698 in the cache */
   /* replace1676_1_2_0 -> 19 in the cache */
   /* replace1676_1_2_1 -> 2370 in the cache */
   /* replace1676_1_2 -> 4706 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4707, 4698, 4706 },
      -1,
   } },
   /* replace1676_2_0_0 -> 19 in the cache */
   /* replace1676_2_0_1_0 -> 19 in the cache */
   /* replace1676_2_0_1_1 -> 2370 in the cache */
   /* replace1676_2_0_1 -> 4706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 4706 },
      -1,
   } },
   /* replace1676_2_1 -> 20 in the cache */
   /* replace1676_2_2_0 -> 19 in the cache */
   /* replace1676_2_2_1 -> 2370 in the cache */
   /* replace1676_2_2 -> 4706 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4709, 20, 4706 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4705, 4708, 4710 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1677_0 -> 24 in the cache */
   /* search1677_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* replace1677_0_0 -> 551 in the cache */
   /* replace1677_0_1 -> 1556 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 551, 1556 },
      -1,
   } },
   /* replace1677_1_0_0_0 -> 24 in the cache */
   /* replace1677_1_0_0_1 -> 551 in the cache */
   /* replace1677_1_0_0 -> 4620 in the cache */
   /* replace1677_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4620, 24 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fffull /* 32767 */ },
   } },
   /* replace1677_1_2_0 -> 24 in the cache */
   /* replace1677_1_2_1 -> 551 in the cache */
   /* replace1677_1_2 -> 4622 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4714, 4715, 4622 },
      -1,
   } },
   /* replace1677_2_0_0 -> 24 in the cache */
   /* replace1677_2_0_1_0 -> 24 in the cache */
   /* replace1677_2_0_1_1 -> 551 in the cache */
   /* replace1677_2_0_1 -> 4629 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 24, 4629 },
      -1,
   } },
   /* replace1677_2_1 -> 25 in the cache */
   /* replace1677_2_2_0 -> 24 in the cache */
   /* replace1677_2_2_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 24, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4717, 25, 4718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4713, 4716, 4719 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1678_0 -> 24 in the cache */
   /* search1678_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 24, 551 },
      -1,
   } },

   /* replace1678_0_0 -> 551 in the cache */
   /* replace1678_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 551, 946 },
      -1,
   } },
   /* replace1678_1_0_0_0 -> 24 in the cache */
   /* replace1678_1_0_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 24, 551 },
      -1,
   } },
   /* replace1678_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4723, 24 },
      -1,
   } },
   /* replace1678_1_1 -> 4715 in the cache */
   /* replace1678_1_2_0 -> 24 in the cache */
   /* replace1678_1_2_1 -> 551 in the cache */
   /* replace1678_1_2 -> 4723 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4724, 4715, 4723 },
      -1,
   } },
   /* replace1678_2_0_0 -> 24 in the cache */
   /* replace1678_2_0_1_0 -> 24 in the cache */
   /* replace1678_2_0_1_1 -> 551 in the cache */
   /* replace1678_2_0_1 -> 4723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 4723 },
      -1,
   } },
   /* replace1678_2_1 -> 25 in the cache */
   /* replace1678_2_2_0 -> 24 in the cache */
   /* replace1678_2_2_1 -> 551 in the cache */
   /* replace1678_2_2 -> 4723 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4726, 25, 4723 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4722, 4725, 4727 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1679_0 -> 29 in the cache */
   /* search1679_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 29, 48 },
      -1,
   } },

   /* replace1679_0_0 -> 48 in the cache */
   /* replace1679_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 48, 486 },
      -1,
   } },
   /* replace1679_1_0_0_0 -> 29 in the cache */
   /* replace1679_1_0_0_1 -> 48 in the cache */
   /* replace1679_1_0_0 -> 4633 in the cache */
   /* replace1679_1_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4633, 29 },
      -1,
   } },
   /* replace1679_1_1 -> 1078 in the cache */
   /* replace1679_1_2_0 -> 29 in the cache */
   /* replace1679_1_2_1 -> 48 in the cache */
   /* replace1679_1_2 -> 4635 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4731, 1078, 4635 },
      -1,
   } },
   /* replace1679_2_0_0 -> 29 in the cache */
   /* replace1679_2_0_1_0 -> 29 in the cache */
   /* replace1679_2_0_1_1 -> 48 in the cache */
   /* replace1679_2_0_1 -> 4642 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 29, 4642 },
      -1,
   } },
   /* replace1679_2_1 -> 30 in the cache */
   /* replace1679_2_2_0 -> 29 in the cache */
   /* replace1679_2_2_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 29, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4733, 30, 4734 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4730, 4732, 4735 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1680_0 -> 29 in the cache */
   /* search1680_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 29, 48 },
      -1,
   } },

   /* replace1680_0_0 -> 48 in the cache */
   /* replace1680_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 48, 135 },
      -1,
   } },
   /* replace1680_1_0_0_0 -> 29 in the cache */
   /* replace1680_1_0_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 29, 48 },
      -1,
   } },
   /* replace1680_1_0_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4739, 29 },
      -1,
   } },
   /* replace1680_1_1 -> 1078 in the cache */
   /* replace1680_1_2_0 -> 29 in the cache */
   /* replace1680_1_2_1 -> 48 in the cache */
   /* replace1680_1_2 -> 4739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4740, 1078, 4739 },
      -1,
   } },
   /* replace1680_2_0_0 -> 29 in the cache */
   /* replace1680_2_0_1_0 -> 29 in the cache */
   /* replace1680_2_0_1_1 -> 48 in the cache */
   /* replace1680_2_0_1 -> 4739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 4739 },
      -1,
   } },
   /* replace1680_2_1 -> 30 in the cache */
   /* replace1680_2_2_0 -> 29 in the cache */
   /* replace1680_2_2_1 -> 48 in the cache */
   /* replace1680_2_2 -> 4739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4742, 30, 4739 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4738, 4741, 4743 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1681_0 -> 34 in the cache */
   /* search1681_1 -> 53 in the cache */
   /* search1681 -> 4291 in the cache */

   /* replace1681_0_0 -> 53 in the cache */
   /* replace1681_0_1 -> 1598 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 53, 1598 },
      -1,
   } },
   /* replace1681_1_0_0_0 -> 34 in the cache */
   /* replace1681_1_0_0_1 -> 53 in the cache */
   /* replace1681_1_0_0 -> 4279 in the cache */
   /* replace1681_1_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4279, 34 },
      -1,
   } },
   /* replace1681_1_1 -> 4302 in the cache */
   /* replace1681_1_2_0 -> 34 in the cache */
   /* replace1681_1_2_1 -> 53 in the cache */
   /* replace1681_1_2 -> 4281 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4746, 4302, 4281 },
      -1,
   } },
   /* replace1681_2_0_0 -> 34 in the cache */
   /* replace1681_2_0_1_0 -> 34 in the cache */
   /* replace1681_2_0_1_1 -> 53 in the cache */
   /* replace1681_2_0_1 -> 4294 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 34, 4294 },
      -1,
   } },
   /* replace1681_2_1 -> 35 in the cache */
   /* replace1681_2_2_0 -> 34 in the cache */
   /* replace1681_2_2_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 34, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4748, 35, 4749 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4745, 4747, 4750 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1682_0 -> 34 in the cache */
   /* search1682_1 -> 53 in the cache */
   /* search1682 -> 4305 in the cache */

   /* replace1682_0_0 -> 53 in the cache */
   /* replace1682_0_1 -> 987 in the cache */
   /* replace1682_0 -> 4292 in the cache */
   /* replace1682_1_0_0_0 -> 34 in the cache */
   /* replace1682_1_0_0_1 -> 53 in the cache */
   /* replace1682_1_0_0 -> 4289 in the cache */
   /* replace1682_1_0_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4289, 34 },
      -1,
   } },
   /* replace1682_1_1 -> 4302 in the cache */
   /* replace1682_1_2_0 -> 34 in the cache */
   /* replace1682_1_2_1 -> 53 in the cache */
   /* replace1682_1_2 -> 4289 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4752, 4302, 4289 },
      -1,
   } },
   /* replace1682_2_0_0 -> 34 in the cache */
   /* replace1682_2_0_1_0 -> 34 in the cache */
   /* replace1682_2_0_1_1 -> 53 in the cache */
   /* replace1682_2_0_1 -> 4289 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 4289 },
      -1,
   } },
   /* replace1682_2_1 -> 35 in the cache */
   /* replace1682_2_2_0 -> 34 in the cache */
   /* replace1682_2_2_1 -> 53 in the cache */
   /* replace1682_2_2 -> 4289 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4754, 35, 4289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4292, 4753, 4755 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1683_0_0_0 -> 0 in the cache */
   /* search1683_0_0_1 -> 1 in the cache */
   /* search1683_0_0 -> 1162 in the cache */
   /* search1683_0_1_0 -> 165 in the cache */
   /* search1683_0_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1162, 4757 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4758 },
      -1,
   } },

   /* replace1683_0_0 -> 0 in the cache */
   /* replace1683_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* replace1683_1_0 -> 165 in the cache */
   /* replace1683_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4760, 4761 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1684_0_0_0 -> 0 in the cache */
   /* search1684_0_0_1 -> 1 in the cache */
   /* search1684_0_0 -> 1162 in the cache */
   /* search1684_0_1_0 -> 165 in the cache */
   /* search1684_0_1_1 -> 166 in the cache */
   /* search1684_0_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1162, 4757 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4763 },
      -1,
   } },

   /* replace1684_0_0 -> 0 in the cache */
   /* replace1684_0_1 -> 1 in the cache */
   /* replace1684_0 -> 4760 in the cache */
   /* replace1684_1_0 -> 165 in the cache */
   /* replace1684_1_1 -> 166 in the cache */
   /* replace1684_1 -> 4761 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4760, 4761 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1685_0_0_0 -> 0 in the cache */
   /* search1685_0_0_1 -> 1 in the cache */
   /* search1685_0_0 -> 1162 in the cache */
   /* search1685_0_1_0 -> 165 in the cache */
   /* search1685_0_1_1 -> 166 in the cache */
   /* search1685_0_1 -> 4761 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1162, 4761 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4766 },
      -1,
   } },

   /* replace1685_0_0 -> 0 in the cache */
   /* replace1685_0_1 -> 1 in the cache */
   /* replace1685_0 -> 4760 in the cache */
   /* replace1685_1_0 -> 165 in the cache */
   /* replace1685_1_1 -> 166 in the cache */
   /* replace1685_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4760, 4757 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1686_0_0_0 -> 0 in the cache */
   /* search1686_0_0_1 -> 1 in the cache */
   /* search1686_0_0 -> 1162 in the cache */
   /* search1686_0_1_0 -> 165 in the cache */
   /* search1686_0_1_1 -> 166 in the cache */
   /* search1686_0_1 -> 4761 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1162, 4761 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4769 },
      -1,
   } },

   /* replace1686_0_0 -> 0 in the cache */
   /* replace1686_0_1 -> 1 in the cache */
   /* replace1686_0 -> 4760 in the cache */
   /* replace1686_1_0 -> 165 in the cache */
   /* replace1686_1_1 -> 166 in the cache */
   /* replace1686_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4760, 4757 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1687_0_0_0 -> 0 in the cache */
   /* search1687_0_0_1 -> 1 in the cache */
   /* search1687_0_0 -> 4760 in the cache */
   /* search1687_0_1_0 -> 165 in the cache */
   /* search1687_0_1_1 -> 166 in the cache */
   /* search1687_0_1 -> 4761 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4760, 4761 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4772 },
      -1,
   } },

   /* replace1687_0_0 -> 0 in the cache */
   /* replace1687_0_1 -> 1 in the cache */
   /* replace1687_0 -> 1162 in the cache */
   /* replace1687_1_0 -> 165 in the cache */
   /* replace1687_1_1 -> 166 in the cache */
   /* replace1687_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1162, 4757 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1688_0_0_0 -> 0 in the cache */
   /* search1688_0_0_1 -> 1 in the cache */
   /* search1688_0_0 -> 4760 in the cache */
   /* search1688_0_1_0 -> 165 in the cache */
   /* search1688_0_1_1 -> 166 in the cache */
   /* search1688_0_1 -> 4761 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4760, 4761 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4775 },
      -1,
   } },

   /* replace1688_0_0 -> 0 in the cache */
   /* replace1688_0_1 -> 1 in the cache */
   /* replace1688_0 -> 1162 in the cache */
   /* replace1688_1_0 -> 165 in the cache */
   /* replace1688_1_1 -> 166 in the cache */
   /* replace1688_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1162, 4757 },
      -1,
   } },

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1689_0_0 -> 9 in the cache */
   /* search1689_0 -> 1632 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1632 },
      -1,
   } },

   /* replace1689_0 -> 9 in the cache */
   /* replace1689 -> 1632 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1690_0_0 -> 9 in the cache */
   /* search1690_0 -> 1632 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1632 },
      -1,
   } },

   /* replace1690_0 -> 9 in the cache */
   /* replace1690 -> 3505 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1691_0_0 -> 9 in the cache */
   /* search1691_0 -> 1632 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1632 },
      -1,
   } },

   /* replace1691_0 -> 9 in the cache */
   /* replace1691 -> 3505 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1692_0_0 -> 9 in the cache */
   /* search1692_0 -> 3505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 3505 },
      -1,
   } },

   /* replace1692_0 -> 9 in the cache */
   /* replace1692 -> 1632 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1693_0_0 -> 9 in the cache */
   /* search1693_0 -> 3505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3505 },
      -1,
   } },

   /* replace1693_0 -> 9 in the cache */
   /* replace1693 -> 3505 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1694_0_0 -> 9 in the cache */
   /* search1694_0 -> 3505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3505 },
      -1,
   } },

   /* replace1694_0 -> 9 in the cache */
   /* replace1694 -> 1632 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1695_0_0 -> 9 in the cache */
   /* search1695_0 -> 3505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3505 },
      -1,
   } },

   /* replace1695_0 -> 9 in the cache */
   /* replace1695 -> 3505 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1696_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 847 },
      -1,
   } },

   /* replace1696 -> 847 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1697_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 19 },
      -1,
   } },

   /* replace1697 -> 19 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1698_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* replace1698 -> 24 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1699_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace1699 -> 29 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1700_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 34 },
      -1,
   } },

   /* replace1700 -> 34 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1701_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 847 },
      -1,
   } },

   /* replace1701 -> 847 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1702_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 19 },
      -1,
   } },

   /* replace1702 -> 19 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1703_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* replace1703 -> 24 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1704_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace1704 -> 29 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1705_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 34 },
      -1,
   } },

   /* replace1705 -> 34 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1706_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* replace1706 -> 24 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1707_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace1707 -> 29 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1708_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 34 },
      -1,
   } },

   /* replace1708 -> 34 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1709_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 847 },
      -1,
   } },

   /* replace1709 -> 847 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1710_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 19 },
      -1,
   } },

   /* replace1710 -> 19 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1711_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 24 },
      -1,
   } },

   /* replace1711 -> 24 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1712_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace1712 -> 29 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1713_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4802 },
      -1,
   } },

   /* replace1713_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1714_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4805 },
      -1,
   } },

   /* replace1714_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 9 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1715_0_0 -> 9 in the cache */
   /* search1715_0 -> 4802 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4802 },
      -1,
   } },

   /* replace1715_0 -> 9 in the cache */
   /* replace1715 -> 4804 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1716_0_0 -> 9 in the cache */
   /* search1716_0 -> 4805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4805 },
      -1,
   } },

   /* replace1716_0 -> 9 in the cache */
   /* replace1716 -> 4807 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1717_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4810 },
      -1,
   } },

   /* replace1717_0 -> 9 in the cache */
   /* replace1717 -> 4804 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1718_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4812 },
      -1,
   } },

   /* replace1718_0 -> 9 in the cache */
   /* replace1718 -> 4807 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1719_0_0 -> 9 in the cache */
   /* search1719_0 -> 4810 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4810 },
      -1,
   } },

   /* replace1719_0 -> 9 in the cache */
   /* replace1719 -> 4804 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1720_0_0 -> 9 in the cache */
   /* search1720_0 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4812 },
      -1,
   } },

   /* replace1720_0 -> 9 in the cache */
   /* replace1720 -> 4807 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1721_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4816 },
      -1,
   } },

   /* replace1721_0 -> 9 in the cache */
   /* replace1721 -> 4804 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1722_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4818 },
      -1,
   } },

   /* replace1722_0 -> 9 in the cache */
   /* replace1722 -> 4807 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1723_0_0 -> 9 in the cache */
   /* search1723_0 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4816 },
      -1,
   } },

   /* replace1723_0 -> 9 in the cache */
   /* replace1723 -> 4804 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1724_0_0 -> 9 in the cache */
   /* search1724_0 -> 4818 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4818 },
      -1,
   } },

   /* replace1724_0 -> 9 in the cache */
   /* replace1724 -> 4807 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1725_0_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1725_0 -> 9 in the cache */
   /* replace1725 -> 4804 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1726_0_0 -> 9 in the cache */
   /* search1726_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1726_0 -> 9 in the cache */
   /* replace1726 -> 4807 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1727_0_0 -> 9 in the cache */
   /* search1727_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1727_0 -> 9 in the cache */
   /* replace1727 -> 4804 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1728_0_0 -> 9 in the cache */
   /* search1728_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1728_0 -> 9 in the cache */
   /* replace1728 -> 4807 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1729_0_0 -> 847 in the cache */
   /* search1729_0 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4785 },
      -1,
   } },

   /* replace1729_0 -> 847 in the cache */
   /* replace1729 -> 2135 in the cache */

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1730_0_0 -> 847 in the cache */
   /* search1730_0 -> 4790 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4790 },
      -1,
   } },

   /* replace1730_0 -> 847 in the cache */
   /* replace1730 -> 2137 in the cache */

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1731_0_0 -> 9 in the cache */
   /* search1731_0 -> 4810 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4810 },
      -1,
   } },

   /* replace1731_0 -> 9 in the cache */
   /* replace1731 -> 4802 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1732_0_0 -> 9 in the cache */
   /* search1732_0 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4812 },
      -1,
   } },

   /* replace1732_0 -> 9 in the cache */
   /* replace1732 -> 4805 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1733_0_0 -> 9 in the cache */
   /* search1733_0 -> 4810 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4810 },
      -1,
   } },

   /* replace1733_0 -> 9 in the cache */
   /* replace1733 -> 4802 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1734_0_0 -> 9 in the cache */
   /* search1734_0 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4812 },
      -1,
   } },

   /* replace1734_0 -> 9 in the cache */
   /* replace1734 -> 4805 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1735_0_0 -> 9 in the cache */
   /* search1735_0 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4816 },
      -1,
   } },

   /* replace1735_0 -> 9 in the cache */
   /* replace1735 -> 4802 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1736_0_0 -> 9 in the cache */
   /* search1736_0 -> 4818 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4818 },
      -1,
   } },

   /* replace1736_0 -> 9 in the cache */
   /* replace1736 -> 4805 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1737_0_0 -> 9 in the cache */
   /* search1737_0 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4816 },
      -1,
   } },

   /* replace1737_0 -> 9 in the cache */
   /* replace1737 -> 4802 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1738_0_0 -> 9 in the cache */
   /* search1738_0 -> 4818 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4818 },
      -1,
   } },

   /* replace1738_0 -> 9 in the cache */
   /* replace1738 -> 4805 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1739_0_0 -> 9 in the cache */
   /* search1739_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1739_0 -> 9 in the cache */
   /* replace1739 -> 4802 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1740_0_0 -> 9 in the cache */
   /* search1740_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1740_0 -> 9 in the cache */
   /* replace1740 -> 4805 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1741_0_0 -> 9 in the cache */
   /* search1741_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1741_0 -> 9 in the cache */
   /* replace1741 -> 4802 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1742_0_0 -> 9 in the cache */
   /* search1742_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1742_0 -> 9 in the cache */
   /* replace1742 -> 4805 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1743_0_0 -> 847 in the cache */
   /* search1743_0 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4785 },
      -1,
   } },

   /* replace1743_0 -> 847 in the cache */
   /* replace1743 -> 2139 in the cache */

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1744_0_0 -> 847 in the cache */
   /* search1744_0 -> 4790 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4790 },
      -1,
   } },

   /* replace1744_0 -> 847 in the cache */
   /* replace1744 -> 2141 in the cache */

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1745_0_0 -> 847 in the cache */
   /* search1745_0 -> 2135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace1745_0 -> 847 in the cache */
   /* replace1745 -> 2139 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1746_0_0 -> 847 in the cache */
   /* search1746_0 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace1746_0 -> 847 in the cache */
   /* replace1746 -> 2141 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1747_0_0 -> 19 in the cache */
   /* search1747_0 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4786 },
      -1,
   } },

   /* replace1747_0 -> 19 in the cache */
   /* replace1747 -> 2181 in the cache */

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1748_0_0 -> 19 in the cache */
   /* search1748_0 -> 4791 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4791 },
      -1,
   } },

   /* replace1748_0 -> 19 in the cache */
   /* replace1748 -> 2183 in the cache */

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1749_0_0 -> 9 in the cache */
   /* search1749_0 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4816 },
      -1,
   } },

   /* replace1749_0 -> 9 in the cache */
   /* replace1749 -> 4810 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1750_0_0 -> 9 in the cache */
   /* search1750_0 -> 4818 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4818 },
      -1,
   } },

   /* replace1750_0 -> 9 in the cache */
   /* replace1750 -> 4812 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1751_0_0 -> 9 in the cache */
   /* search1751_0 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4816 },
      -1,
   } },

   /* replace1751_0 -> 9 in the cache */
   /* replace1751 -> 4810 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1752_0_0 -> 9 in the cache */
   /* search1752_0 -> 4818 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4818 },
      -1,
   } },

   /* replace1752_0 -> 9 in the cache */
   /* replace1752 -> 4812 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1753_0_0 -> 9 in the cache */
   /* search1753_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1753_0 -> 9 in the cache */
   /* replace1753 -> 4810 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1754_0_0 -> 9 in the cache */
   /* search1754_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1754_0 -> 9 in the cache */
   /* replace1754 -> 4812 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1755_0_0 -> 9 in the cache */
   /* search1755_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1755_0 -> 9 in the cache */
   /* replace1755 -> 4810 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1756_0_0 -> 9 in the cache */
   /* search1756_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1756_0 -> 9 in the cache */
   /* replace1756 -> 4812 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1757_0_0 -> 847 in the cache */
   /* search1757_0 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4785 },
      -1,
   } },

   /* replace1757_0 -> 847 in the cache */
   /* replace1757 -> 2151 in the cache */

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1758_0_0 -> 847 in the cache */
   /* search1758_0 -> 4790 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4790 },
      -1,
   } },

   /* replace1758_0 -> 847 in the cache */
   /* replace1758 -> 2149 in the cache */

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1759_0_0 -> 847 in the cache */
   /* search1759_0 -> 2135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace1759_0 -> 847 in the cache */
   /* replace1759 -> 2151 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1760_0_0 -> 847 in the cache */
   /* search1760_0 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace1760_0 -> 847 in the cache */
   /* replace1760 -> 2149 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1761_0_0 -> 19 in the cache */
   /* search1761_0 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4786 },
      -1,
   } },

   /* replace1761_0 -> 19 in the cache */
   /* replace1761 -> 2191 in the cache */

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1762_0_0 -> 19 in the cache */
   /* search1762_0 -> 4791 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4791 },
      -1,
   } },

   /* replace1762_0 -> 19 in the cache */
   /* replace1762 -> 2189 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1763_0_0 -> 847 in the cache */
   /* search1763_0 -> 2139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace1763_0 -> 847 in the cache */
   /* replace1763 -> 2151 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1764_0_0 -> 847 in the cache */
   /* search1764_0 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace1764_0 -> 847 in the cache */
   /* replace1764 -> 2149 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1765_0_0 -> 19 in the cache */
   /* search1765_0 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2181 },
      -1,
   } },

   /* replace1765_0 -> 19 in the cache */
   /* replace1765 -> 2191 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1766_0_0 -> 19 in the cache */
   /* search1766_0 -> 2183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2183 },
      -1,
   } },

   /* replace1766_0 -> 19 in the cache */
   /* replace1766 -> 2189 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1767_0_0 -> 24 in the cache */
   /* search1767_0 -> 4787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4787 },
      -1,
   } },

   /* replace1767_0 -> 24 in the cache */
   /* replace1767 -> 2217 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1768_0_0 -> 24 in the cache */
   /* search1768_0 -> 4792 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4792 },
      -1,
   } },

   /* replace1768_0 -> 24 in the cache */
   /* replace1768 -> 2219 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1769_0_0 -> 9 in the cache */
   /* search1769_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1769_0 -> 9 in the cache */
   /* replace1769 -> 4816 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1770_0_0 -> 9 in the cache */
   /* search1770_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1770_0 -> 9 in the cache */
   /* replace1770 -> 4818 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1771_0_0 -> 9 in the cache */
   /* search1771_0 -> 4822 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4822 },
      -1,
   } },

   /* replace1771_0 -> 9 in the cache */
   /* replace1771 -> 4816 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1772_0_0 -> 9 in the cache */
   /* search1772_0 -> 3620 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3620 },
      -1,
   } },

   /* replace1772_0 -> 9 in the cache */
   /* replace1772 -> 4818 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1773_0_0 -> 847 in the cache */
   /* search1773_0 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4785 },
      -1,
   } },

   /* replace1773_0 -> 847 in the cache */
   /* replace1773 -> 2155 in the cache */

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1774_0_0 -> 847 in the cache */
   /* search1774_0 -> 4790 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4790 },
      -1,
   } },

   /* replace1774_0 -> 847 in the cache */
   /* replace1774 -> 2153 in the cache */

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1775_0_0 -> 847 in the cache */
   /* search1775_0 -> 2135 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2135 },
      -1,
   } },

   /* replace1775_0 -> 847 in the cache */
   /* replace1775 -> 2155 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1776_0_0 -> 847 in the cache */
   /* search1776_0 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2137 },
      -1,
   } },

   /* replace1776_0 -> 847 in the cache */
   /* replace1776 -> 2153 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1777_0_0 -> 19 in the cache */
   /* search1777_0 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4786 },
      -1,
   } },

   /* replace1777_0 -> 19 in the cache */
   /* replace1777 -> 2195 in the cache */

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1778_0_0 -> 19 in the cache */
   /* search1778_0 -> 4791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4791 },
      -1,
   } },

   /* replace1778_0 -> 19 in the cache */
   /* replace1778 -> 2193 in the cache */

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1779_0_0 -> 847 in the cache */
   /* search1779_0 -> 2139 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace1779_0 -> 847 in the cache */
   /* replace1779 -> 2155 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1780_0_0 -> 847 in the cache */
   /* search1780_0 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace1780_0 -> 847 in the cache */
   /* replace1780 -> 2153 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1781_0_0 -> 19 in the cache */
   /* search1781_0 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2181 },
      -1,
   } },

   /* replace1781_0 -> 19 in the cache */
   /* replace1781 -> 2195 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1782_0_0 -> 19 in the cache */
   /* search1782_0 -> 2183 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2183 },
      -1,
   } },

   /* replace1782_0 -> 19 in the cache */
   /* replace1782 -> 2193 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1783_0_0 -> 24 in the cache */
   /* search1783_0 -> 4787 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4787 },
      -1,
   } },

   /* replace1783_0 -> 24 in the cache */
   /* replace1783 -> 2227 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1784_0_0 -> 24 in the cache */
   /* search1784_0 -> 4792 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4792 },
      -1,
   } },

   /* replace1784_0 -> 24 in the cache */
   /* replace1784 -> 2225 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1785_0_0 -> 847 in the cache */
   /* search1785_0 -> 2151 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2151 },
      -1,
   } },

   /* replace1785_0 -> 847 in the cache */
   /* replace1785 -> 2155 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1786_0_0 -> 847 in the cache */
   /* search1786_0 -> 2149 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2149 },
      -1,
   } },

   /* replace1786_0 -> 847 in the cache */
   /* replace1786 -> 2153 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1787_0_0 -> 19 in the cache */
   /* search1787_0 -> 2191 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2191 },
      -1,
   } },

   /* replace1787_0 -> 19 in the cache */
   /* replace1787 -> 2195 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1788_0_0 -> 19 in the cache */
   /* search1788_0 -> 2189 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2189 },
      -1,
   } },

   /* replace1788_0 -> 19 in the cache */
   /* replace1788 -> 2193 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1789_0_0 -> 24 in the cache */
   /* search1789_0 -> 2217 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2217 },
      -1,
   } },

   /* replace1789_0 -> 24 in the cache */
   /* replace1789 -> 2227 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1790_0_0 -> 24 in the cache */
   /* search1790_0 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* replace1790_0 -> 24 in the cache */
   /* replace1790 -> 2225 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1791_0_0 -> 29 in the cache */
   /* search1791_0 -> 4788 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4788 },
      -1,
   } },

   /* replace1791_0 -> 29 in the cache */
   /* replace1791 -> 2237 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1792_0_0 -> 29 in the cache */
   /* search1792_0 -> 4793 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4793 },
      -1,
   } },

   /* replace1792_0 -> 29 in the cache */
   /* replace1792 -> 2239 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1793_0_0 -> 29 in the cache */
   /* search1793_0_1 -> 48 in the cache */
   /* search1793_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1793_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1794_0_0 -> 29 in the cache */
   /* search1794_0_1 -> 48 in the cache */
   /* search1794_0 -> 3613 in the cache */
   /* search1794 -> 4891 in the cache */

   /* replace1794_0 -> 29 in the cache */
   /* replace1794 -> 4892 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1795_0_0 -> 29 in the cache */
   /* search1795_0_1 -> 48 in the cache */
   /* search1795_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1795_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1796_0_0 -> 29 in the cache */
   /* search1796_0_1 -> 48 in the cache */
   /* search1796_0 -> 3613 in the cache */
   /* search1796 -> 4893 in the cache */

   /* replace1796_0 -> 29 in the cache */
   /* replace1796 -> 4894 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1797_0_0 -> 29 in the cache */
   /* search1797_0_1 -> 48 in the cache */
   /* search1797_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1797_0 -> 29 in the cache */
   /* replace1797 -> 4788 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1798_0_0 -> 29 in the cache */
   /* search1798_0_1 -> 48 in the cache */
   /* search1798_0 -> 3613 in the cache */
   /* search1798 -> 4895 in the cache */

   /* replace1798_0 -> 29 in the cache */
   /* replace1798 -> 4788 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1799_0_0 -> 29 in the cache */
   /* search1799_0_1 -> 48 in the cache */
   /* search1799_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1799_0 -> 29 in the cache */
   /* replace1799 -> 2283 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1800_0_0 -> 29 in the cache */
   /* search1800_0_1 -> 48 in the cache */
   /* search1800_0 -> 3613 in the cache */
   /* search1800 -> 4896 in the cache */

   /* replace1800_0 -> 29 in the cache */
   /* replace1800 -> 2283 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1801_0_0 -> 29 in the cache */
   /* search1801_0_1 -> 48 in the cache */
   /* search1801_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1801_0 -> 29 in the cache */
   /* replace1801 -> 3761 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1802_0_0 -> 29 in the cache */
   /* search1802_0_1 -> 48 in the cache */
   /* search1802_0 -> 3613 in the cache */
   /* search1802 -> 4897 in the cache */

   /* replace1802_0 -> 29 in the cache */
   /* replace1802 -> 3761 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1803_0_0 -> 29 in the cache */
   /* search1803_0_1 -> 48 in the cache */
   /* search1803_0 -> 3613 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3613 },
      -1,
   } },

   /* replace1803_0 -> 29 in the cache */
   /* replace1803 -> 4793 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1804_0_0 -> 29 in the cache */
   /* search1804_0_1 -> 48 in the cache */
   /* search1804_0 -> 3613 in the cache */
   /* search1804 -> 4898 in the cache */

   /* replace1804_0 -> 29 in the cache */
   /* replace1804 -> 4793 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1805_0_0 -> 19 in the cache */
   /* search1805_0 -> 2181 in the cache */
   /* search1805_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2181, 4899 },
      -1,
   } },

   /* replace1805_0 -> 19 in the cache */
   /* replace1805_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 19, 4901 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1806_0_0 -> 19 in the cache */
   /* search1806_0 -> 2181 in the cache */
   /* search1806_1_0 -> 2370 in the cache */
   /* search1806_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2181, 4899 },
      -1,
   } },

   /* replace1806_0 -> 19 in the cache */
   /* replace1806_1_0 -> 2370 in the cache */
   /* replace1806_1 -> 4901 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 19, 4901 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1807_0_0 -> 19 in the cache */
   /* search1807_0 -> 2181 in the cache */
   /* search1807_1_0 -> 2370 in the cache */
   /* search1807_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2181, 4899 },
      -1,
   } },

   /* replace1807_0 -> 19 in the cache */
   /* replace1807_1_0 -> 2370 in the cache */
   /* replace1807_1 -> 4901 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 19, 4901 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1808_0_0 -> 19 in the cache */
   /* search1808_0 -> 2181 in the cache */
   /* search1808_1_0 -> 2370 in the cache */
   /* search1808_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2181, 4899 },
      -1,
   } },

   /* replace1808_0 -> 19 in the cache */
   /* replace1808_1_0 -> 2370 in the cache */
   /* replace1808_1 -> 4901 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 4901 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1809_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* search1809_1_0 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4909, 4910 },
      -1,
   } },

   /* replace1809_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* replace1809_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4912, 2388 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1810_0_0 -> 2387 in the cache */
   /* search1810_0 -> 4909 in the cache */
   /* search1810_1_0 -> 2388 in the cache */
   /* search1810_1 -> 4910 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4909, 4910 },
      -1,
   } },

   /* replace1810_0_0 -> 2387 in the cache */
   /* replace1810_0 -> 4912 in the cache */
   /* replace1810_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4912, 2388 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1811_0_0 -> 19 in the cache */
   /* search1811_0 -> 2181 in the cache */
   /* search1811_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2181, 2269 },
      -1,
   } },

   /* replace1811_0_0 -> 19 in the cache */
   /* replace1811_0_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 4917 },
      -1,
   } },
   /* replace1811_1_0_0_0 -> 551 in the cache */
   /* replace1811_1_0_0 -> 4917 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4917 },
      -1,
   } },
   /* replace1811_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4919, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4918, 4920 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1812_0_0 -> 19 in the cache */
   /* search1812_0 -> 2181 in the cache */
   /* search1812_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2181, 2269 },
      -1,
   } },

   /* replace1812_0_0 -> 19 in the cache */
   /* replace1812_0_1_0 -> 551 in the cache */
   /* replace1812_0_1 -> 4917 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 4917 },
      -1,
   } },
   /* replace1812_1_0_0_0 -> 551 in the cache */
   /* replace1812_1_0_0 -> 4917 in the cache */
   /* replace1812_1_0 -> 4919 in the cache */
   /* replace1812_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4919, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4923, 4924 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1813_0_0 -> 19 in the cache */
   /* search1813_0 -> 2181 in the cache */
   /* search1813_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2181, 2269 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffffffffffffff80ull /* -128 */ },
   } },
   /* replace1813_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4927, 551 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7full /* 127 */ },
   } },
   /* replace1813_1_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4929, 551 },
      -1,
   } },
   /* replace1813_1_1_0 -> 19 in the cache */
   /* replace1813_1_1_1_0 -> 551 in the cache */
   /* replace1813_1_1_1 -> 4917 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 4917 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4930, 4931 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4928, 4932 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1814_1_0 -> 2370 in the cache */
   /* search1814_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4934, 4899 },
      -1,
   } },

   /* replace1814_0_0 -> 24 in the cache */
   /* replace1814_0_1 -> 4929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 4929 },
      -1,
   } },
   /* replace1814_1_0_0 -> 24 in the cache */
   /* replace1814_1_0_1 -> 4927 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 4927 },
      -1,
   } },
   /* replace1814_1_1_0_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 24 },
      -1,
   } },
   /* replace1814_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4938, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4937, 4939 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4936, 4940 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1815_0_0 -> 19 in the cache */
   /* search1815_0 -> 2181 in the cache */
   /* search1815_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2181, 2269 },
      -1,
   } },

   /* replace1815_0_0 -> 4929 in the cache */
   /* replace1815_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4929, 551 },
      -1,
   } },
   /* replace1815_1_0_0 -> 4927 in the cache */
   /* replace1815_1_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4927, 551 },
      -1,
   } },
   /* replace1815_1_1_0 -> 19 in the cache */
   /* replace1815_1_1_1_0 -> 551 in the cache */
   /* replace1815_1_1_1 -> 4917 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 19, 4917 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4944, 4945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4943, 4946 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1816_0 -> 4934 in the cache */
   /* search1816_1_0 -> 2370 in the cache */
   /* search1816_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4934, 4899 },
      -1,
   } },

   /* replace1816_0_0 -> 24 in the cache */
   /* replace1816_0_1 -> 4927 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 4927 },
      -1,
   } },
   /* replace1816_1_0_0 -> 24 in the cache */
   /* replace1816_1_0_1 -> 4929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 4929 },
      -1,
   } },
   /* replace1816_1_1_0_0 -> 24 in the cache */
   /* replace1816_1_1_0 -> 4938 in the cache */
   /* replace1816_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4938, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4950, 4951 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4949, 4952 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1817_0_0 -> 19 in the cache */
   /* search1817_0 -> 2191 in the cache */
   /* search1817_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2191, 4954 },
      -1,
   } },

   /* replace1817_0 -> 19 in the cache */
   /* replace1817_1_0 -> 2370 in the cache */
   /* replace1817_1 -> 4901 in the cache */
   /* replace1817 -> 4902 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1818_0_0 -> 19 in the cache */
   /* search1818_0 -> 2191 in the cache */
   /* search1818_1_0 -> 2370 in the cache */
   /* search1818_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2191, 4954 },
      -1,
   } },

   /* replace1818_0 -> 19 in the cache */
   /* replace1818_1_0 -> 2370 in the cache */
   /* replace1818_1 -> 4901 in the cache */
   /* replace1818 -> 4904 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1819_0_0 -> 19 in the cache */
   /* search1819_0 -> 2191 in the cache */
   /* search1819_1_0 -> 2370 in the cache */
   /* search1819_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2191, 4954 },
      -1,
   } },

   /* replace1819_0 -> 19 in the cache */
   /* replace1819_1_0 -> 2370 in the cache */
   /* replace1819_1 -> 4901 in the cache */
   /* replace1819 -> 4906 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1820_0_0 -> 19 in the cache */
   /* search1820_0 -> 2191 in the cache */
   /* search1820_1_0 -> 2370 in the cache */
   /* search1820_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2191, 4954 },
      -1,
   } },

   /* replace1820_0 -> 19 in the cache */
   /* replace1820_1_0 -> 2370 in the cache */
   /* replace1820_1 -> 4901 in the cache */
   /* replace1820 -> 4908 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1821_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* search1821_1_0 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4959, 4960 },
      -1,
   } },

   /* replace1821_0_0 -> 2387 in the cache */
   /* replace1821_0 -> 4912 in the cache */
   /* replace1821_1 -> 2388 in the cache */
   /* replace1821 -> 4913 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1822_0_0 -> 2387 in the cache */
   /* search1822_0 -> 4959 in the cache */
   /* search1822_1_0 -> 2388 in the cache */
   /* search1822_1 -> 4960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4959, 4960 },
      -1,
   } },

   /* replace1822_0_0 -> 2387 in the cache */
   /* replace1822_0 -> 4912 in the cache */
   /* replace1822_1 -> 2388 in the cache */
   /* replace1822 -> 4915 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1823_0_0 -> 19 in the cache */
   /* search1823_0 -> 2191 in the cache */
   /* search1823_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2191, 45 },
      -1,
   } },

   /* replace1823_0_0 -> 19 in the cache */
   /* replace1823_0_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 4964 },
      -1,
   } },
   /* replace1823_1_0_0_0 -> 48 in the cache */
   /* replace1823_1_0_0 -> 4964 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4964 },
      -1,
   } },
   /* replace1823_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4966, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4965, 4967 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1824_0_0 -> 19 in the cache */
   /* search1824_0 -> 2191 in the cache */
   /* search1824_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2191, 45 },
      -1,
   } },

   /* replace1824_0_0 -> 19 in the cache */
   /* replace1824_0_1_0 -> 48 in the cache */
   /* replace1824_0_1 -> 4964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 4964 },
      -1,
   } },
   /* replace1824_1_0_0_0 -> 48 in the cache */
   /* replace1824_1_0_0 -> 4964 in the cache */
   /* replace1824_1_0 -> 4966 in the cache */
   /* replace1824_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4966, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4970, 4971 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1825_0_0 -> 19 in the cache */
   /* search1825_0 -> 2191 in the cache */
   /* search1825_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2191, 45 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffff80ull /* -128 */ },
   } },
   /* replace1825_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4974, 48 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7full /* 127 */ },
   } },
   /* replace1825_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4976, 48 },
      -1,
   } },
   /* replace1825_1_1_0 -> 19 in the cache */
   /* replace1825_1_1_1_0 -> 48 in the cache */
   /* replace1825_1_1_1 -> 4964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 4964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4977, 4978 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4975, 4979 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1826_0 -> 299 in the cache */
   /* search1826_1_0 -> 2370 in the cache */
   /* search1826_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 299, 4954 },
      -1,
   } },

   /* replace1826_0_0 -> 29 in the cache */
   /* replace1826_0_1 -> 4976 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 4976 },
      -1,
   } },
   /* replace1826_1_0_0 -> 29 in the cache */
   /* replace1826_1_0_1 -> 4974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 4974 },
      -1,
   } },
   /* replace1826_1_1_0_0 -> 29 in the cache */
   /* replace1826_1_1_0 -> 4892 in the cache */
   /* replace1826_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4892, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4983, 4984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4982, 4985 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1827_0_0 -> 19 in the cache */
   /* search1827_0 -> 2191 in the cache */
   /* search1827_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2191, 45 },
      -1,
   } },

   /* replace1827_0_0 -> 4976 in the cache */
   /* replace1827_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4976, 48 },
      -1,
   } },
   /* replace1827_1_0_0 -> 4974 in the cache */
   /* replace1827_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4974, 48 },
      -1,
   } },
   /* replace1827_1_1_0 -> 19 in the cache */
   /* replace1827_1_1_1_0 -> 48 in the cache */
   /* replace1827_1_1_1 -> 4964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 19, 4964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4989, 4990 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4988, 4991 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1828_0 -> 299 in the cache */
   /* search1828_1_0 -> 2370 in the cache */
   /* search1828_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 299, 4954 },
      -1,
   } },

   /* replace1828_0_0 -> 29 in the cache */
   /* replace1828_0_1 -> 4974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 4974 },
      -1,
   } },
   /* replace1828_1_0_0 -> 29 in the cache */
   /* replace1828_1_0_1 -> 4976 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 4976 },
      -1,
   } },
   /* replace1828_1_1_0_0 -> 29 in the cache */
   /* replace1828_1_1_0 -> 4892 in the cache */
   /* replace1828_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4892, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4995, 4996 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4994, 4997 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1829_0_0 -> 19 in the cache */
   /* search1829_0 -> 2195 in the cache */
   /* search1829_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2195, 4999 },
      -1,
   } },

   /* replace1829_0 -> 19 in the cache */
   /* replace1829_1_0 -> 2370 in the cache */
   /* replace1829_1 -> 4901 in the cache */
   /* replace1829 -> 4902 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1830_0_0 -> 19 in the cache */
   /* search1830_0 -> 2195 in the cache */
   /* search1830_1_0 -> 2370 in the cache */
   /* search1830_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2195, 4999 },
      -1,
   } },

   /* replace1830_0 -> 19 in the cache */
   /* replace1830_1_0 -> 2370 in the cache */
   /* replace1830_1 -> 4901 in the cache */
   /* replace1830 -> 4904 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1831_0_0 -> 19 in the cache */
   /* search1831_0 -> 2195 in the cache */
   /* search1831_1_0 -> 2370 in the cache */
   /* search1831_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2195, 4999 },
      -1,
   } },

   /* replace1831_0 -> 19 in the cache */
   /* replace1831_1_0 -> 2370 in the cache */
   /* replace1831_1 -> 4901 in the cache */
   /* replace1831 -> 4906 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1832_0_0 -> 19 in the cache */
   /* search1832_0 -> 2195 in the cache */
   /* search1832_1_0 -> 2370 in the cache */
   /* search1832_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2195, 4999 },
      -1,
   } },

   /* replace1832_0 -> 19 in the cache */
   /* replace1832_1_0 -> 2370 in the cache */
   /* replace1832_1 -> 4901 in the cache */
   /* replace1832 -> 4908 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1833_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* search1833_1_0 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5004, 5005 },
      -1,
   } },

   /* replace1833_0_0 -> 2387 in the cache */
   /* replace1833_0 -> 4912 in the cache */
   /* replace1833_1 -> 2388 in the cache */
   /* replace1833 -> 4913 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1834_0_0 -> 2387 in the cache */
   /* search1834_0 -> 5004 in the cache */
   /* search1834_1_0 -> 2388 in the cache */
   /* search1834_1 -> 5005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5004, 5005 },
      -1,
   } },

   /* replace1834_0_0 -> 2387 in the cache */
   /* replace1834_0 -> 4912 in the cache */
   /* replace1834_1 -> 2388 in the cache */
   /* replace1834 -> 4915 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1835_0_0 -> 19 in the cache */
   /* search1835_0 -> 2195 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2195, 5008 },
      -1,
   } },

   /* replace1835_0_0 -> 19 in the cache */
   /* replace1835_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 5010 },
      -1,
   } },
   /* replace1835_1_0_0_0 -> 53 in the cache */
   /* replace1835_1_0_0 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 5010 },
      -1,
   } },
   /* replace1835_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5012, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5011, 5013 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1836_0_0 -> 19 in the cache */
   /* search1836_0 -> 2195 in the cache */
   /* search1836_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2195, 5008 },
      -1,
   } },

   /* replace1836_0_0 -> 19 in the cache */
   /* replace1836_0_1_0 -> 53 in the cache */
   /* replace1836_0_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 5010 },
      -1,
   } },
   /* replace1836_1_0_0_0 -> 53 in the cache */
   /* replace1836_1_0_0 -> 5010 in the cache */
   /* replace1836_1_0 -> 5012 in the cache */
   /* replace1836_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5012, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5016, 5017 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1837_0_0 -> 19 in the cache */
   /* search1837_0 -> 2195 in the cache */
   /* search1837_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2195, 5008 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffff80ull /* -128 */ },
   } },
   /* replace1837_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5020, 53 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7full /* 127 */ },
   } },
   /* replace1837_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5022, 53 },
      -1,
   } },
   /* replace1837_1_1_0 -> 19 in the cache */
   /* replace1837_1_1_1_0 -> 53 in the cache */
   /* replace1837_1_1_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 19, 5010 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5023, 5024 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5021, 5025 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1838_1_0 -> 2370 in the cache */
   /* search1838_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5027, 4999 },
      -1,
   } },

   /* replace1838_0_0 -> 34 in the cache */
   /* replace1838_0_1 -> 5022 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 5022 },
      -1,
   } },
   /* replace1838_1_0_0 -> 34 in the cache */
   /* replace1838_1_0_1 -> 5020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 5020 },
      -1,
   } },
   /* replace1838_1_1_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1838_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5031, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5030, 5032 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5029, 5033 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1839_0_0 -> 19 in the cache */
   /* search1839_0 -> 2195 in the cache */
   /* search1839_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2195, 5008 },
      -1,
   } },

   /* replace1839_0_0 -> 5022 in the cache */
   /* replace1839_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5022, 53 },
      -1,
   } },
   /* replace1839_1_0_0 -> 5020 in the cache */
   /* replace1839_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5020, 53 },
      -1,
   } },
   /* replace1839_1_1_0 -> 19 in the cache */
   /* replace1839_1_1_1_0 -> 53 in the cache */
   /* replace1839_1_1_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 19, 5010 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5037, 5038 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5036, 5039 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1840_0 -> 5027 in the cache */
   /* search1840_1_0 -> 2370 in the cache */
   /* search1840_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5027, 4999 },
      -1,
   } },

   /* replace1840_0_0 -> 34 in the cache */
   /* replace1840_0_1 -> 5020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 5020 },
      -1,
   } },
   /* replace1840_1_0_0 -> 34 in the cache */
   /* replace1840_1_0_1 -> 5022 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 5022 },
      -1,
   } },
   /* replace1840_1_1_0_0 -> 34 in the cache */
   /* replace1840_1_1_0 -> 5031 in the cache */
   /* replace1840_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5031, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5043, 5044 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5042, 5045 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1841_0_0 -> 24 in the cache */
   /* search1841_0 -> 2217 in the cache */
   /* search1841_1_0 -> 2370 in the cache */
   /* search1841_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2217, 4954 },
      -1,
   } },

   /* replace1841_0 -> 24 in the cache */
   /* replace1841_1_0 -> 2370 in the cache */
   /* replace1841_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 24, 4899 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1842_0_0 -> 24 in the cache */
   /* search1842_0 -> 2217 in the cache */
   /* search1842_1_0 -> 2370 in the cache */
   /* search1842_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2217, 4954 },
      -1,
   } },

   /* replace1842_0 -> 24 in the cache */
   /* replace1842_1_0 -> 2370 in the cache */
   /* replace1842_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 24, 4899 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1843_0_0 -> 24 in the cache */
   /* search1843_0 -> 2217 in the cache */
   /* search1843_1_0 -> 2370 in the cache */
   /* search1843_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2217, 4954 },
      -1,
   } },

   /* replace1843_0 -> 24 in the cache */
   /* replace1843_1_0 -> 2370 in the cache */
   /* replace1843_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 4899 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1844_0_0 -> 24 in the cache */
   /* search1844_0 -> 2217 in the cache */
   /* search1844_1_0 -> 2370 in the cache */
   /* search1844_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2217, 4954 },
      -1,
   } },

   /* replace1844_0 -> 24 in the cache */
   /* replace1844_1_0 -> 2370 in the cache */
   /* replace1844_1 -> 4899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 4899 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1845_0_0 -> 2387 in the cache */
   /* search1845_0 -> 4959 in the cache */
   /* search1845_1_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4959, 5055 },
      -1,
   } },

   /* replace1845_0_0 -> 2387 in the cache */
   /* replace1845_0 -> 4909 in the cache */
   /* replace1845_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4909, 614 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1846_0_0 -> 2387 in the cache */
   /* search1846_0 -> 4959 in the cache */
   /* search1846_1_0 -> 614 in the cache */
   /* search1846_1 -> 5055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4959, 5055 },
      -1,
   } },

   /* replace1846_0_0 -> 2387 in the cache */
   /* replace1846_0 -> 4909 in the cache */
   /* replace1846_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4909, 614 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1847_0_0 -> 24 in the cache */
   /* search1847_0 -> 2217 in the cache */
   /* search1847_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2217, 5060 },
      -1,
   } },

   /* replace1847_0 -> 24 in the cache */
   /* replace1847_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 24, 5062 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1848_0_0 -> 24 in the cache */
   /* search1848_0 -> 2217 in the cache */
   /* search1848_1_0 -> 551 in the cache */
   /* search1848_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2217, 5060 },
      -1,
   } },

   /* replace1848_0 -> 24 in the cache */
   /* replace1848_1_0 -> 551 in the cache */
   /* replace1848_1 -> 5062 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 24, 5062 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1849_0_0 -> 24 in the cache */
   /* search1849_0 -> 2217 in the cache */
   /* search1849_1_0 -> 551 in the cache */
   /* search1849_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2217, 5060 },
      -1,
   } },

   /* replace1849_0 -> 24 in the cache */
   /* replace1849_1_0 -> 551 in the cache */
   /* replace1849_1 -> 5062 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 5062 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1850_0_0 -> 24 in the cache */
   /* search1850_0 -> 2217 in the cache */
   /* search1850_1_0 -> 551 in the cache */
   /* search1850_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2217, 5060 },
      -1,
   } },

   /* replace1850_0 -> 24 in the cache */
   /* replace1850_1_0 -> 551 in the cache */
   /* replace1850_1 -> 5062 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 5062 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1851_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 603 },
      -1,
   } },
   /* search1851_1_0 -> 614 in the cache */
   /* search1851_1 -> 5055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5070, 5055 },
      -1,
   } },

   /* replace1851_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 603 },
      -1,
   } },
   /* replace1851_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5072, 614 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1852_0_0 -> 603 in the cache */
   /* search1852_0 -> 5070 in the cache */
   /* search1852_1_0 -> 614 in the cache */
   /* search1852_1 -> 5055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5070, 5055 },
      -1,
   } },

   /* replace1852_0_0 -> 603 in the cache */
   /* replace1852_0 -> 5072 in the cache */
   /* replace1852_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5072, 614 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1853_0_0 -> 24 in the cache */
   /* search1853_0 -> 2217 in the cache */
   /* search1853_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2217, 45 },
      -1,
   } },

   /* replace1853_0_0 -> 24 in the cache */
   /* replace1853_0_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 24, 5077 },
      -1,
   } },
   /* replace1853_1_0_0_0 -> 48 in the cache */
   /* replace1853_1_0_0 -> 5077 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5077 },
      -1,
   } },
   /* replace1853_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5079, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5078, 5080 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1854_0_0 -> 24 in the cache */
   /* search1854_0 -> 2217 in the cache */
   /* search1854_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2217, 45 },
      -1,
   } },

   /* replace1854_0_0 -> 24 in the cache */
   /* replace1854_0_1_0 -> 48 in the cache */
   /* replace1854_0_1 -> 5077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 24, 5077 },
      -1,
   } },
   /* replace1854_1_0_0_0 -> 48 in the cache */
   /* replace1854_1_0_0 -> 5077 in the cache */
   /* replace1854_1_0 -> 5079 in the cache */
   /* replace1854_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5079, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5083, 5084 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1855_0_0 -> 24 in the cache */
   /* search1855_0 -> 2217 in the cache */
   /* search1855_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2217, 45 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffff8000ull /* -32768 */ },
   } },
   /* replace1855_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5087, 48 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffull /* 32767 */ },
   } },
   /* replace1855_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5089, 48 },
      -1,
   } },
   /* replace1855_1_1_0 -> 24 in the cache */
   /* replace1855_1_1_1_0 -> 48 in the cache */
   /* replace1855_1_1_1 -> 5077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 5077 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5090, 5091 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5088, 5092 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1856_0 -> 299 in the cache */
   /* search1856_1_0 -> 551 in the cache */
   /* search1856_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 299, 5060 },
      -1,
   } },

   /* replace1856_0_0 -> 29 in the cache */
   /* replace1856_0_1 -> 5089 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 5089 },
      -1,
   } },
   /* replace1856_1_0_0 -> 29 in the cache */
   /* replace1856_1_0_1 -> 5087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 5087 },
      -1,
   } },
   /* replace1856_1_1_0_0 -> 29 in the cache */
   /* replace1856_1_1_0 -> 4894 in the cache */
   /* replace1856_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4894, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5096, 5097 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5095, 5098 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1857_0_0 -> 24 in the cache */
   /* search1857_0 -> 2217 in the cache */
   /* search1857_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2217, 45 },
      -1,
   } },

   /* replace1857_0_0 -> 5089 in the cache */
   /* replace1857_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5089, 48 },
      -1,
   } },
   /* replace1857_1_0_0 -> 5087 in the cache */
   /* replace1857_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5087, 48 },
      -1,
   } },
   /* replace1857_1_1_0 -> 24 in the cache */
   /* replace1857_1_1_1_0 -> 48 in the cache */
   /* replace1857_1_1_1 -> 5077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 5077 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5102, 5103 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5101, 5104 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1858_0 -> 299 in the cache */
   /* search1858_1_0 -> 551 in the cache */
   /* search1858_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 299, 5060 },
      -1,
   } },

   /* replace1858_0_0 -> 29 in the cache */
   /* replace1858_0_1 -> 5087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 5087 },
      -1,
   } },
   /* replace1858_1_0_0 -> 29 in the cache */
   /* replace1858_1_0_1 -> 5089 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 5089 },
      -1,
   } },
   /* replace1858_1_1_0_0 -> 29 in the cache */
   /* replace1858_1_1_0 -> 4894 in the cache */
   /* replace1858_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4894, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5108, 5109 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5107, 5110 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1859_0_0 -> 24 in the cache */
   /* search1859_0 -> 2227 in the cache */
   /* search1859_1_0 -> 2370 in the cache */
   /* search1859_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2227, 4999 },
      -1,
   } },

   /* replace1859_0 -> 24 in the cache */
   /* replace1859_1_0 -> 2370 in the cache */
   /* replace1859_1 -> 4899 in the cache */
   /* replace1859 -> 5048 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1860_0_0 -> 24 in the cache */
   /* search1860_0 -> 2227 in the cache */
   /* search1860_1_0 -> 2370 in the cache */
   /* search1860_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2227, 4999 },
      -1,
   } },

   /* replace1860_0 -> 24 in the cache */
   /* replace1860_1_0 -> 2370 in the cache */
   /* replace1860_1 -> 4899 in the cache */
   /* replace1860 -> 5050 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1861_0_0 -> 24 in the cache */
   /* search1861_0 -> 2227 in the cache */
   /* search1861_1_0 -> 2370 in the cache */
   /* search1861_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2227, 4999 },
      -1,
   } },

   /* replace1861_0 -> 24 in the cache */
   /* replace1861_1_0 -> 2370 in the cache */
   /* replace1861_1 -> 4899 in the cache */
   /* replace1861 -> 5052 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1862_0_0 -> 24 in the cache */
   /* search1862_0 -> 2227 in the cache */
   /* search1862_1_0 -> 2370 in the cache */
   /* search1862_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2227, 4999 },
      -1,
   } },

   /* replace1862_0 -> 24 in the cache */
   /* replace1862_1_0 -> 2370 in the cache */
   /* replace1862_1 -> 4899 in the cache */
   /* replace1862 -> 5054 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1863_0_0 -> 2387 in the cache */
   /* search1863_0 -> 5004 in the cache */
   /* search1863_1_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5004, 5116 },
      -1,
   } },

   /* replace1863_0_0 -> 2387 in the cache */
   /* replace1863_0 -> 4909 in the cache */
   /* replace1863_1 -> 614 in the cache */
   /* replace1863 -> 5057 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1864_0_0 -> 2387 in the cache */
   /* search1864_0 -> 5004 in the cache */
   /* search1864_1_0 -> 614 in the cache */
   /* search1864_1 -> 5116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5004, 5116 },
      -1,
   } },

   /* replace1864_0_0 -> 2387 in the cache */
   /* replace1864_0 -> 4909 in the cache */
   /* replace1864_1 -> 614 in the cache */
   /* replace1864 -> 5059 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1865_0_0 -> 24 in the cache */
   /* search1865_0 -> 2227 in the cache */
   /* search1865_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2227, 5119 },
      -1,
   } },

   /* replace1865_0 -> 24 in the cache */
   /* replace1865_1_0 -> 551 in the cache */
   /* replace1865_1 -> 5062 in the cache */
   /* replace1865 -> 5063 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1866_0_0 -> 24 in the cache */
   /* search1866_0 -> 2227 in the cache */
   /* search1866_1_0 -> 551 in the cache */
   /* search1866_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2227, 5119 },
      -1,
   } },

   /* replace1866_0 -> 24 in the cache */
   /* replace1866_1_0 -> 551 in the cache */
   /* replace1866_1 -> 5062 in the cache */
   /* replace1866 -> 5065 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1867_0_0 -> 24 in the cache */
   /* search1867_0 -> 2227 in the cache */
   /* search1867_1_0 -> 551 in the cache */
   /* search1867_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2227, 5119 },
      -1,
   } },

   /* replace1867_0 -> 24 in the cache */
   /* replace1867_1_0 -> 551 in the cache */
   /* replace1867_1 -> 5062 in the cache */
   /* replace1867 -> 5067 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1868_0_0 -> 24 in the cache */
   /* search1868_0 -> 2227 in the cache */
   /* search1868_1_0 -> 551 in the cache */
   /* search1868_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2227, 5119 },
      -1,
   } },

   /* replace1868_0 -> 24 in the cache */
   /* replace1868_1_0 -> 551 in the cache */
   /* replace1868_1 -> 5062 in the cache */
   /* replace1868 -> 5069 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1869_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 603 },
      -1,
   } },
   /* search1869_1_0 -> 614 in the cache */
   /* search1869_1 -> 5116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5124, 5116 },
      -1,
   } },

   /* replace1869_0_0 -> 603 in the cache */
   /* replace1869_0 -> 5072 in the cache */
   /* replace1869_1 -> 614 in the cache */
   /* replace1869 -> 5073 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1870_0_0 -> 603 in the cache */
   /* search1870_0 -> 5124 in the cache */
   /* search1870_1_0 -> 614 in the cache */
   /* search1870_1 -> 5116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5124, 5116 },
      -1,
   } },

   /* replace1870_0_0 -> 603 in the cache */
   /* replace1870_0 -> 5072 in the cache */
   /* replace1870_1 -> 614 in the cache */
   /* replace1870 -> 5075 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1871_0_0 -> 24 in the cache */
   /* search1871_0 -> 2227 in the cache */
   /* search1871_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2227, 5008 },
      -1,
   } },

   /* replace1871_0_0 -> 24 in the cache */
   /* replace1871_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 24, 5128 },
      -1,
   } },
   /* replace1871_1_0_0_0 -> 53 in the cache */
   /* replace1871_1_0_0 -> 5128 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 5128 },
      -1,
   } },
   /* replace1871_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5130, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5129, 5131 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1872_0_0 -> 24 in the cache */
   /* search1872_0 -> 2227 in the cache */
   /* search1872_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2227, 5008 },
      -1,
   } },

   /* replace1872_0_0 -> 24 in the cache */
   /* replace1872_0_1_0 -> 53 in the cache */
   /* replace1872_0_1 -> 5128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 24, 5128 },
      -1,
   } },
   /* replace1872_1_0_0_0 -> 53 in the cache */
   /* replace1872_1_0_0 -> 5128 in the cache */
   /* replace1872_1_0 -> 5130 in the cache */
   /* replace1872_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5130, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5134, 5135 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1873_0_0 -> 24 in the cache */
   /* search1873_0 -> 2227 in the cache */
   /* search1873_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2227, 5008 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffff8000ull /* -32768 */ },
   } },
   /* replace1873_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5138, 53 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffull /* 32767 */ },
   } },
   /* replace1873_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5140, 53 },
      -1,
   } },
   /* replace1873_1_1_0 -> 24 in the cache */
   /* replace1873_1_1_1_0 -> 53 in the cache */
   /* replace1873_1_1_1 -> 5128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 24, 5128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5141, 5142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5139, 5143 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1874_0 -> 5027 in the cache */
   /* search1874_1_0 -> 551 in the cache */
   /* search1874_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5027, 5119 },
      -1,
   } },

   /* replace1874_0_0 -> 34 in the cache */
   /* replace1874_0_1 -> 5140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 5140 },
      -1,
   } },
   /* replace1874_1_0_0 -> 34 in the cache */
   /* replace1874_1_0_1 -> 5138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 5138 },
      -1,
   } },
   /* replace1874_1_1_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1874_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5148, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5147, 5149 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5146, 5150 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1875_0_0 -> 24 in the cache */
   /* search1875_0 -> 2227 in the cache */
   /* search1875_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2227, 5008 },
      -1,
   } },

   /* replace1875_0_0 -> 5140 in the cache */
   /* replace1875_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5140, 53 },
      -1,
   } },
   /* replace1875_1_0_0 -> 5138 in the cache */
   /* replace1875_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5138, 53 },
      -1,
   } },
   /* replace1875_1_1_0 -> 24 in the cache */
   /* replace1875_1_1_1_0 -> 53 in the cache */
   /* replace1875_1_1_1 -> 5128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 24, 5128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5154, 5155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5153, 5156 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1876_0 -> 5027 in the cache */
   /* search1876_1_0 -> 551 in the cache */
   /* search1876_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5027, 5119 },
      -1,
   } },

   /* replace1876_0_0 -> 34 in the cache */
   /* replace1876_0_1 -> 5138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 5138 },
      -1,
   } },
   /* replace1876_1_0_0 -> 34 in the cache */
   /* replace1876_1_0_1 -> 5140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 5140 },
      -1,
   } },
   /* replace1876_1_1_0_0 -> 34 in the cache */
   /* replace1876_1_1_0 -> 5148 in the cache */
   /* replace1876_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5148, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5160, 5161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5159, 5162 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1877_0_0 -> 29 in the cache */
   /* search1877_0 -> 2237 in the cache */
   /* search1877_1_0 -> 2370 in the cache */
   /* search1877_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2237, 4999 },
      -1,
   } },

   /* replace1877_0 -> 29 in the cache */
   /* replace1877_1_0 -> 2370 in the cache */
   /* replace1877_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 4954 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1878_0_0 -> 29 in the cache */
   /* search1878_0 -> 2237 in the cache */
   /* search1878_1_0 -> 2370 in the cache */
   /* search1878_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 4999 },
      -1,
   } },

   /* replace1878_0 -> 29 in the cache */
   /* replace1878_1_0 -> 2370 in the cache */
   /* replace1878_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 4954 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1879_0_0 -> 29 in the cache */
   /* search1879_0 -> 2237 in the cache */
   /* search1879_1_0 -> 2370 in the cache */
   /* search1879_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2237, 4999 },
      -1,
   } },

   /* replace1879_0 -> 29 in the cache */
   /* replace1879_1_0 -> 2370 in the cache */
   /* replace1879_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 4954 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1880_0_0 -> 29 in the cache */
   /* search1880_0 -> 2237 in the cache */
   /* search1880_1_0 -> 2370 in the cache */
   /* search1880_1 -> 4999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2237, 4999 },
      -1,
   } },

   /* replace1880_0 -> 29 in the cache */
   /* replace1880_1_0 -> 2370 in the cache */
   /* replace1880_1 -> 4954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 4954 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1881_0_0 -> 2387 in the cache */
   /* search1881_0 -> 5004 in the cache */
   /* search1881_1_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5004, 5172 },
      -1,
   } },

   /* replace1881_0_0 -> 2387 in the cache */
   /* replace1881_0 -> 4959 in the cache */
   /* replace1881_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4959, 196 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1882_0_0 -> 2387 in the cache */
   /* search1882_0 -> 5004 in the cache */
   /* search1882_1_0 -> 196 in the cache */
   /* search1882_1 -> 5172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5004, 5172 },
      -1,
   } },

   /* replace1882_0_0 -> 2387 in the cache */
   /* replace1882_0 -> 4959 in the cache */
   /* replace1882_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4959, 196 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1883_0_0 -> 29 in the cache */
   /* search1883_0 -> 2237 in the cache */
   /* search1883_1_0 -> 551 in the cache */
   /* search1883_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2237, 5119 },
      -1,
   } },

   /* replace1883_0 -> 29 in the cache */
   /* replace1883_1_0 -> 551 in the cache */
   /* replace1883_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 5060 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1884_0_0 -> 29 in the cache */
   /* search1884_0 -> 2237 in the cache */
   /* search1884_1_0 -> 551 in the cache */
   /* search1884_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 5119 },
      -1,
   } },

   /* replace1884_0 -> 29 in the cache */
   /* replace1884_1_0 -> 551 in the cache */
   /* replace1884_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 5060 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1885_0_0 -> 29 in the cache */
   /* search1885_0 -> 2237 in the cache */
   /* search1885_1_0 -> 551 in the cache */
   /* search1885_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2237, 5119 },
      -1,
   } },

   /* replace1885_0 -> 29 in the cache */
   /* replace1885_1_0 -> 551 in the cache */
   /* replace1885_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 5060 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1886_0_0 -> 29 in the cache */
   /* search1886_0 -> 2237 in the cache */
   /* search1886_1_0 -> 551 in the cache */
   /* search1886_1 -> 5119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2237, 5119 },
      -1,
   } },

   /* replace1886_0 -> 29 in the cache */
   /* replace1886_1_0 -> 551 in the cache */
   /* replace1886_1 -> 5060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 5060 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1887_0_0 -> 603 in the cache */
   /* search1887_0 -> 5124 in the cache */
   /* search1887_1_0 -> 196 in the cache */
   /* search1887_1 -> 5172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5124, 5172 },
      -1,
   } },

   /* replace1887_0_0 -> 603 in the cache */
   /* replace1887_0 -> 5070 in the cache */
   /* replace1887_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5070, 196 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1888_0_0 -> 603 in the cache */
   /* search1888_0 -> 5124 in the cache */
   /* search1888_1_0 -> 196 in the cache */
   /* search1888_1 -> 5172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5124, 5172 },
      -1,
   } },

   /* replace1888_0_0 -> 603 in the cache */
   /* replace1888_0 -> 5070 in the cache */
   /* replace1888_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5070, 196 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1889_0_0 -> 29 in the cache */
   /* search1889_0 -> 2237 in the cache */
   /* search1889_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2237, 5189 },
      -1,
   } },

   /* replace1889_0 -> 29 in the cache */
   /* replace1889_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 5191 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1890_0_0 -> 29 in the cache */
   /* search1890_0 -> 2237 in the cache */
   /* search1890_1_0 -> 48 in the cache */
   /* search1890_1 -> 5189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 5189 },
      -1,
   } },

   /* replace1890_0 -> 29 in the cache */
   /* replace1890_1_0 -> 48 in the cache */
   /* replace1890_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 5191 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1891_0_0 -> 29 in the cache */
   /* search1891_0 -> 2237 in the cache */
   /* search1891_1_0 -> 48 in the cache */
   /* search1891_1 -> 5189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2237, 5189 },
      -1,
   } },

   /* replace1891_0 -> 29 in the cache */
   /* replace1891_1_0 -> 48 in the cache */
   /* replace1891_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 5191 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1892_0_0 -> 29 in the cache */
   /* search1892_0 -> 2237 in the cache */
   /* search1892_1_0 -> 48 in the cache */
   /* search1892_1 -> 5189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2237, 5189 },
      -1,
   } },

   /* replace1892_0 -> 29 in the cache */
   /* replace1892_1_0 -> 48 in the cache */
   /* replace1892_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 5191 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1893_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 386 },
      -1,
   } },
   /* search1893_1_0 -> 196 in the cache */
   /* search1893_1 -> 5172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5199, 5172 },
      -1,
   } },

   /* replace1893_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 386 },
      -1,
   } },
   /* replace1893_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5201, 196 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1894_0_0 -> 386 in the cache */
   /* search1894_0 -> 5199 in the cache */
   /* search1894_1_0 -> 196 in the cache */
   /* search1894_1 -> 5172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5199, 5172 },
      -1,
   } },

   /* replace1894_0_0 -> 386 in the cache */
   /* replace1894_0 -> 5201 in the cache */
   /* replace1894_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5201, 196 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1895_0_0 -> 29 in the cache */
   /* search1895_0 -> 2237 in the cache */
   /* search1895_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2237, 5008 },
      -1,
   } },

   /* replace1895_0_0 -> 29 in the cache */
   /* replace1895_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 29, 5206 },
      -1,
   } },
   /* replace1895_1_0_0_0 -> 53 in the cache */
   /* replace1895_1_0_0 -> 5206 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 5206 },
      -1,
   } },
   /* replace1895_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5208, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5207, 5209 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1896_0_0 -> 29 in the cache */
   /* search1896_0 -> 2237 in the cache */
   /* search1896_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 5008 },
      -1,
   } },

   /* replace1896_0_0 -> 29 in the cache */
   /* replace1896_0_1_0 -> 53 in the cache */
   /* replace1896_0_1 -> 5206 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 29, 5206 },
      -1,
   } },
   /* replace1896_1_0_0_0 -> 53 in the cache */
   /* replace1896_1_0_0 -> 5206 in the cache */
   /* replace1896_1_0 -> 5208 in the cache */
   /* replace1896_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5208, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5212, 5213 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1897_0_0 -> 29 in the cache */
   /* search1897_0 -> 2237 in the cache */
   /* search1897_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2237, 5008 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff80000000ull /* -2147483648 */ },
   } },
   /* replace1897_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5216, 53 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffull /* 2147483647 */ },
   } },
   /* replace1897_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5218, 53 },
      -1,
   } },
   /* replace1897_1_1_0 -> 29 in the cache */
   /* replace1897_1_1_1_0 -> 53 in the cache */
   /* replace1897_1_1_1 -> 5206 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 29, 5206 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5219, 5220 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5217, 5221 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1898_0 -> 5027 in the cache */
   /* search1898_1_0 -> 48 in the cache */
   /* search1898_1 -> 5189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5027, 5189 },
      -1,
   } },

   /* replace1898_0_0 -> 34 in the cache */
   /* replace1898_0_1 -> 5218 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 5218 },
      -1,
   } },
   /* replace1898_1_0_0 -> 34 in the cache */
   /* replace1898_1_0_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 34, 5216 },
      -1,
   } },
   /* replace1898_1_1_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1898_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5226, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5225, 5227 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5224, 5228 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1899_0_0 -> 29 in the cache */
   /* search1899_0 -> 2237 in the cache */
   /* search1899_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2237, 5008 },
      -1,
   } },

   /* replace1899_0_0 -> 5218 in the cache */
   /* replace1899_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5218, 53 },
      -1,
   } },
   /* replace1899_1_0_0 -> 5216 in the cache */
   /* replace1899_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5216, 53 },
      -1,
   } },
   /* replace1899_1_1_0 -> 29 in the cache */
   /* replace1899_1_1_1_0 -> 53 in the cache */
   /* replace1899_1_1_1 -> 5206 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 29, 5206 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5232, 5233 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5231, 5234 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1900_0 -> 5027 in the cache */
   /* search1900_1_0 -> 48 in the cache */
   /* search1900_1 -> 5189 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5027, 5189 },
      -1,
   } },

   /* replace1900_0_0 -> 34 in the cache */
   /* replace1900_0_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 5216 },
      -1,
   } },
   /* replace1900_1_0_0 -> 34 in the cache */
   /* replace1900_1_0_1 -> 5218 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 34, 5218 },
      -1,
   } },
   /* replace1900_1_1_0_0 -> 34 in the cache */
   /* replace1900_1_1_0 -> 5226 in the cache */
   /* replace1900_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5226, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5238, 5239 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5237, 5240 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1901_0_0 -> 19 in the cache */
   /* search1901_0 -> 2183 in the cache */
   /* search1901_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2183, 5242 },
      -1,
   } },

   /* replace1901_0 -> 19 in the cache */
   /* replace1901_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 19, 5244 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1902_0_0 -> 19 in the cache */
   /* search1902_0 -> 2183 in the cache */
   /* search1902_1_0 -> 2370 in the cache */
   /* search1902_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2183, 5242 },
      -1,
   } },

   /* replace1902_0 -> 19 in the cache */
   /* replace1902_1_0 -> 2370 in the cache */
   /* replace1902_1 -> 5244 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 19, 5244 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1903_0_0 -> 19 in the cache */
   /* search1903_0 -> 2183 in the cache */
   /* search1903_1_0 -> 2370 in the cache */
   /* search1903_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2183, 5242 },
      -1,
   } },

   /* replace1903_0 -> 19 in the cache */
   /* replace1903_1_0 -> 2370 in the cache */
   /* replace1903_1 -> 5244 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 19, 5244 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1904_0_0 -> 19 in the cache */
   /* search1904_0 -> 2183 in the cache */
   /* search1904_1_0 -> 2370 in the cache */
   /* search1904_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2183, 5242 },
      -1,
   } },

   /* replace1904_0 -> 19 in the cache */
   /* replace1904_1_0 -> 2370 in the cache */
   /* replace1904_1 -> 5244 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 5244 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1905_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* search1905_1_0 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5252, 5253 },
      -1,
   } },

   /* replace1905_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* replace1905_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5255, 2388 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1906_0_0 -> 2387 in the cache */
   /* search1906_0 -> 5252 in the cache */
   /* search1906_1_0 -> 2388 in the cache */
   /* search1906_1 -> 5253 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5252, 5253 },
      -1,
   } },

   /* replace1906_0_0 -> 2387 in the cache */
   /* replace1906_0 -> 5255 in the cache */
   /* replace1906_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5255, 2388 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1907_0_0 -> 19 in the cache */
   /* search1907_0 -> 2183 in the cache */
   /* search1907_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2183, 2269 },
      -1,
   } },

   /* replace1907_0_0 -> 19 in the cache */
   /* replace1907_0_1_0 -> 551 in the cache */
   /* replace1907_0_1 -> 2277 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 2277 },
      -1,
   } },
   /* replace1907_1_0_0_0 -> 551 in the cache */
   /* replace1907_1_0_0 -> 2277 in the cache */
   /* replace1907_1_0 -> 2278 in the cache */
   /* replace1907_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2278, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5260, 5261 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1908_0_0 -> 19 in the cache */
   /* search1908_0 -> 2183 in the cache */
   /* search1908_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2183, 2269 },
      -1,
   } },

   /* replace1908_0_0 -> 19 in the cache */
   /* replace1908_0_1_0 -> 551 in the cache */
   /* replace1908_0_1 -> 2277 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 2277 },
      -1,
   } },
   /* replace1908_1_0_0_0 -> 551 in the cache */
   /* replace1908_1_0_0 -> 2277 in the cache */
   /* replace1908_1_0 -> 2278 in the cache */
   /* replace1908_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2278, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5264, 5265 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1909_0_0 -> 19 in the cache */
   /* search1909_0 -> 2183 in the cache */
   /* search1909_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2183, 2269 },
      -1,
   } },

   /* replace1909_0_0 -> 946 in the cache */
   /* replace1909_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 946, 551 },
      -1,
   } },
   /* replace1909_1_0_0 -> 2271 in the cache */
   /* replace1909_1_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2271, 551 },
      -1,
   } },
   /* replace1909_1_1_0 -> 19 in the cache */
   /* replace1909_1_1_1_0 -> 551 in the cache */
   /* replace1909_1_1_1 -> 2277 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 2277 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5269, 5270 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5268, 5271 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1910_0 -> 4934 in the cache */
   /* search1910_1_0 -> 2370 in the cache */
   /* search1910_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4934, 5242 },
      -1,
   } },

   /* replace1910_0_0 -> 24 in the cache */
   /* replace1910_0_1 -> 2271 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 2271 },
      -1,
   } },
   /* replace1910_1_0_0 -> 24 in the cache */
   /* replace1910_1_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 946 },
      -1,
   } },
   /* replace1910_1_1_0_0 -> 24 in the cache */
   /* replace1910_1_1_0 -> 2267 in the cache */
   /* replace1910_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2267, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5275, 5276 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5274, 5277 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1911_0_0 -> 19 in the cache */
   /* search1911_0 -> 2183 in the cache */
   /* search1911_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2183, 2269 },
      -1,
   } },

   /* replace1911_0_0 -> 2271 in the cache */
   /* replace1911_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2271, 551 },
      -1,
   } },
   /* replace1911_1_0_0 -> 946 in the cache */
   /* replace1911_1_0_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 946, 551 },
      -1,
   } },
   /* replace1911_1_1_0 -> 19 in the cache */
   /* replace1911_1_1_1_0 -> 551 in the cache */
   /* replace1911_1_1_1 -> 2277 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 19, 2277 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5281, 5282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5280, 5283 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1912_0 -> 4934 in the cache */
   /* search1912_1_0 -> 2370 in the cache */
   /* search1912_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4934, 5242 },
      -1,
   } },

   /* replace1912_0_0 -> 24 in the cache */
   /* replace1912_0_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 946 },
      -1,
   } },
   /* replace1912_1_0_0 -> 24 in the cache */
   /* replace1912_1_0_1 -> 2271 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 2271 },
      -1,
   } },
   /* replace1912_1_1_0_0 -> 24 in the cache */
   /* replace1912_1_1_0 -> 2267 in the cache */
   /* replace1912_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2267, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5287, 5288 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5286, 5289 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1913_0_0 -> 19 in the cache */
   /* search1913_0 -> 2189 in the cache */
   /* search1913_1_0 -> 2370 in the cache */
   /* search1913_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2189, 3732 },
      -1,
   } },

   /* replace1913_0 -> 19 in the cache */
   /* replace1913_1_0 -> 2370 in the cache */
   /* replace1913_1 -> 5244 in the cache */
   /* replace1913 -> 5245 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1914_0_0 -> 19 in the cache */
   /* search1914_0 -> 2189 in the cache */
   /* search1914_1_0 -> 2370 in the cache */
   /* search1914_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2189, 3732 },
      -1,
   } },

   /* replace1914_0 -> 19 in the cache */
   /* replace1914_1_0 -> 2370 in the cache */
   /* replace1914_1 -> 5244 in the cache */
   /* replace1914 -> 5247 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1915_0_0 -> 19 in the cache */
   /* search1915_0 -> 2189 in the cache */
   /* search1915_1_0 -> 2370 in the cache */
   /* search1915_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2189, 3732 },
      -1,
   } },

   /* replace1915_0 -> 19 in the cache */
   /* replace1915_1_0 -> 2370 in the cache */
   /* replace1915_1 -> 5244 in the cache */
   /* replace1915 -> 5249 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1916_0_0 -> 19 in the cache */
   /* search1916_0 -> 2189 in the cache */
   /* search1916_1_0 -> 2370 in the cache */
   /* search1916_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2189, 3732 },
      -1,
   } },

   /* replace1916_0 -> 19 in the cache */
   /* replace1916_1_0 -> 2370 in the cache */
   /* replace1916_1 -> 5244 in the cache */
   /* replace1916 -> 5251 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1917_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* search1917_1_0 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5295, 5296 },
      -1,
   } },

   /* replace1917_0_0 -> 2387 in the cache */
   /* replace1917_0 -> 5255 in the cache */
   /* replace1917_1 -> 2388 in the cache */
   /* replace1917 -> 5256 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1918_0_0 -> 2387 in the cache */
   /* search1918_0 -> 5295 in the cache */
   /* search1918_1_0 -> 2388 in the cache */
   /* search1918_1 -> 5296 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5295, 5296 },
      -1,
   } },

   /* replace1918_0_0 -> 2387 in the cache */
   /* replace1918_0 -> 5255 in the cache */
   /* replace1918_1 -> 2388 in the cache */
   /* replace1918 -> 5258 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1919_0_0 -> 19 in the cache */
   /* search1919_0 -> 2189 in the cache */
   /* search1919_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2189, 45 },
      -1,
   } },

   /* replace1919_0_0 -> 19 in the cache */
   /* replace1919_0_1_0 -> 48 in the cache */
   /* replace1919_0_1 -> 2285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 2285 },
      -1,
   } },
   /* replace1919_1_0_0_0 -> 48 in the cache */
   /* replace1919_1_0_0 -> 2285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2285 },
      -1,
   } },
   /* replace1919_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5301, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5300, 5302 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1920_0_0 -> 19 in the cache */
   /* search1920_0 -> 2189 in the cache */
   /* search1920_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2189, 45 },
      -1,
   } },

   /* replace1920_0_0 -> 19 in the cache */
   /* replace1920_0_1_0 -> 48 in the cache */
   /* replace1920_0_1 -> 2285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 2285 },
      -1,
   } },
   /* replace1920_1_0_0_0 -> 48 in the cache */
   /* replace1920_1_0_0 -> 2285 in the cache */
   /* replace1920_1_0 -> 5301 in the cache */
   /* replace1920_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5301, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5305, 5306 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1921_0_0 -> 19 in the cache */
   /* search1921_0 -> 2189 in the cache */
   /* search1921_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2189, 45 },
      -1,
   } },

   /* replace1921_0_0 -> 135 in the cache */
   /* replace1921_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 135, 48 },
      -1,
   } },
   /* replace1921_1_0_0 -> 1100 in the cache */
   /* replace1921_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1100, 48 },
      -1,
   } },
   /* replace1921_1_1_0 -> 19 in the cache */
   /* replace1921_1_1_1_0 -> 48 in the cache */
   /* replace1921_1_1_1 -> 2285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 2285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5310, 5311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5309, 5312 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1922_0 -> 299 in the cache */
   /* search1922_1_0 -> 2370 in the cache */
   /* search1922_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 299, 3732 },
      -1,
   } },

   /* replace1922_0_0 -> 29 in the cache */
   /* replace1922_0_1 -> 1100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 1100 },
      -1,
   } },
   /* replace1922_1_0_0 -> 29 in the cache */
   /* replace1922_1_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace1922_1_1_0_0 -> 29 in the cache */
   /* replace1922_1_1_0 -> 2283 in the cache */
   /* replace1922_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2283, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5316, 5317 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5315, 5318 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1923_0_0 -> 19 in the cache */
   /* search1923_0 -> 2189 in the cache */
   /* search1923_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2189, 45 },
      -1,
   } },

   /* replace1923_0_0 -> 1100 in the cache */
   /* replace1923_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1100, 48 },
      -1,
   } },
   /* replace1923_1_0_0 -> 135 in the cache */
   /* replace1923_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 135, 48 },
      -1,
   } },
   /* replace1923_1_1_0 -> 19 in the cache */
   /* replace1923_1_1_1_0 -> 48 in the cache */
   /* replace1923_1_1_1 -> 2285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 19, 2285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5322, 5323 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5321, 5324 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1924_0 -> 299 in the cache */
   /* search1924_1_0 -> 2370 in the cache */
   /* search1924_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 299, 3732 },
      -1,
   } },

   /* replace1924_0_0 -> 29 in the cache */
   /* replace1924_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace1924_1_0_0 -> 29 in the cache */
   /* replace1924_1_0_1 -> 1100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 1100 },
      -1,
   } },
   /* replace1924_1_1_0_0 -> 29 in the cache */
   /* replace1924_1_1_0 -> 2283 in the cache */
   /* replace1924_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2283, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5328, 5329 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5327, 5330 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1925_0_0 -> 19 in the cache */
   /* search1925_0 -> 2193 in the cache */
   /* search1925_1_0 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2193, 5332 },
      -1,
   } },

   /* replace1925_0 -> 19 in the cache */
   /* replace1925_1_0 -> 2370 in the cache */
   /* replace1925_1 -> 5244 in the cache */
   /* replace1925 -> 5245 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1926_0_0 -> 19 in the cache */
   /* search1926_0 -> 2193 in the cache */
   /* search1926_1_0 -> 2370 in the cache */
   /* search1926_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2193, 5332 },
      -1,
   } },

   /* replace1926_0 -> 19 in the cache */
   /* replace1926_1_0 -> 2370 in the cache */
   /* replace1926_1 -> 5244 in the cache */
   /* replace1926 -> 5247 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1927_0_0 -> 19 in the cache */
   /* search1927_0 -> 2193 in the cache */
   /* search1927_1_0 -> 2370 in the cache */
   /* search1927_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2193, 5332 },
      -1,
   } },

   /* replace1927_0 -> 19 in the cache */
   /* replace1927_1_0 -> 2370 in the cache */
   /* replace1927_1 -> 5244 in the cache */
   /* replace1927 -> 5249 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1928_0_0 -> 19 in the cache */
   /* search1928_0 -> 2193 in the cache */
   /* search1928_1_0 -> 2370 in the cache */
   /* search1928_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2193, 5332 },
      -1,
   } },

   /* replace1928_0 -> 19 in the cache */
   /* replace1928_1_0 -> 2370 in the cache */
   /* replace1928_1 -> 5244 in the cache */
   /* replace1928 -> 5251 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1929_0_0 -> 2387 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2387 },
      -1,
   } },
   /* search1929_1_0 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5337, 5338 },
      -1,
   } },

   /* replace1929_0_0 -> 2387 in the cache */
   /* replace1929_0 -> 5255 in the cache */
   /* replace1929_1 -> 2388 in the cache */
   /* replace1929 -> 5256 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1930_0_0 -> 2387 in the cache */
   /* search1930_0 -> 5337 in the cache */
   /* search1930_1_0 -> 2388 in the cache */
   /* search1930_1 -> 5338 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5337, 5338 },
      -1,
   } },

   /* replace1930_0_0 -> 2387 in the cache */
   /* replace1930_0 -> 5255 in the cache */
   /* replace1930_1 -> 2388 in the cache */
   /* replace1930 -> 5258 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1931_0_0 -> 19 in the cache */
   /* search1931_0 -> 2193 in the cache */
   /* search1931_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2193, 5008 },
      -1,
   } },

   /* replace1931_0_0 -> 19 in the cache */
   /* replace1931_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 19, 5342 },
      -1,
   } },
   /* replace1931_1_0_0_0 -> 53 in the cache */
   /* replace1931_1_0_0 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 5342 },
      -1,
   } },
   /* replace1931_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5344, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5343, 5345 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1932_0_0 -> 19 in the cache */
   /* search1932_0 -> 2193 in the cache */
   /* search1932_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2193, 5008 },
      -1,
   } },

   /* replace1932_0_0 -> 19 in the cache */
   /* replace1932_0_1_0 -> 53 in the cache */
   /* replace1932_0_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 19, 5342 },
      -1,
   } },
   /* replace1932_1_0_0_0 -> 53 in the cache */
   /* replace1932_1_0_0 -> 5342 in the cache */
   /* replace1932_1_0 -> 5344 in the cache */
   /* replace1932_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5344, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5348, 5349 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1933_0_0 -> 19 in the cache */
   /* search1933_0 -> 2193 in the cache */
   /* search1933_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2193, 5008 },
      -1,
   } },

   /* replace1933_0_0 -> 987 in the cache */
   /* replace1933_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 987, 53 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffull /* 255 */ },
   } },
   /* replace1933_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5353, 53 },
      -1,
   } },
   /* replace1933_1_1_0 -> 19 in the cache */
   /* replace1933_1_1_1_0 -> 53 in the cache */
   /* replace1933_1_1_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 5342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5354, 5355 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5352, 5356 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1934_0 -> 5027 in the cache */
   /* search1934_1_0 -> 2370 in the cache */
   /* search1934_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5027, 5332 },
      -1,
   } },

   /* replace1934_0_0 -> 34 in the cache */
   /* replace1934_0_1 -> 5353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 34, 5353 },
      -1,
   } },
   /* replace1934_1_0_0 -> 34 in the cache */
   /* replace1934_1_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 34, 987 },
      -1,
   } },
   /* replace1934_1_1_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1934_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5361, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5360, 5362 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5359, 5363 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1935_0_0 -> 19 in the cache */
   /* search1935_0 -> 2193 in the cache */
   /* search1935_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2193, 5008 },
      -1,
   } },

   /* replace1935_0_0 -> 5353 in the cache */
   /* replace1935_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5353, 53 },
      -1,
   } },
   /* replace1935_1_0_0 -> 987 in the cache */
   /* replace1935_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 987, 53 },
      -1,
   } },
   /* replace1935_1_1_0 -> 19 in the cache */
   /* replace1935_1_1_1_0 -> 53 in the cache */
   /* replace1935_1_1_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 19, 5342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5367, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5366, 5369 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1936_0 -> 5027 in the cache */
   /* search1936_1_0 -> 2370 in the cache */
   /* search1936_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5027, 5332 },
      -1,
   } },

   /* replace1936_0_0 -> 34 in the cache */
   /* replace1936_0_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 34, 987 },
      -1,
   } },
   /* replace1936_1_0_0 -> 34 in the cache */
   /* replace1936_1_0_1 -> 5353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 34, 5353 },
      -1,
   } },
   /* replace1936_1_1_0_0 -> 34 in the cache */
   /* replace1936_1_1_0 -> 5361 in the cache */
   /* replace1936_1_1_1 -> 2370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5361, 2370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5373, 5374 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5372, 5375 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1937_0_0 -> 24 in the cache */
   /* search1937_0 -> 2219 in the cache */
   /* search1937_1_0 -> 2370 in the cache */
   /* search1937_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2219, 3732 },
      -1,
   } },

   /* replace1937_0 -> 24 in the cache */
   /* replace1937_1_0 -> 2370 in the cache */
   /* replace1937_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 24, 5242 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1938_0_0 -> 24 in the cache */
   /* search1938_0 -> 2219 in the cache */
   /* search1938_1_0 -> 2370 in the cache */
   /* search1938_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2219, 3732 },
      -1,
   } },

   /* replace1938_0 -> 24 in the cache */
   /* replace1938_1_0 -> 2370 in the cache */
   /* replace1938_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 24, 5242 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1939_0_0 -> 24 in the cache */
   /* search1939_0 -> 2219 in the cache */
   /* search1939_1_0 -> 2370 in the cache */
   /* search1939_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2219, 3732 },
      -1,
   } },

   /* replace1939_0 -> 24 in the cache */
   /* replace1939_1_0 -> 2370 in the cache */
   /* replace1939_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 5242 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1940_0_0 -> 24 in the cache */
   /* search1940_0 -> 2219 in the cache */
   /* search1940_1_0 -> 2370 in the cache */
   /* search1940_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2219, 3732 },
      -1,
   } },

   /* replace1940_0 -> 24 in the cache */
   /* replace1940_1_0 -> 2370 in the cache */
   /* replace1940_1 -> 5242 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 5242 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1941_0_0 -> 2387 in the cache */
   /* search1941_0 -> 5295 in the cache */
   /* search1941_1_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5295, 5385 },
      -1,
   } },

   /* replace1941_0_0 -> 2387 in the cache */
   /* replace1941_0 -> 5252 in the cache */
   /* replace1941_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5252, 614 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1942_0_0 -> 2387 in the cache */
   /* search1942_0 -> 5295 in the cache */
   /* search1942_1_0 -> 614 in the cache */
   /* search1942_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5295, 5385 },
      -1,
   } },

   /* replace1942_0_0 -> 2387 in the cache */
   /* replace1942_0 -> 5252 in the cache */
   /* replace1942_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5252, 614 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1943_0_0 -> 24 in the cache */
   /* search1943_0 -> 2219 in the cache */
   /* search1943_1_0 -> 551 in the cache */
   /* search1943_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2219, 3753 },
      -1,
   } },

   /* replace1943_0 -> 24 in the cache */
   /* replace1943_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 24, 5391 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1944_0_0 -> 24 in the cache */
   /* search1944_0 -> 2219 in the cache */
   /* search1944_1_0 -> 551 in the cache */
   /* search1944_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2219, 3753 },
      -1,
   } },

   /* replace1944_0 -> 24 in the cache */
   /* replace1944_1_0 -> 551 in the cache */
   /* replace1944_1 -> 5391 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 24, 5391 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1945_0_0 -> 24 in the cache */
   /* search1945_0 -> 2219 in the cache */
   /* search1945_1_0 -> 551 in the cache */
   /* search1945_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2219, 3753 },
      -1,
   } },

   /* replace1945_0 -> 24 in the cache */
   /* replace1945_1_0 -> 551 in the cache */
   /* replace1945_1 -> 5391 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 5391 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1946_0_0 -> 24 in the cache */
   /* search1946_0 -> 2219 in the cache */
   /* search1946_1_0 -> 551 in the cache */
   /* search1946_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2219, 3753 },
      -1,
   } },

   /* replace1946_0 -> 24 in the cache */
   /* replace1946_1_0 -> 551 in the cache */
   /* replace1946_1 -> 5391 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 5391 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1947_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 603 },
      -1,
   } },
   /* search1947_1_0 -> 614 in the cache */
   /* search1947_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5399, 5385 },
      -1,
   } },

   /* replace1947_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 603 },
      -1,
   } },
   /* replace1947_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5401, 614 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1948_0_0 -> 603 in the cache */
   /* search1948_0 -> 5399 in the cache */
   /* search1948_1_0 -> 614 in the cache */
   /* search1948_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5399, 5385 },
      -1,
   } },

   /* replace1948_0_0 -> 603 in the cache */
   /* replace1948_0 -> 5401 in the cache */
   /* replace1948_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5401, 614 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1949_0_0 -> 24 in the cache */
   /* search1949_0 -> 2219 in the cache */
   /* search1949_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2219, 45 },
      -1,
   } },

   /* replace1949_0_0 -> 24 in the cache */
   /* replace1949_0_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 24, 5406 },
      -1,
   } },
   /* replace1949_1_0_0_0 -> 48 in the cache */
   /* replace1949_1_0_0 -> 5406 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5406 },
      -1,
   } },
   /* replace1949_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5408, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5407, 5409 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1950_0_0 -> 24 in the cache */
   /* search1950_0 -> 2219 in the cache */
   /* search1950_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2219, 45 },
      -1,
   } },

   /* replace1950_0_0 -> 24 in the cache */
   /* replace1950_0_1_0 -> 48 in the cache */
   /* replace1950_0_1 -> 5406 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 24, 5406 },
      -1,
   } },
   /* replace1950_1_0_0_0 -> 48 in the cache */
   /* replace1950_1_0_0 -> 5406 in the cache */
   /* replace1950_1_0 -> 5408 in the cache */
   /* replace1950_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5408, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5412, 5413 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1951_0_0 -> 24 in the cache */
   /* search1951_0 -> 2219 in the cache */
   /* search1951_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2219, 45 },
      -1,
   } },

   /* replace1951_0_0 -> 135 in the cache */
   /* replace1951_0_1 -> 48 in the cache */
   /* replace1951_0 -> 5309 in the cache */
   /* replace1951_1_0_0 -> 1092 in the cache */
   /* replace1951_1_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1092, 48 },
      -1,
   } },
   /* replace1951_1_1_0 -> 24 in the cache */
   /* replace1951_1_1_1_0 -> 48 in the cache */
   /* replace1951_1_1_1 -> 5406 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 5406 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5416, 5417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5309, 5418 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1952_0 -> 299 in the cache */
   /* search1952_1_0 -> 551 in the cache */
   /* search1952_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 299, 3753 },
      -1,
   } },

   /* replace1952_0_0 -> 29 in the cache */
   /* replace1952_0_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 1092 },
      -1,
   } },
   /* replace1952_1_0_0 -> 29 in the cache */
   /* replace1952_1_0_1 -> 135 in the cache */
   /* replace1952_1_0 -> 5316 in the cache */
   /* replace1952_1_1_0_0 -> 29 in the cache */
   /* replace1952_1_1_0 -> 3761 in the cache */
   /* replace1952_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3761, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5316, 5422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5421, 5423 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1953_0_0 -> 24 in the cache */
   /* search1953_0 -> 2219 in the cache */
   /* search1953_1 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2219, 45 },
      -1,
   } },

   /* replace1953_0_0 -> 1092 in the cache */
   /* replace1953_0_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1092, 48 },
      -1,
   } },
   /* replace1953_1_0_0 -> 135 in the cache */
   /* replace1953_1_0_1 -> 48 in the cache */
   /* replace1953_1_0 -> 5322 in the cache */
   /* replace1953_1_1_0 -> 24 in the cache */
   /* replace1953_1_1_1_0 -> 48 in the cache */
   /* replace1953_1_1_1 -> 5406 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 5406 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5322, 5427 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5426, 5428 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1954_0 -> 299 in the cache */
   /* search1954_1_0 -> 551 in the cache */
   /* search1954_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 299, 3753 },
      -1,
   } },

   /* replace1954_0_0 -> 29 in the cache */
   /* replace1954_0_1 -> 135 in the cache */
   /* replace1954_0 -> 5327 in the cache */
   /* replace1954_1_0_0 -> 29 in the cache */
   /* replace1954_1_0_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 1092 },
      -1,
   } },
   /* replace1954_1_1_0_0 -> 29 in the cache */
   /* replace1954_1_1_0 -> 3761 in the cache */
   /* replace1954_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3761, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5431, 5432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5327, 5433 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1955_0_0 -> 24 in the cache */
   /* search1955_0 -> 2225 in the cache */
   /* search1955_1_0 -> 2370 in the cache */
   /* search1955_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2225, 5332 },
      -1,
   } },

   /* replace1955_0 -> 24 in the cache */
   /* replace1955_1_0 -> 2370 in the cache */
   /* replace1955_1 -> 5242 in the cache */
   /* replace1955 -> 5378 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1956_0_0 -> 24 in the cache */
   /* search1956_0 -> 2225 in the cache */
   /* search1956_1_0 -> 2370 in the cache */
   /* search1956_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2225, 5332 },
      -1,
   } },

   /* replace1956_0 -> 24 in the cache */
   /* replace1956_1_0 -> 2370 in the cache */
   /* replace1956_1 -> 5242 in the cache */
   /* replace1956 -> 5380 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1957_0_0 -> 24 in the cache */
   /* search1957_0 -> 2225 in the cache */
   /* search1957_1_0 -> 2370 in the cache */
   /* search1957_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2225, 5332 },
      -1,
   } },

   /* replace1957_0 -> 24 in the cache */
   /* replace1957_1_0 -> 2370 in the cache */
   /* replace1957_1 -> 5242 in the cache */
   /* replace1957 -> 5382 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1958_0_0 -> 24 in the cache */
   /* search1958_0 -> 2225 in the cache */
   /* search1958_1_0 -> 2370 in the cache */
   /* search1958_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2225, 5332 },
      -1,
   } },

   /* replace1958_0 -> 24 in the cache */
   /* replace1958_1_0 -> 2370 in the cache */
   /* replace1958_1 -> 5242 in the cache */
   /* replace1958 -> 5384 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1959_0_0 -> 2387 in the cache */
   /* search1959_0 -> 5337 in the cache */
   /* search1959_1_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5337, 5439 },
      -1,
   } },

   /* replace1959_0_0 -> 2387 in the cache */
   /* replace1959_0 -> 5252 in the cache */
   /* replace1959_1 -> 614 in the cache */
   /* replace1959 -> 5387 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1960_0_0 -> 2387 in the cache */
   /* search1960_0 -> 5337 in the cache */
   /* search1960_1_0 -> 614 in the cache */
   /* search1960_1 -> 5439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5337, 5439 },
      -1,
   } },

   /* replace1960_0_0 -> 2387 in the cache */
   /* replace1960_0 -> 5252 in the cache */
   /* replace1960_1 -> 614 in the cache */
   /* replace1960 -> 5389 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1961_0_0 -> 24 in the cache */
   /* search1961_0 -> 2225 in the cache */
   /* search1961_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2225, 5442 },
      -1,
   } },

   /* replace1961_0 -> 24 in the cache */
   /* replace1961_1_0 -> 551 in the cache */
   /* replace1961_1 -> 5391 in the cache */
   /* replace1961 -> 5392 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1962_0_0 -> 24 in the cache */
   /* search1962_0 -> 2225 in the cache */
   /* search1962_1_0 -> 551 in the cache */
   /* search1962_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2225, 5442 },
      -1,
   } },

   /* replace1962_0 -> 24 in the cache */
   /* replace1962_1_0 -> 551 in the cache */
   /* replace1962_1 -> 5391 in the cache */
   /* replace1962 -> 5394 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1963_0_0 -> 24 in the cache */
   /* search1963_0 -> 2225 in the cache */
   /* search1963_1_0 -> 551 in the cache */
   /* search1963_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2225, 5442 },
      -1,
   } },

   /* replace1963_0 -> 24 in the cache */
   /* replace1963_1_0 -> 551 in the cache */
   /* replace1963_1 -> 5391 in the cache */
   /* replace1963 -> 5396 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1964_0_0 -> 24 in the cache */
   /* search1964_0 -> 2225 in the cache */
   /* search1964_1_0 -> 551 in the cache */
   /* search1964_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2225, 5442 },
      -1,
   } },

   /* replace1964_0 -> 24 in the cache */
   /* replace1964_1_0 -> 551 in the cache */
   /* replace1964_1 -> 5391 in the cache */
   /* replace1964 -> 5398 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1965_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 603 },
      -1,
   } },
   /* search1965_1_0 -> 614 in the cache */
   /* search1965_1 -> 5439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5447, 5439 },
      -1,
   } },

   /* replace1965_0_0 -> 603 in the cache */
   /* replace1965_0 -> 5401 in the cache */
   /* replace1965_1 -> 614 in the cache */
   /* replace1965 -> 5402 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1966_0_0 -> 603 in the cache */
   /* search1966_0 -> 5447 in the cache */
   /* search1966_1_0 -> 614 in the cache */
   /* search1966_1 -> 5439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5447, 5439 },
      -1,
   } },

   /* replace1966_0_0 -> 603 in the cache */
   /* replace1966_0 -> 5401 in the cache */
   /* replace1966_1 -> 614 in the cache */
   /* replace1966 -> 5404 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1967_0_0 -> 24 in the cache */
   /* search1967_0 -> 2225 in the cache */
   /* search1967_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2225, 5008 },
      -1,
   } },

   /* replace1967_0_0 -> 24 in the cache */
   /* replace1967_0_1_0 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 24, 5451 },
      -1,
   } },
   /* replace1967_1_0_0_0 -> 53 in the cache */
   /* replace1967_1_0_0 -> 5451 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 5451 },
      -1,
   } },
   /* replace1967_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5453, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5452, 5454 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1968_0_0 -> 24 in the cache */
   /* search1968_0 -> 2225 in the cache */
   /* search1968_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2225, 5008 },
      -1,
   } },

   /* replace1968_0_0 -> 24 in the cache */
   /* replace1968_0_1_0 -> 53 in the cache */
   /* replace1968_0_1 -> 5451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 24, 5451 },
      -1,
   } },
   /* replace1968_1_0_0_0 -> 53 in the cache */
   /* replace1968_1_0_0 -> 5451 in the cache */
   /* replace1968_1_0 -> 5453 in the cache */
   /* replace1968_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5453, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5457, 5458 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1969_0_0 -> 24 in the cache */
   /* search1969_0 -> 2225 in the cache */
   /* search1969_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2225, 5008 },
      -1,
   } },

   /* replace1969_0_0 -> 987 in the cache */
   /* replace1969_0_1 -> 53 in the cache */
   /* replace1969_0 -> 5352 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffull /* 65535 */ },
   } },
   /* replace1969_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5461, 53 },
      -1,
   } },
   /* replace1969_1_1_0 -> 24 in the cache */
   /* replace1969_1_1_1_0 -> 53 in the cache */
   /* replace1969_1_1_1 -> 5451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 24, 5451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5462, 5463 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5352, 5464 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1970_0 -> 5027 in the cache */
   /* search1970_1_0 -> 551 in the cache */
   /* search1970_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5027, 5442 },
      -1,
   } },

   /* replace1970_0_0 -> 34 in the cache */
   /* replace1970_0_1 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 34, 5461 },
      -1,
   } },
   /* replace1970_1_0_0 -> 34 in the cache */
   /* replace1970_1_0_1 -> 987 in the cache */
   /* replace1970_1_0 -> 5360 in the cache */
   /* replace1970_1_1_0_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 34 },
      -1,
   } },
   /* replace1970_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5468, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5360, 5469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5467, 5470 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1971_0_0 -> 24 in the cache */
   /* search1971_0 -> 2225 in the cache */
   /* search1971_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2225, 5008 },
      -1,
   } },

   /* replace1971_0_0 -> 5461 in the cache */
   /* replace1971_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5461, 53 },
      -1,
   } },
   /* replace1971_1_0_0 -> 987 in the cache */
   /* replace1971_1_0_1 -> 53 in the cache */
   /* replace1971_1_0 -> 5367 in the cache */
   /* replace1971_1_1_0 -> 24 in the cache */
   /* replace1971_1_1_1_0 -> 53 in the cache */
   /* replace1971_1_1_1 -> 5451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 24, 5451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5367, 5474 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5473, 5475 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1972_0 -> 5027 in the cache */
   /* search1972_1_0 -> 551 in the cache */
   /* search1972_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5027, 5442 },
      -1,
   } },

   /* replace1972_0_0 -> 34 in the cache */
   /* replace1972_0_1 -> 987 in the cache */
   /* replace1972_0 -> 5372 in the cache */
   /* replace1972_1_0_0 -> 34 in the cache */
   /* replace1972_1_0_1 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 34, 5461 },
      -1,
   } },
   /* replace1972_1_1_0_0 -> 34 in the cache */
   /* replace1972_1_1_0 -> 5468 in the cache */
   /* replace1972_1_1_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5468, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5478, 5479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5372, 5480 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1973_0_0 -> 29 in the cache */
   /* search1973_0 -> 2239 in the cache */
   /* search1973_1_0 -> 2370 in the cache */
   /* search1973_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2239, 5332 },
      -1,
   } },

   /* replace1973_0 -> 29 in the cache */
   /* replace1973_1_0 -> 2370 in the cache */
   /* replace1973_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 3732 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1974_0_0 -> 29 in the cache */
   /* search1974_0 -> 2239 in the cache */
   /* search1974_1_0 -> 2370 in the cache */
   /* search1974_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2239, 5332 },
      -1,
   } },

   /* replace1974_0 -> 29 in the cache */
   /* replace1974_1_0 -> 2370 in the cache */
   /* replace1974_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 3732 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1975_0_0 -> 29 in the cache */
   /* search1975_0 -> 2239 in the cache */
   /* search1975_1_0 -> 2370 in the cache */
   /* search1975_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2239, 5332 },
      -1,
   } },

   /* replace1975_0 -> 29 in the cache */
   /* replace1975_1_0 -> 2370 in the cache */
   /* replace1975_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 3732 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1976_0_0 -> 29 in the cache */
   /* search1976_0 -> 2239 in the cache */
   /* search1976_1_0 -> 2370 in the cache */
   /* search1976_1 -> 5332 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2239, 5332 },
      -1,
   } },

   /* replace1976_0 -> 29 in the cache */
   /* replace1976_1_0 -> 2370 in the cache */
   /* replace1976_1 -> 3732 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 3732 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1977_0_0 -> 2387 in the cache */
   /* search1977_0 -> 5337 in the cache */
   /* search1977_1_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5337, 5490 },
      -1,
   } },

   /* replace1977_0_0 -> 2387 in the cache */
   /* replace1977_0 -> 5295 in the cache */
   /* replace1977_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5295, 196 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1978_0_0 -> 2387 in the cache */
   /* search1978_0 -> 5337 in the cache */
   /* search1978_1_0 -> 196 in the cache */
   /* search1978_1 -> 5490 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5337, 5490 },
      -1,
   } },

   /* replace1978_0_0 -> 2387 in the cache */
   /* replace1978_0 -> 5295 in the cache */
   /* replace1978_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5295, 196 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1979_0_0 -> 29 in the cache */
   /* search1979_0 -> 2239 in the cache */
   /* search1979_1_0 -> 551 in the cache */
   /* search1979_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2239, 5442 },
      -1,
   } },

   /* replace1979_0 -> 29 in the cache */
   /* replace1979_1_0 -> 551 in the cache */
   /* replace1979_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 3753 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1980_0_0 -> 29 in the cache */
   /* search1980_0 -> 2239 in the cache */
   /* search1980_1_0 -> 551 in the cache */
   /* search1980_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2239, 5442 },
      -1,
   } },

   /* replace1980_0 -> 29 in the cache */
   /* replace1980_1_0 -> 551 in the cache */
   /* replace1980_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 3753 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1981_0_0 -> 29 in the cache */
   /* search1981_0 -> 2239 in the cache */
   /* search1981_1_0 -> 551 in the cache */
   /* search1981_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2239, 5442 },
      -1,
   } },

   /* replace1981_0 -> 29 in the cache */
   /* replace1981_1_0 -> 551 in the cache */
   /* replace1981_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 3753 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1982_0_0 -> 29 in the cache */
   /* search1982_0 -> 2239 in the cache */
   /* search1982_1_0 -> 551 in the cache */
   /* search1982_1 -> 5442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2239, 5442 },
      -1,
   } },

   /* replace1982_0 -> 29 in the cache */
   /* replace1982_1_0 -> 551 in the cache */
   /* replace1982_1 -> 3753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 3753 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1983_0_0 -> 603 in the cache */
   /* search1983_0 -> 5447 in the cache */
   /* search1983_1_0 -> 196 in the cache */
   /* search1983_1 -> 5490 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5447, 5490 },
      -1,
   } },

   /* replace1983_0_0 -> 603 in the cache */
   /* replace1983_0 -> 5399 in the cache */
   /* replace1983_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5399, 196 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1984_0_0 -> 603 in the cache */
   /* search1984_0 -> 5447 in the cache */
   /* search1984_1_0 -> 196 in the cache */
   /* search1984_1 -> 5490 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5447, 5490 },
      -1,
   } },

   /* replace1984_0_0 -> 603 in the cache */
   /* replace1984_0 -> 5399 in the cache */
   /* replace1984_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5399, 196 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1985_0_0 -> 29 in the cache */
   /* search1985_0 -> 2239 in the cache */
   /* search1985_1_0 -> 48 in the cache */
   /* search1985_1 -> 3750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2239, 3750 },
      -1,
   } },

   /* replace1985_0 -> 29 in the cache */
   /* replace1985_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 29, 5508 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1986_0_0 -> 29 in the cache */
   /* search1986_0 -> 2239 in the cache */
   /* search1986_1_0 -> 48 in the cache */
   /* search1986_1 -> 3750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2239, 3750 },
      -1,
   } },

   /* replace1986_0 -> 29 in the cache */
   /* replace1986_1_0 -> 48 in the cache */
   /* replace1986_1 -> 5508 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 29, 5508 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1987_0_0 -> 29 in the cache */
   /* search1987_0 -> 2239 in the cache */
   /* search1987_1_0 -> 48 in the cache */
   /* search1987_1 -> 3750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2239, 3750 },
      -1,
   } },

   /* replace1987_0 -> 29 in the cache */
   /* replace1987_1_0 -> 48 in the cache */
   /* replace1987_1 -> 5508 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 5508 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1988_0_0 -> 29 in the cache */
   /* search1988_0 -> 2239 in the cache */
   /* search1988_1_0 -> 48 in the cache */
   /* search1988_1 -> 3750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2239, 3750 },
      -1,
   } },

   /* replace1988_0 -> 29 in the cache */
   /* replace1988_1_0 -> 48 in the cache */
   /* replace1988_1 -> 5508 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 5508 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1989_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 386 },
      -1,
   } },
   /* search1989_1_0 -> 196 in the cache */
   /* search1989_1 -> 5490 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5516, 5490 },
      -1,
   } },

   /* replace1989_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 386 },
      -1,
   } },
   /* replace1989_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5518, 196 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1990_0_0 -> 386 in the cache */
   /* search1990_0 -> 5516 in the cache */
   /* search1990_1_0 -> 196 in the cache */
   /* search1990_1 -> 5490 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5516, 5490 },
      -1,
   } },

   /* replace1990_0_0 -> 386 in the cache */
   /* replace1990_0 -> 5518 in the cache */
   /* replace1990_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5518, 196 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1991_0_0 -> 29 in the cache */
   /* search1991_0 -> 2239 in the cache */
   /* search1991_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2239, 5008 },
      -1,
   } },

   /* replace1991_0_0 -> 29 in the cache */
   /* replace1991_0_1_0 -> 53 in the cache */
   /* replace1991_0_1 -> 3828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 29, 3828 },
      -1,
   } },
   /* replace1991_1_0_0_0 -> 53 in the cache */
   /* replace1991_1_0_0 -> 3828 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3828 },
      -1,
   } },
   /* replace1991_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5524, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5523, 5525 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1992_0_0 -> 29 in the cache */
   /* search1992_0 -> 2239 in the cache */
   /* search1992_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2239, 5008 },
      -1,
   } },

   /* replace1992_0_0 -> 29 in the cache */
   /* replace1992_0_1_0 -> 53 in the cache */
   /* replace1992_0_1 -> 3828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 29, 3828 },
      -1,
   } },
   /* replace1992_1_0_0_0 -> 53 in the cache */
   /* replace1992_1_0_0 -> 3828 in the cache */
   /* replace1992_1_0 -> 5524 in the cache */
   /* replace1992_1_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5524, 53 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5528, 5529 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1993_0_0 -> 29 in the cache */
   /* search1993_0 -> 2239 in the cache */
   /* search1993_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2239, 5008 },
      -1,
   } },

   /* replace1993_0_0 -> 987 in the cache */
   /* replace1993_0_1 -> 53 in the cache */
   /* replace1993_0 -> 5352 in the cache */
   /* replace1993_1_0_0 -> 3767 in the cache */
   /* replace1993_1_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3767, 53 },
      -1,
   } },
   /* replace1993_1_1_0 -> 29 in the cache */
   /* replace1993_1_1_1_0 -> 53 in the cache */
   /* replace1993_1_1_1 -> 3828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 29, 3828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5532, 5533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5352, 5534 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1994_0 -> 5027 in the cache */
   /* search1994_1_0 -> 48 in the cache */
   /* search1994_1 -> 3750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5027, 3750 },
      -1,
   } },

   /* replace1994_0_0 -> 34 in the cache */
   /* replace1994_0_1 -> 3767 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 34, 3767 },
      -1,
   } },
   /* replace1994_1_0_0 -> 34 in the cache */
   /* replace1994_1_0_1 -> 987 in the cache */
   /* replace1994_1_0 -> 5360 in the cache */
   /* replace1994_1_1_0_0 -> 34 in the cache */
   /* replace1994_1_1_0 -> 3758 in the cache */
   /* replace1994_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3758, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5360, 5538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5537, 5539 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1995_0_0 -> 29 in the cache */
   /* search1995_0 -> 2239 in the cache */
   /* search1995_1 -> 5008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2239, 5008 },
      -1,
   } },

   /* replace1995_0_0 -> 3767 in the cache */
   /* replace1995_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3767, 53 },
      -1,
   } },
   /* replace1995_1_0_0 -> 987 in the cache */
   /* replace1995_1_0_1 -> 53 in the cache */
   /* replace1995_1_0 -> 5367 in the cache */
   /* replace1995_1_1_0 -> 29 in the cache */
   /* replace1995_1_1_1_0 -> 53 in the cache */
   /* replace1995_1_1_1 -> 3828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 29, 3828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5367, 5543 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5542, 5544 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1996_0 -> 5027 in the cache */
   /* search1996_1_0 -> 48 in the cache */
   /* search1996_1 -> 3750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5027, 3750 },
      -1,
   } },

   /* replace1996_0_0 -> 34 in the cache */
   /* replace1996_0_1 -> 987 in the cache */
   /* replace1996_0 -> 5372 in the cache */
   /* replace1996_1_0_0 -> 34 in the cache */
   /* replace1996_1_0_1 -> 3767 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 34, 3767 },
      -1,
   } },
   /* replace1996_1_1_0_0 -> 34 in the cache */
   /* replace1996_1_1_0 -> 3758 in the cache */
   /* replace1996_1_1_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3758, 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5547, 5548 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5372, 5549 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1997_0_0 -> 24 in the cache */
   /* search1997_0 -> 1935 in the cache */
   /* search1997_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1935, 5551 },
      -1,
   } },

   /* replace1997_0 -> 24 in the cache */
   /* replace1997_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 24, 5553 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1998_0_0 -> 24 in the cache */
   /* search1998_0 -> 1935 in the cache */
   /* search1998_1_0 -> 551 in the cache */
   /* search1998_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1935, 5551 },
      -1,
   } },

   /* replace1998_0 -> 24 in the cache */
   /* replace1998_1_0 -> 551 in the cache */
   /* replace1998_1 -> 5553 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 24, 5553 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1999_0_0 -> 24 in the cache */
   /* search1999_0 -> 1935 in the cache */
   /* search1999_1_0 -> 551 in the cache */
   /* search1999_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1935, 5551 },
      -1,
   } },

   /* replace1999_0 -> 24 in the cache */
   /* replace1999_1_0 -> 551 in the cache */
   /* replace1999_1 -> 5553 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 24, 5553 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search2000_0_0 -> 24 in the cache */
   /* search2000_0 -> 1935 in the cache */
   /* search2000_1_0 -> 551 in the cache */
   /* search2000_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1935, 5551 },
      -1,
   } },

   /* replace2000_0 -> 24 in the cache */
   /* replace2000_1_0 -> 551 in the cache */
   /* replace2000_1 -> 5553 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 24, 5553 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search2001_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 603 },
      -1,
   } },
   /* search2001_1_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5561, 5562 },
      -1,
   } },

   /* replace2001_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 603 },
      -1,
   } },
   /* replace2001_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5564, 614 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search2002_0_0 -> 603 in the cache */
   /* search2002_0 -> 5561 in the cache */
   /* search2002_1_0 -> 614 in the cache */
   /* search2002_1 -> 5562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5561, 5562 },
      -1,
   } },

   /* replace2002_0_0 -> 603 in the cache */
   /* replace2002_0 -> 5564 in the cache */
   /* replace2002_1 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5564, 614 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search2003_0_0 -> 24 in the cache */
   /* search2003_0 -> 1945 in the cache */
   /* search2003_1_0 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1945, 5568 },
      -1,
   } },

   /* replace2003_0 -> 24 in the cache */
   /* replace2003_1_0 -> 551 in the cache */
   /* replace2003_1 -> 5553 in the cache */
   /* replace2003 -> 5554 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search2004_0_0 -> 24 in the cache */
   /* search2004_0 -> 1945 in the cache */
   /* search2004_1_0 -> 551 in the cache */
   /* search2004_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1945, 5568 },
      -1,
   } },

   /* replace2004_0 -> 24 in the cache */
   /* replace2004_1_0 -> 551 in the cache */
   /* replace2004_1 -> 5553 in the cache */
   /* replace2004 -> 5556 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search2005_0_0 -> 24 in the cache */
   /* search2005_0 -> 1945 in the cache */
   /* search2005_1_0 -> 551 in the cache */
   /* search2005_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1945, 5568 },
      -1,
   } },

   /* replace2005_0 -> 24 in the cache */
   /* replace2005_1_0 -> 551 in the cache */
   /* replace2005_1 -> 5553 in the cache */
   /* replace2005 -> 5558 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search2006_0_0 -> 24 in the cache */
   /* search2006_0 -> 1945 in the cache */
   /* search2006_1_0 -> 551 in the cache */
   /* search2006_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1945, 5568 },
      -1,
   } },

   /* replace2006_0 -> 24 in the cache */
   /* replace2006_1_0 -> 551 in the cache */
   /* replace2006_1 -> 5553 in the cache */
   /* replace2006 -> 5560 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search2007_0_0 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 603 },
      -1,
   } },
   /* search2007_1_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5573, 5574 },
      -1,
   } },

   /* replace2007_0_0 -> 603 in the cache */
   /* replace2007_0 -> 5564 in the cache */
   /* replace2007_1 -> 614 in the cache */
   /* replace2007 -> 5565 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search2008_0_0 -> 603 in the cache */
   /* search2008_0 -> 5573 in the cache */
   /* search2008_1_0 -> 614 in the cache */
   /* search2008_1 -> 5574 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5573, 5574 },
      -1,
   } },

   /* replace2008_0_0 -> 603 in the cache */
   /* replace2008_0 -> 5564 in the cache */
   /* replace2008_1 -> 614 in the cache */
   /* replace2008 -> 5567 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search2009_0_0 -> 29 in the cache */
   /* search2009_0 -> 2041 in the cache */
   /* search2009_1_0 -> 551 in the cache */
   /* search2009_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2041, 5568 },
      -1,
   } },

   /* replace2009_0 -> 29 in the cache */
   /* replace2009_1_0 -> 551 in the cache */
   /* replace2009_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 29, 5551 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search2010_0_0 -> 29 in the cache */
   /* search2010_0 -> 2041 in the cache */
   /* search2010_1_0 -> 551 in the cache */
   /* search2010_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2041, 5568 },
      -1,
   } },

   /* replace2010_0 -> 29 in the cache */
   /* replace2010_1_0 -> 551 in the cache */
   /* replace2010_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 29, 5551 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search2011_0_0 -> 29 in the cache */
   /* search2011_0 -> 2041 in the cache */
   /* search2011_1_0 -> 551 in the cache */
   /* search2011_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2041, 5568 },
      -1,
   } },

   /* replace2011_0 -> 29 in the cache */
   /* replace2011_1_0 -> 551 in the cache */
   /* replace2011_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 29, 5551 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search2012_0_0 -> 29 in the cache */
   /* search2012_0 -> 2041 in the cache */
   /* search2012_1_0 -> 551 in the cache */
   /* search2012_1 -> 5568 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2041, 5568 },
      -1,
   } },

   /* replace2012_0 -> 29 in the cache */
   /* replace2012_1_0 -> 551 in the cache */
   /* replace2012_1 -> 5551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 29, 5551 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search2013_0_0 -> 603 in the cache */
   /* search2013_0 -> 5573 in the cache */
   /* search2013_1_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5573, 5585 },
      -1,
   } },

   /* replace2013_0_0 -> 603 in the cache */
   /* replace2013_0 -> 5561 in the cache */
   /* replace2013_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5561, 196 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search2014_0_0 -> 603 in the cache */
   /* search2014_0 -> 5573 in the cache */
   /* search2014_1_0 -> 196 in the cache */
   /* search2014_1 -> 5585 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5573, 5585 },
      -1,
   } },

   /* replace2014_0_0 -> 603 in the cache */
   /* replace2014_0 -> 5561 in the cache */
   /* replace2014_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5561, 196 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search2015_0_0 -> 29 in the cache */
   /* search2015_0 -> 2041 in the cache */
   /* search2015_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2041, 5590 },
      -1,
   } },

   /* replace2015_0 -> 29 in the cache */
   /* replace2015_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 29, 5592 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search2016_0_0 -> 29 in the cache */
   /* search2016_0 -> 2041 in the cache */
   /* search2016_1_0 -> 48 in the cache */
   /* search2016_1 -> 5590 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2041, 5590 },
      -1,
   } },

   /* replace2016_0 -> 29 in the cache */
   /* replace2016_1_0 -> 48 in the cache */
   /* replace2016_1 -> 5592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 29, 5592 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search2017_0_0 -> 29 in the cache */
   /* search2017_0 -> 2041 in the cache */
   /* search2017_1_0 -> 48 in the cache */
   /* search2017_1 -> 5590 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2041, 5590 },
      -1,
   } },

   /* replace2017_0 -> 29 in the cache */
   /* replace2017_1_0 -> 48 in the cache */
   /* replace2017_1 -> 5592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 29, 5592 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search2018_0_0 -> 29 in the cache */
   /* search2018_0 -> 2041 in the cache */
   /* search2018_1_0 -> 48 in the cache */
   /* search2018_1 -> 5590 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2041, 5590 },
      -1,
   } },

   /* replace2018_0 -> 29 in the cache */
   /* replace2018_1_0 -> 48 in the cache */
   /* replace2018_1 -> 5592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 29, 5592 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search2019_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 386 },
      -1,
   } },
   /* search2019_1_0 -> 196 in the cache */
   /* search2019_1 -> 5585 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5600, 5585 },
      -1,
   } },

   /* replace2019_0_0 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 386 },
      -1,
   } },
   /* replace2019_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5602, 196 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search2020_0_0 -> 386 in the cache */
   /* search2020_0 -> 5600 in the cache */
   /* search2020_1_0 -> 196 in the cache */
   /* search2020_1 -> 5585 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5600, 5585 },
      -1,
   } },

   /* replace2020_0_0 -> 386 in the cache */
   /* replace2020_0 -> 5602 in the cache */
   /* replace2020_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5602, 196 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search2021_0_0 -> 34 in the cache */
   /* search2021_0_1 -> 3767 in the cache */
   /* search2021_0 -> 3768 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 3768 },
      -1,
   } },

   /* replace2021_0 -> 34 in the cache */
   /* replace2021 -> 3758 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search2022_0_0 -> 29 in the cache */
   /* search2022_0_1 -> 1092 in the cache */
   /* search2022_0 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 1093 },
      -1,
   } },

   /* replace2022_0 -> 29 in the cache */
   /* replace2022 -> 3761 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search2023_0_0 -> 34 in the cache */
   /* search2023_0_1 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 5461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 5608 },
      -1,
   } },

   /* replace2023_0 -> 34 in the cache */
   /* replace2023 -> 5468 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search2024_0_0 -> 24 in the cache */
   /* search2024_0_1 -> 2271 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 2271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 5610 },
      -1,
   } },

   /* replace2024_0 -> 24 in the cache */
   /* replace2024 -> 2267 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search2025_0_0 -> 29 in the cache */
   /* search2025_0_1 -> 1100 in the cache */
   /* search2025_0 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 1101 },
      -1,
   } },

   /* replace2025_0 -> 29 in the cache */
   /* replace2025 -> 2283 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search2026_0_0 -> 34 in the cache */
   /* search2026_0_1 -> 5353 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 34, 5353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 5613 },
      -1,
   } },

   /* replace2026_0 -> 34 in the cache */
   /* replace2026 -> 5361 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search2027_0_0 -> 24 in the cache */
   /* search2027_0 -> 2267 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2267 },
      5,
   } },

   /* replace2027 -> 24 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search2028_0 -> 24 in the cache */
   /* search2028_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 24, 946 },
      5,
   } },

   /* replace2028 -> 24 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2029_0 -> 609 in the cache */
   /* search2029_1_0_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5617 },
      -1,
   } },
   /* search2029_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5618, 576 },
      5,
   } },

   /* replace2029_0 -> 609 in the cache */
   /* replace2029_1 -> 614 in the cache */
   /* replace2029_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 614, 576 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2030_0 -> 609 in the cache */
   /* search2030_1_0_0 -> 614 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5621 },
      -1,
   } },
   /* search2030_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5622, 576 },
      5,
   } },

   /* replace2030_0 -> 609 in the cache */
   /* replace2030_1 -> 614 in the cache */
   /* replace2030_2 -> 576 in the cache */
   /* replace2030 -> 5620 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2031_0 -> 609 in the cache */
   /* search2031_1_0 -> 614 in the cache */
   /* search2031_1_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 614, 946 },
      -1,
   } },
   /* search2031_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5624, 576 },
      5,
   } },

   /* replace2031_0 -> 609 in the cache */
   /* replace2031_1 -> 614 in the cache */
   /* replace2031_2 -> 576 in the cache */
   /* replace2031 -> 5620 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search2032_0_0_0 -> 24 in the cache */
   /* search2032_0_0 -> 2267 in the cache */
   /* search2032_0 -> 2268 in the cache */
   /* search2032_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 2268, 551 },
      5,
   } },

   /* replace2032_0 -> 24 in the cache */
   /* replace2032_1 -> 551 in the cache */
   /* replace2032 -> 4620 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search2033_0_0_0 -> 24 in the cache */
   /* search2033_0_0 -> 4938 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4938 },
      -1,
   } },
   /* search2033_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5627, 551 },
      5,
   } },

   /* replace2033_0 -> 24 in the cache */
   /* replace2033_1 -> 551 in the cache */
   /* replace2033 -> 4620 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search2034_0_0 -> 24 in the cache */
   /* search2034_0_1 -> 946 in the cache */
   /* search2034_0 -> 3890 in the cache */
   /* search2034_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3890, 551 },
      5,
   } },

   /* replace2034_0 -> 24 in the cache */
   /* replace2034_1 -> 551 in the cache */
   /* replace2034 -> 4620 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search2035_0_0_0 -> 24 in the cache */
   /* search2035_0_0 -> 2267 in the cache */
   /* search2035_0 -> 2268 in the cache */
   /* search2035_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 2268, 551 },
      5,
   } },

   /* replace2035_0 -> 24 in the cache */
   /* replace2035_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 24, 551 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search2036_0_0_0 -> 24 in the cache */
   /* search2036_0_0 -> 4938 in the cache */
   /* search2036_0 -> 5627 in the cache */
   /* search2036_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5627, 551 },
      5,
   } },

   /* replace2036_0 -> 24 in the cache */
   /* replace2036_1 -> 551 in the cache */
   /* replace2036 -> 5631 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search2037_0_0 -> 24 in the cache */
   /* search2037_0_1 -> 946 in the cache */
   /* search2037_0 -> 3890 in the cache */
   /* search2037_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3890, 551 },
      5,
   } },

   /* replace2037_0 -> 24 in the cache */
   /* replace2037_1 -> 551 in the cache */
   /* replace2037 -> 5631 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search2038_0_0_0 -> 24 in the cache */
   /* search2038_0_0 -> 2267 in the cache */
   /* search2038_0 -> 2268 in the cache */
   /* search2038_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2268, 551 },
      5,
   } },

   /* replace2038_0 -> 24 in the cache */
   /* replace2038_1 -> 551 in the cache */
   /* replace2038 -> 2281 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search2039_0_0_0 -> 24 in the cache */
   /* search2039_0_0 -> 4938 in the cache */
   /* search2039_0 -> 5627 in the cache */
   /* search2039_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5627, 551 },
      5,
   } },

   /* replace2039_0 -> 24 in the cache */
   /* replace2039_1 -> 551 in the cache */
   /* replace2039 -> 2281 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search2040_0_0 -> 24 in the cache */
   /* search2040_0_1 -> 946 in the cache */
   /* search2040_0 -> 3890 in the cache */
   /* search2040_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3890, 551 },
      5,
   } },

   /* replace2040_0 -> 24 in the cache */
   /* replace2040_1 -> 551 in the cache */
   /* replace2040 -> 2281 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search2041_0_0_0 -> 24 in the cache */
   /* search2041_0_0 -> 2267 in the cache */
   /* search2041_0 -> 2268 in the cache */
   /* search2041_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2268, 551 },
      5,
   } },

   /* replace2041_0 -> 24 in the cache */
   /* replace2041_1 -> 551 in the cache */
   /* replace2041 -> 2323 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search2042_0_0_0 -> 24 in the cache */
   /* search2042_0_0 -> 4938 in the cache */
   /* search2042_0 -> 5627 in the cache */
   /* search2042_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5627, 551 },
      5,
   } },

   /* replace2042_0 -> 24 in the cache */
   /* replace2042_1 -> 551 in the cache */
   /* replace2042 -> 2323 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search2043_0_0 -> 24 in the cache */
   /* search2043_0_1 -> 946 in the cache */
   /* search2043_0 -> 3890 in the cache */
   /* search2043_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3890, 551 },
      5,
   } },

   /* replace2043_0 -> 24 in the cache */
   /* replace2043_1 -> 551 in the cache */
   /* replace2043 -> 2323 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search2044_0_0_0 -> 24 in the cache */
   /* search2044_0_0 -> 2267 in the cache */
   /* search2044_0 -> 2268 in the cache */
   /* search2044_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2268, 551 },
      5,
   } },

   /* replace2044_0 -> 24 in the cache */
   /* replace2044_1 -> 551 in the cache */
   /* replace2044 -> 2347 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search2045_0_0_0 -> 24 in the cache */
   /* search2045_0_0 -> 4938 in the cache */
   /* search2045_0 -> 5627 in the cache */
   /* search2045_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5627, 551 },
      5,
   } },

   /* replace2045_0 -> 24 in the cache */
   /* replace2045_1 -> 551 in the cache */
   /* replace2045 -> 2347 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search2046_0_0 -> 24 in the cache */
   /* search2046_0_1 -> 946 in the cache */
   /* search2046_0 -> 3890 in the cache */
   /* search2046_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3890, 551 },
      5,
   } },

   /* replace2046_0 -> 24 in the cache */
   /* replace2046_1 -> 551 in the cache */
   /* replace2046 -> 2347 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search2047_0_0 -> 24 in the cache */
   /* search2047_0 -> 2267 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2267 },
      5,
   } },

   /* replace2047 -> 24 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search2048_0 -> 24 in the cache */
   /* search2048_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 24, 946 },
      5,
   } },

   /* replace2048 -> 24 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2049_0 -> 609 in the cache */
   /* search2049_1_0_0 -> 614 in the cache */
   /* search2049_1_0 -> 5617 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5617 },
      -1,
   } },
   /* search2049_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5645, 576 },
      5,
   } },

   /* replace2049_0 -> 609 in the cache */
   /* replace2049_1 -> 614 in the cache */
   /* replace2049_2 -> 576 in the cache */
   /* replace2049 -> 5620 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2050_0 -> 609 in the cache */
   /* search2050_1_0_0 -> 614 in the cache */
   /* search2050_1_0 -> 5621 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5621 },
      -1,
   } },
   /* search2050_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5647, 576 },
      5,
   } },

   /* replace2050_0 -> 609 in the cache */
   /* replace2050_1 -> 614 in the cache */
   /* replace2050_2 -> 576 in the cache */
   /* replace2050 -> 5620 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2051_0 -> 609 in the cache */
   /* search2051_1_0 -> 614 in the cache */
   /* search2051_1_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 614, 946 },
      -1,
   } },
   /* search2051_2 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5649, 576 },
      5,
   } },

   /* replace2051_0 -> 609 in the cache */
   /* replace2051_1 -> 614 in the cache */
   /* replace2051_2 -> 576 in the cache */
   /* replace2051 -> 5620 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search2052_0_0_0 -> 24 in the cache */
   /* search2052_0_0 -> 2267 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2267 },
      -1,
   } },
   /* search2052_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5651, 551 },
      5,
   } },

   /* replace2052_0 -> 24 in the cache */
   /* replace2052_1 -> 551 in the cache */
   /* replace2052 -> 4620 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search2053_0_0_0 -> 24 in the cache */
   /* search2053_0_0 -> 4938 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4938 },
      -1,
   } },
   /* search2053_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5653, 551 },
      5,
   } },

   /* replace2053_0 -> 24 in the cache */
   /* replace2053_1 -> 551 in the cache */
   /* replace2053 -> 4620 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search2054_0_0 -> 24 in the cache */
   /* search2054_0_1 -> 946 in the cache */
   /* search2054_0 -> 3910 in the cache */
   /* search2054_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3910, 551 },
      5,
   } },

   /* replace2054_0 -> 24 in the cache */
   /* replace2054_1 -> 551 in the cache */
   /* replace2054 -> 4620 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search2055_0_0_0 -> 24 in the cache */
   /* search2055_0_0 -> 2267 in the cache */
   /* search2055_0 -> 5651 in the cache */
   /* search2055_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5651, 551 },
      5,
   } },

   /* replace2055_0 -> 24 in the cache */
   /* replace2055_1 -> 551 in the cache */
   /* replace2055 -> 5631 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search2056_0_0_0 -> 24 in the cache */
   /* search2056_0_0 -> 4938 in the cache */
   /* search2056_0 -> 5653 in the cache */
   /* search2056_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5653, 551 },
      5,
   } },

   /* replace2056_0 -> 24 in the cache */
   /* replace2056_1 -> 551 in the cache */
   /* replace2056 -> 5631 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search2057_0_0 -> 24 in the cache */
   /* search2057_0_1 -> 946 in the cache */
   /* search2057_0 -> 3910 in the cache */
   /* search2057_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3910, 551 },
      5,
   } },

   /* replace2057_0 -> 24 in the cache */
   /* replace2057_1 -> 551 in the cache */
   /* replace2057 -> 5631 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search2058_0_0_0 -> 24 in the cache */
   /* search2058_0_0 -> 2267 in the cache */
   /* search2058_0 -> 5651 in the cache */
   /* search2058_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5651, 551 },
      5,
   } },

   /* replace2058_0 -> 24 in the cache */
   /* replace2058_1 -> 551 in the cache */
   /* replace2058 -> 2281 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search2059_0_0_0 -> 24 in the cache */
   /* search2059_0_0 -> 4938 in the cache */
   /* search2059_0 -> 5653 in the cache */
   /* search2059_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5653, 551 },
      5,
   } },

   /* replace2059_0 -> 24 in the cache */
   /* replace2059_1 -> 551 in the cache */
   /* replace2059 -> 2281 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search2060_0_0 -> 24 in the cache */
   /* search2060_0_1 -> 946 in the cache */
   /* search2060_0 -> 3910 in the cache */
   /* search2060_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3910, 551 },
      5,
   } },

   /* replace2060_0 -> 24 in the cache */
   /* replace2060_1 -> 551 in the cache */
   /* replace2060 -> 2281 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search2061_0_0_0 -> 24 in the cache */
   /* search2061_0_0 -> 2267 in the cache */
   /* search2061_0 -> 5651 in the cache */
   /* search2061_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5651, 551 },
      5,
   } },

   /* replace2061_0 -> 24 in the cache */
   /* replace2061_1 -> 551 in the cache */
   /* replace2061 -> 2323 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search2062_0_0_0 -> 24 in the cache */
   /* search2062_0_0 -> 4938 in the cache */
   /* search2062_0 -> 5653 in the cache */
   /* search2062_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5653, 551 },
      5,
   } },

   /* replace2062_0 -> 24 in the cache */
   /* replace2062_1 -> 551 in the cache */
   /* replace2062 -> 2323 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search2063_0_0 -> 24 in the cache */
   /* search2063_0_1 -> 946 in the cache */
   /* search2063_0 -> 3910 in the cache */
   /* search2063_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3910, 551 },
      5,
   } },

   /* replace2063_0 -> 24 in the cache */
   /* replace2063_1 -> 551 in the cache */
   /* replace2063 -> 2323 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search2064_0_0_0 -> 24 in the cache */
   /* search2064_0_0 -> 2267 in the cache */
   /* search2064_0 -> 5651 in the cache */
   /* search2064_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5651, 551 },
      5,
   } },

   /* replace2064_0 -> 24 in the cache */
   /* replace2064_1 -> 551 in the cache */
   /* replace2064 -> 2347 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search2065_0_0_0 -> 24 in the cache */
   /* search2065_0_0 -> 4938 in the cache */
   /* search2065_0 -> 5653 in the cache */
   /* search2065_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5653, 551 },
      5,
   } },

   /* replace2065_0 -> 24 in the cache */
   /* replace2065_1 -> 551 in the cache */
   /* replace2065 -> 2347 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search2066_0_0 -> 24 in the cache */
   /* search2066_0_1 -> 946 in the cache */
   /* search2066_0 -> 3910 in the cache */
   /* search2066_1 -> 551 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3910, 551 },
      5,
   } },

   /* replace2066_0 -> 24 in the cache */
   /* replace2066_1 -> 551 in the cache */
   /* replace2066 -> 2347 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search2067_0_0 -> 29 in the cache */
   /* search2067_0 -> 2283 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2283 },
      5,
   } },

   /* replace2067 -> 29 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search2068_0 -> 29 in the cache */
   /* search2068_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 29, 135 },
      5,
   } },

   /* replace2068 -> 29 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2069_0 -> 609 in the cache */
   /* search2069_1_0_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5670 },
      -1,
   } },
   /* search2069_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5671, 647 },
      5,
   } },

   /* replace2069_0 -> 609 in the cache */
   /* replace2069_1 -> 196 in the cache */
   /* replace2069_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 196, 647 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2070_0 -> 609 in the cache */
   /* search2070_1_0_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5674 },
      -1,
   } },
   /* search2070_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5675, 647 },
      5,
   } },

   /* replace2070_0 -> 609 in the cache */
   /* replace2070_1 -> 196 in the cache */
   /* replace2070_2 -> 647 in the cache */
   /* replace2070 -> 5673 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2071_0 -> 609 in the cache */
   /* search2071_1_0 -> 196 in the cache */
   /* search2071_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 196, 135 },
      -1,
   } },
   /* search2071_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5677, 647 },
      5,
   } },

   /* replace2071_0 -> 609 in the cache */
   /* replace2071_1 -> 196 in the cache */
   /* replace2071_2 -> 647 in the cache */
   /* replace2071 -> 5673 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2072_0_0_0 -> 29 in the cache */
   /* search2072_0_0 -> 2283 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2283 },
      -1,
   } },
   /* search2072_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5679, 48 },
      5,
   } },

   /* replace2072_0 -> 29 in the cache */
   /* replace2072_1 -> 48 in the cache */
   /* replace2072 -> 4633 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2073_0_0_0 -> 29 in the cache */
   /* search2073_0_0 -> 4892 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4892 },
      -1,
   } },
   /* search2073_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5681, 48 },
      5,
   } },

   /* replace2073_0 -> 29 in the cache */
   /* replace2073_1 -> 48 in the cache */
   /* replace2073 -> 4633 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search2074_0_0 -> 29 in the cache */
   /* search2074_0_1 -> 135 in the cache */
   /* search2074_0 -> 502 in the cache */
   /* search2074_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 502, 48 },
      5,
   } },

   /* replace2074_0 -> 29 in the cache */
   /* replace2074_1 -> 48 in the cache */
   /* replace2074 -> 4633 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2075_0_0_0 -> 29 in the cache */
   /* search2075_0_0 -> 2283 in the cache */
   /* search2075_0 -> 5679 in the cache */
   /* search2075_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5679, 48 },
      5,
   } },

   /* replace2075_0 -> 29 in the cache */
   /* replace2075_1 -> 48 in the cache */
   /* replace2075 -> 61 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2076_0_0_0 -> 29 in the cache */
   /* search2076_0_0 -> 4892 in the cache */
   /* search2076_0 -> 5681 in the cache */
   /* search2076_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5681, 48 },
      5,
   } },

   /* replace2076_0 -> 29 in the cache */
   /* replace2076_1 -> 48 in the cache */
   /* replace2076 -> 61 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search2077_0_0 -> 29 in the cache */
   /* search2077_0_1 -> 135 in the cache */
   /* search2077_0 -> 502 in the cache */
   /* search2077_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 502, 48 },
      5,
   } },

   /* replace2077_0 -> 29 in the cache */
   /* replace2077_1 -> 48 in the cache */
   /* replace2077 -> 61 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2078_0_0_0 -> 29 in the cache */
   /* search2078_0_0 -> 2283 in the cache */
   /* search2078_0 -> 5679 in the cache */
   /* search2078_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5679, 48 },
      5,
   } },

   /* replace2078_0 -> 29 in the cache */
   /* replace2078_1 -> 48 in the cache */
   /* replace2078 -> 2289 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2079_0_0_0 -> 29 in the cache */
   /* search2079_0_0 -> 4892 in the cache */
   /* search2079_0 -> 5681 in the cache */
   /* search2079_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5681, 48 },
      5,
   } },

   /* replace2079_0 -> 29 in the cache */
   /* replace2079_1 -> 48 in the cache */
   /* replace2079 -> 2289 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search2080_0_0 -> 29 in the cache */
   /* search2080_0_1 -> 135 in the cache */
   /* search2080_0 -> 502 in the cache */
   /* search2080_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 502, 48 },
      5,
   } },

   /* replace2080_0 -> 29 in the cache */
   /* replace2080_1 -> 48 in the cache */
   /* replace2080 -> 2289 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2081_0_0_0 -> 29 in the cache */
   /* search2081_0_0 -> 2283 in the cache */
   /* search2081_0 -> 5679 in the cache */
   /* search2081_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5679, 48 },
      5,
   } },

   /* replace2081_0 -> 29 in the cache */
   /* replace2081_1 -> 48 in the cache */
   /* replace2081 -> 2327 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2082_0_0_0 -> 29 in the cache */
   /* search2082_0_0 -> 4892 in the cache */
   /* search2082_0 -> 5681 in the cache */
   /* search2082_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5681, 48 },
      5,
   } },

   /* replace2082_0 -> 29 in the cache */
   /* replace2082_1 -> 48 in the cache */
   /* replace2082 -> 2327 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search2083_0_0 -> 29 in the cache */
   /* search2083_0_1 -> 135 in the cache */
   /* search2083_0 -> 502 in the cache */
   /* search2083_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 502, 48 },
      5,
   } },

   /* replace2083_0 -> 29 in the cache */
   /* replace2083_1 -> 48 in the cache */
   /* replace2083 -> 2327 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2084_0_0_0 -> 29 in the cache */
   /* search2084_0_0 -> 2283 in the cache */
   /* search2084_0 -> 5679 in the cache */
   /* search2084_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5679, 48 },
      5,
   } },

   /* replace2084_0 -> 29 in the cache */
   /* replace2084_1 -> 48 in the cache */
   /* replace2084 -> 2351 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2085_0_0_0 -> 29 in the cache */
   /* search2085_0_0 -> 4892 in the cache */
   /* search2085_0 -> 5681 in the cache */
   /* search2085_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5681, 48 },
      5,
   } },

   /* replace2085_0 -> 29 in the cache */
   /* replace2085_1 -> 48 in the cache */
   /* replace2085 -> 2351 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search2086_0_0 -> 29 in the cache */
   /* search2086_0_1 -> 135 in the cache */
   /* search2086_0 -> 502 in the cache */
   /* search2086_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 502, 48 },
      5,
   } },

   /* replace2086_0 -> 29 in the cache */
   /* replace2086_1 -> 48 in the cache */
   /* replace2086 -> 2351 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search2087_0_0 -> 29 in the cache */
   /* search2087_0 -> 2283 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2283 },
      5,
   } },

   /* replace2087 -> 29 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search2088_0 -> 29 in the cache */
   /* search2088_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 29, 135 },
      5,
   } },

   /* replace2088 -> 29 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2089_0 -> 609 in the cache */
   /* search2089_1_0_0 -> 196 in the cache */
   /* search2089_1_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5670 },
      -1,
   } },
   /* search2089_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5698, 647 },
      5,
   } },

   /* replace2089_0 -> 609 in the cache */
   /* replace2089_1 -> 196 in the cache */
   /* replace2089_2 -> 647 in the cache */
   /* replace2089 -> 5673 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2090_0 -> 609 in the cache */
   /* search2090_1_0_0 -> 196 in the cache */
   /* search2090_1_0 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5674 },
      -1,
   } },
   /* search2090_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5700, 647 },
      5,
   } },

   /* replace2090_0 -> 609 in the cache */
   /* replace2090_1 -> 196 in the cache */
   /* replace2090_2 -> 647 in the cache */
   /* replace2090 -> 5673 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2091_0 -> 609 in the cache */
   /* search2091_1_0 -> 196 in the cache */
   /* search2091_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 196, 135 },
      -1,
   } },
   /* search2091_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5702, 647 },
      5,
   } },

   /* replace2091_0 -> 609 in the cache */
   /* replace2091_1 -> 196 in the cache */
   /* replace2091_2 -> 647 in the cache */
   /* replace2091 -> 5673 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2092_0_0_0 -> 29 in the cache */
   /* search2092_0_0 -> 2283 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2283 },
      -1,
   } },
   /* search2092_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5704, 48 },
      5,
   } },

   /* replace2092_0 -> 29 in the cache */
   /* replace2092_1 -> 48 in the cache */
   /* replace2092 -> 4633 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2093_0_0_0 -> 29 in the cache */
   /* search2093_0_0 -> 4892 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4892 },
      -1,
   } },
   /* search2093_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5706, 48 },
      5,
   } },

   /* replace2093_0 -> 29 in the cache */
   /* replace2093_1 -> 48 in the cache */
   /* replace2093 -> 4633 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search2094_0_0 -> 29 in the cache */
   /* search2094_0_1 -> 135 in the cache */
   /* search2094_0 -> 483 in the cache */
   /* search2094_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 483, 48 },
      5,
   } },

   /* replace2094_0 -> 29 in the cache */
   /* replace2094_1 -> 48 in the cache */
   /* replace2094 -> 4633 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2095_0_0_0 -> 29 in the cache */
   /* search2095_0_0 -> 2283 in the cache */
   /* search2095_0 -> 5704 in the cache */
   /* search2095_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5704, 48 },
      5,
   } },

   /* replace2095_0 -> 29 in the cache */
   /* replace2095_1 -> 48 in the cache */
   /* replace2095 -> 61 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2096_0_0_0 -> 29 in the cache */
   /* search2096_0_0 -> 4892 in the cache */
   /* search2096_0 -> 5706 in the cache */
   /* search2096_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5706, 48 },
      5,
   } },

   /* replace2096_0 -> 29 in the cache */
   /* replace2096_1 -> 48 in the cache */
   /* replace2096 -> 61 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search2097_0_0 -> 29 in the cache */
   /* search2097_0_1 -> 135 in the cache */
   /* search2097_0 -> 483 in the cache */
   /* search2097_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 483, 48 },
      5,
   } },

   /* replace2097_0 -> 29 in the cache */
   /* replace2097_1 -> 48 in the cache */
   /* replace2097 -> 61 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2098_0_0_0 -> 29 in the cache */
   /* search2098_0_0 -> 2283 in the cache */
   /* search2098_0 -> 5704 in the cache */
   /* search2098_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5704, 48 },
      5,
   } },

   /* replace2098_0 -> 29 in the cache */
   /* replace2098_1 -> 48 in the cache */
   /* replace2098 -> 2289 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2099_0_0_0 -> 29 in the cache */
   /* search2099_0_0 -> 4892 in the cache */
   /* search2099_0 -> 5706 in the cache */
   /* search2099_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5706, 48 },
      5,
   } },

   /* replace2099_0 -> 29 in the cache */
   /* replace2099_1 -> 48 in the cache */
   /* replace2099 -> 2289 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search2100_0_0 -> 29 in the cache */
   /* search2100_0_1 -> 135 in the cache */
   /* search2100_0 -> 483 in the cache */
   /* search2100_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 483, 48 },
      5,
   } },

   /* replace2100_0 -> 29 in the cache */
   /* replace2100_1 -> 48 in the cache */
   /* replace2100 -> 2289 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2101_0_0_0 -> 29 in the cache */
   /* search2101_0_0 -> 2283 in the cache */
   /* search2101_0 -> 5704 in the cache */
   /* search2101_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5704, 48 },
      5,
   } },

   /* replace2101_0 -> 29 in the cache */
   /* replace2101_1 -> 48 in the cache */
   /* replace2101 -> 2327 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2102_0_0_0 -> 29 in the cache */
   /* search2102_0_0 -> 4892 in the cache */
   /* search2102_0 -> 5706 in the cache */
   /* search2102_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5706, 48 },
      5,
   } },

   /* replace2102_0 -> 29 in the cache */
   /* replace2102_1 -> 48 in the cache */
   /* replace2102 -> 2327 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search2103_0_0 -> 29 in the cache */
   /* search2103_0_1 -> 135 in the cache */
   /* search2103_0 -> 483 in the cache */
   /* search2103_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 483, 48 },
      5,
   } },

   /* replace2103_0 -> 29 in the cache */
   /* replace2103_1 -> 48 in the cache */
   /* replace2103 -> 2327 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2104_0_0_0 -> 29 in the cache */
   /* search2104_0_0 -> 2283 in the cache */
   /* search2104_0 -> 5704 in the cache */
   /* search2104_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5704, 48 },
      5,
   } },

   /* replace2104_0 -> 29 in the cache */
   /* replace2104_1 -> 48 in the cache */
   /* replace2104 -> 2351 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2105_0_0_0 -> 29 in the cache */
   /* search2105_0_0 -> 4892 in the cache */
   /* search2105_0 -> 5706 in the cache */
   /* search2105_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5706, 48 },
      5,
   } },

   /* replace2105_0 -> 29 in the cache */
   /* replace2105_1 -> 48 in the cache */
   /* replace2105 -> 2351 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search2106_0_0 -> 29 in the cache */
   /* search2106_0_1 -> 135 in the cache */
   /* search2106_0 -> 483 in the cache */
   /* search2106_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 483, 48 },
      5,
   } },

   /* replace2106_0 -> 29 in the cache */
   /* replace2106_1 -> 48 in the cache */
   /* replace2106 -> 2351 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search2107_0_0 -> 29 in the cache */
   /* search2107_0 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3761 },
      6,
   } },

   /* replace2107 -> 29 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search2108_0 -> 29 in the cache */
   /* search2108_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 29, 135 },
      6,
   } },

   /* replace2108 -> 29 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2109_0 -> 609 in the cache */
   /* search2109_1_0_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5723 },
      -1,
   } },
   /* search2109_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5724, 647 },
      6,
   } },

   /* replace2109_0 -> 609 in the cache */
   /* replace2109_1 -> 196 in the cache */
   /* replace2109_2 -> 647 in the cache */
   /* replace2109 -> 5673 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2110_0 -> 609 in the cache */
   /* search2110_1_0_0 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 196 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5726 },
      -1,
   } },
   /* search2110_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5727, 647 },
      6,
   } },

   /* replace2110_0 -> 609 in the cache */
   /* replace2110_1 -> 196 in the cache */
   /* replace2110_2 -> 647 in the cache */
   /* replace2110 -> 5673 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2111_0 -> 609 in the cache */
   /* search2111_1_0 -> 196 in the cache */
   /* search2111_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 196, 135 },
      -1,
   } },
   /* search2111_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5729, 647 },
      6,
   } },

   /* replace2111_0 -> 609 in the cache */
   /* replace2111_1 -> 196 in the cache */
   /* replace2111_2 -> 647 in the cache */
   /* replace2111 -> 5673 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2112_0_0_0 -> 29 in the cache */
   /* search2112_0_0 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3761 },
      -1,
   } },
   /* search2112_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5731, 48 },
      6,
   } },

   /* replace2112_0 -> 29 in the cache */
   /* replace2112_1 -> 48 in the cache */
   /* replace2112 -> 4633 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2113_0_0_0 -> 29 in the cache */
   /* search2113_0_0 -> 4894 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4894 },
      -1,
   } },
   /* search2113_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5733, 48 },
      6,
   } },

   /* replace2113_0 -> 29 in the cache */
   /* replace2113_1 -> 48 in the cache */
   /* replace2113 -> 4633 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search2114_0_0 -> 29 in the cache */
   /* search2114_0_1 -> 135 in the cache */
   /* search2114_0 -> 534 in the cache */
   /* search2114_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 534, 48 },
      6,
   } },

   /* replace2114_0 -> 29 in the cache */
   /* replace2114_1 -> 48 in the cache */
   /* replace2114 -> 4633 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2115_0_0_0 -> 29 in the cache */
   /* search2115_0_0 -> 3761 in the cache */
   /* search2115_0 -> 5731 in the cache */
   /* search2115_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5731, 48 },
      6,
   } },

   /* replace2115_0 -> 29 in the cache */
   /* replace2115_1 -> 48 in the cache */
   /* replace2115 -> 61 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2116_0_0_0 -> 29 in the cache */
   /* search2116_0_0 -> 4894 in the cache */
   /* search2116_0 -> 5733 in the cache */
   /* search2116_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5733, 48 },
      6,
   } },

   /* replace2116_0 -> 29 in the cache */
   /* replace2116_1 -> 48 in the cache */
   /* replace2116 -> 61 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search2117_0_0 -> 29 in the cache */
   /* search2117_0_1 -> 135 in the cache */
   /* search2117_0 -> 534 in the cache */
   /* search2117_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 534, 48 },
      6,
   } },

   /* replace2117_0 -> 29 in the cache */
   /* replace2117_1 -> 48 in the cache */
   /* replace2117 -> 61 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2118_0_0_0 -> 29 in the cache */
   /* search2118_0_0 -> 3761 in the cache */
   /* search2118_0 -> 5731 in the cache */
   /* search2118_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5731, 48 },
      6,
   } },

   /* replace2118_0 -> 29 in the cache */
   /* replace2118_1 -> 48 in the cache */
   /* replace2118 -> 2289 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2119_0_0_0 -> 29 in the cache */
   /* search2119_0_0 -> 4894 in the cache */
   /* search2119_0 -> 5733 in the cache */
   /* search2119_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5733, 48 },
      6,
   } },

   /* replace2119_0 -> 29 in the cache */
   /* replace2119_1 -> 48 in the cache */
   /* replace2119 -> 2289 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search2120_0_0 -> 29 in the cache */
   /* search2120_0_1 -> 135 in the cache */
   /* search2120_0 -> 534 in the cache */
   /* search2120_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 534, 48 },
      6,
   } },

   /* replace2120_0 -> 29 in the cache */
   /* replace2120_1 -> 48 in the cache */
   /* replace2120 -> 2289 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2121_0_0_0 -> 29 in the cache */
   /* search2121_0_0 -> 3761 in the cache */
   /* search2121_0 -> 5731 in the cache */
   /* search2121_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5731, 48 },
      6,
   } },

   /* replace2121_0 -> 29 in the cache */
   /* replace2121_1 -> 48 in the cache */
   /* replace2121 -> 2327 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2122_0_0_0 -> 29 in the cache */
   /* search2122_0_0 -> 4894 in the cache */
   /* search2122_0 -> 5733 in the cache */
   /* search2122_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5733, 48 },
      6,
   } },

   /* replace2122_0 -> 29 in the cache */
   /* replace2122_1 -> 48 in the cache */
   /* replace2122 -> 2327 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search2123_0_0 -> 29 in the cache */
   /* search2123_0_1 -> 135 in the cache */
   /* search2123_0 -> 534 in the cache */
   /* search2123_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 534, 48 },
      6,
   } },

   /* replace2123_0 -> 29 in the cache */
   /* replace2123_1 -> 48 in the cache */
   /* replace2123 -> 2327 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2124_0_0_0 -> 29 in the cache */
   /* search2124_0_0 -> 3761 in the cache */
   /* search2124_0 -> 5731 in the cache */
   /* search2124_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5731, 48 },
      6,
   } },

   /* replace2124_0 -> 29 in the cache */
   /* replace2124_1 -> 48 in the cache */
   /* replace2124 -> 2351 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2125_0_0_0 -> 29 in the cache */
   /* search2125_0_0 -> 4894 in the cache */
   /* search2125_0 -> 5733 in the cache */
   /* search2125_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5733, 48 },
      6,
   } },

   /* replace2125_0 -> 29 in the cache */
   /* replace2125_1 -> 48 in the cache */
   /* replace2125 -> 2351 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search2126_0_0 -> 29 in the cache */
   /* search2126_0_1 -> 135 in the cache */
   /* search2126_0 -> 534 in the cache */
   /* search2126_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 534, 48 },
      6,
   } },

   /* replace2126_0 -> 29 in the cache */
   /* replace2126_1 -> 48 in the cache */
   /* replace2126 -> 2351 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search2127_0_0 -> 29 in the cache */
   /* search2127_0 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3761 },
      6,
   } },

   /* replace2127 -> 29 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search2128_0 -> 29 in the cache */
   /* search2128_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 29, 135 },
      6,
   } },

   /* replace2128 -> 29 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2129_0 -> 609 in the cache */
   /* search2129_1_0_0 -> 196 in the cache */
   /* search2129_1_0 -> 5723 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5723 },
      -1,
   } },
   /* search2129_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5750, 647 },
      6,
   } },

   /* replace2129_0 -> 609 in the cache */
   /* replace2129_1 -> 196 in the cache */
   /* replace2129_2 -> 647 in the cache */
   /* replace2129 -> 5673 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2130_0 -> 609 in the cache */
   /* search2130_1_0_0 -> 196 in the cache */
   /* search2130_1_0 -> 5726 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5726 },
      -1,
   } },
   /* search2130_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5752, 647 },
      6,
   } },

   /* replace2130_0 -> 609 in the cache */
   /* replace2130_1 -> 196 in the cache */
   /* replace2130_2 -> 647 in the cache */
   /* replace2130 -> 5673 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search2131_0 -> 609 in the cache */
   /* search2131_1_0 -> 196 in the cache */
   /* search2131_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 196, 135 },
      -1,
   } },
   /* search2131_2 -> 647 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 5754, 647 },
      6,
   } },

   /* replace2131_0 -> 609 in the cache */
   /* replace2131_1 -> 196 in the cache */
   /* replace2131_2 -> 647 in the cache */
   /* replace2131 -> 5673 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2132_0_0_0 -> 29 in the cache */
   /* search2132_0_0 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3761 },
      -1,
   } },
   /* search2132_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5756, 48 },
      6,
   } },

   /* replace2132_0 -> 29 in the cache */
   /* replace2132_1 -> 48 in the cache */
   /* replace2132 -> 4633 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search2133_0_0_0 -> 29 in the cache */
   /* search2133_0_0 -> 4894 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4894 },
      -1,
   } },
   /* search2133_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5758, 48 },
      6,
   } },

   /* replace2133_0 -> 29 in the cache */
   /* replace2133_1 -> 48 in the cache */
   /* replace2133 -> 4633 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search2134_0_0 -> 29 in the cache */
   /* search2134_0_1 -> 135 in the cache */
   /* search2134_0 -> 526 in the cache */
   /* search2134_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 526, 48 },
      6,
   } },

   /* replace2134_0 -> 29 in the cache */
   /* replace2134_1 -> 48 in the cache */
   /* replace2134 -> 4633 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2135_0_0_0 -> 29 in the cache */
   /* search2135_0_0 -> 3761 in the cache */
   /* search2135_0 -> 5756 in the cache */
   /* search2135_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5756, 48 },
      6,
   } },

   /* replace2135_0 -> 29 in the cache */
   /* replace2135_1 -> 48 in the cache */
   /* replace2135 -> 61 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search2136_0_0_0 -> 29 in the cache */
   /* search2136_0_0 -> 4894 in the cache */
   /* search2136_0 -> 5758 in the cache */
   /* search2136_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5758, 48 },
      6,
   } },

   /* replace2136_0 -> 29 in the cache */
   /* replace2136_1 -> 48 in the cache */
   /* replace2136 -> 61 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search2137_0_0 -> 29 in the cache */
   /* search2137_0_1 -> 135 in the cache */
   /* search2137_0 -> 526 in the cache */
   /* search2137_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 526, 48 },
      6,
   } },

   /* replace2137_0 -> 29 in the cache */
   /* replace2137_1 -> 48 in the cache */
   /* replace2137 -> 61 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2138_0_0_0 -> 29 in the cache */
   /* search2138_0_0 -> 3761 in the cache */
   /* search2138_0 -> 5756 in the cache */
   /* search2138_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5756, 48 },
      6,
   } },

   /* replace2138_0 -> 29 in the cache */
   /* replace2138_1 -> 48 in the cache */
   /* replace2138 -> 2289 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search2139_0_0_0 -> 29 in the cache */
   /* search2139_0_0 -> 4894 in the cache */
   /* search2139_0 -> 5758 in the cache */
   /* search2139_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5758, 48 },
      6,
   } },

   /* replace2139_0 -> 29 in the cache */
   /* replace2139_1 -> 48 in the cache */
   /* replace2139 -> 2289 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search2140_0_0 -> 29 in the cache */
   /* search2140_0_1 -> 135 in the cache */
   /* search2140_0 -> 526 in the cache */
   /* search2140_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 526, 48 },
      6,
   } },

   /* replace2140_0 -> 29 in the cache */
   /* replace2140_1 -> 48 in the cache */
   /* replace2140 -> 2289 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2141_0_0_0 -> 29 in the cache */
   /* search2141_0_0 -> 3761 in the cache */
   /* search2141_0 -> 5756 in the cache */
   /* search2141_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5756, 48 },
      6,
   } },

   /* replace2141_0 -> 29 in the cache */
   /* replace2141_1 -> 48 in the cache */
   /* replace2141 -> 2327 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search2142_0_0_0 -> 29 in the cache */
   /* search2142_0_0 -> 4894 in the cache */
   /* search2142_0 -> 5758 in the cache */
   /* search2142_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5758, 48 },
      6,
   } },

   /* replace2142_0 -> 29 in the cache */
   /* replace2142_1 -> 48 in the cache */
   /* replace2142 -> 2327 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search2143_0_0 -> 29 in the cache */
   /* search2143_0_1 -> 135 in the cache */
   /* search2143_0 -> 526 in the cache */
   /* search2143_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 526, 48 },
      6,
   } },

   /* replace2143_0 -> 29 in the cache */
   /* replace2143_1 -> 48 in the cache */
   /* replace2143 -> 2327 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2144_0_0_0 -> 29 in the cache */
   /* search2144_0_0 -> 3761 in the cache */
   /* search2144_0 -> 5756 in the cache */
   /* search2144_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5756, 48 },
      6,
   } },

   /* replace2144_0 -> 29 in the cache */
   /* replace2144_1 -> 48 in the cache */
   /* replace2144 -> 2351 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search2145_0_0_0 -> 29 in the cache */
   /* search2145_0_0 -> 4894 in the cache */
   /* search2145_0 -> 5758 in the cache */
   /* search2145_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5758, 48 },
      6,
   } },

   /* replace2145_0 -> 29 in the cache */
   /* replace2145_1 -> 48 in the cache */
   /* replace2145 -> 2351 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search2146_0_0 -> 29 in the cache */
   /* search2146_0_1 -> 135 in the cache */
   /* search2146_0 -> 526 in the cache */
   /* search2146_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 526, 48 },
      6,
   } },

   /* replace2146_0 -> 29 in the cache */
   /* replace2146_1 -> 48 in the cache */
   /* replace2146 -> 2351 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5773, 5774 },
      -1,
   } },

   /* replace2147_0_0 -> 5773 in the cache */
   /* replace2147_0_1_0_0_0_0_0_0 -> 5774 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffe2ull /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5774, 5776 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1eull /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5777, 5778 },
      -1,
   } },
   /* replace2147_0_1_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5779, 486 },
      -1,
   } },
   /* replace2147_0_1_0_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5780, 27 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaull /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5781, 5782 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 5783 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5773, 5784 },
      -1,
   } },
   /* replace2147_1_0_0_0_0_0_0 -> 5774 in the cache */
   /* replace2147_1_0_0_0_0_0_1 -> 5776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5774, 5776 },
      -1,
   } },
   /* replace2147_1_0_0_0_0_1 -> 5778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5786, 5778 },
      -1,
   } },
   /* replace2147_1_0_0_0_1_0_0_0 -> 5774 in the cache */
   /* replace2147_1_0_0_0_1_0_0_1 -> 5776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5774, 5776 },
      -1,
   } },
   /* replace2147_1_0_0_0_1_0_1 -> 5778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5788, 5778 },
      -1,
   } },
   /* replace2147_1_0_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5789, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5787, 5790 },
      -1,
   } },
   /* replace2147_1_0_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5791, 27 },
      -1,
   } },
   /* replace2147_1_0_1 -> 5782 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5792, 5782 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 5793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5785, 5794 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2148_1 -> 5774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5796, 5774 },
      -1,
   } },

   /* replace2148_0_0 -> 5796 in the cache */
   /* replace2148_0_1_0_0_0_0_0 -> 5774 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffff02ull /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5774, 5798 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfeull /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5799, 5800 },
      -1,
   } },
   /* replace2148_0_1_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5801, 486 },
      -1,
   } },
   /* replace2148_0_1_0_1 -> 4976 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5802, 4976 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17ull /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5803, 5804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5796, 5805 },
      -1,
   } },
   /* replace2148_1_0_0_0_0_0 -> 5774 in the cache */
   /* replace2148_1_0_0_0_0_1 -> 5798 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5774, 5798 },
      -1,
   } },
   /* replace2148_1_0_0_0_1 -> 5800 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5807, 5800 },
      -1,
   } },
   /* replace2148_1_0_0_1_0_0_0 -> 5774 in the cache */
   /* replace2148_1_0_0_1_0_0_1 -> 5798 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5774, 5798 },
      -1,
   } },
   /* replace2148_1_0_0_1_0_1 -> 5800 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5809, 5800 },
      -1,
   } },
   /* replace2148_1_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5810, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5808, 5811 },
      -1,
   } },
   /* replace2148_1_0_1 -> 4976 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5812, 4976 },
      -1,
   } },
   /* replace2148_1_1 -> 5804 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5813, 5804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5806, 5814 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2149_1 -> 5774 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5816, 5774 },
      -1,
   } },

   /* replace2149_0_0 -> 5816 in the cache */
   /* replace2149_0_1_0 -> 135 in the cache */
   /* replace2149_0_1_1_0_0_0_0_0 -> 5774 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffffffff802ull /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5774, 5818 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7feull /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5819, 5820 },
      -1,
   } },
   /* replace2149_0_1_1_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5821, 486 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ffull /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5822, 5823 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14ull /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5824, 5825 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 135, 5826 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5816, 5827 },
      -1,
   } },
   /* replace2149_1_0 -> 135 in the cache */
   /* replace2149_1_1_0_0_0_0_0 -> 5774 in the cache */
   /* replace2149_1_1_0_0_0_0_1 -> 5818 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5774, 5818 },
      -1,
   } },
   /* replace2149_1_1_0_0_0_1 -> 5820 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5829, 5820 },
      -1,
   } },
   /* replace2149_1_1_0_0_1_0_0_0 -> 5774 in the cache */
   /* replace2149_1_1_0_0_1_0_0_1 -> 5818 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5774, 5818 },
      -1,
   } },
   /* replace2149_1_1_0_0_1_0_1 -> 5820 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5831, 5820 },
      -1,
   } },
   /* replace2149_1_1_0_0_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5832, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5830, 5833 },
      -1,
   } },
   /* replace2149_1_1_0_1 -> 5823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5834, 5823 },
      -1,
   } },
   /* replace2149_1_1_1 -> 5825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5835, 5825 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 135, 5836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5828, 5837 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search2150_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 5796, 943 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 5796, 943 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 5839, 5840 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ffull /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5841, 5842 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_0_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5843, 921 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 5839, 5840 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00ull /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5845, 5846 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_0_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5847, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5844, 5848 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0full /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5849, 5850 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5851, 2530 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5853, 5842 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5854, 921 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5856, 5846 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5857, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5855, 5858 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0ull /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5859, 5860 },
      -1,
   } },
   /* search2150_0_0_0_0_0_0_1_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5861, 2530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5852, 5862 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333ull /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5863, 5864 },
      -1,
   } },
   /* search2150_0_0_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5865, 491 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5867, 5842 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5868, 921 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5870, 5846 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5871, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5869, 5872 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_0_1 -> 5850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5873, 5850 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5874, 2530 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5876, 5842 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5877, 921 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5879, 5846 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5880, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5878, 5881 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_0_1 -> 5860 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5882, 5860 },
      -1,
   } },
   /* search2150_0_0_0_1_0_0_1_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5883, 2530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5875, 5884 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xccccccccull /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5885, 5886 },
      -1,
   } },
   /* search2150_0_0_0_1_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5887, 491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5866, 5888 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555ull /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5889, 5890 },
      -1,
   } },
   /* search2150_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 5891, 486 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5893, 5842 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5894, 921 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5896, 5846 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5897, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5895, 5898 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_0_1 -> 5850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5899, 5850 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5900, 2530 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5902, 5842 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5903, 921 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5905, 5846 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5906, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5904, 5907 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_0_1 -> 5860 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5908, 5860 },
      -1,
   } },
   /* search2150_1_0_0_0_0_0_1_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5909, 2530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5901, 5910 },
      -1,
   } },
   /* search2150_1_0_0_0_0_1 -> 5864 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5911, 5864 },
      -1,
   } },
   /* search2150_1_0_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5912, 491 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5914, 5842 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5915, 921 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5917, 5846 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5918, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5916, 5919 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_0_1 -> 5850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5920, 5850 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5921, 2530 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_0_0_0_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5923, 5842 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5924, 921 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 5839, 5840 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_0_1_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5926, 5846 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_0_1_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5927, 921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5925, 5928 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_0_1 -> 5860 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5929, 5860 },
      -1,
   } },
   /* search2150_1_0_0_1_0_0_1_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5930, 2530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5922, 5931 },
      -1,
   } },
   /* search2150_1_0_0_1_0_1 -> 5886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5932, 5886 },
      -1,
   } },
   /* search2150_1_0_0_1_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5933, 491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5913, 5934 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaaull /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5935, 5936 },
      -1,
   } },
   /* search2150_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 5937, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5892, 5938 },
      -1,
   } },

   /* replace2150_0 -> 5796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 5796 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_0 -> 5841 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5841, 486 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_0_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5941, 5936 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_0 -> 5845 in the cache */
   /* search2151_0_0_0_0_0_0_0_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5845, 486 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_0_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5943, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5942, 5944 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5945, 491 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_0_1 -> 5886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5946, 5886 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_0 -> 5853 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5853, 486 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_1_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5948, 5936 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_0 -> 5856 in the cache */
   /* search2151_0_0_0_0_0_0_1_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5856, 486 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_1_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5950, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5949, 5951 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_1_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5952, 491 },
      -1,
   } },
   /* search2151_0_0_0_0_0_0_1_1 -> 5864 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5953, 5864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5947, 5954 },
      -1,
   } },
   /* search2151_0_0_0_0_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5955, 2530 },
      -1,
   } },
   /* search2151_0_0_0_0_1 -> 5860 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5956, 5860 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_0 -> 5867 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5867, 486 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_0_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5958, 5936 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_0 -> 5870 in the cache */
   /* search2151_0_0_0_1_0_0_0_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5870, 486 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_0_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5960, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5959, 5961 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5962, 491 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_0_1 -> 5886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5963, 5886 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_0 -> 5876 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5876, 486 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_1_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5965, 5936 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_0 -> 5879 in the cache */
   /* search2151_0_0_0_1_0_0_1_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5879, 486 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_1_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5967, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5966, 5968 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_1_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5969, 491 },
      -1,
   } },
   /* search2151_0_0_0_1_0_0_1_1 -> 5864 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5970, 5864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5964, 5971 },
      -1,
   } },
   /* search2151_0_0_0_1_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5972, 2530 },
      -1,
   } },
   /* search2151_0_0_0_1_1 -> 5850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5973, 5850 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5957, 5974 },
      -1,
   } },
   /* search2151_0_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 5975, 921 },
      -1,
   } },
   /* search2151_0_1 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5976, 5846 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_0 -> 5893 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5893, 486 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_0_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5978, 5936 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_0 -> 5896 in the cache */
   /* search2151_1_0_0_0_0_0_0_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5896, 486 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_0_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5980, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5979, 5981 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5982, 491 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_0_1 -> 5886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5983, 5886 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_0 -> 5902 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5902, 486 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_1_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5985, 5936 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_0 -> 5905 in the cache */
   /* search2151_1_0_0_0_0_0_1_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5905, 486 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_1_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5987, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5986, 5988 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_1_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5989, 491 },
      -1,
   } },
   /* search2151_1_0_0_0_0_0_1_1 -> 5864 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5990, 5864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5984, 5991 },
      -1,
   } },
   /* search2151_1_0_0_0_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5992, 2530 },
      -1,
   } },
   /* search2151_1_0_0_0_1 -> 5860 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5993, 5860 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_0 -> 5914 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5914, 486 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_0_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5995, 5936 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_0 -> 5917 in the cache */
   /* search2151_1_0_0_1_0_0_0_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5917, 486 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_0_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5997, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5996, 5998 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5999, 491 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_0_1 -> 5886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 6000, 5886 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_0 -> 5923 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_0_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5923, 486 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_1_0_0_0_1 -> 5936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 6002, 5936 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5839 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5796 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 943 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5840 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_0 -> 5926 in the cache */
   /* search2151_1_0_0_1_0_0_1_0_0_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5926, 486 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_1_0_0_1_1 -> 5890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 6004, 5890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 6003, 6005 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_1_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 6006, 491 },
      -1,
   } },
   /* search2151_1_0_0_1_0_0_1_1 -> 5864 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 6007, 5864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 6001, 6008 },
      -1,
   } },
   /* search2151_1_0_0_1_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 6009, 2530 },
      -1,
   } },
   /* search2151_1_0_0_1_1 -> 5850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 6010, 5850 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5994, 6011 },
      -1,
   } },
   /* search2151_1_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 6012, 921 },
      -1,
   } },
   /* search2151_1_1 -> 5842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 6013, 5842 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5977, 6014 },
      -1,
   } },

   /* replace2151_0 -> 5796 in the cache */
   /* replace2151 -> 5940 in the cache */

   /* ('bcsel', ('iand', ('ine', ('fabs', 'x'), 2139095040), ('ieq', ('iand', ('pack_half_2x16_rtz_split', 'x', 0), 32767), 31744)), ('iadd', ('pack_half_2x16_rtz_split', 'x', 0), 4294967295), ('pack_half_2x16_rtz_split', 'x', 0)) => ('pack_half_2x16_rtz_split', 'x', 0) */
   /* search2152_0_0_0_0 -> 5796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5796 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f800000ull /* 2139095040 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6016, 6017 },
      -1,
   } },
   /* search2152_0_1_0_0_0 -> 5796 in the cache */
   /* search2152_0_1_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 5796, 135 },
      -1,
   } },
   /* search2152_0_1_0_1 -> 5089 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 6019, 5089 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7c00ull /* 31744 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 6020, 6021 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 6018, 6022 },
      -1,
   } },
   /* search2152_1_0_0 -> 5796 in the cache */
   /* search2152_1_0_1 -> 135 in the cache */
   /* search2152_1_0 -> 6019 in the cache */
   /* search2152_1_1 -> 1017 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      4, 1,
      { 6019, 1017 },
      -1,
   } },
   /* search2152_2_0 -> 5796 in the cache */
   /* search2152_2_1 -> 135 in the cache */
   /* search2152_2 -> 6019 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 5,
      { 6023, 6024, 6019 },
      -1,
   } },

   /* replace2152_0 -> 5796 in the cache */
   /* replace2152_1 -> 135 in the cache */
   /* replace2152 -> 6019 in the cache */

   /* ('bcsel', ('iand', ('ine', 'x', 2139095040), ('ieq', ('iand', ('pack_half_2x16_rtz_split', 'x(is_not_negative)', 0), 32767), 31744)), ('iadd', ('pack_half_2x16_rtz_split', 'x(is_not_negative)', 0), 4294967295), ('pack_half_2x16_rtz_split', 'x(is_not_negative)', 0)) => ('pack_half_2x16_rtz_split', 'x', 0) */
   /* search2153_0_0_0 -> 5796 in the cache */
   /* search2153_0_0_1 -> 6017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 5796, 6017 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2153_0_1_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 6027, 135 },
      -1,
   } },
   /* search2153_0_1_0_1 -> 5089 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 6028, 5089 },
      -1,
   } },
   /* search2153_0_1_1 -> 6021 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 6029, 6021 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 6026, 6030 },
      -1,
   } },
   /* search2153_1_0_0 -> 6027 in the cache */
   /* search2153_1_0_1 -> 135 in the cache */
   /* search2153_1_0 -> 6028 in the cache */
   /* search2153_1_1 -> 1017 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      4, 1,
      { 6028, 1017 },
      -1,
   } },
   /* search2153_2_0 -> 6027 in the cache */
   /* search2153_2_1 -> 135 in the cache */
   /* search2153_2 -> 6028 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 5,
      { 6031, 6032, 6028 },
      -1,
   } },

   /* replace2153_0 -> 5796 in the cache */
   /* replace2153_1 -> 135 in the cache */
   /* replace2153 -> 6019 in the cache */

   /* ('bcsel', ('iand', ('ine', ('fabs', 'x'), 2139095040), ('ieq', ('iand', ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0), 32767), 31744)), ('iadd', ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0), 4294967295), ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0)) => ('pack_half_2x16_rtz_split', ('fneg', 'x'), 0) */
   /* search2154_0_0_0_0 -> 5796 in the cache */
   /* search2154_0_0_0 -> 6016 in the cache */
   /* search2154_0_0_1 -> 6017 in the cache */
   /* search2154_0_0 -> 6018 in the cache */
   /* search2154_0_1_0_0_0_0 -> 5796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5796 },
      -1,
   } },
   /* search2154_0_1_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_half_2x16_rtz_split,
      -1, 0,
      { 6034, 135 },
      -1,
   } },
   /* search2154_0_1_0_1 -> 5089 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 6035, 5089 },
      -1,
   } },
   /* search2154_0_1_1 -> 6021 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 6036, 6021 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 6018, 6037 },
      -1,
   } },
   /* search2154_1_0_0_0 -> 5796 in the cache */
   /* search2154_1_0_0 -> 6034 in the cache */
   /* search2154_1_0_1 -> 135 in the cache */
   /* search2154_1_0 -> 6035 in the cache */
   /* search2154_1_1 -> 1017 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      4, 1,
      { 6035, 1017 },
      -1,
   } },
   /* search2154_2_0_0 -> 5796 in the cache */
   /* search2154_2_0 -> 6034 in the cache */
   /* search2154_2_1 -> 135 in the cache */
   /* search2154_2 -> 6035 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 5,
      { 6038, 6039, 6035 },
      -1,
   } },

   /* replace2154_0_0 -> 5796 in the cache */
   /* replace2154_0 -> 6034 in the cache */
   /* replace2154_1 -> 135 in the cache */
   /* replace2154 -> 6035 in the cache */

   /* ('iadd(many-comm-expr)', ('iadd', ('iadd', ('bcsel', ('ieq', ('extract_u8', 'a@32', 0), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 0), ('ineg', ('extract_u8', 'b@32', 0))))), ('bcsel', ('ieq', ('extract_u8', 'a@32', 1), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 1), ('ineg', ('extract_u8', 'b@32', 1)))))), ('bcsel', ('ieq', ('extract_u8', 'a@32', 2), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 2), ('ineg', ('extract_u8', 'b@32', 2)))))), ('bcsel', ('ieq', ('extract_u8', 'a@32', 3), 0), 0, ('iabs', ('iadd', ('extract_u8', 'a@32', 3), ('ineg', ('extract_u8', 'b@32', 3)))))) => ('msad_4x8', 'a', 'b', 0) */
   /* search2155_0_0_0_0_0_0 -> 29 in the cache */
   /* search2155_0_0_0_0_0_1 -> 135 in the cache */
   /* search2155_0_0_0_0_0 -> 502 in the cache */
   /* search2155_0_0_0_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 502, 135 },
      -1,
   } },
   /* search2155_0_0_0_1 -> 135 in the cache */
   /* search2155_0_0_0_2_0_0_0 -> 29 in the cache */
   /* search2155_0_0_0_2_0_0_1 -> 135 in the cache */
   /* search2155_0_0_0_2_0_0 -> 502 in the cache */
   /* search2155_0_0_0_2_0_1_0_0 -> 48 in the cache */
   /* search2155_0_0_0_2_0_1_0_1 -> 135 in the cache */
   /* search2155_0_0_0_2_0_1_0 -> 503 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 503 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      4, 1,
      { 502, 6042 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 1,
      { 6043 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 6041, 135, 6044 },
      -1,
   } },
   /* search2155_0_0_1_0_0_0 -> 29 in the cache */
   /* search2155_0_0_1_0_0_1 -> 486 in the cache */
   /* search2155_0_0_1_0_0 -> 505 in the cache */
   /* search2155_0_0_1_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      5, 1,
      { 505, 135 },
      -1,
   } },
   /* search2155_0_0_1_1 -> 135 in the cache */
   /* search2155_0_0_1_2_0_0_0 -> 29 in the cache */
   /* search2155_0_0_1_2_0_0_1 -> 486 in the cache */
   /* search2155_0_0_1_2_0_0 -> 505 in the cache */
   /* search2155_0_0_1_2_0_1_0_0 -> 48 in the cache */
   /* search2155_0_0_1_2_0_1_0_1 -> 486 in the cache */
   /* search2155_0_0_1_2_0_1_0 -> 506 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 506 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 505, 6047 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 1,
      { 6048 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 6046, 135, 6049 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      2, 5,
      { 6045, 6050 },
      -1,
   } },
   /* search2155_0_1_0_0_0 -> 29 in the cache */
   /* search2155_0_1_0_0_1 -> 491 in the cache */
   /* search2155_0_1_0_0 -> 509 in the cache */
   /* search2155_0_1_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      7, 1,
      { 509, 135 },
      -1,
   } },
   /* search2155_0_1_1 -> 135 in the cache */
   /* search2155_0_1_2_0_0_0 -> 29 in the cache */
   /* search2155_0_1_2_0_0_1 -> 491 in the cache */
   /* search2155_0_1_2_0_0 -> 509 in the cache */
   /* search2155_0_1_2_0_1_0_0 -> 48 in the cache */
   /* search2155_0_1_2_0_1_0_1 -> 491 in the cache */
   /* search2155_0_1_2_0_1_0 -> 510 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      8, 1,
      { 509, 6053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 1,
      { 6054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 6052, 135, 6055 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 8,
      { 6051, 6056 },
      -1,
   } },
   /* search2155_1_0_0_0 -> 29 in the cache */
   /* search2155_1_0_0_1 -> 495 in the cache */
   /* search2155_1_0_0 -> 512 in the cache */
   /* search2155_1_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      9, 1,
      { 512, 135 },
      -1,
   } },
   /* search2155_1_1 -> 135 in the cache */
   /* search2155_1_2_0_0_0 -> 29 in the cache */
   /* search2155_1_2_0_0_1 -> 495 in the cache */
   /* search2155_1_2_0_0 -> 512 in the cache */
   /* search2155_1_2_0_1_0_0 -> 48 in the cache */
   /* search2155_1_2_0_1_0_1 -> 495 in the cache */
   /* search2155_1_2_0_1_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      10, 1,
      { 512, 6059 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 1,
      { 6060 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 6058, 135, 6061 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 11,
      { 6057, 6062 },
      -1,
   } },

   /* replace2155_0 -> 29 in the cache */
   /* replace2155_1 -> 48 in the cache */
   /* replace2155_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_msad_4x8,
      -1, 0,
      { 29, 48, 135 },
      -1,
   } },

   /* ('iadd', ('msad_4x8', 'a', 'b', 0), 'c') => ('msad_4x8', 'a', 'b', 'c') */
   /* search2156_0_0 -> 29 in the cache */
   /* search2156_0_1 -> 48 in the cache */
   /* search2156_0_2 -> 135 in the cache */
   /* search2156_0 -> 6064 in the cache */
   /* search2156_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6064, 148 },
      -1,
   } },

   /* replace2156_0 -> 29 in the cache */
   /* replace2156_1 -> 48 in the cache */
   /* replace2156_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_msad_4x8,
      -1, 0,
      { 29, 48, 148 },
      -1,
   } },

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search2157_0_0 -> 0 in the cache */
   /* search2157_0_1 -> 1 in the cache */
   /* search2157_0 -> 1168 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1168, 6067 },
      -1,
   } },

   /* replace2157_0 -> 0 in the cache */
   /* replace2157_1 -> 1 in the cache */
   /* replace2157 -> 2820 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search2158_0_0 -> 0 in the cache */
   /* search2158_0_1 -> 1 in the cache */
   /* search2158_0 -> 1162 in the cache */
   /* search2158_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1162, 6067 },
      -1,
   } },

   /* replace2158_0 -> 0 in the cache */
   /* replace2158_1 -> 1 in the cache */
   /* replace2158 -> 2890 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search2159_0_0 -> 0 in the cache */
   /* search2159_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 6070, 6071 },
      -1,
   } },

   /* replace2159_0 -> 0 in the cache */
   /* replace2159_1 -> 1 in the cache */
   /* replace2159 -> 2931 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search2160_0_0 -> 0 in the cache */
   /* search2160_0_1 -> 1 in the cache */
   /* search2160_0 -> 4760 in the cache */
   /* search2160_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 4760, 6071 },
      -1,
   } },

   /* replace2160_0 -> 0 in the cache */
   /* replace2160_1 -> 1 in the cache */
   /* replace2160 -> 2972 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search2161_0_0 -> 0 in the cache */
   /* search2161_0_1 -> 1 in the cache */
   /* search2161_0 -> 1168 in the cache */
   /* search2161_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1168, 6067 },
      -1,
   } },

   /* replace2161_0 -> 0 in the cache */
   /* replace2161_1 -> 1 in the cache */
   /* replace2161 -> 2826 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search2162_0_0 -> 0 in the cache */
   /* search2162_0_1 -> 1 in the cache */
   /* search2162_0 -> 1162 in the cache */
   /* search2162_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1162, 6067 },
      -1,
   } },

   /* replace2162_0 -> 0 in the cache */
   /* replace2162_1 -> 1 in the cache */
   /* replace2162 -> 2894 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search2163_0_0 -> 0 in the cache */
   /* search2163_0_1 -> 1 in the cache */
   /* search2163_0 -> 6070 in the cache */
   /* search2163_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 6070, 6071 },
      -1,
   } },

   /* replace2163_0 -> 0 in the cache */
   /* replace2163_1 -> 1 in the cache */
   /* replace2163 -> 2935 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search2164_0_0 -> 0 in the cache */
   /* search2164_0_1 -> 1 in the cache */
   /* search2164_0 -> 4760 in the cache */
   /* search2164_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 4760, 6071 },
      -1,
   } },

   /* replace2164_0 -> 0 in the cache */
   /* replace2164_1 -> 1 in the cache */
   /* replace2164 -> 2976 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search2165_0_0 -> 0 in the cache */
   /* search2165_0_1 -> 1 in the cache */
   /* search2165_0 -> 1168 in the cache */
   /* search2165_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1168, 6067 },
      -1,
   } },

   /* replace2165_0 -> 0 in the cache */
   /* replace2165_1 -> 1 in the cache */
   /* replace2165 -> 2833 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search2166_0_0 -> 0 in the cache */
   /* search2166_0_1 -> 1 in the cache */
   /* search2166_0 -> 1162 in the cache */
   /* search2166_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1162, 6067 },
      -1,
   } },

   /* replace2166_0 -> 0 in the cache */
   /* replace2166_1 -> 1 in the cache */
   /* replace2166 -> 2900 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search2167_0_0 -> 0 in the cache */
   /* search2167_0_1 -> 1 in the cache */
   /* search2167_0 -> 6070 in the cache */
   /* search2167_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 6070, 6071 },
      -1,
   } },

   /* replace2167_0 -> 0 in the cache */
   /* replace2167_1 -> 1 in the cache */
   /* replace2167 -> 2941 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search2168_0_0 -> 0 in the cache */
   /* search2168_0_1 -> 1 in the cache */
   /* search2168_0 -> 4760 in the cache */
   /* search2168_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 4760, 6071 },
      -1,
   } },

   /* replace2168_0 -> 0 in the cache */
   /* replace2168_1 -> 1 in the cache */
   /* replace2168 -> 2982 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search2169_0_0 -> 0 in the cache */
   /* search2169_0_1 -> 1 in the cache */
   /* search2169_0 -> 1168 in the cache */
   /* search2169_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1168, 6067 },
      -1,
   } },

   /* replace2169_0 -> 0 in the cache */
   /* replace2169_1 -> 1 in the cache */
   /* replace2169 -> 2840 in the cache */

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search2170_0_0 -> 0 in the cache */
   /* search2170_0_1 -> 1 in the cache */
   /* search2170_0 -> 1162 in the cache */
   /* search2170_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1162, 6067 },
      -1,
   } },

   /* replace2170_0 -> 0 in the cache */
   /* replace2170_1 -> 1 in the cache */
   /* replace2170 -> 2905 in the cache */

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search2171_0_0 -> 0 in the cache */
   /* search2171_0_1 -> 1 in the cache */
   /* search2171_0 -> 6070 in the cache */
   /* search2171_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 6070, 6071 },
      -1,
   } },

   /* replace2171_0 -> 0 in the cache */
   /* replace2171_1 -> 1 in the cache */
   /* replace2171 -> 2946 in the cache */

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search2172_0_0 -> 0 in the cache */
   /* search2172_0_1 -> 1 in the cache */
   /* search2172_0 -> 4760 in the cache */
   /* search2172_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 4760, 6071 },
      -1,
   } },

   /* replace2172_0 -> 0 in the cache */
   /* replace2172_1 -> 1 in the cache */
   /* replace2172 -> 2987 in the cache */

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search2173_0_0 -> 0 in the cache */
   /* search2173_0_1 -> 1 in the cache */
   /* search2173_0 -> 1168 in the cache */
   /* search2173_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1168, 6067 },
      -1,
   } },

   /* replace2173_0 -> 0 in the cache */
   /* replace2173_1 -> 1 in the cache */
   /* replace2173 -> 2857 in the cache */

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search2174_0_0 -> 0 in the cache */
   /* search2174_0_1 -> 1 in the cache */
   /* search2174_0 -> 1162 in the cache */
   /* search2174_1 -> 6067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1162, 6067 },
      -1,
   } },

   /* replace2174_0 -> 0 in the cache */
   /* replace2174_1 -> 1 in the cache */
   /* replace2174 -> 2914 in the cache */

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search2175_0_0 -> 0 in the cache */
   /* search2175_0_1 -> 1 in the cache */
   /* search2175_0 -> 6070 in the cache */
   /* search2175_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 6070, 6071 },
      -1,
   } },

   /* replace2175_0 -> 0 in the cache */
   /* replace2175_1 -> 1 in the cache */
   /* replace2175 -> 2955 in the cache */

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search2176_0_0 -> 0 in the cache */
   /* search2176_0_1 -> 1 in the cache */
   /* search2176_0 -> 4760 in the cache */
   /* search2176_1 -> 6071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 4760, 6071 },
      -1,
   } },

   /* replace2176_0 -> 0 in the cache */
   /* replace2176_1 -> 1 in the cache */
   /* replace2176 -> 2996 in the cache */

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search2177_0_0 -> 0 in the cache */
   /* search2177_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2177_1_0 -> 0 in the cache */
   /* search2177_1_1 -> 1 in the cache */
   /* search2177_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6090, 3 },
      -1,
   } },

   /* replace2177_0 -> 0 in the cache */
   /* replace2177_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search2178_0_0 -> 9 in the cache */
   /* search2178_0_1 -> 9 in the cache */
   /* search2178_0 -> 1230 in the cache */
   /* search2178_1_0 -> 2653 in the cache */
   /* search2178_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1230, 6093 },
      -1,
   } },

   /* replace2178_0 -> 2653 in the cache */
   /* replace2178_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2653, 9 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search2179_0_0 -> 0 in the cache */
   /* search2179_0_1 -> 0 in the cache */
   /* search2179_0 -> 6090 in the cache */
   /* search2179_1_0 -> 0 in the cache */
   /* search2179_1_1 -> 1 in the cache */
   /* search2179_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6090, 6 },
      -1,
   } },

   /* replace2179_0 -> 0 in the cache */
   /* replace2179_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search2180_0_0 -> 9 in the cache */
   /* search2180_0_1 -> 9 in the cache */
   /* search2180_0 -> 1230 in the cache */
   /* search2180_1_0 -> 2653 in the cache */
   /* search2180_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1230, 6098 },
      -1,
   } },

   /* replace2180_0 -> 2653 in the cache */
   /* replace2180_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2653, 9 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search2181_0_0 -> 0 in the cache */
   /* search2181_0_1 -> 0 in the cache */
   /* search2181_0 -> 6090 in the cache */
   /* search2181_1_0 -> 0 in the cache */
   /* search2181_1_1 -> 1 in the cache */
   /* search2181_1 -> 1162 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 6090, 1162 },
      -1,
   } },

   /* replace2181_0 -> 0 in the cache */
   /* replace2181_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search2182_0_0 -> 9 in the cache */
   /* search2182_0_1 -> 9 in the cache */
   /* search2182_0 -> 1230 in the cache */
   /* search2182_1_0 -> 2653 in the cache */
   /* search2182_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2653, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 1230, 6103 },
      -1,
   } },

   /* replace2182_0 -> 2653 in the cache */
   /* replace2182_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2653, 9 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search2183_0_0 -> 847 in the cache */
   /* search2183_0_1 -> 1118 in the cache */
   /* search2183_0_2 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1118, 4036 },
      -1,
   } },
   /* search2183_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 6106, 1121 },
      -1,
   } },

   /* replace2183_0 -> 847 in the cache */
   /* replace2183_1_0 -> 163 in the cache */
   /* replace2183_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2183_2_0 -> 165 in the cache */
   /* replace2183_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6108, 6109 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search2184_0_0 -> 847 in the cache */
   /* search2184_0_1 -> 1118 in the cache */
   /* search2184_0_2 -> 4036 in the cache */
   /* search2184_0 -> 6106 in the cache */
   /* search2184_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 6106, 1121 },
      -1,
   } },

   /* replace2184_0 -> 847 in the cache */
   /* replace2184_1_0 -> 163 in the cache */
   /* replace2184_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2184_2_0 -> 165 in the cache */
   /* replace2184_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6112, 6113 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search2185_0_0 -> 847 in the cache */
   /* search2185_0_1 -> 1118 in the cache */
   /* search2185_0_2 -> 4036 in the cache */
   /* search2185_0 -> 6106 in the cache */
   /* search2185_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6106, 1121 },
      -1,
   } },

   /* replace2185_0 -> 847 in the cache */
   /* replace2185_1_0 -> 163 in the cache */
   /* replace2185_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2185_2_0 -> 165 in the cache */
   /* replace2185_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6116, 6117 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search2186_0_0 -> 847 in the cache */
   /* search2186_0_1 -> 1118 in the cache */
   /* search2186_0_2 -> 4036 in the cache */
   /* search2186_0 -> 6106 in the cache */
   /* search2186_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6106, 1121 },
      -1,
   } },

   /* replace2186_0 -> 847 in the cache */
   /* replace2186_1_0 -> 163 in the cache */
   /* replace2186_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2186_2_0 -> 165 in the cache */
   /* replace2186_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6120, 6121 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search2187_0_0 -> 847 in the cache */
   /* search2187_0_1 -> 1118 in the cache */
   /* search2187_0_2 -> 4036 in the cache */
   /* search2187_0 -> 6106 in the cache */
   /* search2187_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 6106, 1121 },
      -1,
   } },

   /* replace2187_0 -> 847 in the cache */
   /* replace2187_1_0 -> 163 in the cache */
   /* replace2187_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   /* replace2187_2_0 -> 165 in the cache */
   /* replace2187_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6124, 6125 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2188_1_0 -> 1293 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6128, 6129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 6127, 6130 },
      -1,
   } },

   /* replace2188_0 -> 1293 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 6132, 6133 },
      -1,
   } },
   /* replace2188_2_0 -> 6132 in the cache */
   /* replace2188_2_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 6132, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6134, 6135 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search2189_0_0 -> 847 in the cache */
   /* search2189_0_1 -> 1118 in the cache */
   /* search2189_0_2 -> 4036 in the cache */
   /* search2189_0 -> 6106 in the cache */
   /* search2189_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 6106, 1121 },
      -1,
   } },

   /* replace2189_0 -> 847 in the cache */
   /* replace2189_1_0 -> 163 in the cache */
   /* replace2189_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   /* replace2189_2_0 -> 165 in the cache */
   /* replace2189_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6138, 6139 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search2190_0 -> 6127 in the cache */
   /* search2190_1_0 -> 1293 in the cache */
   /* search2190_1_1 -> 6128 in the cache */
   /* search2190_1_2 -> 6129 in the cache */
   /* search2190_1 -> 6130 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 6127, 6130 },
      -1,
   } },

   /* replace2190_0 -> 1293 in the cache */
   /* replace2190_1_0 -> 6132 in the cache */
   /* replace2190_1_1 -> 6133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 6132, 6133 },
      -1,
   } },
   /* replace2190_2_0 -> 6132 in the cache */
   /* replace2190_2_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 6132, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6142, 6143 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search2191_0_0 -> 847 in the cache */
   /* search2191_0_1 -> 1118 in the cache */
   /* search2191_0_2 -> 4036 in the cache */
   /* search2191_0 -> 6106 in the cache */
   /* search2191_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6106, 1121 },
      -1,
   } },

   /* replace2191_0 -> 847 in the cache */
   /* replace2191_1_0 -> 163 in the cache */
   /* replace2191_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   /* replace2191_2_0 -> 165 in the cache */
   /* replace2191_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6146, 6147 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search2192_0 -> 6127 in the cache */
   /* search2192_1_0 -> 1293 in the cache */
   /* search2192_1_1 -> 6128 in the cache */
   /* search2192_1_2 -> 6129 in the cache */
   /* search2192_1 -> 6130 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6127, 6130 },
      -1,
   } },

   /* replace2192_0 -> 1293 in the cache */
   /* replace2192_1_0 -> 6132 in the cache */
   /* replace2192_1_1 -> 6133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6132, 6133 },
      -1,
   } },
   /* replace2192_2_0 -> 6132 in the cache */
   /* replace2192_2_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6132, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6150, 6151 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search2193_0_0 -> 847 in the cache */
   /* search2193_0_1 -> 1118 in the cache */
   /* search2193_0_2 -> 4036 in the cache */
   /* search2193_0 -> 6106 in the cache */
   /* search2193_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6106, 1121 },
      -1,
   } },

   /* replace2193_0 -> 847 in the cache */
   /* replace2193_1_0 -> 163 in the cache */
   /* replace2193_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   /* replace2193_2_0 -> 165 in the cache */
   /* replace2193_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6154, 6155 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search2194_0 -> 6127 in the cache */
   /* search2194_1_0 -> 1293 in the cache */
   /* search2194_1_1 -> 6128 in the cache */
   /* search2194_1_2 -> 6129 in the cache */
   /* search2194_1 -> 6130 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6127, 6130 },
      -1,
   } },

   /* replace2194_0 -> 1293 in the cache */
   /* replace2194_1_0 -> 6132 in the cache */
   /* replace2194_1_1 -> 6133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6132, 6133 },
      -1,
   } },
   /* replace2194_2_0 -> 6132 in the cache */
   /* replace2194_2_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6132, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6158, 6159 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search2195_0_0 -> 847 in the cache */
   /* search2195_0_1 -> 1118 in the cache */
   /* search2195_0_2 -> 4036 in the cache */
   /* search2195_0 -> 6106 in the cache */
   /* search2195_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6106, 1121 },
      -1,
   } },

   /* replace2195_0 -> 847 in the cache */
   /* replace2195_1_0 -> 163 in the cache */
   /* replace2195_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   /* replace2195_2_0 -> 165 in the cache */
   /* replace2195_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6162, 6163 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search2196_0 -> 6127 in the cache */
   /* search2196_1_0 -> 1293 in the cache */
   /* search2196_1_1 -> 6128 in the cache */
   /* search2196_1_2 -> 6129 in the cache */
   /* search2196_1 -> 6130 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6127, 6130 },
      -1,
   } },

   /* replace2196_0 -> 1293 in the cache */
   /* replace2196_1_0 -> 6132 in the cache */
   /* replace2196_1_1 -> 6133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6132, 6133 },
      -1,
   } },
   /* replace2196_2_0 -> 6132 in the cache */
   /* replace2196_2_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6132, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6166, 6167 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search2197_0_0 -> 847 in the cache */
   /* search2197_0_1 -> 1118 in the cache */
   /* search2197_0_2 -> 4036 in the cache */
   /* search2197_0 -> 6106 in the cache */
   /* search2197_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6106, 1121 },
      -1,
   } },

   /* replace2197_0 -> 847 in the cache */
   /* replace2197_1_0 -> 163 in the cache */
   /* replace2197_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   /* replace2197_2_0 -> 165 in the cache */
   /* replace2197_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6170, 6171 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search2198_0 -> 6127 in the cache */
   /* search2198_1_0 -> 1293 in the cache */
   /* search2198_1_1 -> 6128 in the cache */
   /* search2198_1_2 -> 6129 in the cache */
   /* search2198_1 -> 6130 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6127, 6130 },
      -1,
   } },

   /* replace2198_0 -> 1293 in the cache */
   /* replace2198_1_0 -> 6132 in the cache */
   /* replace2198_1_1 -> 6133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6132, 6133 },
      -1,
   } },
   /* replace2198_2_0 -> 6132 in the cache */
   /* replace2198_2_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6132, 1831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 6174, 6175 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search2199_0_0 -> 847 in the cache */
   /* search2199_0_1 -> 1118 in the cache */
   /* search2199_0_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 1118, 165 },
      0,
   } },
   /* search2199_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 6177, 1121 },
      -1,
   } },

   /* replace2199_0 -> 847 in the cache */
   /* replace2199_1_0 -> 163 in the cache */
   /* replace2199_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2199_2_0 -> 165 in the cache */
   /* replace2199_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6179, 6180 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search2200_0_0 -> 847 in the cache */
   /* search2200_0_1 -> 1118 in the cache */
   /* search2200_0_2 -> 165 in the cache */
   /* search2200_0 -> 6177 in the cache */
   /* search2200_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 6177, 1121 },
      -1,
   } },

   /* replace2200_0 -> 847 in the cache */
   /* replace2200_1_0 -> 163 in the cache */
   /* replace2200_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2200_2_0 -> 165 in the cache */
   /* replace2200_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6183, 6184 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search2201_0_0 -> 847 in the cache */
   /* search2201_0_1 -> 45 in the cache */
   /* search2201_0_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 45, 148 },
      0,
   } },
   /* search2201_1 -> 324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 6186, 324 },
      -1,
   } },

   /* replace2201_0 -> 847 in the cache */
   /* replace2201_1_0 -> 48 in the cache */
   /* replace2201_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 48, 176 },
      -1,
   } },
   /* replace2201_2_0 -> 148 in the cache */
   /* replace2201_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 148, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6188, 6189 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search2202_0_0 -> 847 in the cache */
   /* search2202_0_1 -> 1118 in the cache */
   /* search2202_0_2 -> 165 in the cache */
   /* search2202_0 -> 6177 in the cache */
   /* search2202_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6177, 1121 },
      -1,
   } },

   /* replace2202_0 -> 847 in the cache */
   /* replace2202_1_0 -> 163 in the cache */
   /* replace2202_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2202_2_0 -> 165 in the cache */
   /* replace2202_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6192, 6193 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search2203_0_0 -> 847 in the cache */
   /* search2203_0_1 -> 1118 in the cache */
   /* search2203_0_2 -> 165 in the cache */
   /* search2203_0 -> 6177 in the cache */
   /* search2203_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6177, 1121 },
      -1,
   } },

   /* replace2203_0 -> 847 in the cache */
   /* replace2203_1_0 -> 163 in the cache */
   /* replace2203_1_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 163, 166 },
      -1,
   } },
   /* replace2203_2_0 -> 165 in the cache */
   /* replace2203_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6196, 6197 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search2204_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace2204 -> 8 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search2205_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace2205 -> 8 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search2206_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace2206 -> 8 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search2207_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace2207 -> 8 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search2208_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace2208 -> 8 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search2209_0 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 9 },
      -1,
   } },

   /* replace2209 -> 8 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2210_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 6205, 48 },
      -1,
   } },

   /* replace2210 -> 135 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search2211_0 -> 6205 in the cache */
   /* search2211_1 -> 48 in the cache */
   /* search2211_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 6205, 48, 148 },
      -1,
   } },

   /* replace2211 -> 148 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search2212_0 -> 29 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2212_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 29, 6208, 148 },
      -1,
   } },

   /* replace2212 -> 148 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2213_0 -> 847 in the cache */
   /* search2213_1_0 -> 839 in the cache */
   /* search2213_1_1 -> 840 in the cache */
   /* search2213_1_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 840, 849 },
      0,
   } },
   /* search2213_2_0 -> 839 in the cache */
   /* search2213_2_1 -> 840 in the cache */
   /* search2213_2_2 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 840, 851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6210, 6211 },
      -1,
   } },

   /* replace2213_0 -> 839 in the cache */
   /* replace2213_1 -> 840 in the cache */
   /* replace2213_2_0 -> 847 in the cache */
   /* replace2213_2_1 -> 849 in the cache */
   /* replace2213_2_2 -> 851 in the cache */
   /* replace2213_2 -> 1417 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 840, 1417 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2214_0 -> 847 in the cache */
   /* search2214_1_0 -> 839 in the cache */
   /* search2214_1_1 -> 840 in the cache */
   /* search2214_1_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 840, 849 },
      -1,
   } },
   /* search2214_2_0 -> 839 in the cache */
   /* search2214_2_1 -> 840 in the cache */
   /* search2214_2_2 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 840, 851 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6214, 6215 },
      -1,
   } },

   /* replace2214_0 -> 839 in the cache */
   /* replace2214_1 -> 840 in the cache */
   /* replace2214_2_0 -> 847 in the cache */
   /* replace2214_2_1 -> 849 in the cache */
   /* replace2214_2_2 -> 851 in the cache */
   /* replace2214_2 -> 1417 in the cache */
   /* replace2214 -> 6213 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2215_0 -> 847 in the cache */
   /* search2215_1_0 -> 839 in the cache */
   /* search2215_1_1 -> 840 in the cache */
   /* search2215_1_2 -> 849 in the cache */
   /* search2215_1 -> 6210 in the cache */
   /* search2215_2_0 -> 839 in the cache */
   /* search2215_2_1 -> 851 in the cache */
   /* search2215_2_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 851, 849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6210, 6217 },
      -1,
   } },

   /* replace2215_0 -> 839 in the cache */
   /* replace2215_1_0 -> 847 in the cache */
   /* replace2215_1_1 -> 840 in the cache */
   /* replace2215_1_2 -> 851 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 840, 851 },
      -1,
   } },
   /* replace2215_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 6219, 849 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2216_0 -> 847 in the cache */
   /* search2216_1_0 -> 839 in the cache */
   /* search2216_1_1 -> 840 in the cache */
   /* search2216_1_2 -> 849 in the cache */
   /* search2216_1 -> 6214 in the cache */
   /* search2216_2_0 -> 839 in the cache */
   /* search2216_2_1 -> 851 in the cache */
   /* search2216_2_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 839, 851, 849 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6214, 6221 },
      -1,
   } },

   /* replace2216_0 -> 839 in the cache */
   /* replace2216_1_0 -> 847 in the cache */
   /* replace2216_1_1 -> 840 in the cache */
   /* replace2216_1_2 -> 851 in the cache */
   /* replace2216_1 -> 6219 in the cache */
   /* replace2216_2 -> 849 in the cache */
   /* replace2216 -> 6220 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search2217_0 -> 847 in the cache */
   /* search2217_1_0 -> 163 in the cache */
   /* search2217_1_1 -> 165 in the cache */
   /* search2217_1_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 163, 165, 166 },
      0,
   } },
   /* search2217_2_0 -> 1423 in the cache */
   /* search2217_2_1 -> 165 in the cache */
   /* search2217_2_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1423, 165, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6223, 6224 },
      -1,
   } },

   /* replace2217_0_0 -> 847 in the cache */
   /* replace2217_0_1 -> 163 in the cache */
   /* replace2217_0_2 -> 1423 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 163, 1423 },
      -1,
   } },
   /* replace2217_1 -> 165 in the cache */
   /* replace2217_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6226, 165, 166 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search2218_0 -> 847 in the cache */
   /* search2218_1_0 -> 163 in the cache */
   /* search2218_1_1 -> 165 in the cache */
   /* search2218_1_2 -> 166 in the cache */
   /* search2218_1 -> 769 in the cache */
   /* search2218_2_0 -> 1423 in the cache */
   /* search2218_2_1 -> 165 in the cache */
   /* search2218_2_2 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1423, 165, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 769, 6228 },
      -1,
   } },

   /* replace2218_0_0 -> 847 in the cache */
   /* replace2218_0_1 -> 163 in the cache */
   /* replace2218_0_2 -> 1423 in the cache */
   /* replace2218_0 -> 6226 in the cache */
   /* replace2218_1 -> 165 in the cache */
   /* replace2218_2 -> 166 in the cache */
   /* replace2218 -> 6227 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2219_0 -> 847 in the cache */
   /* search2219_1_0 -> 48 in the cache */
   /* search2219_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 48, 148 },
      0,
   } },
   /* search2219_2_0 -> 48 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 48, 6231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6230, 6232 },
      -1,
   } },

   /* replace2219_0 -> 48 in the cache */
   /* replace2219_1_0 -> 847 in the cache */
   /* replace2219_1_1 -> 148 in the cache */
   /* replace2219_1_2 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 148, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 48, 6234 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2220_0 -> 847 in the cache */
   /* search2220_1_0 -> 48 in the cache */
   /* search2220_1_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 48, 360 },
      0,
   } },
   /* search2220_2_0 -> 48 in the cache */
   /* search2220_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 48, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6236, 6237 },
      -1,
   } },

   /* replace2220_0 -> 48 in the cache */
   /* replace2220_1_0 -> 847 in the cache */
   /* replace2220_1_1 -> 148 in the cache */
   /* replace2220_1_2 -> 176 in the cache */
   /* replace2220_1 -> 6234 in the cache */
   /* replace2220 -> 6235 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2221_0 -> 847 in the cache */
   /* search2221_1_0 -> 48 in the cache */
   /* search2221_1_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 48, 360 },
      -1,
   } },
   /* search2221_2_0 -> 48 in the cache */
   /* search2221_2_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 48, 176 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6239, 6240 },
      -1,
   } },

   /* replace2221_0 -> 48 in the cache */
   /* replace2221_1_0 -> 847 in the cache */
   /* replace2221_1_1 -> 148 in the cache */
   /* replace2221_1_2 -> 176 in the cache */
   /* replace2221_1 -> 6234 in the cache */
   /* replace2221 -> 6235 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2222_0 -> 847 in the cache */
   /* search2222_1_0 -> 48 in the cache */
   /* search2222_1_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 48, 148 },
      -1,
   } },
   /* search2222_2_0 -> 48 in the cache */
   /* search2222_2_1 -> 6231 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 48, 6231 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6242, 6243 },
      -1,
   } },

   /* replace2222_0 -> 48 in the cache */
   /* replace2222_1_0 -> 847 in the cache */
   /* replace2222_1_1 -> 148 in the cache */
   /* replace2222_1_2 -> 176 in the cache */
   /* replace2222_1 -> 6234 in the cache */
   /* replace2222 -> 6235 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2223_0 -> 847 in the cache */
   /* search2223_1_0 -> 163 in the cache */
   /* search2223_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2223_2_0 -> 163 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6245, 6247 },
      -1,
   } },

   /* replace2223_0 -> 163 in the cache */
   /* replace2223_1_0 -> 847 in the cache */
   /* replace2223_1_1 -> 165 in the cache */
   /* replace2223_1_2 -> 166 in the cache */
   /* replace2223_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2224_0 -> 847 in the cache */
   /* search2224_1_0 -> 163 in the cache */
   /* search2224_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2224_2_0 -> 163 in the cache */
   /* search2224_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6250, 6251 },
      -1,
   } },

   /* replace2224_0 -> 163 in the cache */
   /* replace2224_1_0 -> 847 in the cache */
   /* replace2224_1_1 -> 165 in the cache */
   /* replace2224_1_2 -> 166 in the cache */
   /* replace2224_1 -> 1412 in the cache */
   /* replace2224 -> 6249 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2225_0 -> 847 in the cache */
   /* search2225_1_0 -> 163 in the cache */
   /* search2225_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2225_2_0 -> 163 in the cache */
   /* search2225_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6253, 6254 },
      -1,
   } },

   /* replace2225_0 -> 163 in the cache */
   /* replace2225_1_0 -> 847 in the cache */
   /* replace2225_1_1 -> 165 in the cache */
   /* replace2225_1_2 -> 166 in the cache */
   /* replace2225_1 -> 1412 in the cache */
   /* replace2225 -> 6249 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2226_0 -> 847 in the cache */
   /* search2226_1_0 -> 163 in the cache */
   /* search2226_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2226_2_0 -> 163 in the cache */
   /* search2226_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6256, 6257 },
      -1,
   } },

   /* replace2226_0 -> 163 in the cache */
   /* replace2226_1_0 -> 847 in the cache */
   /* replace2226_1_1 -> 165 in the cache */
   /* replace2226_1_2 -> 166 in the cache */
   /* replace2226_1 -> 1412 in the cache */
   /* replace2226 -> 6249 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2227_0 -> 847 in the cache */
   /* search2227_1_0 -> 163 in the cache */
   /* search2227_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2227_2_0 -> 163 in the cache */
   /* search2227_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6259, 6260 },
      -1,
   } },

   /* replace2227_0 -> 163 in the cache */
   /* replace2227_1_0 -> 847 in the cache */
   /* replace2227_1_1 -> 165 in the cache */
   /* replace2227_1_2 -> 166 in the cache */
   /* replace2227_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2228_0 -> 847 in the cache */
   /* search2228_1_0 -> 163 in the cache */
   /* search2228_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2228_2_0 -> 163 in the cache */
   /* search2228_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6263, 6264 },
      -1,
   } },

   /* replace2228_0 -> 163 in the cache */
   /* replace2228_1_0 -> 847 in the cache */
   /* replace2228_1_1 -> 165 in the cache */
   /* replace2228_1_2 -> 166 in the cache */
   /* replace2228_1 -> 1412 in the cache */
   /* replace2228 -> 6262 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2229_0 -> 847 in the cache */
   /* search2229_1_0 -> 163 in the cache */
   /* search2229_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2229_2_0 -> 163 in the cache */
   /* search2229_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6266, 6267 },
      -1,
   } },

   /* replace2229_0 -> 163 in the cache */
   /* replace2229_1_0 -> 847 in the cache */
   /* replace2229_1_1 -> 165 in the cache */
   /* replace2229_1_2 -> 166 in the cache */
   /* replace2229_1 -> 1412 in the cache */
   /* replace2229 -> 6262 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2230_0 -> 847 in the cache */
   /* search2230_1_0 -> 163 in the cache */
   /* search2230_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2230_2_0 -> 163 in the cache */
   /* search2230_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6269, 6270 },
      -1,
   } },

   /* replace2230_0 -> 163 in the cache */
   /* replace2230_1_0 -> 847 in the cache */
   /* replace2230_1_1 -> 165 in the cache */
   /* replace2230_1_2 -> 166 in the cache */
   /* replace2230_1 -> 1412 in the cache */
   /* replace2230 -> 6262 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2231_0 -> 847 in the cache */
   /* search2231_1_0 -> 163 in the cache */
   /* search2231_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2231_2_0 -> 163 in the cache */
   /* search2231_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6272, 6273 },
      -1,
   } },

   /* replace2231_0 -> 163 in the cache */
   /* replace2231_1_0 -> 847 in the cache */
   /* replace2231_1_1 -> 165 in the cache */
   /* replace2231_1_2 -> 166 in the cache */
   /* replace2231_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2232_0 -> 847 in the cache */
   /* search2232_1_0 -> 163 in the cache */
   /* search2232_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2232_2_0 -> 163 in the cache */
   /* search2232_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6276, 6277 },
      -1,
   } },

   /* replace2232_0 -> 163 in the cache */
   /* replace2232_1_0 -> 847 in the cache */
   /* replace2232_1_1 -> 165 in the cache */
   /* replace2232_1_2 -> 166 in the cache */
   /* replace2232_1 -> 1412 in the cache */
   /* replace2232 -> 6275 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2233_0 -> 847 in the cache */
   /* search2233_1_0 -> 163 in the cache */
   /* search2233_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2233_2_0 -> 163 in the cache */
   /* search2233_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6279, 6280 },
      -1,
   } },

   /* replace2233_0 -> 163 in the cache */
   /* replace2233_1_0 -> 847 in the cache */
   /* replace2233_1_1 -> 165 in the cache */
   /* replace2233_1_2 -> 166 in the cache */
   /* replace2233_1 -> 1412 in the cache */
   /* replace2233 -> 6275 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2234_0 -> 847 in the cache */
   /* search2234_1_0 -> 163 in the cache */
   /* search2234_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2234_2_0 -> 163 in the cache */
   /* search2234_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6282, 6283 },
      -1,
   } },

   /* replace2234_0 -> 163 in the cache */
   /* replace2234_1_0 -> 847 in the cache */
   /* replace2234_1_1 -> 165 in the cache */
   /* replace2234_1_2 -> 166 in the cache */
   /* replace2234_1 -> 1412 in the cache */
   /* replace2234 -> 6275 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2235_0 -> 847 in the cache */
   /* search2235_1_0 -> 163 in the cache */
   /* search2235_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2235_2_0 -> 163 in the cache */
   /* search2235_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6285, 6286 },
      -1,
   } },

   /* replace2235_0 -> 163 in the cache */
   /* replace2235_1_0 -> 847 in the cache */
   /* replace2235_1_1 -> 165 in the cache */
   /* replace2235_1_2 -> 166 in the cache */
   /* replace2235_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2236_0 -> 847 in the cache */
   /* search2236_1_0 -> 163 in the cache */
   /* search2236_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2236_2_0 -> 163 in the cache */
   /* search2236_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6289, 6290 },
      -1,
   } },

   /* replace2236_0 -> 163 in the cache */
   /* replace2236_1_0 -> 847 in the cache */
   /* replace2236_1_1 -> 165 in the cache */
   /* replace2236_1_2 -> 166 in the cache */
   /* replace2236_1 -> 1412 in the cache */
   /* replace2236 -> 6288 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2237_0 -> 847 in the cache */
   /* search2237_1_0 -> 163 in the cache */
   /* search2237_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2237_2_0 -> 163 in the cache */
   /* search2237_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6292, 6293 },
      -1,
   } },

   /* replace2237_0 -> 163 in the cache */
   /* replace2237_1_0 -> 847 in the cache */
   /* replace2237_1_1 -> 165 in the cache */
   /* replace2237_1_2 -> 166 in the cache */
   /* replace2237_1 -> 1412 in the cache */
   /* replace2237 -> 6288 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2238_0 -> 847 in the cache */
   /* search2238_1_0 -> 163 in the cache */
   /* search2238_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2238_2_0 -> 163 in the cache */
   /* search2238_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6295, 6296 },
      -1,
   } },

   /* replace2238_0 -> 163 in the cache */
   /* replace2238_1_0 -> 847 in the cache */
   /* replace2238_1_1 -> 165 in the cache */
   /* replace2238_1_2 -> 166 in the cache */
   /* replace2238_1 -> 1412 in the cache */
   /* replace2238 -> 6288 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2239_0 -> 847 in the cache */
   /* search2239_1_0 -> 163 in the cache */
   /* search2239_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2239_2_0 -> 163 in the cache */
   /* search2239_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6298, 6299 },
      -1,
   } },

   /* replace2239_0 -> 163 in the cache */
   /* replace2239_1_0 -> 847 in the cache */
   /* replace2239_1_1 -> 165 in the cache */
   /* replace2239_1_2 -> 166 in the cache */
   /* replace2239_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2240_0 -> 847 in the cache */
   /* search2240_1_0 -> 163 in the cache */
   /* search2240_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2240_2_0 -> 163 in the cache */
   /* search2240_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6302, 6303 },
      -1,
   } },

   /* replace2240_0 -> 163 in the cache */
   /* replace2240_1_0 -> 847 in the cache */
   /* replace2240_1_1 -> 165 in the cache */
   /* replace2240_1_2 -> 166 in the cache */
   /* replace2240_1 -> 1412 in the cache */
   /* replace2240 -> 6301 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2241_0 -> 847 in the cache */
   /* search2241_1_0 -> 163 in the cache */
   /* search2241_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2241_2_0 -> 163 in the cache */
   /* search2241_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6305, 6306 },
      -1,
   } },

   /* replace2241_0 -> 163 in the cache */
   /* replace2241_1_0 -> 847 in the cache */
   /* replace2241_1_1 -> 165 in the cache */
   /* replace2241_1_2 -> 166 in the cache */
   /* replace2241_1 -> 1412 in the cache */
   /* replace2241 -> 6301 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2242_0 -> 847 in the cache */
   /* search2242_1_0 -> 163 in the cache */
   /* search2242_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2242_2_0 -> 163 in the cache */
   /* search2242_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6308, 6309 },
      -1,
   } },

   /* replace2242_0 -> 163 in the cache */
   /* replace2242_1_0 -> 847 in the cache */
   /* replace2242_1_1 -> 165 in the cache */
   /* replace2242_1_2 -> 166 in the cache */
   /* replace2242_1 -> 1412 in the cache */
   /* replace2242 -> 6301 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2243_0 -> 847 in the cache */
   /* search2243_1_0 -> 163 in the cache */
   /* search2243_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2243_2_0 -> 163 in the cache */
   /* search2243_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6311, 6312 },
      -1,
   } },

   /* replace2243_0 -> 163 in the cache */
   /* replace2243_1_0 -> 847 in the cache */
   /* replace2243_1_1 -> 165 in the cache */
   /* replace2243_1_2 -> 166 in the cache */
   /* replace2243_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2244_0 -> 847 in the cache */
   /* search2244_1_0 -> 163 in the cache */
   /* search2244_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2244_2_0 -> 163 in the cache */
   /* search2244_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6315, 6316 },
      -1,
   } },

   /* replace2244_0 -> 163 in the cache */
   /* replace2244_1_0 -> 847 in the cache */
   /* replace2244_1_1 -> 165 in the cache */
   /* replace2244_1_2 -> 166 in the cache */
   /* replace2244_1 -> 1412 in the cache */
   /* replace2244 -> 6314 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2245_0 -> 847 in the cache */
   /* search2245_1_0 -> 163 in the cache */
   /* search2245_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2245_2_0 -> 163 in the cache */
   /* search2245_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6318, 6319 },
      -1,
   } },

   /* replace2245_0 -> 163 in the cache */
   /* replace2245_1_0 -> 847 in the cache */
   /* replace2245_1_1 -> 165 in the cache */
   /* replace2245_1_2 -> 166 in the cache */
   /* replace2245_1 -> 1412 in the cache */
   /* replace2245 -> 6314 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2246_0 -> 847 in the cache */
   /* search2246_1_0 -> 163 in the cache */
   /* search2246_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2246_2_0 -> 163 in the cache */
   /* search2246_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6321, 6322 },
      -1,
   } },

   /* replace2246_0 -> 163 in the cache */
   /* replace2246_1_0 -> 847 in the cache */
   /* replace2246_1_1 -> 165 in the cache */
   /* replace2246_1_2 -> 166 in the cache */
   /* replace2246_1 -> 1412 in the cache */
   /* replace2246 -> 6314 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2247_0 -> 847 in the cache */
   /* search2247_1_0 -> 163 in the cache */
   /* search2247_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2247_2_0 -> 163 in the cache */
   /* search2247_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6324, 6325 },
      -1,
   } },

   /* replace2247_0 -> 163 in the cache */
   /* replace2247_1_0 -> 847 in the cache */
   /* replace2247_1_1 -> 165 in the cache */
   /* replace2247_1_2 -> 166 in the cache */
   /* replace2247_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2248_0 -> 847 in the cache */
   /* search2248_1_0 -> 163 in the cache */
   /* search2248_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2248_2_0 -> 163 in the cache */
   /* search2248_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6328, 6329 },
      -1,
   } },

   /* replace2248_0 -> 163 in the cache */
   /* replace2248_1_0 -> 847 in the cache */
   /* replace2248_1_1 -> 165 in the cache */
   /* replace2248_1_2 -> 166 in the cache */
   /* replace2248_1 -> 1412 in the cache */
   /* replace2248 -> 6327 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2249_0 -> 847 in the cache */
   /* search2249_1_0 -> 163 in the cache */
   /* search2249_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2249_2_0 -> 163 in the cache */
   /* search2249_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6331, 6332 },
      -1,
   } },

   /* replace2249_0 -> 163 in the cache */
   /* replace2249_1_0 -> 847 in the cache */
   /* replace2249_1_1 -> 165 in the cache */
   /* replace2249_1_2 -> 166 in the cache */
   /* replace2249_1 -> 1412 in the cache */
   /* replace2249 -> 6327 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2250_0 -> 847 in the cache */
   /* search2250_1_0 -> 163 in the cache */
   /* search2250_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2250_2_0 -> 163 in the cache */
   /* search2250_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6334, 6335 },
      -1,
   } },

   /* replace2250_0 -> 163 in the cache */
   /* replace2250_1_0 -> 847 in the cache */
   /* replace2250_1_1 -> 165 in the cache */
   /* replace2250_1_2 -> 166 in the cache */
   /* replace2250_1 -> 1412 in the cache */
   /* replace2250 -> 6327 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2251_0 -> 847 in the cache */
   /* search2251_1_0 -> 163 in the cache */
   /* search2251_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2251_2_0 -> 163 in the cache */
   /* search2251_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6337, 6338 },
      -1,
   } },

   /* replace2251_0 -> 163 in the cache */
   /* replace2251_1_0 -> 847 in the cache */
   /* replace2251_1_1 -> 165 in the cache */
   /* replace2251_1_2 -> 166 in the cache */
   /* replace2251_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2252_0 -> 847 in the cache */
   /* search2252_1_0 -> 163 in the cache */
   /* search2252_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2252_2_0 -> 163 in the cache */
   /* search2252_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6341, 6342 },
      -1,
   } },

   /* replace2252_0 -> 163 in the cache */
   /* replace2252_1_0 -> 847 in the cache */
   /* replace2252_1_1 -> 165 in the cache */
   /* replace2252_1_2 -> 166 in the cache */
   /* replace2252_1 -> 1412 in the cache */
   /* replace2252 -> 6340 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2253_0 -> 847 in the cache */
   /* search2253_1_0 -> 163 in the cache */
   /* search2253_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2253_2_0 -> 163 in the cache */
   /* search2253_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6344, 6345 },
      -1,
   } },

   /* replace2253_0 -> 163 in the cache */
   /* replace2253_1_0 -> 847 in the cache */
   /* replace2253_1_1 -> 165 in the cache */
   /* replace2253_1_2 -> 166 in the cache */
   /* replace2253_1 -> 1412 in the cache */
   /* replace2253 -> 6340 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2254_0 -> 847 in the cache */
   /* search2254_1_0 -> 163 in the cache */
   /* search2254_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2254_2_0 -> 163 in the cache */
   /* search2254_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6347, 6348 },
      -1,
   } },

   /* replace2254_0 -> 163 in the cache */
   /* replace2254_1_0 -> 847 in the cache */
   /* replace2254_1_1 -> 165 in the cache */
   /* replace2254_1_2 -> 166 in the cache */
   /* replace2254_1 -> 1412 in the cache */
   /* replace2254 -> 6340 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2255_0 -> 847 in the cache */
   /* search2255_1_0 -> 163 in the cache */
   /* search2255_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2255_2_0 -> 163 in the cache */
   /* search2255_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6350, 6351 },
      -1,
   } },

   /* replace2255_0 -> 163 in the cache */
   /* replace2255_1_0 -> 847 in the cache */
   /* replace2255_1_1 -> 165 in the cache */
   /* replace2255_1_2 -> 166 in the cache */
   /* replace2255_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2256_0 -> 847 in the cache */
   /* search2256_1_0 -> 163 in the cache */
   /* search2256_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2256_2_0 -> 163 in the cache */
   /* search2256_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6354, 6355 },
      -1,
   } },

   /* replace2256_0 -> 163 in the cache */
   /* replace2256_1_0 -> 847 in the cache */
   /* replace2256_1_1 -> 165 in the cache */
   /* replace2256_1_2 -> 166 in the cache */
   /* replace2256_1 -> 1412 in the cache */
   /* replace2256 -> 6353 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2257_0 -> 847 in the cache */
   /* search2257_1_0 -> 163 in the cache */
   /* search2257_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2257_2_0 -> 163 in the cache */
   /* search2257_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6357, 6358 },
      -1,
   } },

   /* replace2257_0 -> 163 in the cache */
   /* replace2257_1_0 -> 847 in the cache */
   /* replace2257_1_1 -> 165 in the cache */
   /* replace2257_1_2 -> 166 in the cache */
   /* replace2257_1 -> 1412 in the cache */
   /* replace2257 -> 6353 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2258_0 -> 847 in the cache */
   /* search2258_1_0 -> 163 in the cache */
   /* search2258_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2258_2_0 -> 163 in the cache */
   /* search2258_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6360, 6361 },
      -1,
   } },

   /* replace2258_0 -> 163 in the cache */
   /* replace2258_1_0 -> 847 in the cache */
   /* replace2258_1_1 -> 165 in the cache */
   /* replace2258_1_2 -> 166 in the cache */
   /* replace2258_1 -> 1412 in the cache */
   /* replace2258 -> 6353 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2259_0 -> 847 in the cache */
   /* search2259_1_0 -> 163 in the cache */
   /* search2259_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2259_2_0 -> 163 in the cache */
   /* search2259_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6363, 6364 },
      -1,
   } },

   /* replace2259_0 -> 163 in the cache */
   /* replace2259_1_0 -> 847 in the cache */
   /* replace2259_1_1 -> 165 in the cache */
   /* replace2259_1_2 -> 166 in the cache */
   /* replace2259_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2260_0 -> 847 in the cache */
   /* search2260_1_0 -> 163 in the cache */
   /* search2260_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2260_2_0 -> 163 in the cache */
   /* search2260_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6367, 6368 },
      -1,
   } },

   /* replace2260_0 -> 163 in the cache */
   /* replace2260_1_0 -> 847 in the cache */
   /* replace2260_1_1 -> 165 in the cache */
   /* replace2260_1_2 -> 166 in the cache */
   /* replace2260_1 -> 1412 in the cache */
   /* replace2260 -> 6366 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2261_0 -> 847 in the cache */
   /* search2261_1_0 -> 163 in the cache */
   /* search2261_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2261_2_0 -> 163 in the cache */
   /* search2261_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6370, 6371 },
      -1,
   } },

   /* replace2261_0 -> 163 in the cache */
   /* replace2261_1_0 -> 847 in the cache */
   /* replace2261_1_1 -> 165 in the cache */
   /* replace2261_1_2 -> 166 in the cache */
   /* replace2261_1 -> 1412 in the cache */
   /* replace2261 -> 6366 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2262_0 -> 847 in the cache */
   /* search2262_1_0 -> 163 in the cache */
   /* search2262_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2262_2_0 -> 163 in the cache */
   /* search2262_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6373, 6374 },
      -1,
   } },

   /* replace2262_0 -> 163 in the cache */
   /* replace2262_1_0 -> 847 in the cache */
   /* replace2262_1_1 -> 165 in the cache */
   /* replace2262_1_2 -> 166 in the cache */
   /* replace2262_1 -> 1412 in the cache */
   /* replace2262 -> 6366 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2263_0 -> 847 in the cache */
   /* search2263_1_0 -> 163 in the cache */
   /* search2263_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2263_2_0 -> 163 in the cache */
   /* search2263_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6376, 6377 },
      -1,
   } },

   /* replace2263_0 -> 163 in the cache */
   /* replace2263_1_0 -> 847 in the cache */
   /* replace2263_1_1 -> 165 in the cache */
   /* replace2263_1_2 -> 166 in the cache */
   /* replace2263_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2264_0 -> 847 in the cache */
   /* search2264_1_0 -> 163 in the cache */
   /* search2264_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2264_2_0 -> 163 in the cache */
   /* search2264_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6380, 6381 },
      -1,
   } },

   /* replace2264_0 -> 163 in the cache */
   /* replace2264_1_0 -> 847 in the cache */
   /* replace2264_1_1 -> 165 in the cache */
   /* replace2264_1_2 -> 166 in the cache */
   /* replace2264_1 -> 1412 in the cache */
   /* replace2264 -> 6379 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2265_0 -> 847 in the cache */
   /* search2265_1_0 -> 163 in the cache */
   /* search2265_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2265_2_0 -> 163 in the cache */
   /* search2265_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6383, 6384 },
      -1,
   } },

   /* replace2265_0 -> 163 in the cache */
   /* replace2265_1_0 -> 847 in the cache */
   /* replace2265_1_1 -> 165 in the cache */
   /* replace2265_1_2 -> 166 in the cache */
   /* replace2265_1 -> 1412 in the cache */
   /* replace2265 -> 6379 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2266_0 -> 847 in the cache */
   /* search2266_1_0 -> 163 in the cache */
   /* search2266_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2266_2_0 -> 163 in the cache */
   /* search2266_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6386, 6387 },
      -1,
   } },

   /* replace2266_0 -> 163 in the cache */
   /* replace2266_1_0 -> 847 in the cache */
   /* replace2266_1_1 -> 165 in the cache */
   /* replace2266_1_2 -> 166 in the cache */
   /* replace2266_1 -> 1412 in the cache */
   /* replace2266 -> 6379 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2267_0 -> 847 in the cache */
   /* search2267_1_0 -> 163 in the cache */
   /* search2267_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 163, 165 },
      0,
   } },
   /* search2267_2_0 -> 163 in the cache */
   /* search2267_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 163, 6246 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6389, 6390 },
      -1,
   } },

   /* replace2267_0 -> 163 in the cache */
   /* replace2267_1_0 -> 847 in the cache */
   /* replace2267_1_1 -> 165 in the cache */
   /* replace2267_1_2 -> 166 in the cache */
   /* replace2267_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2268_0 -> 847 in the cache */
   /* search2268_1_0 -> 163 in the cache */
   /* search2268_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 163, 4051 },
      0,
   } },
   /* search2268_2_0 -> 163 in the cache */
   /* search2268_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6393, 6394 },
      -1,
   } },

   /* replace2268_0 -> 163 in the cache */
   /* replace2268_1_0 -> 847 in the cache */
   /* replace2268_1_1 -> 165 in the cache */
   /* replace2268_1_2 -> 166 in the cache */
   /* replace2268_1 -> 1412 in the cache */
   /* replace2268 -> 6392 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2269_0 -> 847 in the cache */
   /* search2269_1_0 -> 163 in the cache */
   /* search2269_1_1 -> 4051 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 163, 4051 },
      -1,
   } },
   /* search2269_2_0 -> 163 in the cache */
   /* search2269_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6396, 6397 },
      -1,
   } },

   /* replace2269_0 -> 163 in the cache */
   /* replace2269_1_0 -> 847 in the cache */
   /* replace2269_1_1 -> 165 in the cache */
   /* replace2269_1_2 -> 166 in the cache */
   /* replace2269_1 -> 1412 in the cache */
   /* replace2269 -> 6392 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2270_0 -> 847 in the cache */
   /* search2270_1_0 -> 163 in the cache */
   /* search2270_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 163, 165 },
      -1,
   } },
   /* search2270_2_0 -> 163 in the cache */
   /* search2270_2_1 -> 6246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 163, 6246 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 847, 6399, 6400 },
      -1,
   } },

   /* replace2270_0 -> 163 in the cache */
   /* replace2270_1_0 -> 847 in the cache */
   /* replace2270_1_1 -> 165 in the cache */
   /* replace2270_1_2 -> 166 in the cache */
   /* replace2270_1 -> 1412 in the cache */
   /* replace2270 -> 6392 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2271_0 -> 847 in the cache */
   /* search2271_1_0 -> 163 in the cache */
   /* search2271_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 163, 165 },
      0,
   } },
   /* search2271_2_0 -> 163 in the cache */
   /* search2271_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 163, 166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6402, 6403 },
      -1,
   } },

   /* replace2271_0 -> 163 in the cache */
   /* replace2271_1_0 -> 847 in the cache */
   /* replace2271_1_1 -> 165 in the cache */
   /* replace2271_1_2 -> 166 in the cache */
   /* replace2271_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 163, 1412 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2272_0 -> 847 in the cache */
   /* search2272_1_0 -> 163 in the cache */
   /* search2272_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 163, 165 },
      -1,
   } },
   /* search2272_2_0 -> 163 in the cache */
   /* search2272_2_1 -> 166 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 163, 166 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6406, 6407 },
      -1,
   } },

   /* replace2272_0 -> 163 in the cache */
   /* replace2272_1_0 -> 847 in the cache */
   /* replace2272_1_1 -> 165 in the cache */
   /* replace2272_1_2 -> 166 in the cache */
   /* replace2272_1 -> 1412 in the cache */
   /* replace2272 -> 6405 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search2273_0 -> 847 in the cache */
   /* search2273_1_0 -> 140 in the cache */
   /* search2273_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 140, 142 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2273_2_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 6410, 142 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6409, 6411 },
      -1,
   } },

   /* replace2273_0_0 -> 847 in the cache */
   /* replace2273_0_1 -> 140 in the cache */
   /* replace2273_0_2 -> 6410 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 140, 6410 },
      -1,
   } },
   /* replace2273_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 6413, 142 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search2274_0 -> 847 in the cache */
   /* search2274_1_0 -> 140 in the cache */
   /* search2274_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 140, 142 },
      -1,
   } },
   /* search2274_2_0 -> 6410 in the cache */
   /* search2274_2_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 6410, 142 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 847, 6415, 6416 },
      -1,
   } },

   /* replace2274_0_0 -> 847 in the cache */
   /* replace2274_0_1 -> 140 in the cache */
   /* replace2274_0_2 -> 6410 in the cache */
   /* replace2274_0 -> 6413 in the cache */
   /* replace2274_1 -> 142 in the cache */
   /* replace2274 -> 6414 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search2275_0 -> 609 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 6418 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6419, 6421 },
      -1,
   } },

   /* replace2275_0_0 -> 609 in the cache */
   /* replace2275_0_1 -> 6418 in the cache */
   /* replace2275_0_2 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6418, 6420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search2276_0 -> 609 in the cache */
   /* search2276_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2276_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6425, 6426 },
      -1,
   } },

   /* replace2276_0_0 -> 609 in the cache */
   /* replace2276_0_1 -> 6418 in the cache */
   /* replace2276_0_2 -> 6420 in the cache */
   /* replace2276_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search2277_0 -> 609 in the cache */
   /* search2277_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2277_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6429, 6430 },
      -1,
   } },

   /* replace2277_0_0 -> 609 in the cache */
   /* replace2277_0_1 -> 6418 in the cache */
   /* replace2277_0_2 -> 6420 in the cache */
   /* replace2277_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search2278_0 -> 609 in the cache */
   /* search2278_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2278_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6433, 6434 },
      -1,
   } },

   /* replace2278_0_0 -> 609 in the cache */
   /* replace2278_0_1 -> 6418 in the cache */
   /* replace2278_0_2 -> 6420 in the cache */
   /* replace2278_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search2279_0 -> 609 in the cache */
   /* search2279_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2279_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6437, 6438 },
      -1,
   } },

   /* replace2279_0_0 -> 609 in the cache */
   /* replace2279_0_1 -> 6418 in the cache */
   /* replace2279_0_2 -> 6420 in the cache */
   /* replace2279_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search2280_0 -> 609 in the cache */
   /* search2280_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2280_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6441, 6442 },
      -1,
   } },

   /* replace2280_0_0 -> 609 in the cache */
   /* replace2280_0_1 -> 6418 in the cache */
   /* replace2280_0_2 -> 6420 in the cache */
   /* replace2280_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search2281_0 -> 609 in the cache */
   /* search2281_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2281_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6445, 6446 },
      -1,
   } },

   /* replace2281_0_0 -> 609 in the cache */
   /* replace2281_0_1 -> 6418 in the cache */
   /* replace2281_0_2 -> 6420 in the cache */
   /* replace2281_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search2282_0 -> 609 in the cache */
   /* search2282_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2282_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6449, 6450 },
      -1,
   } },

   /* replace2282_0_0 -> 609 in the cache */
   /* replace2282_0_1 -> 6418 in the cache */
   /* replace2282_0_2 -> 6420 in the cache */
   /* replace2282_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search2283_0 -> 609 in the cache */
   /* search2283_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2283_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6453, 6454 },
      -1,
   } },

   /* replace2283_0_0 -> 609 in the cache */
   /* replace2283_0_1 -> 6418 in the cache */
   /* replace2283_0_2 -> 6420 in the cache */
   /* replace2283_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search2284_0 -> 609 in the cache */
   /* search2284_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2284_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6457, 6458 },
      -1,
   } },

   /* replace2284_0_0 -> 609 in the cache */
   /* replace2284_0_1 -> 6418 in the cache */
   /* replace2284_0_2 -> 6420 in the cache */
   /* replace2284_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin_mdg(is_used_once)', 'a'), ('fsin_mdg(is_used_once)', 'b')) => ('fsin_mdg', ('bcsel', 'c', 'a', 'b')) */
   /* search2285_0 -> 609 in the cache */
   /* search2285_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_mdg,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2285_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_mdg,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6461, 6462 },
      -1,
   } },

   /* replace2285_0_0 -> 609 in the cache */
   /* replace2285_0_1 -> 6418 in the cache */
   /* replace2285_0_2 -> 6420 in the cache */
   /* replace2285_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_mdg,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos_mdg(is_used_once)', 'a'), ('fcos_mdg(is_used_once)', 'b')) => ('fcos_mdg', ('bcsel', 'c', 'a', 'b')) */
   /* search2286_0 -> 609 in the cache */
   /* search2286_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos_mdg,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2286_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos_mdg,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6465, 6466 },
      -1,
   } },

   /* replace2286_0_0 -> 609 in the cache */
   /* replace2286_0_1 -> 6418 in the cache */
   /* replace2286_0_2 -> 6420 in the cache */
   /* replace2286_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos_mdg,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin_agx(is_used_once)', 'a'), ('fsin_agx(is_used_once)', 'b')) => ('fsin_agx', ('bcsel', 'c', 'a', 'b')) */
   /* search2287_0 -> 609 in the cache */
   /* search2287_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_agx,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2287_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_agx,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6469, 6470 },
      -1,
   } },

   /* replace2287_0_0 -> 609 in the cache */
   /* replace2287_0_1 -> 6418 in the cache */
   /* replace2287_0_2 -> 6420 in the cache */
   /* replace2287_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin_agx,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search2288_0 -> 609 in the cache */
   /* search2288_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2288_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6473, 6474 },
      -1,
   } },

   /* replace2288_0_0 -> 609 in the cache */
   /* replace2288_0_1 -> 6418 in the cache */
   /* replace2288_0_2 -> 6420 in the cache */
   /* replace2288_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search2289_0 -> 609 in the cache */
   /* search2289_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 6418 },
      0,
   } },
   /* search2289_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 6420 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6477, 6478 },
      -1,
   } },

   /* replace2289_0_0 -> 609 in the cache */
   /* replace2289_0_1 -> 6418 in the cache */
   /* replace2289_0_2 -> 6420 in the cache */
   /* replace2289_0 -> 6423 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 6423 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search2290_0 -> 609 in the cache */
   /* search2290_1_0 -> 6418 in the cache */
   /* search2290_1 -> 6441 in the cache */
   /* search2290_2_0 -> 6420 in the cache */
   /* search2290_2 -> 6442 in the cache */
   /* search2290 -> 6443 in the cache */

   /* replace2290_0_0 -> 609 in the cache */
   /* replace2290_0_1 -> 6418 in the cache */
   /* replace2290_0_2 -> 6420 in the cache */
   /* replace2290_0 -> 6423 in the cache */
   /* replace2290 -> 6444 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search2291_0_0 -> 609 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6481, 6482 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 6483 },
      -1,
   } },

   /* replace2291_0 -> 609 in the cache */
   /* replace2291_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 6418 },
      -1,
   } },
   /* replace2291_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 6420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6485, 6486 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search2292_0_0 -> 609 in the cache */
   /* search2292_0_1 -> 6481 in the cache */
   /* search2292_0_2 -> 6482 in the cache */
   /* search2292_0 -> 6483 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 6483 },
      -1,
   } },

   /* replace2292_0 -> 609 in the cache */
   /* replace2292_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 6418 },
      -1,
   } },
   /* replace2292_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 6420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6489, 6490 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search2293_0_0 -> 609 in the cache */
   /* search2293_0_1 -> 6481 in the cache */
   /* search2293_0_2 -> 6482 in the cache */
   /* search2293_0 -> 6483 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 6483 },
      -1,
   } },

   /* replace2293_0 -> 609 in the cache */
   /* replace2293_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 6418 },
      -1,
   } },
   /* replace2293_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 6420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6493, 6494 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search2294_0_0 -> 609 in the cache */
   /* search2294_0_1 -> 6481 in the cache */
   /* search2294_0_2 -> 6482 in the cache */
   /* search2294_0 -> 6483 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 6483 },
      -1,
   } },

   /* replace2294_0 -> 609 in the cache */
   /* replace2294_1_0 -> 6418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 6418 },
      -1,
   } },
   /* replace2294_2_0 -> 6420 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 6420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 609, 6497, 6498 },
      -1,
   } },

   /* ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048)) */
   /* search2295_0 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 24 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xfffull /* 4095 */ },
   } },
   /* replace2295_1_0_0 -> 24 in the cache */
   /* replace2295_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 24, 486 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x800ull /* 2048 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6502, 6503 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 6501, 6504 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search2296_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 29 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffffull /* 33554431 */ },
   } },
   /* replace2296_1_0_0 -> 29 in the cache */
   /* replace2296_1_0_1 -> 486 in the cache */
   /* replace2296_1_0 -> 1081 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000ull /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1081, 6508 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 6507, 6509 },
      -1,
   } },

   /* ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992)) */
   /* search2297_0 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 34 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3fffffffffffffull /* 18014398509481983 */ },
   } },
   /* replace2297_1_0_0 -> 34 in the cache */
   /* replace2297_1_0_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 34, 486 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x20000000000000ull /* 9007199254740992 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6513, 6514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 6512, 6515 },
      -1,
   } },

   /* ('fquantize2f16', 'a@32') => ('bcsel', ('!flt', ('!fabs', 'a'), 6.103515625e-05), ('iand', 'a', 2147483648), ('!f2f32', ('!f2f16_rtne', 'a'))) */
   /* search2298_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fquantize2f16,
      -1, 0,
      { 29 },
      -1,
   } },

   /* replace2298_0_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 29 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3f10000000000000ull /* 6.103515625e-05 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 6518, 6519 },
      -1,
   } },
   /* replace2298_1_0 -> 29 in the cache */
   /* replace2298_1_1 -> 30 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 29, 30 },
      -1,
   } },
   /* replace2298_2_0_0 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_f2f16_rtne,
      -1, 0,
      { 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 6522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 6520, 6521, 6523 },
      -1,
   } },

   /* ('bfi', 4294967295, 'a', '#b') => ('iadd', ('ishl', 'a', 0), ('iand', 'b', -4294967296)) */
   /* search2299_0 -> 1017 in the cache */
   /* search2299_1 -> 29 in the cache */
   /* search2299_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 1017, 29, 45 },
      -1,
   } },

   /* replace2299_0_0 -> 29 in the cache */
   /* replace2299_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 135 },
      -1,
   } },
   /* replace2299_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff00000000ull /* -4294967296 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6527 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6526, 6528 },
      -1,
   } },

   /* ('bfi', 8589934590, 'a', '#b') => ('iadd', ('ishl', 'a', 1), ('iand', 'b', -8589934591)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffeull /* 8589934590 */ },
   } },
   /* search2300_1 -> 29 in the cache */
   /* search2300_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6530, 29, 45 },
      -1,
   } },

   /* replace2300_0_0 -> 29 in the cache */
   /* replace2300_0_1 -> 486 in the cache */
   /* replace2300_0 -> 1081 in the cache */
   /* replace2300_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe00000001ull /* -8589934591 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6532 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1081, 6533 },
      -1,
   } },

   /* ('bfi', 17179869180, 'a', '#b') => ('iadd', ('ishl', 'a', 2), ('iand', 'b', -17179869181)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffcull /* 17179869180 */ },
   } },
   /* search2301_1 -> 29 in the cache */
   /* search2301_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6535, 29, 45 },
      -1,
   } },

   /* replace2301_0_0 -> 29 in the cache */
   /* replace2301_0_1 -> 491 in the cache */
   /* replace2301_0 -> 1088 in the cache */
   /* replace2301_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc00000003ull /* -17179869181 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1088, 6538 },
      -1,
   } },

   /* ('bfi', 34359738360, 'a', '#b') => ('iadd', ('ishl', 'a', 3), ('iand', 'b', -34359738361)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff8ull /* 34359738360 */ },
   } },
   /* search2302_1 -> 29 in the cache */
   /* search2302_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6540, 29, 45 },
      -1,
   } },

   /* replace2302_0_0 -> 29 in the cache */
   /* replace2302_0_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 495 },
      -1,
   } },
   /* replace2302_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff800000007ull /* -34359738361 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6543 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6542, 6544 },
      -1,
   } },

   /* ('bfi', 68719476720, 'a', '#b') => ('iadd', ('ishl', 'a', 4), ('iand', 'b', -68719476721)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff0ull /* 68719476720 */ },
   } },
   /* search2303_1 -> 29 in the cache */
   /* search2303_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6546, 29, 45 },
      -1,
   } },

   /* replace2303_0_0 -> 29 in the cache */
   /* replace2303_0_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 2530 },
      -1,
   } },
   /* replace2303_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff00000000full /* -68719476721 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6549 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6548, 6550 },
      -1,
   } },

   /* ('bfi', 137438953440, 'a', '#b') => ('iadd', ('ishl', 'a', 5), ('iand', 'b', -137438953441)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe0ull /* 137438953440 */ },
   } },
   /* search2304_1 -> 29 in the cache */
   /* search2304_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6552, 29, 45 },
      -1,
   } },

   /* replace2304_0_0 -> 29 in the cache */
   /* replace2304_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 2585 },
      -1,
   } },
   /* replace2304_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe00000001full /* -137438953441 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6554, 6556 },
      -1,
   } },

   /* ('bfi', 274877906880, 'a', '#b') => ('iadd', ('ishl', 'a', 6), ('iand', 'b', -274877906881)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc0ull /* 274877906880 */ },
   } },
   /* search2305_1 -> 29 in the cache */
   /* search2305_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6558, 29, 45 },
      -1,
   } },

   /* replace2305_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x6ull /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6560 },
      -1,
   } },
   /* replace2305_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc00000003full /* -274877906881 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6562 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6561, 6563 },
      -1,
   } },

   /* ('bfi', 549755813760, 'a', '#b') => ('iadd', ('ishl', 'a', 7), ('iand', 'b', -549755813761)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff80ull /* 549755813760 */ },
   } },
   /* search2306_1 -> 29 in the cache */
   /* search2306_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6565, 29, 45 },
      -1,
   } },

   /* replace2306_0_0 -> 29 in the cache */
   /* replace2306_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 22 },
      -1,
   } },
   /* replace2306_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff800000007full /* -549755813761 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6567, 6569 },
      -1,
   } },

   /* ('bfi', 1099511627520, 'a', '#b') => ('iadd', ('ishl', 'a', 8), ('iand', 'b', -1099511627521)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff00ull /* 1099511627520 */ },
   } },
   /* search2307_1 -> 29 in the cache */
   /* search2307_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6571, 29, 45 },
      -1,
   } },

   /* replace2307_0_0 -> 29 in the cache */
   /* replace2307_0_1 -> 921 in the cache */
   /* replace2307_0 -> 3891 in the cache */
   /* replace2307_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff00000000ffull /* -1099511627521 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6573 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3891, 6574 },
      -1,
   } },

   /* ('bfi', 2199023255040, 'a', '#b') => ('iadd', ('ishl', 'a', 9), ('iand', 'b', -2199023255041)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe00ull /* 2199023255040 */ },
   } },
   /* search2308_1 -> 29 in the cache */
   /* search2308_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6576, 29, 45 },
      -1,
   } },

   /* replace2308_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x9ull /* 9 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6578 },
      -1,
   } },
   /* replace2308_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffe00000001ffull /* -2199023255041 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6580 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6579, 6581 },
      -1,
   } },

   /* ('bfi', 4398046510080, 'a', '#b') => ('iadd', ('ishl', 'a', 10), ('iand', 'b', -4398046510081)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc00ull /* 4398046510080 */ },
   } },
   /* search2309_1 -> 29 in the cache */
   /* search2309_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6583, 29, 45 },
      -1,
   } },

   /* replace2309_0_0 -> 29 in the cache */
   /* replace2309_0_1 -> 5782 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 5782 },
      -1,
   } },
   /* replace2309_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffc00000003ffull /* -4398046510081 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6585, 6587 },
      -1,
   } },

   /* ('bfi', 8796093020160, 'a', '#b') => ('iadd', ('ishl', 'a', 11), ('iand', 'b', -8796093020161)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff800ull /* 8796093020160 */ },
   } },
   /* search2310_1 -> 29 in the cache */
   /* search2310_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6589, 29, 45 },
      -1,
   } },

   /* replace2310_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xbull /* 11 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6591 },
      -1,
   } },
   /* replace2310_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffff800000007ffull /* -8796093020161 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6593 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6592, 6594 },
      -1,
   } },

   /* ('bfi', 17592186040320, 'a', '#b') => ('iadd', ('ishl', 'a', 12), ('iand', 'b', -17592186040321)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff000ull /* 17592186040320 */ },
   } },
   /* search2311_1 -> 29 in the cache */
   /* search2311_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6596, 29, 45 },
      -1,
   } },

   /* replace2311_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcull /* 12 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6598 },
      -1,
   } },
   /* replace2311_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffff00000000fffull /* -17592186040321 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6599, 6601 },
      -1,
   } },

   /* ('bfi', 35184372080640, 'a', '#b') => ('iadd', ('ishl', 'a', 13), ('iand', 'b', -35184372080641)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe000ull /* 35184372080640 */ },
   } },
   /* search2312_1 -> 29 in the cache */
   /* search2312_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6603, 29, 45 },
      -1,
   } },

   /* replace2312_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xdull /* 13 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6605 },
      -1,
   } },
   /* replace2312_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffe00000001fffull /* -35184372080641 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6606, 6608 },
      -1,
   } },

   /* ('bfi', 70368744161280, 'a', '#b') => ('iadd', ('ishl', 'a', 14), ('iand', 'b', -70368744161281)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc000ull /* 70368744161280 */ },
   } },
   /* search2313_1 -> 29 in the cache */
   /* search2313_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6610, 29, 45 },
      -1,
   } },

   /* replace2313_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xeull /* 14 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6612 },
      -1,
   } },
   /* replace2313_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffc00000003fffull /* -70368744161281 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6613, 6615 },
      -1,
   } },

   /* ('bfi', 140737488322560, 'a', '#b') => ('iadd', ('ishl', 'a', 15), ('iand', 'b', -140737488322561)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff8000ull /* 140737488322560 */ },
   } },
   /* search2314_1 -> 29 in the cache */
   /* search2314_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6617, 29, 45 },
      -1,
   } },

   /* replace2314_0_0 -> 29 in the cache */
   /* replace2314_0_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 27 },
      -1,
   } },
   /* replace2314_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff800000007fffull /* -140737488322561 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6620 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6619, 6621 },
      -1,
   } },

   /* ('bfi', 281474976645120, 'a', '#b') => ('iadd', ('ishl', 'a', 16), ('iand', 'b', -281474976645121)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff0000ull /* 281474976645120 */ },
   } },
   /* search2315_1 -> 29 in the cache */
   /* search2315_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6623, 29, 45 },
      -1,
   } },

   /* replace2315_0_0 -> 29 in the cache */
   /* replace2315_0_1 -> 943 in the cache */
   /* replace2315_0 -> 1095 in the cache */
   /* replace2315_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff00000000ffffull /* -281474976645121 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1095, 6626 },
      -1,
   } },

   /* ('bfi', 562949953290240, 'a', '#b') => ('iadd', ('ishl', 'a', 17), ('iand', 'b', -562949953290241)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe0000ull /* 562949953290240 */ },
   } },
   /* search2316_1 -> 29 in the cache */
   /* search2316_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6628, 29, 45 },
      -1,
   } },

   /* replace2316_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x11ull /* 17 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6630 },
      -1,
   } },
   /* replace2316_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffe00000001ffffull /* -562949953290241 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6632 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6631, 6633 },
      -1,
   } },

   /* ('bfi', 1125899906580480, 'a', '#b') => ('iadd', ('ishl', 'a', 18), ('iand', 'b', -1125899906580481)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc0000ull /* 1125899906580480 */ },
   } },
   /* search2317_1 -> 29 in the cache */
   /* search2317_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6635, 29, 45 },
      -1,
   } },

   /* replace2317_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x12ull /* 18 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6637 },
      -1,
   } },
   /* replace2317_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffc00000003ffffull /* -1125899906580481 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6639 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6638, 6640 },
      -1,
   } },

   /* ('bfi', 2251799813160960, 'a', '#b') => ('iadd', ('ishl', 'a', 19), ('iand', 'b', -2251799813160961)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff80000ull /* 2251799813160960 */ },
   } },
   /* search2318_1 -> 29 in the cache */
   /* search2318_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6642, 29, 45 },
      -1,
   } },

   /* replace2318_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x13ull /* 19 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6644 },
      -1,
   } },
   /* replace2318_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfff800000007ffffull /* -2251799813160961 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6646 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6645, 6647 },
      -1,
   } },

   /* ('bfi', 4503599626321920, 'a', '#b') => ('iadd', ('ishl', 'a', 20), ('iand', 'b', -4503599626321921)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff00000ull /* 4503599626321920 */ },
   } },
   /* search2319_1 -> 29 in the cache */
   /* search2319_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6649, 29, 45 },
      -1,
   } },

   /* replace2319_0_0 -> 29 in the cache */
   /* replace2319_0_1 -> 5825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 5825 },
      -1,
   } },
   /* replace2319_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfff00000000fffffull /* -4503599626321921 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6652 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6651, 6653 },
      -1,
   } },

   /* ('bfi', 9007199252643840, 'a', '#b') => ('iadd', ('ishl', 'a', 21), ('iand', 'b', -9007199252643841)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe00000ull /* 9007199252643840 */ },
   } },
   /* search2320_1 -> 29 in the cache */
   /* search2320_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6655, 29, 45 },
      -1,
   } },

   /* replace2320_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x15ull /* 21 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6657 },
      -1,
   } },
   /* replace2320_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffe00000001fffffull /* -9007199252643841 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6659 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6658, 6660 },
      -1,
   } },

   /* ('bfi', 18014398505287680, 'a', '#b') => ('iadd', ('ishl', 'a', 22), ('iand', 'b', -18014398505287681)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc00000ull /* 18014398505287680 */ },
   } },
   /* search2321_1 -> 29 in the cache */
   /* search2321_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6662, 29, 45 },
      -1,
   } },

   /* replace2321_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x16ull /* 22 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6664 },
      -1,
   } },
   /* replace2321_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffc00000003fffffull /* -18014398505287681 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6666 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6665, 6667 },
      -1,
   } },

   /* ('bfi', 36028797010575360, 'a', '#b') => ('iadd', ('ishl', 'a', 23), ('iand', 'b', -36028797010575361)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff800000ull /* 36028797010575360 */ },
   } },
   /* search2322_1 -> 29 in the cache */
   /* search2322_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6669, 29, 45 },
      -1,
   } },

   /* replace2322_0_0 -> 29 in the cache */
   /* replace2322_0_1 -> 5804 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 5804 },
      -1,
   } },
   /* replace2322_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff800000007fffffull /* -36028797010575361 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6672 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6671, 6673 },
      -1,
   } },

   /* ('bfi', 72057594021150720, 'a', '#b') => ('iadd', ('ishl', 'a', 24), ('iand', 'b', -72057594021150721)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff000000ull /* 72057594021150720 */ },
   } },
   /* search2323_1 -> 29 in the cache */
   /* search2323_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6675, 29, 45 },
      -1,
   } },

   /* replace2323_0_0 -> 29 in the cache */
   /* replace2323_0_1 -> 1102 in the cache */
   /* replace2323_0 -> 1104 in the cache */
   /* replace2323_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00000000ffffffull /* -72057594021150721 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6677 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1104, 6678 },
      -1,
   } },

   /* ('bfi', 144115188042301440, 'a', '#b') => ('iadd', ('ishl', 'a', 25), ('iand', 'b', -144115188042301441)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe000000ull /* 144115188042301440 */ },
   } },
   /* search2324_1 -> 29 in the cache */
   /* search2324_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6680, 29, 45 },
      -1,
   } },

   /* replace2324_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x19ull /* 25 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6682 },
      -1,
   } },
   /* replace2324_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe00000001ffffffull /* -144115188042301441 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6683, 6685 },
      -1,
   } },

   /* ('bfi', 288230376084602880, 'a', '#b') => ('iadd', ('ishl', 'a', 26), ('iand', 'b', -288230376084602881)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc000000ull /* 288230376084602880 */ },
   } },
   /* search2325_1 -> 29 in the cache */
   /* search2325_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6687, 29, 45 },
      -1,
   } },

   /* replace2325_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1aull /* 26 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6689 },
      -1,
   } },
   /* replace2325_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfc00000003ffffffull /* -288230376084602881 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6690, 6692 },
      -1,
   } },

   /* ('bfi', 576460752169205760, 'a', '#b') => ('iadd', ('ishl', 'a', 27), ('iand', 'b', -576460752169205761)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff8000000ull /* 576460752169205760 */ },
   } },
   /* search2326_1 -> 29 in the cache */
   /* search2326_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6694, 29, 45 },
      -1,
   } },

   /* replace2326_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1bull /* 27 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6696 },
      -1,
   } },
   /* replace2326_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf800000007ffffffull /* -576460752169205761 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6698 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6697, 6699 },
      -1,
   } },

   /* ('bfi', 1152921504338411520, 'a', '#b') => ('iadd', ('ishl', 'a', 28), ('iand', 'b', -1152921504338411521)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff0000000ull /* 1152921504338411520 */ },
   } },
   /* search2327_1 -> 29 in the cache */
   /* search2327_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6701, 29, 45 },
      -1,
   } },

   /* replace2327_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1cull /* 28 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6703 },
      -1,
   } },
   /* replace2327_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf00000000fffffffull /* -1152921504338411521 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6705 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6704, 6706 },
      -1,
   } },

   /* ('bfi', 2305843008676823040, 'a', '#b') => ('iadd', ('ishl', 'a', 29), ('iand', 'b', -2305843008676823041)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1fffffffe0000000ull /* 2305843008676823040 */ },
   } },
   /* search2328_1 -> 29 in the cache */
   /* search2328_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6708, 29, 45 },
      -1,
   } },

   /* replace2328_0_0 -> 29 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1dull /* 29 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 6710 },
      -1,
   } },
   /* replace2328_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xe00000001fffffffull /* -2305843008676823041 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6711, 6713 },
      -1,
   } },

   /* ('bfi', 4611686017353646080, 'a', '#b') => ('iadd', ('ishl', 'a', 30), ('iand', 'b', -4611686017353646081)) */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffffc0000000ull /* 4611686017353646080 */ },
   } },
   /* search2329_1 -> 29 in the cache */
   /* search2329_2 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 6715, 29, 45 },
      -1,
   } },

   /* replace2329_0_0 -> 29 in the cache */
   /* replace2329_0_1 -> 5778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 29, 5778 },
      -1,
   } },
   /* replace2329_1_0 -> 48 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xc00000003fffffffull /* -4611686017353646081 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 48, 6718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 6717, 6719 },
      -1,
   } },

   /* ('fadd', '#a(is_nan)', 'b') => nan */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      37,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2330_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x7ff8000000000000ull /* nan */ },
   } },

   /* ('fadd', 'a', '#b(is_nan)') => nan */
   /* search2331_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      37,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 6724 },
      -1,
   } },

   /* replace2331 -> 6723 in the cache */

   /* ('fdiv', '#a(is_nan)', 'b') => nan */
   /* search2332_0 -> 6721 in the cache */
   /* search2332_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2332 -> 6723 in the cache */

   /* ('fdiv', 'a', '#b(is_nan)') => nan */
   /* search2333_0 -> 0 in the cache */
   /* search2333_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2333 -> 6723 in the cache */

   /* ('fmod', '#a(is_nan)', 'b') => nan */
   /* search2334_0 -> 6721 in the cache */
   /* search2334_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2334 -> 6723 in the cache */

   /* ('fmod', 'a', '#b(is_nan)') => nan */
   /* search2335_0 -> 0 in the cache */
   /* search2335_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2335 -> 6723 in the cache */

   /* ('fmul', '#a(is_nan)', 'b') => nan */
   /* search2336_0 -> 6721 in the cache */
   /* search2336_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2336 -> 6723 in the cache */

   /* ('fmul', 'a', '#b(is_nan)') => nan */
   /* search2337_0 -> 0 in the cache */
   /* search2337_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 6724 },
      -1,
   } },

   /* replace2337 -> 6723 in the cache */

   /* ('fpow', '#a(is_nan)', 'b') => nan */
   /* search2338_0 -> 6721 in the cache */
   /* search2338_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2338 -> 6723 in the cache */

   /* ('fpow', 'a', '#b(is_nan)') => nan */
   /* search2339_0 -> 0 in the cache */
   /* search2339_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2339 -> 6723 in the cache */

   /* ('frem', '#a(is_nan)', 'b') => nan */
   /* search2340_0 -> 6721 in the cache */
   /* search2340_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2340 -> 6723 in the cache */

   /* ('frem', 'a', '#b(is_nan)') => nan */
   /* search2341_0 -> 0 in the cache */
   /* search2341_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2341 -> 6723 in the cache */

   /* ('fsub', '#a(is_nan)', 'b') => nan */
   /* search2342_0 -> 6721 in the cache */
   /* search2342_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2342 -> 6723 in the cache */

   /* ('fsub', 'a', '#b(is_nan)') => nan */
   /* search2343_0 -> 0 in the cache */
   /* search2343_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2343 -> 6723 in the cache */

   /* ('ffma', '#a(is_nan)', 'b', 'c') => nan */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      37,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2344_1 -> 140 in the cache */
   /* search2344_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6738, 140, 142 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x7ff8000000000000ull /* nan */ },
   } },

   /* ('ffma', 'a', '#b(is_nan)', 'c') => nan */
   /* search2345_0 -> 139 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      37,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2345_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 139, 6741, 142 },
      -1,
   } },

   /* replace2345 -> 6740 in the cache */

   /* ('ffma', 'a', 'b', '#c(is_nan)') => nan */
   /* search2346_0 -> 139 in the cache */
   /* search2346_1 -> 140 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      37,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 139, 140, 6743 },
      -1,
   } },

   /* replace2346 -> 6740 in the cache */

   /* ('flrp', '#a(is_nan)', 'b', 'c') => nan */
   /* search2347_0 -> 6738 in the cache */
   /* search2347_1 -> 140 in the cache */
   /* search2347_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6738, 140, 142 },
      -1,
   } },

   /* replace2347 -> 6740 in the cache */

   /* ('flrp', 'a', '#b(is_nan)', 'c') => nan */
   /* search2348_0 -> 139 in the cache */
   /* search2348_1 -> 6741 in the cache */
   /* search2348_2 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 139, 6741, 142 },
      -1,
   } },

   /* replace2348 -> 6740 in the cache */

   /* ('flrp', 'a', 'b', '#c(is_nan)') => nan */
   /* search2349_0 -> 139 in the cache */
   /* search2349_1 -> 140 in the cache */
   /* search2349_2 -> 6743 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 139, 140, 6743 },
      -1,
   } },

   /* replace2349 -> 6740 in the cache */

   /* ('fmin', '#a(is_nan)', 'b') => b */
   /* search2350_0 -> 6721 in the cache */
   /* search2350_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2350 -> 1 in the cache */

   /* ('fmax', '#a(is_nan)', 'b') => b */
   /* search2351_0 -> 6721 in the cache */
   /* search2351_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2351 -> 1 in the cache */

   /* ('ldexp', '#a(is_nan)', 'b') => nan */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      true,
      nir_type_invalid,
      37,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2352_1 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 6750, 48 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff8000000000000ull /* nan */ },
   } },

   /* ('fdot2', '#a(is_any_comp_nan)', 'b') => nan */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      38,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2353_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 6753, 1 },
      -1,
   } },

   /* replace2353 -> 6723 in the cache */

   /* ('fdot3', '#a(is_any_comp_nan)', 'b') => nan */
   /* search2354_0 -> 6753 in the cache */
   /* search2354_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 6753, 1 },
      -1,
   } },

   /* replace2354 -> 6723 in the cache */

   /* ('fdot4', '#a(is_any_comp_nan)', 'b') => nan */
   /* search2355_0 -> 6753 in the cache */
   /* search2355_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 6753, 1 },
      -1,
   } },

   /* replace2355 -> 6723 in the cache */

   /* ('fdot5', '#a(is_any_comp_nan)', 'b') => nan */
   /* search2356_0 -> 6753 in the cache */
   /* search2356_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot5,
      0, 1,
      { 6753, 1 },
      -1,
   } },

   /* replace2356 -> 6723 in the cache */

   /* ('fdot8', '#a(is_any_comp_nan)', 'b') => nan */
   /* search2357_0 -> 6753 in the cache */
   /* search2357_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot8,
      0, 1,
      { 6753, 1 },
      -1,
   } },

   /* replace2357 -> 6723 in the cache */

   /* ('fdot16', '#a(is_any_comp_nan)', 'b') => nan */
   /* search2358_0 -> 6753 in the cache */
   /* search2358_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot16,
      0, 1,
      { 6753, 1 },
      -1,
   } },

   /* replace2358 -> 6723 in the cache */

   /* ('feq', '#a(is_nan)', 'b') => False */
   /* search2359_0 -> 6721 in the cache */
   /* search2359_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2359 -> 1165 in the cache */

   /* ('feq', 'a', '#b(is_nan)') => False */
   /* search2360_0 -> 0 in the cache */
   /* search2360_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 6724 },
      -1,
   } },

   /* replace2360 -> 1165 in the cache */

   /* ('fge', '#a(is_nan)', 'b') => False */
   /* search2361_0 -> 6721 in the cache */
   /* search2361_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2361 -> 1165 in the cache */

   /* ('fge', 'a', '#b(is_nan)') => False */
   /* search2362_0 -> 0 in the cache */
   /* search2362_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2362 -> 1165 in the cache */

   /* ('flt', '#a(is_nan)', 'b') => False */
   /* search2363_0 -> 6721 in the cache */
   /* search2363_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2363 -> 1165 in the cache */

   /* ('flt', 'a', '#b(is_nan)') => False */
   /* search2364_0 -> 0 in the cache */
   /* search2364_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2364 -> 1165 in the cache */

   /* ('fneu', '#a(is_nan)', 'b') => True */
   /* search2365_0 -> 6721 in the cache */
   /* search2365_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2365 -> 1350 in the cache */

   /* ('seq', '#a(is_nan)', 'b') => 0.0 */
   /* search2366_0 -> 6721 in the cache */
   /* search2366_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2366 -> 273 in the cache */

   /* ('seq', 'a', '#b(is_nan)') => 0.0 */
   /* search2367_0 -> 0 in the cache */
   /* search2367_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 6724 },
      -1,
   } },

   /* replace2367 -> 273 in the cache */

   /* ('sge', '#a(is_nan)', 'b') => 0.0 */
   /* search2368_0 -> 6721 in the cache */
   /* search2368_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2368 -> 273 in the cache */

   /* ('sge', 'a', '#b(is_nan)') => 0.0 */
   /* search2369_0 -> 0 in the cache */
   /* search2369_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2369 -> 273 in the cache */

   /* ('slt', '#a(is_nan)', 'b') => 0.0 */
   /* search2370_0 -> 6721 in the cache */
   /* search2370_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 6721, 1 },
      -1,
   } },

   /* replace2370 -> 273 in the cache */

   /* ('slt', 'a', '#b(is_nan)') => 0.0 */
   /* search2371_0 -> 0 in the cache */
   /* search2371_1 -> 6724 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 6724 },
      -1,
   } },

   /* replace2371 -> 273 in the cache */

   /* ('sne', '#a(is_nan)', 'b') => 1.0 */
   /* search2372_0 -> 6721 in the cache */
   /* search2372_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 6721, 1 },
      -1,
   } },

   /* replace2372 -> 283 in the cache */

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search2373_0_0 -> 29 in the cache */
   /* search2373_0_1 -> 48 in the cache */
   /* search2373_0 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 3626 },
      -1,
   } },

   /* replace2373_0_0 -> 29 in the cache */
   /* replace2373_0 -> 4553 in the cache */
   /* replace2373_1_0 -> 48 in the cache */
   /* replace2373_1 -> 4550 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4553, 4550 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search2374_0_0 -> 29 in the cache */
   /* search2374_0_1 -> 48 in the cache */
   /* search2374_0 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 3626 },
      -1,
   } },

   /* replace2374_0_0 -> 29 in the cache */
   /* replace2374_0 -> 2251 in the cache */
   /* replace2374_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2251, 6777 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search2375_0_0 -> 29 in the cache */
   /* search2375_0_1 -> 48 in the cache */
   /* search2375_0 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3626 },
      -1,
   } },

   /* replace2375_0_0 -> 29 in the cache */
   /* replace2375_0 -> 3761 in the cache */
   /* replace2375_1_0 -> 48 in the cache */
   /* replace2375_1 -> 5406 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3761, 5406 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search2376_0_0 -> 29 in the cache */
   /* search2376_0_1 -> 48 in the cache */
   /* search2376_0 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3626 },
      -1,
   } },

   /* replace2376_0_0 -> 29 in the cache */
   /* replace2376_0 -> 4894 in the cache */
   /* replace2376_1_0 -> 48 in the cache */
   /* replace2376_1 -> 5077 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4894, 5077 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search2377_0_0 -> 29 in the cache */
   /* search2377_0_1 -> 48 in the cache */
   /* search2377_0 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 3626 },
      -1,
   } },

   /* replace2377_0_0 -> 29 in the cache */
   /* replace2377_0 -> 2262 in the cache */
   /* replace2377_1_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 48 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2262, 6784 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search2378_0_0 -> 29 in the cache */
   /* search2378_0_1 -> 48 in the cache */
   /* search2378_0_2 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 29, 48, 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 6786 },
      -1,
   } },

   /* replace2378_0_0 -> 29 in the cache */
   /* replace2378_0 -> 4553 in the cache */
   /* replace2378_1_0 -> 48 in the cache */
   /* replace2378_1 -> 4550 in the cache */
   /* replace2378_2_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 4553, 4550, 6788 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search2379_0_0 -> 29 in the cache */
   /* search2379_0_1 -> 48 in the cache */
   /* search2379_0_2 -> 148 in the cache */
   /* search2379_0 -> 6786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 6786 },
      -1,
   } },

   /* replace2379_0_0 -> 29 in the cache */
   /* replace2379_0 -> 2251 in the cache */
   /* replace2379_1_0 -> 48 in the cache */
   /* replace2379_1 -> 6777 in the cache */
   /* replace2379_2_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 2251, 6777, 6791 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search2380_0_0 -> 29 in the cache */
   /* search2380_0_1 -> 48 in the cache */
   /* search2380_0_2 -> 148 in the cache */
   /* search2380_0 -> 6786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6786 },
      -1,
   } },

   /* replace2380_0_0 -> 29 in the cache */
   /* replace2380_0 -> 3761 in the cache */
   /* replace2380_1_0 -> 48 in the cache */
   /* replace2380_1 -> 5406 in the cache */
   /* replace2380_2_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3761, 5406, 6794 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search2381_0_0 -> 29 in the cache */
   /* search2381_0_1 -> 48 in the cache */
   /* search2381_0_2 -> 148 in the cache */
   /* search2381_0 -> 6786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6786 },
      -1,
   } },

   /* replace2381_0_0 -> 29 in the cache */
   /* replace2381_0 -> 4894 in the cache */
   /* replace2381_1_0 -> 48 in the cache */
   /* replace2381_1 -> 5077 in the cache */
   /* replace2381_2_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 4894, 5077, 6797 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search2382_0_0 -> 29 in the cache */
   /* search2382_0_1 -> 48 in the cache */
   /* search2382_0_2 -> 148 in the cache */
   /* search2382_0 -> 6786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 6786 },
      -1,
   } },

   /* replace2382_0_0 -> 29 in the cache */
   /* replace2382_0 -> 2262 in the cache */
   /* replace2382_1_0 -> 48 in the cache */
   /* replace2382_1 -> 6784 in the cache */
   /* replace2382_2_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 148 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 2262, 6784, 6800 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search2383_0_0 -> 29 in the cache */
   /* search2383_0_1 -> 48 in the cache */
   /* search2383_0_2 -> 148 in the cache */
   /* search2383_0_3 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 29, 48, 148, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 6802 },
      -1,
   } },

   /* replace2383_0_0 -> 29 in the cache */
   /* replace2383_0 -> 4553 in the cache */
   /* replace2383_1_0 -> 48 in the cache */
   /* replace2383_1 -> 4550 in the cache */
   /* replace2383_2_0 -> 148 in the cache */
   /* replace2383_2 -> 6788 in the cache */
   /* replace2383_3_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4553, 4550, 6788, 6804 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search2384_0_0 -> 29 in the cache */
   /* search2384_0_1 -> 48 in the cache */
   /* search2384_0_2 -> 148 in the cache */
   /* search2384_0_3 -> 176 in the cache */
   /* search2384_0 -> 6802 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 6802 },
      -1,
   } },

   /* replace2384_0_0 -> 29 in the cache */
   /* replace2384_0 -> 2251 in the cache */
   /* replace2384_1_0 -> 48 in the cache */
   /* replace2384_1 -> 6777 in the cache */
   /* replace2384_2_0 -> 148 in the cache */
   /* replace2384_2 -> 6791 in the cache */
   /* replace2384_3_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2251, 6777, 6791, 6807 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search2385_0_0 -> 29 in the cache */
   /* search2385_0_1 -> 48 in the cache */
   /* search2385_0_2 -> 148 in the cache */
   /* search2385_0_3 -> 176 in the cache */
   /* search2385_0 -> 6802 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6802 },
      -1,
   } },

   /* replace2385_0_0 -> 29 in the cache */
   /* replace2385_0 -> 3761 in the cache */
   /* replace2385_1_0 -> 48 in the cache */
   /* replace2385_1 -> 5406 in the cache */
   /* replace2385_2_0 -> 148 in the cache */
   /* replace2385_2 -> 6794 in the cache */
   /* replace2385_3_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3761, 5406, 6794, 6810 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search2386_0_0 -> 29 in the cache */
   /* search2386_0_1 -> 48 in the cache */
   /* search2386_0_2 -> 148 in the cache */
   /* search2386_0_3 -> 176 in the cache */
   /* search2386_0 -> 6802 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6802 },
      -1,
   } },

   /* replace2386_0_0 -> 29 in the cache */
   /* replace2386_0 -> 4894 in the cache */
   /* replace2386_1_0 -> 48 in the cache */
   /* replace2386_1 -> 5077 in the cache */
   /* replace2386_2_0 -> 148 in the cache */
   /* replace2386_2 -> 6797 in the cache */
   /* replace2386_3_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4894, 5077, 6797, 6813 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search2387_0_0 -> 29 in the cache */
   /* search2387_0_1 -> 48 in the cache */
   /* search2387_0_2 -> 148 in the cache */
   /* search2387_0_3 -> 176 in the cache */
   /* search2387_0 -> 6802 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 6802 },
      -1,
   } },

   /* replace2387_0_0 -> 29 in the cache */
   /* replace2387_0 -> 2262 in the cache */
   /* replace2387_1_0 -> 48 in the cache */
   /* replace2387_1 -> 6784 in the cache */
   /* replace2387_2_0 -> 148 in the cache */
   /* replace2387_2 -> 6800 in the cache */
   /* replace2387_3_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2262, 6784, 6800, 6816 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   is_used_once,
   is_only_used_as_float,
   is_not_used_by_if,
   is_used_by_non_fsat,
   no_signed_wrap,
   only_lower_8_bits_used,
   only_lower_16_bits_used,
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_negative_zero),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_lower_half_zero),
   (is_upper_half_zero),
   (is_lower_half_negative_one),
   (is_upper_half_negative_one),
   (is_odd),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_ult_32),
   (is_nan),
   (is_any_comp_nan),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 4, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5, 7, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 10, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3120, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3120, 1346, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 64, 66, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 67, 69, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 70, 9, 0 },
   { 79, 80, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 71, 9, 0 },
   { 81, 85, 1 },
   { 86, 89, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 73, 0 },
   { 90, 93, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 74, 73, 0 },
   { 76, 73, 0 },
   { 94, 93, 1 },
   { 95, 100, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 73, 0 },
   { 78, 73, 0 },
   { 101, 107, 1 },
   { 108, 109, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 110, 4569, 127 },
   { 2117, 4573, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 794, 796, 24 },
   { 797, 799, 24 },
   { 800, 802, 25 },
   { 3558, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3565, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4291, 4304, 95 },
   { 4695, 4703, 138 },
   { 4712, 4720, 138 },
   { 4729, 4736, 138 },
   { 4291, 4751, 138 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 9, 0 },
   { 4291, 4304, 95 },
   { 4695, 4703, 138 },
   { 4712, 4720, 138 },
   { 4729, 4736, 138 },
   { 4291, 4751, 138 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4305, 4313, 95 },
   { 4704, 4711, 138 },
   { 4721, 4728, 138 },
   { 4737, 4744, 138 },
   { 4305, 4756, 138 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 132, 9, 0 },
   { 4305, 4313, 95 },
   { 4704, 4711, 138 },
   { 4721, 4728, 138 },
   { 4737, 4744, 138 },
   { 4305, 4756, 138 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4278, 4282, 91 },
   { 4283, 4285, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 9, 0 },
   { 4278, 4282, 91 },
   { 4283, 4285, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4286, 4287, 93 },
   { 4288, 4290, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 134, 9, 0 },
   { 4286, 4287, 93 },
   { 4288, 4290, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 136, 29, 0 },
   { 138, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 241, 0 },
   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 262, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 297, 298, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 297, 298, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 281, 282, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 281, 282, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 300, 301, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 281, 282, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 300, 301, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3126, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3126, 1346, 0 },
   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 135, 0 },
   { 258, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 772, 774, 0 },
   { 6746, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 772, 774, 0 },
   { 6746, 6740, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 6745, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 305, 279, 0 },
   { 6745, 6740, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 772, 774, 0 },
   { 6745, 6740, 0 },
   { 6746, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 305, 279, 0 },
   { 772, 774, 0 },
   { 6745, 6740, 0 },
   { 6746, 6740, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 501, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 501, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 48, 0 },
   { 344, 501, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 48, 0 },
   { 344, 501, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 48, 0 },
   { 361, 363, 0 },
   { 344, 501, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 48, 0 },
   { 361, 363, 0 },
   { 344, 501, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 517, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 517, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 311, 48, 0 },
   { 347, 517, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 311, 48, 0 },
   { 347, 517, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 311, 48, 0 },
   { 364, 366, 0 },
   { 347, 517, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 311, 48, 0 },
   { 364, 366, 0 },
   { 347, 517, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 545, 377, 14 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 312, 48, 0 },
   { 545, 377, 14 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 312, 48, 0 },
   { 376, 377, 6 },
   { 545, 377, 14 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 544, 379, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 543, 347, 0 },
   { 544, 379, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 313, 48, 0 },
   { 544, 379, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 313, 48, 0 },
   { 543, 347, 0 },
   { 544, 379, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 313, 48, 0 },
   { 378, 379, 7 },
   { 544, 379, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 313, 48, 0 },
   { 378, 379, 7 },
   { 543, 347, 0 },
   { 544, 379, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 356, 533, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 356, 533, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 314, 48, 0 },
   { 356, 533, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 314, 48, 0 },
   { 356, 533, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 314, 48, 0 },
   { 370, 372, 0 },
   { 356, 533, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 314, 48, 0 },
   { 370, 372, 0 },
   { 356, 533, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 359, 541, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 359, 541, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 48, 0 },
   { 359, 541, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 48, 0 },
   { 359, 541, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 48, 0 },
   { 373, 375, 0 },
   { 359, 541, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 48, 0 },
   { 373, 375, 0 },
   { 359, 541, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 549, 550, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 48, 0 },
   { 549, 550, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 48, 0 },
   { 382, 383, 6 },
   { 549, 550, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 547, 548, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 317, 48, 0 },
   { 547, 548, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 317, 48, 0 },
   { 384, 385, 7 },
   { 547, 548, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 48, 0 },
   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 48, 0 },
   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 48, 0 },
   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 48, 0 },
   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 48, 0 },
   { 319, 48, 0 },
   { 367, 369, 0 },
   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 48, 0 },
   { 319, 48, 0 },
   { 367, 369, 0 },
   { 350, 525, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 546, 381, 15 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 320, 48, 0 },
   { 546, 381, 15 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 48, 0 },
   { 546, 381, 15 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 320, 48, 0 },
   { 321, 48, 0 },
   { 380, 381, 6 },
   { 546, 381, 15 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 775, 781, 22 },
   { 782, 786, 22 },
   { 787, 793, 23 },
   { 3560, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 795, 818, 28 },
   { 798, 819, 28 },
   { 801, 820, 29 },
   { 3562, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 821, 823, 30 },
   { 3559, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 855, 860, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 895, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 861, 8, 0 },
   { 894, 895, 39 },
   { 6756, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 892, 893, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 862, 8, 0 },
   { 892, 893, 39 },
   { 6755, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 890, 891, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 863, 8, 0 },
   { 886, 889, 0 },
   { 890, 891, 39 },
   { 6754, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 896, 889, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3125, 9, 0 },
   { 3661, 3662, 71 },
   { 3663, 496, 71 },
   { 3664, 3665, 71 },
   { 3713, 529, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3122, 1346, 0 },
   { 3124, 3123, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3122, 1346, 0 },
   { 3124, 3123, 0 },
   { 3125, 9, 0 },
   { 3661, 3662, 71 },
   { 3663, 496, 71 },
   { 3664, 3665, 71 },
   { 3713, 529, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1207, 1208, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 1211, 1212, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 3612, 1165, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1443, 9, 0 },
   { 1444, 75, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4467, 4470, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4462, 4466, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4462, 4466, 110 },
   { 5644, 24, 0 },
   { 5697, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4471, 4475, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4471, 4475, 111 },
   { 5749, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4476, 4479, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4476, 4479, 111 },
   { 5722, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2752, 2760, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2752, 2760, 55 },
   { 6772, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2752, 2760, 55 },
   { 6771, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2752, 2760, 55 },
   { 6771, 273, 0 },
   { 6772, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2754, 2761, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2754, 2761, 55 },
   { 6770, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2754, 2761, 55 },
   { 6769, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2754, 2761, 55 },
   { 6769, 273, 0 },
   { 6770, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 2762, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 2762, 55 },
   { 6767, 273, 0 },
   { 6768, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 2763, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 2763, 55 },
   { 6773, 283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 2789, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2790, 2792, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2793, 2795, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2796, 2798, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2799, 2801, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2802, 2805, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2806, 2810, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2811, 2813, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2814, 2816, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2817, 2819, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 2825, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 2832, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2833, 2839, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2840, 2856, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2857, 2889, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2890, 2893, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2894, 2899, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2900, 2904, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2905, 2913, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2914, 2930, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2931, 2934, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2935, 2940, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2941, 2945, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2946, 2954, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2955, 2971, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2972, 2975, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2976, 2981, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2982, 2986, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2987, 2995, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2996, 3012, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3996, 3997, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3996, 3997, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3153, 3156, 60 },
   { 3132, 3135, 61 },
   { 3139, 3142, 62 },
   { 3157, 3160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3163, 60 },
   { 3145, 3147, 61 },
   { 3150, 3152, 62 },
   { 3164, 3166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4355, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3189, 29, 0 },
   { 3190, 48, 0 },
   { 3195, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3189, 29, 0 },
   { 3190, 48, 0 },
   { 3195, 2327, 0 },
   { 3196, 2289, 0 },
   { 6525, 6529, 147 },
   { 6531, 6534, 147 },
   { 6536, 6539, 147 },
   { 6541, 6545, 147 },
   { 6547, 6551, 147 },
   { 6553, 6557, 147 },
   { 6559, 6564, 147 },
   { 6566, 6570, 147 },
   { 6572, 6575, 147 },
   { 6577, 6582, 147 },
   { 6584, 6588, 147 },
   { 6590, 6595, 147 },
   { 6597, 6602, 147 },
   { 6604, 6609, 147 },
   { 6611, 6616, 147 },
   { 6618, 6622, 147 },
   { 6624, 6627, 147 },
   { 6629, 6634, 147 },
   { 6636, 6641, 147 },
   { 6643, 6648, 147 },
   { 6650, 6654, 147 },
   { 6656, 6661, 147 },
   { 6663, 6668, 147 },
   { 6670, 6674, 147 },
   { 6676, 6679, 147 },
   { 6681, 6686, 147 },
   { 6688, 6693, 147 },
   { 6695, 6700, 147 },
   { 6702, 6707, 147 },
   { 6709, 6714, 147 },
   { 6716, 6720, 147 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 64 },
   { 3251, 9, 0 },
   { 3252, 268, 0 },
   { 3253, 3234, 0 },
   { 3254, 3238, 0 },
   { 6733, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 64 },
   { 3255, 3209, 0 },
   { 6732, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 64 },
   { 3251, 9, 0 },
   { 3252, 268, 0 },
   { 3253, 3234, 0 },
   { 3254, 3238, 0 },
   { 3255, 3209, 0 },
   { 6732, 6723, 0 },
   { 6733, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3227, 3297, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3292, 3294, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3292, 3294, 66 },
   { 6727, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3291, 3273, 0 },
   { 3292, 3294, 66 },
   { 6726, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3291, 3273, 0 },
   { 3292, 3294, 66 },
   { 6726, 6723, 0 },
   { 6727, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3299, 3381, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3382, 3451, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3488, 48, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3561, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3613, 3752, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3613, 3752, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3613, 3752, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3613, 3752, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3760, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3639, 3755, 75 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3647, 3761, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3649, 3762, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4394, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3689, 502, 71 },
   { 3690, 505, 71 },
   { 3691, 509, 71 },
   { 3692, 512, 71 },
   { 3717, 534, 72 },
   { 3718, 537, 72 },
   { 4394, 135, 0 },
   { 4396, 4398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4395, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3693, 483, 71 },
   { 3694, 487, 71 },
   { 3695, 492, 71 },
   { 3696, 496, 71 },
   { 3719, 526, 72 },
   { 3720, 529, 72 },
   { 4395, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 76 },
   { 3756, 4555, 122 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 76 },
   { 3756, 4555, 122 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 76 },
   { 3756, 4555, 122 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 76 },
   { 3756, 4555, 122 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3765, 4556, 123 },
   { 3765, 4558, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3772, 4559, 123 },
   { 3772, 4561, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3992, 29, 0 },
   { 3993, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3994, 3995, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3994, 3995, 0 },
   { 6737, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3994, 3995, 0 },
   { 6736, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3994, 3995, 0 },
   { 6736, 6723, 0 },
   { 6737, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3998, 4000, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4001, 4002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4003, 4005, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4452, 4455, 109 },
   { 4457, 4461, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4429, 4433, 103 },
   { 4429, 4437, 104 },
   { 4429, 4441, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4442, 4446, 106 },
   { 4442, 4448, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4222, 4225, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4222, 4225, 84 },
   { 6729, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4222, 4225, 84 },
   { 6728, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4222, 4225, 84 },
   { 6728, 6723, 0 },
   { 6729, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4226, 4229, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4226, 4229, 84 },
   { 6735, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4226, 4229, 84 },
   { 6734, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4226, 4229, 84 },
   { 6734, 6723, 0 },
   { 6735, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4230, 4233, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4234, 4235, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4240, 4244, 87 },
   { 4240, 4342, 98 },
   { 4240, 4344, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4245, 4248, 88 },
   { 4258, 4262, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4249, 4251, 88 },
   { 4263, 4265, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 4254, 88 },
   { 4266, 4270, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4255, 4257, 88 },
   { 4271, 4273, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4274, 4275, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4276, 4277, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4348, 4351, 100 },
   { 4348, 4422, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4352, 4354, 100 },
   { 4352, 4428, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4449, 4450, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4481, 4487, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4489, 4495, 113 },
   { 4489, 4497, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4498, 4505, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4506, 4513, 116 },
   { 4506, 4515, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 4522, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4523, 4530, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4531, 4539, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 4549, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4562, 4564, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4574, 1041, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4575, 4579, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4580, 4584, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4585, 4586, 132 },
   { 4585, 61, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4587, 4580, 133 },
   { 4587, 4589, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4590, 4575, 134 },
   { 4590, 61, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4591, 4586, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4592, 643, 0 },
   { 4593, 4594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4591, 4586, 0 },
   { 4592, 643, 0 },
   { 4593, 4594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4592, 643, 0 },
   { 4593, 4594, 0 },
   { 4595, 4597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4591, 4586, 0 },
   { 4592, 643, 0 },
   { 4593, 4594, 0 },
   { 4595, 4597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4598, 4599, 1 },
   { 4601, 4605, 1 },
   { 4606, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4798, 847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4799, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4800, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4801, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5775, 5795, 141 },
   { 5797, 5815, 141 },
   { 5817, 5838, 141 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5775, 5795, 141 },
   { 5797, 5815, 141 },
   { 5817, 5838, 141 },
   { 6751, 6752, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6199, 8, 144 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6200, 8, 144 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6201, 8, 144 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6202, 8, 144 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6203, 8, 144 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6204, 8, 144 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6206, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6209, 148, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6207, 148, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6207, 148, 0 },
   { 6209, 148, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6500, 6505, 145 },
   { 6506, 6510, 145 },
   { 6511, 6516, 145 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6517, 6524, 146 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6757, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6758, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6759, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5633, 5631, 0 },
   { 5686, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5658, 5631, 0 },
   { 5711, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 4031, 4032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 4031, 4032, 0 },
   { 4075, 4032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 4014, 4015, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 1114, 1117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 6195, 6198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5633, 5631, 0 },
   { 5686, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5658, 5631, 0 },
   { 5711, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5633, 5631, 0 },
   { 5686, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5658, 5631, 0 },
   { 5711, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3031, 3032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5633, 5631, 0 },
   { 5658, 5631, 0 },
   { 5686, 61, 0 },
   { 5711, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5633, 5631, 0 },
   { 5686, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5633, 5631, 0 },
   { 5686, 61, 0 },
   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5658, 5631, 0 },
   { 5711, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5658, 5631, 0 },
   { 5711, 61, 0 },
   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5738, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4121, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 71, 9, 0 },
   { 81, 85, 1 },
   { 86, 89, 1 },
   { 4121, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 4390, 4391, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 4061, 4062, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 4061, 4062, 0 },
   { 4103, 4062, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 325, 327, 0 },
   { 343, 344, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 329, 330, 0 },
   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 336, 337, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 339, 340, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 332, 334, 0 },
   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 6191, 6194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 192, 194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 199, 201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 227, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 227, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 343, 344, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5655, 4620, 0 },
   { 5683, 4633, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5735, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5760, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5735, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3804, 3756, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3807, 3757, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4137, 4122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4139, 4125, 0 },
   { 4144, 4125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4140, 4128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4141, 4131, 0 },
   { 4145, 4131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4142, 4134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3285, 3287, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4215, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4215, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4215, 11, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4215, 11, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3454, 847, 0 },
   { 3455, 1248, 0 },
   { 3458, 3459, 0 },
   { 3460, 3461, 0 },
   { 3464, 3465, 0 },
   { 3466, 3467, 0 },
   { 3468, 3469, 0 },
   { 3470, 3471, 0 },
   { 3473, 3474, 0 },
   { 3475, 3476, 0 },
   { 3477, 3478, 70 },
   { 3479, 3480, 70 },
   { 3483, 3484, 70 },
   { 3485, 3486, 70 },
   { 3487, 1, 0 },
   { 3489, 2604, 0 },
   { 3490, 3492, 0 },
   { 3494, 1345, 0 },
   { 3495, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6274, 6275, 0 },
   { 6278, 6275, 0 },
   { 6281, 6275, 0 },
   { 6284, 6275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6248, 6249, 0 },
   { 6252, 6249, 0 },
   { 6255, 6249, 0 },
   { 6258, 6249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6443, 6444, 0 },
   { 6443, 6444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6479, 6480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6475, 6476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6261, 6262, 0 },
   { 6265, 6262, 0 },
   { 6268, 6262, 0 },
   { 6271, 6262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6233, 6235, 0 },
   { 6238, 6235, 0 },
   { 6241, 6235, 0 },
   { 6244, 6235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6287, 6288, 0 },
   { 6291, 6288, 0 },
   { 6294, 6288, 0 },
   { 6297, 6288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6300, 6301, 0 },
   { 6304, 6301, 0 },
   { 6307, 6301, 0 },
   { 6310, 6301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6212, 6213, 0 },
   { 6216, 6213, 0 },
   { 6218, 6220, 0 },
   { 6222, 6220, 0 },
   { 6225, 6227, 0 },
   { 6229, 6227, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1413, 1411, 0 },
   { 1416, 1418, 0 },
   { 1421, 1418, 0 },
   { 1425, 1427, 0 },
   { 1430, 1427, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4216, 4217, 0 },
   { 4219, 4221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6435, 6436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1899, 1901, 0 },
   { 2008, 2010, 0 },
   { 2102, 2104, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6326, 6327, 0 },
   { 6330, 6327, 0 },
   { 6333, 6327, 0 },
   { 6336, 6327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6339, 6340, 0 },
   { 6343, 6340, 0 },
   { 6346, 6340, 0 },
   { 6349, 6340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6352, 6353, 0 },
   { 6356, 6353, 0 },
   { 6359, 6353, 0 },
   { 6362, 6353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6365, 6366, 0 },
   { 6369, 6366, 0 },
   { 6372, 6366, 0 },
   { 6375, 6366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6378, 6379, 0 },
   { 6382, 6379, 0 },
   { 6385, 6379, 0 },
   { 6388, 6379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6391, 6392, 0 },
   { 6395, 6392, 0 },
   { 6398, 6392, 0 },
   { 6401, 6392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5625, 5620, 0 },
   { 5678, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5650, 5620, 0 },
   { 5703, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5755, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5730, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6313, 6314, 0 },
   { 6317, 6314, 0 },
   { 6320, 6314, 0 },
   { 6323, 6314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6439, 6440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6404, 6405, 0 },
   { 6408, 6405, 0 },
   { 6412, 6414, 0 },
   { 6417, 6414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6431, 6432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6422, 6424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6427, 6428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6447, 6448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6451, 6452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6455, 6456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6459, 6460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6463, 6464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6467, 6468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 6471, 6472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2417, 0 },
   { 2471, 2472, 0 },
   { 2525, 1036, 0 },
   { 2579, 2580, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2417, 0 },
   { 2471, 2472, 0 },
   { 2525, 1036, 0 },
   { 2579, 2580, 0 },
   { 3120, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3120, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 913, 915, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 917, 926, 0 },
   { 939, 947, 0 },
   { 960, 967, 0 },
   { 980, 988, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1110, 1112, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1080, 1081, 0 },
   { 1087, 1088, 0 },
   { 1094, 1095, 0 },
   { 1103, 1104, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1000, 1003, 0 },
   { 1008, 1011, 0 },
   { 1016, 1019, 0 },
   { 1024, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1000, 1003, 0 },
   { 1008, 1011, 0 },
   { 1016, 1019, 0 },
   { 1024, 1027, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1000, 1003, 0 },
   { 1008, 1011, 0 },
   { 1016, 1019, 0 },
   { 1024, 1027, 0 },
   { 2416, 2417, 0 },
   { 2471, 2472, 0 },
   { 2525, 1036, 0 },
   { 2579, 2580, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1000, 1003, 0 },
   { 1008, 1011, 0 },
   { 1016, 1019, 0 },
   { 1024, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1004, 1003, 0 },
   { 1012, 1011, 0 },
   { 1020, 1019, 0 },
   { 1028, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1004, 1003, 0 },
   { 1012, 1011, 0 },
   { 1020, 1019, 0 },
   { 1028, 1027, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1004, 1003, 0 },
   { 1012, 1011, 0 },
   { 1020, 1019, 0 },
   { 1028, 1027, 0 },
   { 2416, 2417, 0 },
   { 2471, 2472, 0 },
   { 2525, 1036, 0 },
   { 2579, 2580, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1004, 1003, 0 },
   { 1012, 1011, 0 },
   { 1020, 1019, 0 },
   { 1028, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { 3794, 3795, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { 3799, 3800, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4392, 4393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { 4392, 4393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2417, 0 },
   { 2471, 2472, 0 },
   { 2525, 1036, 0 },
   { 2579, 2580, 0 },
   { 4392, 4393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4392, 4393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1040, 1041, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1036, 0 },
   { 1082, 1081, 0 },
   { 1089, 1088, 0 },
   { 1097, 1095, 0 },
   { 1106, 1104, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1045, 1047, 0 },
   { 1051, 1053, 0 },
   { 1057, 1059, 0 },
   { 1063, 1065, 0 },
   { 1069, 1071, 0 },
   { 1075, 1077, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3074, 3075, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3074, 3075, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 4105, 4107, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3073, 1, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1083, 0 },
   { 1091, 1090, 0 },
   { 1099, 1098, 0 },
   { 1108, 1107, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3515, 3505, 0 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3060, 73, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2319, 2320, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 3078, 3079, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2634, 2635, 0 },
   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 206, 0 },
   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1165, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 2374, 45 },
   { 2372, 2380, 47 },
   { 2429, 2431, 45 },
   { 2429, 2437, 47 },
   { 2483, 2485, 45 },
   { 2483, 2491, 47 },
   { 2537, 2539, 50 },
   { 2537, 2545, 52 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2384, 2385, 48 },
   { 2441, 2442, 48 },
   { 2495, 2496, 48 },
   { 2549, 2550, 53 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2310, 2312, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 6101, 6102, 0 },
   { 6104, 6105, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 6091, 6092, 0 },
   { 6094, 6095, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 6096, 6097, 0 },
   { 6099, 6100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1879, 1880, 0 },
   { 1988, 1989, 0 },
   { 2082, 2083, 0 },
   { 3056, 9, 0 },
   { 6101, 6102, 0 },
   { 6104, 6105, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3033, 3032, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2315, 2316, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3116, 3117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 1749, 1735, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 1862, 1863, 0 },
   { 1864, 1863, 0 },
   { 1971, 1972, 0 },
   { 1973, 1972, 0 },
   { 2065, 2066, 0 },
   { 2067, 2066, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 1749, 1735, 0 },
   { 1862, 1863, 0 },
   { 1864, 1863, 0 },
   { 1971, 1972, 0 },
   { 1973, 1972, 0 },
   { 2065, 2066, 0 },
   { 2067, 2066, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 1754, 1738, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 1754, 1738, 0 },
   { 1862, 1863, 0 },
   { 1864, 1863, 0 },
   { 1971, 1972, 0 },
   { 1973, 1972, 0 },
   { 2065, 2066, 0 },
   { 2067, 2066, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 1165, 0 },
   { 1733, 1735, 0 },
   { 1736, 1738, 0 },
   { 1749, 1735, 0 },
   { 1754, 1738, 0 },
   { 1862, 1863, 0 },
   { 1864, 1863, 0 },
   { 1971, 1972, 0 },
   { 1973, 1972, 0 },
   { 2065, 2066, 0 },
   { 2067, 2066, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 1757, 1741, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1379, 1380, 40 },
   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1974, 1975, 0 },
   { 1976, 1975, 0 },
   { 2068, 2069, 0 },
   { 2070, 2069, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1379, 1380, 40 },
   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 1757, 1741, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1974, 1975, 0 },
   { 1976, 1975, 0 },
   { 2068, 2069, 0 },
   { 2070, 2069, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 1760, 1744, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1379, 1380, 40 },
   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 1760, 1744, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1974, 1975, 0 },
   { 1976, 1975, 0 },
   { 2068, 2069, 0 },
   { 2070, 2069, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1379, 1380, 40 },
   { 1739, 1741, 0 },
   { 1742, 1744, 0 },
   { 1757, 1741, 0 },
   { 1760, 1744, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1974, 1975, 0 },
   { 1976, 1975, 0 },
   { 2068, 2069, 0 },
   { 2070, 2069, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1881, 1882, 0 },
   { 1990, 1991, 0 },
   { 2084, 2085, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1172, 1165, 0 },
   { 1801, 1802, 0 },
   { 1803, 1804, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1165, 0 },
   { 1809, 1810, 0 },
   { 1811, 1812, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1805, 1806, 0 },
   { 1807, 1808, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1813, 1814, 0 },
   { 1815, 1816, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2299, 0 },
   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5661, 2281, 0 },
   { 5689, 2289, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 2295, 0 },
   { 3056, 9, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2302, 2303, 0 },
   { 3056, 9, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5741, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2306, 2307, 0 },
   { 3056, 9, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3071, 1, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3072, 2694, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3072, 2694, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 4109, 4111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3064, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2343, 2344, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3180, 3170, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3182, 3179, 63 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3181, 3174, 63 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 211, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2631, 2633, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 2383, 48 },
   { 2438, 2440, 48 },
   { 2492, 2494, 48 },
   { 2546, 2548, 53 },
   { 2592, 2593, 0 },
   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2596, 2597, 0 },
   { 2600, 2601, 0 },
   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2377, 2378, 46 },
   { 2377, 2386, 47 },
   { 2434, 2435, 46 },
   { 2434, 2443, 47 },
   { 2488, 2489, 46 },
   { 2488, 2497, 47 },
   { 2542, 2543, 51 },
   { 2542, 2551, 52 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 2340, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1870, 1873, 0 },
   { 1979, 1982, 0 },
   { 2073, 2076, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3034, 3035, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2341, 2342, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 3118, 3119, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1842, 1140, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1721, 1702, 0 },
   { 1842, 1140, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1842, 1140, 0 },
   { 1848, 1850, 0 },
   { 1853, 1850, 0 },
   { 1957, 1959, 0 },
   { 1962, 1959, 0 },
   { 2051, 2053, 0 },
   { 2056, 2053, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1721, 1702, 0 },
   { 1842, 1140, 0 },
   { 1848, 1850, 0 },
   { 1853, 1850, 0 },
   { 1957, 1959, 0 },
   { 1962, 1959, 0 },
   { 2051, 2053, 0 },
   { 2056, 2053, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1726, 1708, 0 },
   { 1842, 1140, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1726, 1708, 0 },
   { 1842, 1140, 0 },
   { 1848, 1850, 0 },
   { 1853, 1850, 0 },
   { 1957, 1959, 0 },
   { 1962, 1959, 0 },
   { 2051, 2053, 0 },
   { 2056, 2053, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1702, 0 },
   { 1706, 1708, 0 },
   { 1721, 1702, 0 },
   { 1726, 1708, 0 },
   { 1842, 1140, 0 },
   { 1848, 1850, 0 },
   { 1853, 1850, 0 },
   { 1957, 1959, 0 },
   { 1962, 1959, 0 },
   { 2051, 2053, 0 },
   { 2056, 2053, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 1729, 1713, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 1856, 1858, 0 },
   { 1861, 1858, 0 },
   { 1965, 1967, 0 },
   { 1970, 1967, 0 },
   { 2059, 2061, 0 },
   { 2064, 2061, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 1729, 1713, 0 },
   { 1856, 1858, 0 },
   { 1861, 1858, 0 },
   { 1965, 1967, 0 },
   { 1970, 1967, 0 },
   { 2059, 2061, 0 },
   { 2064, 2061, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 1732, 1718, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 1732, 1718, 0 },
   { 1856, 1858, 0 },
   { 1861, 1858, 0 },
   { 1965, 1967, 0 },
   { 1970, 1967, 0 },
   { 2059, 2061, 0 },
   { 2064, 2061, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1711, 1713, 0 },
   { 1716, 1718, 0 },
   { 1729, 1713, 0 },
   { 1732, 1718, 0 },
   { 1856, 1858, 0 },
   { 1861, 1858, 0 },
   { 1965, 1967, 0 },
   { 1970, 1967, 0 },
   { 2059, 2061, 0 },
   { 2064, 2061, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1876, 1878, 0 },
   { 1985, 1987, 0 },
   { 2079, 2081, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1763, 1765, 0 },
   { 1768, 1770, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1783, 1785, 0 },
   { 1788, 1790, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1773, 1775, 0 },
   { 1778, 1780, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1793, 1795, 0 },
   { 1798, 1800, 0 },
   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2332, 2333, 0 },
   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5664, 2323, 0 },
   { 5692, 2327, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5692, 2327, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2329, 2331, 0 },
   { 3061, 9, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5664, 2323, 0 },
   { 5717, 2327, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 3061, 9, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5744, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 2337, 0 },
   { 3061, 9, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3805, 3756, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3808, 3757, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5695, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5667, 2347, 0 },
   { 5720, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5642, 2347, 0 },
   { 5695, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5667, 2347, 0 },
   { 5720, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3068, 1, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3068, 1, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 4113, 4115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 2368, 0 },
   { 3065, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2362, 2364, 0 },
   { 3065, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 2366, 0 },
   { 3065, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 2357, 0 },
   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5695, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5667, 2347, 0 },
   { 5695, 2351, 0 },
   { 5720, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5695, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5695, 2351, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5642, 2347, 0 },
   { 5695, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 2355, 0 },
   { 3065, 73, 0 },
   { 5667, 2347, 0 },
   { 5720, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5667, 2347, 0 },
   { 5720, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5667, 2347, 0 },
   { 5720, 2351, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5667, 2347, 0 },
   { 5720, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 3065, 73, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5747, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2360, 2361, 0 },
   { 3065, 73, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2420, 2421, 0 },
   { 2475, 2476, 0 },
   { 2528, 2529, 0 },
   { 2583, 2584, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2420, 2421, 0 },
   { 2475, 2476, 0 },
   { 2528, 2529, 0 },
   { 2583, 2584, 0 },
   { 3126, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3126, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1005, 1007, 0 },
   { 1013, 1015, 0 },
   { 1021, 1023, 0 },
   { 1029, 1031, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1005, 1007, 0 },
   { 1013, 1015, 0 },
   { 1021, 1023, 0 },
   { 1029, 1031, 0 },
   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 3711, 534, 72 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1005, 1007, 0 },
   { 1013, 1015, 0 },
   { 1021, 1023, 0 },
   { 1029, 1031, 0 },
   { 2420, 2421, 0 },
   { 2475, 2476, 0 },
   { 2528, 2529, 0 },
   { 2583, 2584, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1005, 1007, 0 },
   { 1013, 1015, 0 },
   { 1021, 1023, 0 },
   { 1029, 1031, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 928, 930, 0 },
   { 949, 951, 0 },
   { 969, 971, 0 },
   { 990, 992, 0 },
   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { 3796, 3793, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { 3801, 3798, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2419, 0 },
   { 2473, 2474, 0 },
   { 2526, 2527, 0 },
   { 2581, 2582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2419, 0 },
   { 2473, 2474, 0 },
   { 2526, 2527, 0 },
   { 2581, 2582, 0 },
   { 3122, 1346, 0 },
   { 3124, 3123, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3125, 9, 0 },
   { 3661, 3662, 71 },
   { 3663, 496, 71 },
   { 3664, 3665, 71 },
   { 3712, 526, 72 },
   { 3713, 529, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3125, 9, 0 },
   { 3661, 3662, 71 },
   { 3663, 496, 71 },
   { 3664, 3665, 71 },
   { 3713, 529, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2419, 0 },
   { 2473, 2474, 0 },
   { 2526, 2527, 0 },
   { 2581, 2582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3125, 9, 0 },
   { 3661, 3662, 71 },
   { 3663, 496, 71 },
   { 3664, 3665, 71 },
   { 3670, 3671, 71 },
   { 3674, 3675, 71 },
   { 3713, 529, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 932, 937, 0 },
   { 953, 958, 0 },
   { 973, 978, 0 },
   { 994, 999, 0 },
   { 3125, 9, 0 },
   { 3661, 3662, 71 },
   { 3663, 496, 71 },
   { 3664, 3665, 71 },
   { 3713, 529, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3889, 3890, 0 },
   { 3892, 509, 0 },
   { 3893, 505, 0 },
   { 3894, 502, 0 },
   { 3896, 3867, 0 },
   { 3898, 3862, 0 },
   { 3900, 3857, 0 },
   { 3901, 3854, 0 },
   { 3903, 3850, 0 },
   { 3905, 3846, 0 },
   { 3907, 3908, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3707, 3671, 0 },
   { 3708, 3675, 0 },
   { 3709, 3710, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3839, 3656, 0 },
   { 3841, 505, 0 },
   { 3842, 509, 0 },
   { 3843, 512, 0 },
   { 3845, 3846, 0 },
   { 3848, 3850, 0 },
   { 3852, 3854, 0 },
   { 3855, 3857, 0 },
   { 3860, 3862, 0 },
   { 3865, 3867, 0 },
   { 3868, 3660, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3869, 3656, 0 },
   { 3871, 505, 0 },
   { 3872, 509, 0 },
   { 3873, 512, 0 },
   { 3875, 3846, 0 },
   { 3877, 3850, 0 },
   { 3879, 3854, 0 },
   { 3881, 3857, 0 },
   { 3883, 3862, 0 },
   { 3885, 3867, 0 },
   { 3886, 3660, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3698, 3682, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3697, 3682, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3887, 3675, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3818, 3819, 0 },
   { 3820, 3821, 0 },
   { 3822, 3823, 0 },
   { 3824, 3825, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3909, 3910, 0 },
   { 3911, 492, 0 },
   { 3912, 487, 0 },
   { 3913, 483, 0 },
   { 3914, 3915, 0 },
   { 3916, 3917, 0 },
   { 3918, 3919, 0 },
   { 3920, 3921, 0 },
   { 3922, 3923, 0 },
   { 3924, 3925, 0 },
   { 3926, 3927, 0 },
   { 4462, 4466, 110 },
   { 5644, 24, 0 },
   { 5697, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3699, 3700, 0 },
   { 3701, 3702, 0 },
   { 3705, 3706, 0 },
   { 4462, 4466, 110 },
   { 5644, 24, 0 },
   { 5697, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3810, 3811, 0 },
   { 3812, 3813, 0 },
   { 3814, 3815, 0 },
   { 3816, 3817, 0 },
   { 4462, 4466, 110 },
   { 5644, 24, 0 },
   { 5697, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4357, 4358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4355, 3075, 0 },
   { 4357, 4358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3178, 3179, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3173, 3174, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3630, 34, 0 },
   { 3613, 3752, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3613, 3752, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 63, 61, 0 },
   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3088, 3758, 77 },
   { 3769, 3088, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3088, 3758, 77 },
   { 3763, 3082, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3622, 29, 0 },
   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3619, 29, 0 },
   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3614, 29, 0 },
   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3617, 2783, 0 },
   { 3088, 3758, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4019, 4021, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4019, 4021, 0 },
   { 4064, 4021, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4006, 4007, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4027, 4029, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4027, 4029, 0 },
   { 4068, 4029, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6182, 6185, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { 6182, 6185, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3283, 3284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3036, 1386, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3288, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 4046, 4048, 0 },
   { 4050, 4048, 0 },
   { 4119, 4048, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 4046, 4048, 0 },
   { 4050, 4048, 0 },
   { 4077, 4048, 0 },
   { 4119, 4048, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 4053, 4055, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 4053, 4055, 0 },
   { 4084, 4086, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 4057, 4059, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 4057, 4059, 0 },
   { 4094, 4096, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 6178, 6181, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 170, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 232, 1, 0 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 150, 152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 184, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 122, 11, 0 },
   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 124, 123, 0 },
   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2753, 2752, 0 },
   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2755, 2754, 0 },
   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2757, 2756, 0 },
   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 2758, 0 },
   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 173, 175, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 297, 298, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 297, 298, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 173, 175, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 4071, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 4071, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 173, 175, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 4071, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4037, 4039, 0 },
   { 4071, 4039, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4042, 4043, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4042, 4043, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4042, 4043, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4042, 4043, 0 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 173, 175, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4011, 4012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4011, 4012, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4011, 4012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 4011, 4012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 554, 555, 16 },
   { 629, 630, 18 },
   { 694, 695, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 554, 555, 16 },
   { 629, 630, 18 },
   { 694, 695, 20 },
   { 772, 774, 0 },
   { 6746, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 568, 571, 16 },
   { 640, 642, 18 },
   { 708, 711, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 568, 571, 16 },
   { 640, 642, 18 },
   { 708, 711, 20 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 554, 555, 16 },
   { 568, 571, 16 },
   { 629, 630, 18 },
   { 640, 642, 18 },
   { 694, 695, 20 },
   { 708, 711, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 307, 309, 0 },
   { 558, 560, 16 },
   { 631, 633, 18 },
   { 698, 700, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 307, 309, 0 },
   { 558, 560, 16 },
   { 631, 633, 18 },
   { 698, 700, 20 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 307, 309, 0 },
   { 554, 555, 16 },
   { 558, 560, 16 },
   { 629, 630, 18 },
   { 631, 633, 18 },
   { 694, 695, 20 },
   { 698, 700, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 554, 555, 16 },
   { 629, 630, 18 },
   { 694, 695, 20 },
   { 6745, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 554, 555, 16 },
   { 629, 630, 18 },
   { 694, 695, 20 },
   { 772, 774, 0 },
   { 6745, 6740, 0 },
   { 6746, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 568, 571, 16 },
   { 640, 642, 18 },
   { 708, 711, 20 },
   { 6745, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 305, 279, 0 },
   { 568, 571, 16 },
   { 640, 642, 18 },
   { 708, 711, 20 },
   { 6745, 6740, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 554, 555, 16 },
   { 568, 571, 16 },
   { 629, 630, 18 },
   { 640, 642, 18 },
   { 694, 695, 20 },
   { 708, 711, 20 },
   { 6745, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 307, 309, 0 },
   { 558, 560, 16 },
   { 631, 633, 18 },
   { 698, 700, 20 },
   { 6745, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 305, 279, 0 },
   { 307, 309, 0 },
   { 558, 560, 16 },
   { 631, 633, 18 },
   { 698, 700, 20 },
   { 6745, 6740, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 305, 279, 0 },
   { 307, 309, 0 },
   { 554, 555, 16 },
   { 558, 560, 16 },
   { 629, 630, 18 },
   { 631, 633, 18 },
   { 694, 695, 20 },
   { 698, 700, 20 },
   { 6745, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 568, 571, 16 },
   { 640, 642, 18 },
   { 708, 711, 20 },
   { 768, 770, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 568, 571, 16 },
   { 640, 642, 18 },
   { 708, 711, 20 },
   { 768, 770, 0 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 554, 555, 16 },
   { 568, 571, 16 },
   { 629, 630, 18 },
   { 640, 642, 18 },
   { 694, 695, 20 },
   { 708, 711, 20 },
   { 768, 770, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 307, 309, 0 },
   { 558, 560, 16 },
   { 564, 566, 16 },
   { 631, 633, 18 },
   { 636, 638, 18 },
   { 698, 700, 20 },
   { 704, 706, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 0, 0 },
   { 303, 1, 0 },
   { 304, 0, 0 },
   { 307, 309, 0 },
   { 558, 560, 16 },
   { 564, 566, 16 },
   { 631, 633, 18 },
   { 636, 638, 18 },
   { 698, 700, 20 },
   { 704, 706, 20 },
   { 6747, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 0, 0 },
   { 307, 309, 0 },
   { 554, 555, 16 },
   { 558, 560, 16 },
   { 564, 566, 16 },
   { 629, 630, 18 },
   { 631, 633, 18 },
   { 636, 638, 18 },
   { 694, 695, 20 },
   { 698, 700, 20 },
   { 704, 706, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3208, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1629, 1631, 0 },
   { 235, 1621, 42 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 1634, 235, 0 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1633, 1632, 0 },
   { 235, 1621, 42 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1907, 24, 0 },
   { 2016, 29, 0 },
   { 2110, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4780, 3505, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3526, 3527, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1905, 24, 0 },
   { 2014, 29, 0 },
   { 2108, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1931, 1932, 0 },
   { 1939, 1940, 0 },
   { 1949, 1950, 0 },
   { 2037, 2038, 0 },
   { 2045, 2046, 0 },
   { 2131, 2132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2254, 2255, 0 },
   { 3554, 2259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1309, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1308, 1309, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1308, 1309, 0 },
   { 1327, 1329, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1225, 1226, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 0 },
   { 1215, 1216, 0 },
   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1355, 1218, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1238, 1143, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6107, 6110, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1343, 1248, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1364, 1218, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 3015, 3, 0 },
   { 3023, 6, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 3016, 6, 0 },
   { 3024, 3, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 3013, 1143, 0 },
   { 3021, 1140, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 3014, 1140, 0 },
   { 3022, 1143, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1309, 0 },
   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1280, 1279, 0 },
   { 1510, 1279, 0 },
   { 1514, 1279, 0 },
   { 1518, 1279, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3054, 1350, 0 },
   { 5552, 5554, 140 },
   { 5569, 5554, 140 },
   { 5577, 5578, 0 },
   { 5591, 5593, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2661, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 2656, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 1373, 1224, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1190, 1194, 0 },
   { 1207, 1208, 0 },
   { 1288, 1289, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 1360, 1361, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 1233, 1234, 0 },
   { 1243, 1244, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6131, 6136, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 2661, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 1371, 1372, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 2655, 2656, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1304, 1305, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1304, 1305, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1304, 1305, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1304, 1305, 0 },
   { 2661, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1304, 1305, 0 },
   { 2655, 2656, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1304, 1305, 0 },
   { 1313, 1316, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1186, 0 },
   { 1204, 1205, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1166, 0 },
   { 1288, 1289, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1359, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6123, 6126, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1166, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 2657, 1166, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 2657, 1166, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1166, 0 },
   { 2661, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 2656, 0 },
   { 2657, 1166, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1369, 1370, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2662, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 2662, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 2662, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2661, 1165, 0 },
   { 2662, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 2656, 0 },
   { 2662, 1165, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 5559, 5560, 140 },
   { 5566, 5567, 140 },
   { 5572, 5560, 140 },
   { 5576, 5567, 140 },
   { 5583, 5584, 0 },
   { 5588, 5589, 0 },
   { 5598, 5599, 0 },
   { 5604, 5605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1291, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2659, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 2664, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 1376, 1226, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1197, 1198, 0 },
   { 1211, 1212, 0 },
   { 1290, 1291, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 1357, 1358, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6141, 6144, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 1247, 1248, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 2659, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 1367, 1368, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 2663, 2664, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1306, 1307, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 1306, 1307, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1291, 0 },
   { 1306, 1307, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1306, 1307, 0 },
   { 2659, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1306, 1307, 0 },
   { 2663, 2664, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 1306, 1307, 0 },
   { 1322, 1323, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1195, 1196, 0 },
   { 1209, 1210, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1177, 1178, 0 },
   { 1290, 1291, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 1356, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 1237, 6, 0 },
   { 1241, 1242, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6137, 6140, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2665, 1178, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 2665, 1178, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1291, 0 },
   { 2665, 1178, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2659, 1350, 0 },
   { 2665, 1178, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 2664, 0 },
   { 2665, 1178, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 1365, 1366, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 2660, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1291, 0 },
   { 2660, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2659, 1350, 0 },
   { 2660, 1350, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1350, 0 },
   { 2663, 2664, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 5557, 5558, 140 },
   { 5563, 5565, 140 },
   { 5571, 5558, 140 },
   { 5575, 5565, 140 },
   { 5581, 5582, 0 },
   { 5586, 5587, 0 },
   { 5596, 5597, 0 },
   { 5601, 5603, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1310, 1311, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1310, 1311, 0 },
   { 1335, 1336, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1223, 1224, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1199, 1200, 0 },
   { 1213, 1214, 0 },
   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1354, 1220, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1239, 1140, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6111, 6114, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1344, 847, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1363, 1220, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 3019, 3, 0 },
   { 3027, 6, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 3020, 6, 0 },
   { 3028, 3, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 3017, 1143, 0 },
   { 3025, 1140, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 3018, 1140, 0 },
   { 3026, 1143, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1227, 1228, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1181, 1182, 0 },
   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 1268, 0 },
   { 1511, 1495, 0 },
   { 1515, 1495, 0 },
   { 1519, 1495, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3055, 1165, 0 },
   { 5555, 5556, 140 },
   { 5570, 5556, 140 },
   { 5579, 5580, 0 },
   { 5594, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1341, 1342, 0 },
   { 3048, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 0 },
   { 3048, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1219, 1220, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1222, 1220, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1341, 1342, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 1527, 1526, 0 },
   { 1528, 1529, 0 },
   { 1549, 1548, 0 },
   { 1550, 1551, 0 },
   { 1571, 1570, 0 },
   { 1572, 1573, 0 },
   { 1591, 1590, 0 },
   { 1592, 1593, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 222, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 1532, 1529, 0 },
   { 1536, 1526, 0 },
   { 1554, 1551, 0 },
   { 1558, 1548, 0 },
   { 1576, 1573, 0 },
   { 1579, 1570, 0 },
   { 1596, 1593, 0 },
   { 1600, 1590, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { 6119, 6122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1348, 847, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 1537, 1529, 0 },
   { 1541, 1526, 0 },
   { 1559, 1551, 0 },
   { 1563, 1548, 0 },
   { 1580, 1573, 0 },
   { 1583, 1570, 0 },
   { 1601, 1593, 0 },
   { 1605, 1590, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { 4922, 4925, 139 },
   { 4969, 4972, 139 },
   { 5015, 5018, 139 },
   { 5082, 5085, 140 },
   { 5133, 5136, 140 },
   { 5211, 5214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { 5263, 5266, 139 },
   { 5304, 5307, 139 },
   { 5347, 5350, 139 },
   { 5411, 5414, 140 },
   { 5456, 5459, 140 },
   { 5527, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 3947, 3948, 0 },
   { 3949, 3950, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 3952, 3953, 0 },
   { 3954, 3955, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 3947, 3948, 0 },
   { 3949, 3950, 0 },
   { 3952, 3953, 0 },
   { 3954, 3955, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { 4415, 4411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { 4406, 4411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 0 },
   { 1341, 1342, 0 },
   { 3048, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1494, 1495, 0 },
   { 1499, 1495, 0 },
   { 1503, 1495, 0 },
   { 1507, 1495, 0 },
   { 3048, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 1165, 0 },
   { 4903, 4904, 139 },
   { 4956, 4904, 139 },
   { 5001, 4904, 139 },
   { 5049, 5050, 140 },
   { 5064, 5065, 140 },
   { 5113, 5050, 140 },
   { 5121, 5065, 140 },
   { 5166, 5167, 0 },
   { 5179, 5180, 0 },
   { 5193, 5194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 1165, 0 },
   { 5246, 5247, 139 },
   { 5292, 5247, 139 },
   { 5334, 5247, 139 },
   { 5379, 5380, 140 },
   { 5393, 5394, 140 },
   { 5436, 5380, 140 },
   { 5444, 5394, 140 },
   { 5484, 5485, 0 },
   { 5497, 5498, 0 },
   { 5510, 5511, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 1165, 0 },
   { 3945, 3946, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 1165, 0 },
   { 3951, 3946, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 1165, 0 },
   { 3945, 3946, 0 },
   { 3951, 3946, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1611, 9, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1676, 1677, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1392, 1395, 0 },
   { 1435, 9, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1621, 235, 40 },
   { 1625, 1626, 40 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1388, 1386, 0 },
   { 1435, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1615, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1615, 11, 0 },
   { 1619, 11, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1672, 1673, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1623, 235, 40 },
   { 1628, 1626, 40 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1615, 11, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1615, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1675, 1673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1382, 1383, 0 },
   { 1436, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 4008, 4009, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 4204, 4205, 0 },
   { 4207, 4208, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 241, 0 },
   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 262, 29, 0 },
   { 4008, 4009, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 241, 0 },
   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 262, 29, 0 },
   { 4023, 4025, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 241, 0 },
   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 262, 29, 0 },
   { 4023, 4025, 0 },
   { 4066, 4025, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 241, 0 },
   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 262, 29, 0 },
   { 6187, 6190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 241, 0 },
   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 262, 29, 0 },
   { 4204, 4205, 0 },
   { 4207, 4208, 0 },
   { 6187, 6190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 4008, 4009, 0 },
   { 4204, 4205, 0 },
   { 4207, 4208, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 0 },
   { 248, 245, 0 },
   { 249, 250, 0 },
   { 3290, 423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 179, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 179, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 187, 189, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 300, 301, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 179, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 300, 301, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 281, 282, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 187, 189, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 179, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { 4072, 4041, 0 },
   { 4073, 4043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 281, 282, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { 4072, 4041, 0 },
   { 4073, 4043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 187, 189, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { 4072, 4041, 0 },
   { 4073, 4043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 179, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 276, 277, 0 },
   { 286, 287, 0 },
   { 292, 294, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4040, 4041, 0 },
   { 4072, 4041, 0 },
   { 4073, 4043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4013, 462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 281, 282, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4013, 462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 152, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4013, 462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 179, 0 },
   { 251, 252, 0 },
   { 253, 252, 0 },
   { 254, 255, 0 },
   { 462, 301, 32 },
   { 835, 301, 35 },
   { 4013, 462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6484, 6487, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2414, 19, 0 },
   { 2469, 24, 0 },
   { 2523, 29, 0 },
   { 2577, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 127, 125, 0 },
   { 3565, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 126, 125, 0 },
   { 3565, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3565, 9, 0 },
   { 6488, 6491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 1340, 0 },
   { 3047, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 215, 0 },
   { 3047, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1217, 1218, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1221, 1218, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 1340, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 215, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 1525, 1526, 0 },
   { 1530, 1529, 0 },
   { 1547, 1548, 0 },
   { 1552, 1551, 0 },
   { 1569, 1570, 0 },
   { 1574, 1573, 0 },
   { 1589, 1590, 0 },
   { 1594, 1593, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 220, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 1533, 1526, 0 },
   { 1535, 1529, 0 },
   { 1555, 1548, 0 },
   { 1557, 1551, 0 },
   { 1577, 1570, 0 },
   { 1578, 1573, 0 },
   { 1597, 1590, 0 },
   { 1599, 1593, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { 6115, 6118, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1248, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 1538, 1526, 0 },
   { 1540, 1529, 0 },
   { 1560, 1548, 0 },
   { 1562, 1551, 0 },
   { 1581, 1570, 0 },
   { 1582, 1573, 0 },
   { 1602, 1590, 0 },
   { 1604, 1593, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { 4916, 4921, 139 },
   { 4963, 4968, 139 },
   { 5009, 5014, 139 },
   { 5076, 5081, 140 },
   { 5127, 5132, 140 },
   { 5205, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { 5259, 5262, 139 },
   { 5299, 5303, 139 },
   { 5341, 5346, 139 },
   { 5405, 5410, 140 },
   { 5450, 5455, 140 },
   { 5522, 5526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 3932, 3933, 0 },
   { 3935, 3936, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 3940, 3941, 0 },
   { 3943, 3944, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 3932, 3933, 0 },
   { 3935, 3936, 0 },
   { 3940, 3941, 0 },
   { 3943, 3944, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { 4416, 4413, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { 4412, 4413, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 215, 0 },
   { 1339, 1340, 0 },
   { 3047, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1493, 1279, 0 },
   { 1498, 1279, 0 },
   { 1502, 1279, 0 },
   { 1506, 1279, 0 },
   { 3047, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 1350, 0 },
   { 4900, 4902, 139 },
   { 4955, 4902, 139 },
   { 5000, 4902, 139 },
   { 5047, 5048, 140 },
   { 5061, 5063, 140 },
   { 5112, 5048, 140 },
   { 5120, 5063, 140 },
   { 5164, 5165, 0 },
   { 5177, 5178, 0 },
   { 5190, 5192, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 1350, 0 },
   { 5243, 5245, 139 },
   { 5291, 5245, 139 },
   { 5333, 5245, 139 },
   { 5377, 5378, 140 },
   { 5390, 5392, 140 },
   { 5435, 5378, 140 },
   { 5443, 5392, 140 },
   { 5482, 5483, 0 },
   { 5495, 5496, 0 },
   { 5507, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 1350, 0 },
   { 3930, 3931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 1350, 0 },
   { 3939, 3931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 1350, 0 },
   { 3930, 3931, 0 },
   { 3939, 3931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 4564, 4562, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1607, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1616, 125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1616, 125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 4566, 4562, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1616, 125, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1616, 125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1909, 24, 0 },
   { 2018, 29, 0 },
   { 2112, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4779, 3505, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3528, 3529, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1908, 24, 0 },
   { 2017, 29, 0 },
   { 2111, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1929, 1930, 0 },
   { 1937, 1938, 0 },
   { 1947, 1948, 0 },
   { 2035, 2036, 0 },
   { 2043, 2044, 0 },
   { 2129, 2130, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2252, 2253, 0 },
   { 3555, 2256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1925, 1926, 0 },
   { 1942, 1926, 0 },
   { 1952, 1926, 0 },
   { 2033, 1941, 0 },
   { 2047, 1941, 0 },
   { 2127, 1951, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4778, 1632, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { 6803, 6805, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { 6787, 6789, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { 6774, 6775, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1927, 1928, 0 },
   { 1944, 1928, 0 },
   { 1954, 1928, 0 },
   { 2034, 1943, 0 },
   { 2048, 1943, 0 },
   { 2128, 1953, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1923, 1924, 0 },
   { 1936, 24, 0 },
   { 1946, 24, 0 },
   { 2031, 2032, 0 },
   { 2042, 29, 0 },
   { 2125, 2126, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3547, 29, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3552, 2248, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3553, 2245, 0 },
   { 4795, 24, 0 },
   { 4796, 29, 0 },
   { 4797, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2246, 2247, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3541, 1508, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6806, 6808, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6790, 6792, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6776, 6778, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2249, 2250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3530, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2693, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2693, 1165, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { 6165, 6168, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 2738, 2739, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { 4375, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 2715, 2717, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { 5273, 5278, 139 },
   { 5314, 5319, 139 },
   { 5358, 5364, 139 },
   { 5420, 5424, 140 },
   { 5466, 5471, 140 },
   { 5536, 5540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 3959, 3960, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 3964, 3965, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 3959, 3960, 0 },
   { 3964, 3965, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2693, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2695, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2695, 1165, 0 },
   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2693, 1165, 0 },
   { 2695, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 2695, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 2695, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { 6161, 6164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1173, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1173, 0 },
   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1173, 0 },
   { 2693, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1173, 0 },
   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 2676, 1173, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1173, 0 },
   { 2719, 2721, 0 },
   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1165, 0 },
   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1165, 0 },
   { 2693, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 2687, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 2675, 0 },
   { 2687, 1165, 0 },
   { 3049, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1165, 0 },
   { 2740, 2741, 0 },
   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { 5267, 5272, 139 },
   { 5308, 5313, 139 },
   { 5351, 5357, 139 },
   { 5415, 5419, 140 },
   { 5460, 5465, 140 },
   { 5531, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 5250, 5251, 139 },
   { 5257, 5258, 139 },
   { 5294, 5251, 139 },
   { 5298, 5258, 139 },
   { 5336, 5251, 139 },
   { 5340, 5258, 139 },
   { 5383, 5384, 140 },
   { 5388, 5389, 140 },
   { 5397, 5398, 140 },
   { 5403, 5404, 140 },
   { 5438, 5384, 140 },
   { 5441, 5389, 140 },
   { 5446, 5398, 140 },
   { 5449, 5404, 140 },
   { 5488, 5489, 0 },
   { 5493, 5494, 0 },
   { 5501, 5502, 0 },
   { 5505, 5506, 0 },
   { 5514, 5515, 0 },
   { 5520, 5521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { 3957, 3958, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3956, 2501, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { 3962, 3963, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3961, 2501, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3612, 1165, 0 },
   { 3957, 3958, 0 },
   { 3962, 3963, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3956, 2501, 0 },
   { 3961, 2501, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 2689, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 6173, 6176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 2723, 2725, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 2689, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 2689, 0 },
   { 2742, 2743, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 5285, 5290, 139 },
   { 5326, 5331, 139 },
   { 5371, 5376, 139 },
   { 5430, 5434, 140 },
   { 5477, 5481, 140 },
   { 5546, 5550, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3977, 3978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3982, 3983, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3977, 3978, 0 },
   { 3982, 3983, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 2689, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2697, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 1350, 0 },
   { 2697, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 2697, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 2689, 0 },
   { 2697, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 6169, 6172, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2690, 2691, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2690, 2691, 0 },
   { 2696, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 2690, 2691, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 2689, 0 },
   { 2690, 2691, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2690, 2691, 0 },
   { 2744, 2745, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2679, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2679, 1350, 0 },
   { 2696, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1350, 0 },
   { 2679, 1350, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2679, 1350, 0 },
   { 2688, 2689, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2679, 1350, 0 },
   { 2727, 2729, 0 },
   { 3050, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 5279, 5284, 139 },
   { 5320, 5325, 139 },
   { 5365, 5370, 139 },
   { 5425, 5429, 140 },
   { 5472, 5476, 140 },
   { 5541, 5545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 5248, 5249, 139 },
   { 5254, 5256, 139 },
   { 5293, 5249, 139 },
   { 5297, 5256, 139 },
   { 5335, 5249, 139 },
   { 5339, 5256, 139 },
   { 5381, 5382, 140 },
   { 5386, 5387, 140 },
   { 5395, 5396, 140 },
   { 5400, 5402, 140 },
   { 5437, 5382, 140 },
   { 5440, 5387, 140 },
   { 5445, 5396, 140 },
   { 5448, 5402, 140 },
   { 5486, 5487, 0 },
   { 5491, 5492, 0 },
   { 5499, 5500, 0 },
   { 5503, 5504, 0 },
   { 5512, 5513, 0 },
   { 5517, 5519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3975, 3976, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3974, 2504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3980, 3981, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3979, 2504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3975, 3976, 0 },
   { 3980, 3981, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1350, 0 },
   { 3974, 2504, 0 },
   { 3979, 2504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3827, 3829, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3680, 3681, 71 },
   { 3760, 3082, 79 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4782, 3505, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 6809, 6811, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 6793, 6795, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 6779, 6780, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 4808, 4804, 0 },
   { 4814, 4804, 0 },
   { 4820, 4804, 0 },
   { 4825, 4804, 0 },
   { 4831, 4802, 0 },
   { 4835, 4802, 0 },
   { 4839, 4802, 0 },
   { 4849, 4810, 0 },
   { 4853, 4810, 0 },
   { 4869, 4816, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2138, 847, 0 },
   { 2142, 847, 0 },
   { 2158, 847, 0 },
   { 2170, 847, 0 },
   { 2184, 19, 0 },
   { 2198, 19, 0 },
   { 2208, 19, 0 },
   { 2220, 24, 0 },
   { 2230, 24, 0 },
   { 2240, 29, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 4809, 4807, 0 },
   { 4815, 4807, 0 },
   { 4821, 4807, 0 },
   { 4826, 4807, 0 },
   { 4828, 2137, 0 },
   { 4832, 4805, 0 },
   { 4836, 4805, 0 },
   { 4840, 4805, 0 },
   { 4842, 2141, 0 },
   { 4844, 2141, 0 },
   { 4846, 2183, 0 },
   { 4850, 4812, 0 },
   { 4854, 4812, 0 },
   { 4856, 2149, 0 },
   { 4858, 2149, 0 },
   { 4860, 2189, 0 },
   { 4862, 2149, 0 },
   { 4864, 2189, 0 },
   { 4866, 2219, 0 },
   { 4870, 4818, 0 },
   { 4872, 2153, 0 },
   { 4874, 2153, 0 },
   { 4876, 2193, 0 },
   { 4878, 2153, 0 },
   { 4880, 2193, 0 },
   { 4882, 2225, 0 },
   { 4884, 2153, 0 },
   { 4886, 2193, 0 },
   { 4888, 2225, 0 },
   { 4890, 2239, 0 },
   { 5615, 24, 0 },
   { 5668, 29, 0 },
   { 5721, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3549, 29, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3677, 3678, 71 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3551, 2256, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 4896, 2283, 0 },
   { 4896, 2283, 0 },
   { 4897, 3761, 0 },
   { 4897, 3761, 0 },
   { 4898, 4793, 0 },
   { 4898, 4793, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { 1456, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1844, 1845, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 3514, 3032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 5606, 3758, 0 },
   { 5607, 3761, 0 },
   { 5609, 5468, 0 },
   { 5611, 2267, 0 },
   { 5612, 2283, 0 },
   { 5614, 5361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4784, 3505, 0 },
   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 6812, 6814, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 6796, 6798, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 6781, 6782, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2136, 847, 0 },
   { 2140, 847, 0 },
   { 2157, 847, 0 },
   { 2169, 847, 0 },
   { 2182, 19, 0 },
   { 2197, 19, 0 },
   { 2207, 19, 0 },
   { 2218, 24, 0 },
   { 2229, 24, 0 },
   { 2238, 29, 0 },
   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 4803, 4804, 0 },
   { 4811, 4804, 0 },
   { 4817, 4804, 0 },
   { 4823, 4804, 0 },
   { 4827, 2135, 0 },
   { 4829, 4802, 0 },
   { 4833, 4802, 0 },
   { 4837, 4802, 0 },
   { 4841, 2139, 0 },
   { 4843, 2139, 0 },
   { 4845, 2181, 0 },
   { 4847, 4810, 0 },
   { 4851, 4810, 0 },
   { 4855, 2151, 0 },
   { 4857, 2151, 0 },
   { 4859, 2191, 0 },
   { 4861, 2151, 0 },
   { 4863, 2191, 0 },
   { 4865, 2217, 0 },
   { 4867, 4816, 0 },
   { 4871, 2155, 0 },
   { 4873, 2155, 0 },
   { 4875, 2195, 0 },
   { 4877, 2155, 0 },
   { 4879, 2195, 0 },
   { 4881, 2227, 0 },
   { 4883, 2155, 0 },
   { 4885, 2195, 0 },
   { 4887, 2227, 0 },
   { 4889, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 4806, 4807, 0 },
   { 4813, 4807, 0 },
   { 4819, 4807, 0 },
   { 4824, 4807, 0 },
   { 4830, 4805, 0 },
   { 4834, 4805, 0 },
   { 4838, 4805, 0 },
   { 4848, 4812, 0 },
   { 4852, 4812, 0 },
   { 4868, 4818, 0 },
   { 5643, 24, 0 },
   { 5696, 29, 0 },
   { 5748, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3548, 29, 0 },
   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3550, 2259, 0 },
   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 4891, 4892, 0 },
   { 4891, 4892, 0 },
   { 4893, 4894, 0 },
   { 4893, 4894, 0 },
   { 4895, 4788, 0 },
   { 4895, 4788, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3748, 3675, 71 },
   { 4471, 4475, 111 },
   { 5749, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3749, 3675, 71 },
   { 4476, 4479, 111 },
   { 5722, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3745, 3746, 0 },
   { 4476, 4479, 111 },
   { 5722, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3747, 3746, 0 },
   { 4476, 4479, 111 },
   { 5722, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3797, 3793, 0 },
   { 4476, 4479, 111 },
   { 5722, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3802, 3798, 0 },
   { 4476, 4479, 111 },
   { 5722, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3760, 77 },
   { 3776, 3082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3624, 1564, 0 },
   { 3082, 3760, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3621, 135, 0 },
   { 3082, 3760, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3615, 48, 0 },
   { 3082, 3760, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3618, 2786, 0 },
   { 3082, 3760, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3647, 3761, 78 },
   { 3766, 3647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3647, 3761, 78 },
   { 3780, 3647, 0 },
   { 3781, 3649, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3649, 3762, 78 },
   { 3773, 3649, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4360, 4353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4362, 4353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4362, 4353, 0 },
   { 4394, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4360, 4353, 0 },
   { 4362, 4353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4363, 4350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4364, 4350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4364, 4350, 0 },
   { 4395, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4363, 4350, 0 },
   { 4364, 4350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 3765, 0 },
   { 3765, 4556, 123 },
   { 3765, 4558, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 3772, 0 },
   { 3765, 4556, 123 },
   { 3765, 4558, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3777, 3765, 0 },
   { 3778, 3772, 0 },
   { 3765, 4556, 123 },
   { 3765, 4558, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3771, 3772, 0 },
   { 3772, 4559, 123 },
   { 3772, 4561, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4366, 4367, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4369, 4367, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4369, 4367, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4366, 4367, 0 },
   { 4369, 4367, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1157, 1158, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1160, 1161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6492, 6495, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1139, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3070, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1142, 1143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1148, 1149, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1151, 1152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1154, 1155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 2825, 56 },
   { 6068, 2820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 2825, 56 },
   { 6069, 2890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 2832, 56 },
   { 6074, 2826, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 2832, 56 },
   { 6075, 2894, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2833, 2839, 56 },
   { 6078, 2833, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2833, 2839, 56 },
   { 6079, 2900, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2840, 2856, 56 },
   { 6082, 2840, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2840, 2856, 56 },
   { 6083, 2905, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2857, 2889, 56 },
   { 6086, 2857, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2857, 2889, 56 },
   { 6087, 2914, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2608, 2609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2931, 2934, 56 },
   { 6072, 2931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2931, 2934, 56 },
   { 6073, 2972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2935, 2940, 56 },
   { 6076, 2935, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2935, 2940, 56 },
   { 6077, 2976, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2941, 2945, 56 },
   { 6080, 2941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2941, 2945, 56 },
   { 6081, 2982, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2946, 2954, 56 },
   { 6084, 2946, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2946, 2954, 56 },
   { 6085, 2987, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2955, 2971, 56 },
   { 6088, 2955, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2955, 2971, 56 },
   { 6089, 2996, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2680, 1165, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2667, 2668, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 6149, 6152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2680, 1165, 0 },
   { 2730, 2731, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2667, 2668, 0 },
   { 2699, 2701, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 4935, 4941, 139 },
   { 4981, 4986, 139 },
   { 5028, 5034, 139 },
   { 5094, 5099, 140 },
   { 5145, 5151, 140 },
   { 5223, 5229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3968, 3960, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3972, 3973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3968, 3960, 0 },
   { 3972, 3973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 1593, 4326, 97 },
   { 6145, 6148, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2669, 1171, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2669, 1171, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 4319, 4321, 96 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2669, 1171, 0 },
   { 2680, 1165, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2667, 2668, 0 },
   { 2669, 1171, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2669, 1171, 0 },
   { 2703, 2705, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 4319, 4321, 96 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2681, 1165, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2681, 1165, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 4315, 4317, 96 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2680, 1165, 0 },
   { 2681, 1165, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2667, 2668, 0 },
   { 2681, 1165, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2681, 1165, 0 },
   { 2732, 2733, 0 },
   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 4315, 4317, 96 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 1593, 4326, 97 },
   { 4926, 4933, 139 },
   { 4973, 4980, 139 },
   { 5019, 5026, 139 },
   { 5086, 5093, 140 },
   { 5137, 5144, 140 },
   { 5215, 5222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 4907, 4908, 139 },
   { 4914, 4915, 139 },
   { 4958, 4908, 139 },
   { 4962, 4915, 139 },
   { 5003, 4908, 139 },
   { 5007, 4915, 139 },
   { 5053, 5054, 140 },
   { 5058, 5059, 140 },
   { 5068, 5069, 140 },
   { 5074, 5075, 140 },
   { 5115, 5054, 140 },
   { 5118, 5059, 140 },
   { 5123, 5069, 140 },
   { 5126, 5075, 140 },
   { 5170, 5171, 0 },
   { 5175, 5176, 0 },
   { 5183, 5184, 0 },
   { 5187, 5188, 0 },
   { 5197, 5198, 0 },
   { 5203, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3967, 3958, 0 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3966, 2501, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3970, 3971, 0 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3969, 2513, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3967, 3958, 0 },
   { 3970, 3971, 0 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 3966, 2501, 0 },
   { 3969, 2513, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2671, 1350, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2682, 2683, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 6157, 6160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2671, 1350, 0 },
   { 2707, 2709, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2682, 2683, 0 },
   { 2734, 2735, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 4948, 4953, 139 },
   { 4993, 4998, 139 },
   { 5041, 5046, 139 },
   { 5106, 5111, 140 },
   { 5158, 5163, 140 },
   { 5236, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3986, 3978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3990, 3991, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3986, 3978, 0 },
   { 3990, 3991, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { 6153, 6156, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2684, 2685, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2684, 2685, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 4324, 4325, 96 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2671, 1350, 0 },
   { 2684, 2685, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2682, 2683, 0 },
   { 2684, 2685, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2684, 2685, 0 },
   { 2736, 2737, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 4324, 4325, 96 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 1350, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 1350, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 4322, 4323, 96 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2671, 1350, 0 },
   { 2672, 1350, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 1350, 0 },
   { 2682, 2683, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 1350, 0 },
   { 2711, 2713, 0 },
   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 4322, 4323, 96 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { 4942, 4947, 139 },
   { 4987, 4992, 139 },
   { 5035, 5040, 139 },
   { 5100, 5105, 140 },
   { 5152, 5157, 140 },
   { 5230, 5235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 4905, 4906, 139 },
   { 4911, 4913, 139 },
   { 4957, 4906, 139 },
   { 4961, 4913, 139 },
   { 5002, 4906, 139 },
   { 5006, 4913, 139 },
   { 5051, 5052, 140 },
   { 5056, 5057, 140 },
   { 5066, 5067, 140 },
   { 5071, 5073, 140 },
   { 5114, 5052, 140 },
   { 5117, 5057, 140 },
   { 5122, 5067, 140 },
   { 5125, 5073, 140 },
   { 5168, 5169, 0 },
   { 5173, 5174, 0 },
   { 5181, 5182, 0 },
   { 5185, 5186, 0 },
   { 5195, 5196, 0 },
   { 5200, 5202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3985, 3976, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3984, 2504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3988, 3989, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3987, 2516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3985, 3976, 0 },
   { 3988, 3989, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 3984, 2504, 0 },
   { 3987, 2516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4562, 4564, 125 },
   { 6496, 6499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3210, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3279, 3280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3271, 3272, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3274, 3275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3277, 3278, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3262, 3264, 0 },
   { 3227, 3297, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3265, 3266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3296, 3276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3295, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3298, 3227, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3267, 3270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3543, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3533, 3534, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3544, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3535, 3536, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4781, 1632, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2143, 2144, 0 },
   { 2147, 2144, 0 },
   { 2150, 2144, 0 },
   { 2154, 2144, 0 },
   { 2159, 2160, 0 },
   { 2163, 2160, 0 },
   { 2165, 2160, 0 },
   { 2167, 2160, 0 },
   { 2171, 2172, 0 },
   { 2175, 2172, 0 },
   { 2177, 2172, 0 },
   { 2179, 2172, 0 },
   { 2185, 2186, 0 },
   { 2190, 2186, 0 },
   { 2194, 2186, 0 },
   { 2199, 2200, 0 },
   { 2203, 2200, 0 },
   { 2205, 2200, 0 },
   { 2209, 2210, 0 },
   { 2213, 2210, 0 },
   { 2215, 2210, 0 },
   { 2221, 2222, 0 },
   { 2226, 2222, 0 },
   { 2231, 2232, 0 },
   { 2235, 2232, 0 },
   { 2241, 2242, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 2264, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3199, 3204, 0 },
   { 3205, 3206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4783, 1632, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1903, 775, 0 },
   { 2012, 782, 0 },
   { 2106, 787, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2145, 2146, 0 },
   { 2148, 2146, 0 },
   { 2152, 2146, 0 },
   { 2156, 2146, 0 },
   { 2161, 2162, 0 },
   { 2164, 2162, 0 },
   { 2166, 2162, 0 },
   { 2168, 2162, 0 },
   { 2173, 2174, 0 },
   { 2176, 2174, 0 },
   { 2178, 2174, 0 },
   { 2180, 2174, 0 },
   { 2187, 2188, 0 },
   { 2192, 2188, 0 },
   { 2196, 2188, 0 },
   { 2201, 2202, 0 },
   { 2204, 2202, 0 },
   { 2206, 2202, 0 },
   { 2211, 2212, 0 },
   { 2214, 2212, 0 },
   { 2216, 2212, 0 },
   { 2223, 2224, 0 },
   { 2228, 2224, 0 },
   { 2233, 2234, 0 },
   { 2236, 2234, 0 },
   { 2243, 2244, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2265, 2266, 0 },
   { 3556, 2248, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1448, 1449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1443, 9, 0 },
   { 1444, 75, 0 },
   { 1448, 1449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 3513, 3035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3542, 1496, 0 },
   { 3542, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6815, 6817, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6799, 6801, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6783, 6785, 148 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2260, 2261, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2257, 2258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3531, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3532, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3545, 1508, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3537, 3538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3546, 1508, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3539, 3540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 866, 868, 38 },
   { 878, 879, 0 },
   { 894, 895, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 866, 868, 38 },
   { 873, 875, 0 },
   { 878, 879, 0 },
   { 894, 895, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 866, 868, 38 },
   { 870, 279, 0 },
   { 873, 875, 0 },
   { 878, 879, 0 },
   { 894, 895, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 861, 8, 0 },
   { 866, 868, 38 },
   { 878, 879, 0 },
   { 894, 895, 39 },
   { 6756, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 861, 8, 0 },
   { 866, 868, 38 },
   { 873, 875, 0 },
   { 878, 879, 0 },
   { 894, 895, 39 },
   { 6756, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 861, 8, 0 },
   { 866, 868, 38 },
   { 870, 279, 0 },
   { 873, 875, 0 },
   { 878, 879, 0 },
   { 894, 895, 39 },
   { 6756, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 883, 875, 0 },
   { 892, 893, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 881, 279, 0 },
   { 883, 875, 0 },
   { 892, 893, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 862, 8, 0 },
   { 883, 875, 0 },
   { 892, 893, 39 },
   { 6755, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 862, 8, 0 },
   { 881, 279, 0 },
   { 883, 875, 0 },
   { 892, 893, 39 },
   { 6755, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 885, 279, 0 },
   { 890, 891, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 863, 8, 0 },
   { 885, 279, 0 },
   { 886, 889, 0 },
   { 890, 891, 39 },
   { 6754, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4194, 4196, 0 },
   { 4429, 4433, 103 },
   { 4429, 4437, 104 },
   { 4429, 4441, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 2762, 55 },
   { 2768, 2752, 0 },
   { 2776, 2754, 0 },
   { 6767, 273, 0 },
   { 6768, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 2762, 55 },
   { 2769, 2754, 0 },
   { 2777, 2752, 0 },
   { 6767, 273, 0 },
   { 6768, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 2762, 55 },
   { 2765, 2756, 0 },
   { 2774, 2758, 0 },
   { 6767, 273, 0 },
   { 6768, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 2762, 55 },
   { 2767, 2758, 0 },
   { 2775, 2756, 0 },
   { 6767, 273, 0 },
   { 6768, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 2763, 55 },
   { 2772, 2752, 0 },
   { 2780, 2754, 0 },
   { 6773, 283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 2763, 55 },
   { 2773, 2754, 0 },
   { 2781, 2752, 0 },
   { 6773, 283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 2763, 55 },
   { 2770, 2756, 0 },
   { 2778, 2758, 0 },
   { 6773, 283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 2763, 55 },
   { 2771, 2758, 0 },
   { 2779, 2756, 0 },
   { 6773, 283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 64 },
   { 3251, 9, 0 },
   { 3252, 268, 0 },
   { 3253, 3234, 0 },
   { 3254, 3238, 0 },
   { 3259, 9, 0 },
   { 6733, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3625, 3626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3627, 29, 0 },
   { 3627, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3634, 34, 0 },
   { 3634, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3636, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3629, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3730, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3638, 24, 0 },
   { 3638, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3726, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3722, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3728, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3724, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4190, 4155, 80 },
   { 4452, 4455, 109 },
   { 4457, 4461, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4191, 4192, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 229, 1, 0 },
   { 4061, 4062, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 229, 1, 0 },
   { 4061, 4062, 0 },
   { 4103, 4062, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 224, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 9, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 227, 1, 0 },
   { 229, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 227, 1, 0 },
   { 229, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 343, 344, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 343, 344, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 344, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 346, 347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 347, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 355, 356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 355, 356, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 358, 359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 358, 359, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 349, 350, 0 },
   { 353, 350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 0 },
   { 353, 350, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 5629, 4620, 0 },
   { 5683, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5629, 4620, 0 },
   { 5682, 4633, 0 },
   { 5683, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5629, 4620, 0 },
   { 5680, 4633, 0 },
   { 5683, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5654, 4620, 0 },
   { 5683, 4633, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 4620, 0 },
   { 5652, 4620, 0 },
   { 5683, 4633, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5655, 4620, 0 },
   { 5708, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5655, 4620, 0 },
   { 5682, 4633, 0 },
   { 5708, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5655, 4620, 0 },
   { 5680, 4633, 0 },
   { 5708, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5654, 4620, 0 },
   { 5655, 4620, 0 },
   { 5707, 4633, 0 },
   { 5708, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5655, 4620, 0 },
   { 5705, 4633, 0 },
   { 5708, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { 5760, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { 5735, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5735, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5735, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { 6065, 6066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5628, 4620, 0 },
   { 5682, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5626, 4620, 0 },
   { 5680, 4633, 0 },
   { 5732, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5654, 4620, 0 },
   { 5707, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 1, 0 },
   { 5652, 4620, 0 },
   { 5705, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5628, 4620, 0 },
   { 5680, 4633, 0 },
   { 5682, 4633, 0 },
   { 5732, 4633, 0 },
   { 5734, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5654, 4620, 0 },
   { 5682, 4633, 0 },
   { 5707, 4633, 0 },
   { 5734, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 4620, 0 },
   { 5652, 4620, 0 },
   { 5682, 4633, 0 },
   { 5705, 4633, 0 },
   { 5734, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5654, 4620, 0 },
   { 5680, 4633, 0 },
   { 5707, 4633, 0 },
   { 5732, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5626, 4620, 0 },
   { 5652, 4620, 0 },
   { 5680, 4633, 0 },
   { 5705, 4633, 0 },
   { 5732, 4633, 0 },
   { 5757, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5652, 4620, 0 },
   { 5654, 4620, 0 },
   { 5705, 4633, 0 },
   { 5707, 4633, 0 },
   { 5757, 4633, 0 },
   { 5759, 4633, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3790, 3791, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3456, 1192, 0 },
   { 3457, 771, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 481, 482, 8 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1407, 1408, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1399, 0 },
   { 1400, 1401, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1403, 0 },
   { 1405, 1406, 0 },
   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2402, 2403, 49 },
   { 2405, 2406, 49 },
   { 2457, 2458, 49 },
   { 2460, 2461, 49 },
   { 2511, 2512, 49 },
   { 2514, 2515, 49 },
   { 2565, 2566, 54 },
   { 2568, 2569, 54 },
   { 2748, 2749, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4655, 4656, 136 },
   { 4666, 4667, 136 },
   { 4676, 4677, 136 },
   { 4687, 4288, 137 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4657, 4656, 136 },
   { 4668, 4667, 136 },
   { 4678, 4677, 136 },
   { 4688, 4288, 137 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5623, 5620, 0 },
   { 5676, 5673, 0 },
   { 5728, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5619, 5620, 0 },
   { 5672, 5673, 0 },
   { 5725, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5648, 5620, 0 },
   { 5701, 5673, 0 },
   { 5753, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1413, 1411, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4219, 4221, 0 },
   { 5646, 5620, 0 },
   { 5699, 5673, 0 },
   { 5751, 5673, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4619, 4611, 7 },
   { 4632, 4624, 7 },
   { 4645, 4637, 7 },
   { 4652, 4278, 135 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4663, 4656, 136 },
   { 4674, 4667, 136 },
   { 4684, 4677, 136 },
   { 4694, 4288, 137 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4617, 4611, 7 },
   { 4630, 4624, 7 },
   { 4643, 4637, 7 },
   { 4650, 4278, 135 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4661, 4656, 136 },
   { 4672, 4667, 136 },
   { 4682, 4677, 136 },
   { 4692, 4288, 137 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4610, 4611, 7 },
   { 4623, 4624, 7 },
   { 4636, 4637, 7 },
   { 4282, 4278, 135 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 2390, 2391, 48 },
   { 2393, 2394, 47 },
   { 2445, 2446, 48 },
   { 2448, 2449, 47 },
   { 2499, 2500, 48 },
   { 2502, 2503, 47 },
   { 2553, 2554, 53 },
   { 2556, 2557, 52 },
   { 3487, 1, 0 },
   { 4610, 4611, 7 },
   { 4623, 4624, 7 },
   { 4636, 4637, 7 },
   { 4282, 4278, 135 },
   { 4655, 4656, 136 },
   { 4666, 4667, 136 },
   { 4676, 4677, 136 },
   { 4687, 4288, 137 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4613, 4611, 7 },
   { 4626, 4624, 7 },
   { 4639, 4637, 7 },
   { 4647, 4278, 135 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2396, 2397, 48 },
   { 2399, 2400, 47 },
   { 2451, 2452, 48 },
   { 2454, 2455, 47 },
   { 2505, 2506, 48 },
   { 2508, 2509, 47 },
   { 2559, 2560, 53 },
   { 2562, 2563, 52 },
   { 3487, 1, 0 },
   { 4613, 4611, 7 },
   { 4626, 4624, 7 },
   { 4639, 4637, 7 },
   { 4647, 4278, 135 },
   { 4657, 4656, 136 },
   { 4668, 4667, 136 },
   { 4678, 4677, 136 },
   { 4688, 4288, 137 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4124, 4122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4127, 4125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4130, 4128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4133, 4131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 2408, 2409, 49 },
   { 2411, 2412, 49 },
   { 2463, 2464, 49 },
   { 2466, 2467, 49 },
   { 2517, 2518, 49 },
   { 2520, 2521, 49 },
   { 2571, 2572, 54 },
   { 2574, 2575, 54 },
   { 3487, 1, 0 },
   { 4136, 4134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5685, 61, 0 },
   { 5737, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5684, 61, 0 },
   { 5736, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5657, 5631, 0 },
   { 5710, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5656, 5631, 0 },
   { 5709, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 1122, 1126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 1114, 1117, 0 },
   { 1122, 1126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5632, 5631, 0 },
   { 5685, 61, 0 },
   { 5737, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5630, 5631, 0 },
   { 5684, 61, 0 },
   { 5736, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5657, 5631, 0 },
   { 5710, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 16, 18, 1 },
   { 21, 23, 1 },
   { 26, 28, 1 },
   { 31, 33, 1 },
   { 36, 38, 1 },
   { 40, 44, 1 },
   { 52, 58, 3 },
   { 256, 73, 0 },
   { 264, 9, 0 },
   { 267, 120, 0 },
   { 5656, 5631, 0 },
   { 5709, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5632, 5631, 0 },
   { 5685, 61, 0 },
   { 5737, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5630, 5631, 0 },
   { 5684, 61, 0 },
   { 5736, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5657, 5631, 0 },
   { 5710, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4015, 0 },
   { 5656, 5631, 0 },
   { 5709, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5633, 5631, 0 },
   { 5685, 61, 0 },
   { 5686, 61, 0 },
   { 5737, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5633, 5631, 0 },
   { 5684, 61, 0 },
   { 5686, 61, 0 },
   { 5736, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5633, 5631, 0 },
   { 5657, 5631, 0 },
   { 5686, 61, 0 },
   { 5710, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5633, 5631, 0 },
   { 5656, 5631, 0 },
   { 5686, 61, 0 },
   { 5709, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5658, 5631, 0 },
   { 5685, 61, 0 },
   { 5711, 61, 0 },
   { 5737, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5658, 5631, 0 },
   { 5684, 61, 0 },
   { 5711, 61, 0 },
   { 5736, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5657, 5631, 0 },
   { 5658, 5631, 0 },
   { 5710, 61, 0 },
   { 5711, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5656, 5631, 0 },
   { 5658, 5631, 0 },
   { 5709, 61, 0 },
   { 5711, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5685, 61, 0 },
   { 5737, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5684, 61, 0 },
   { 5736, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5657, 5631, 0 },
   { 5710, 61, 0 },
   { 5762, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5656, 5631, 0 },
   { 5709, 61, 0 },
   { 5761, 61, 0 },
   { 5763, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5685, 61, 0 },
   { 5737, 61, 0 },
   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5684, 61, 0 },
   { 5736, 61, 0 },
   { 5738, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5657, 5631, 0 },
   { 5710, 61, 0 },
   { 5738, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5656, 5631, 0 },
   { 5709, 61, 0 },
   { 5738, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5632, 5631, 0 },
   { 5684, 61, 0 },
   { 5685, 61, 0 },
   { 5736, 61, 0 },
   { 5737, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5657, 5631, 0 },
   { 5685, 61, 0 },
   { 5710, 61, 0 },
   { 5737, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 5631, 0 },
   { 5656, 5631, 0 },
   { 5685, 61, 0 },
   { 5709, 61, 0 },
   { 5737, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5657, 5631, 0 },
   { 5684, 61, 0 },
   { 5710, 61, 0 },
   { 5736, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 5631, 0 },
   { 5656, 5631, 0 },
   { 5684, 61, 0 },
   { 5709, 61, 0 },
   { 5736, 61, 0 },
   { 5761, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5656, 5631, 0 },
   { 5657, 5631, 0 },
   { 5709, 61, 0 },
   { 5710, 61, 0 },
   { 5761, 61, 0 },
   { 5762, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3120, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1000, 1003, 0 },
   { 1008, 1011, 0 },
   { 1016, 1019, 0 },
   { 1024, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1004, 1003, 0 },
   { 1012, 1011, 0 },
   { 1020, 1019, 0 },
   { 1028, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4392, 4393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1128, 1131, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 906, 910, 0 },
   { 1110, 1112, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1110, 1112, 0 },
   { 1128, 1131, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { 3784, 3786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 2426, 0 },
   { 2478, 2480, 0 },
   { 2532, 2534, 0 },
   { 2587, 2589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3126, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 2426, 0 },
   { 2478, 2480, 0 },
   { 2532, 2534, 0 },
   { 2587, 2589, 0 },
   { 3126, 1346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1005, 1007, 0 },
   { 1013, 1015, 0 },
   { 1021, 1023, 0 },
   { 1029, 1031, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1005, 1007, 0 },
   { 1013, 1015, 0 },
   { 1021, 1023, 0 },
   { 1029, 1031, 0 },
   { 2424, 2426, 0 },
   { 2478, 2480, 0 },
   { 2532, 2534, 0 },
   { 2587, 2589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { 3787, 3783, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 9, 0 },
   { 4214, 4212, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 9, 0 },
   { 4211, 4212, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 9, 0 },
   { 4211, 4212, 0 },
   { 4214, 4212, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1273, 1272, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1277, 1276, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1275, 1276, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1271, 1272, 0 },
   { 1308, 1309, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 0 },
   { 1215, 1216, 0 },
   { 1331, 1334, 0 },
   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1274, 1272, 0 },
   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1281, 1279, 0 },
   { 3030, 1226, 0 },
   { 3054, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1258, 1255, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1265, 1263, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1262, 1263, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1254, 1255, 0 },
   { 1310, 1311, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1199, 1200, 0 },
   { 1213, 1214, 0 },
   { 1337, 1338, 0 },
   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 1255, 0 },
   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1181, 1182, 0 },
   { 1270, 1268, 0 },
   { 3029, 1224, 0 },
   { 3055, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { 6182, 6185, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 272, 270, 0 },
   { 4019, 4021, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 272, 270, 0 },
   { 4019, 4021, 0 },
   { 4064, 4021, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 4006, 4007, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 430, 431, 8 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 432, 433, 8 },
   { 434, 282, 8 },
   { 4006, 4007, 0 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 8 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 412, 413, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 412, 413, 8 },
   { 421, 422, 8 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 418, 419, 8 },
   { 421, 422, 8 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 428, 429, 8 },
   { 432, 433, 8 },
   { 434, 282, 8 },
   { 4006, 4007, 0 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 408, 409, 8 },
   { 412, 413, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 410, 411, 8 },
   { 412, 413, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 416, 417, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 607, 608, 0 },
   { 675, 676, 0 },
   { 746, 747, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 607, 608, 0 },
   { 675, 676, 0 },
   { 746, 747, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 1, 0 },
   { 275, 1, 0 },
   { 278, 279, 0 },
   { 280, 279, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 173, 175, 0 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 457, 458, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 457, 458, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 457, 458, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 457, 458, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 607, 608, 0 },
   { 675, 676, 0 },
   { 746, 747, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 461, 462, 8 },
   { 607, 608, 0 },
   { 675, 676, 0 },
   { 746, 747, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 612, 613, 0 },
   { 679, 680, 0 },
   { 750, 751, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 612, 613, 0 },
   { 679, 680, 0 },
   { 750, 751, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 612, 613, 0 },
   { 679, 680, 0 },
   { 750, 751, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 612, 613, 0 },
   { 679, 680, 0 },
   { 750, 751, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 607, 608, 0 },
   { 612, 613, 0 },
   { 675, 676, 0 },
   { 679, 680, 0 },
   { 746, 747, 0 },
   { 750, 751, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 618, 620, 0 },
   { 683, 685, 0 },
   { 756, 758, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 447, 448, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 455, 456, 8 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 455, 456, 8 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 455, 456, 8 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 455, 456, 8 },
   { 459, 460, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 443, 444, 8 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 443, 444, 8 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 443, 444, 8 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 443, 444, 8 },
   { 447, 448, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3062, 9, 0 },
   { 3063, 75, 0 },
   { 3098, 3100, 57 },
   { 3101, 3103, 57 },
   { 3104, 3105, 57 },
   { 3106, 3107, 57 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3135, 3132, 58 },
   { 3142, 3139, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 1350, 0 },
   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3147, 3145, 58 },
   { 3152, 3150, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3064, 75, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1821, 1824, 0 },
   { 1828, 1824, 0 },
   { 1833, 1836, 0 },
   { 1840, 1836, 0 },
   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5639, 2323, 0 },
   { 5691, 2327, 0 },
   { 5692, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5639, 2323, 0 },
   { 5690, 2327, 0 },
   { 5692, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5663, 2323, 0 },
   { 5692, 2327, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5639, 2323, 0 },
   { 5662, 2323, 0 },
   { 5692, 2327, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5664, 2323, 0 },
   { 5691, 2327, 0 },
   { 5717, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5664, 2323, 0 },
   { 5690, 2327, 0 },
   { 5717, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5663, 2323, 0 },
   { 5664, 2323, 0 },
   { 5716, 2327, 0 },
   { 5717, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5664, 2323, 0 },
   { 5715, 2327, 0 },
   { 5717, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5768, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5767, 2327, 0 },
   { 5769, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { 5744, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5663, 2323, 0 },
   { 5716, 2327, 0 },
   { 5744, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5715, 2327, 0 },
   { 5744, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3135, 3132, 58 },
   { 3142, 3139, 59 },
   { 3147, 3145, 58 },
   { 3152, 3150, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5691, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3498, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5638, 2323, 0 },
   { 5690, 2327, 0 },
   { 5691, 2327, 0 },
   { 5742, 2327, 0 },
   { 5743, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5663, 2323, 0 },
   { 5691, 2327, 0 },
   { 5716, 2327, 0 },
   { 5743, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5638, 2323, 0 },
   { 5662, 2323, 0 },
   { 5691, 2327, 0 },
   { 5715, 2327, 0 },
   { 5743, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5690, 2327, 0 },
   { 5742, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5663, 2323, 0 },
   { 5690, 2327, 0 },
   { 5716, 2327, 0 },
   { 5742, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5637, 2323, 0 },
   { 5662, 2323, 0 },
   { 5690, 2327, 0 },
   { 5715, 2327, 0 },
   { 5742, 2327, 0 },
   { 5767, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 5662, 2323, 0 },
   { 5663, 2323, 0 },
   { 5715, 2327, 0 },
   { 5716, 2327, 0 },
   { 5767, 2327, 0 },
   { 5768, 2327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3792, 3791, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 215, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 1525, 1526, 0 },
   { 1530, 1529, 0 },
   { 1547, 1548, 0 },
   { 1552, 1551, 0 },
   { 1569, 1570, 0 },
   { 1574, 1573, 0 },
   { 1589, 1590, 0 },
   { 1594, 1593, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1217, 1218, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3500, 847, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4764, 4765, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4770, 4771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4776, 4777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4759, 4762, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4767, 4768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4773, 4774, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3073, 1, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3073, 1, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3507, 1632, 0 },
   { 3508, 3505, 0 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 2273, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3060, 73, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3074, 3075, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3074, 3075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 206, 0 },
   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 2374, 45 },
   { 2372, 2380, 47 },
   { 2429, 2431, 45 },
   { 2429, 2437, 47 },
   { 2483, 2485, 45 },
   { 2483, 2491, 47 },
   { 2537, 2539, 50 },
   { 2537, 2545, 52 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1165, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3116, 3117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5636, 2281, 0 },
   { 5688, 2289, 0 },
   { 5689, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5636, 2281, 0 },
   { 5687, 2289, 0 },
   { 5689, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5660, 2281, 0 },
   { 5689, 2289, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5636, 2281, 0 },
   { 5659, 2281, 0 },
   { 5689, 2289, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5636, 2281, 0 },
   { 5689, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5661, 2281, 0 },
   { 5688, 2289, 0 },
   { 5714, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5661, 2281, 0 },
   { 5687, 2289, 0 },
   { 5714, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5660, 2281, 0 },
   { 5661, 2281, 0 },
   { 5713, 2289, 0 },
   { 5714, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5659, 2281, 0 },
   { 5661, 2281, 0 },
   { 5712, 2289, 0 },
   { 5714, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5661, 2281, 0 },
   { 5714, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5766, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5741, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5741, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5741, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3073, 1, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 3073, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 3496, 3497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 2374, 45 },
   { 2372, 2380, 47 },
   { 2429, 2431, 45 },
   { 2429, 2437, 47 },
   { 2483, 2485, 45 },
   { 2483, 2491, 47 },
   { 2537, 2539, 50 },
   { 2537, 2545, 52 },
   { 3056, 9, 0 },
   { 3652, 3654, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5635, 2281, 0 },
   { 5687, 2289, 0 },
   { 5688, 2289, 0 },
   { 5739, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5660, 2281, 0 },
   { 5688, 2289, 0 },
   { 5713, 2289, 0 },
   { 5740, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5635, 2281, 0 },
   { 5659, 2281, 0 },
   { 5688, 2289, 0 },
   { 5712, 2289, 0 },
   { 5740, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5635, 2281, 0 },
   { 5688, 2289, 0 },
   { 5740, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5660, 2281, 0 },
   { 5687, 2289, 0 },
   { 5713, 2289, 0 },
   { 5739, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5634, 2281, 0 },
   { 5659, 2281, 0 },
   { 5687, 2289, 0 },
   { 5712, 2289, 0 },
   { 5739, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5634, 2281, 0 },
   { 5687, 2289, 0 },
   { 5739, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 9, 0 },
   { 5659, 2281, 0 },
   { 5660, 2281, 0 },
   { 5712, 2289, 0 },
   { 5713, 2289, 0 },
   { 5764, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5660, 2281, 0 },
   { 5713, 2289, 0 },
   { 5765, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1522, 1523, 0 },
   { 1544, 1545, 0 },
   { 1566, 1567, 0 },
   { 1586, 1587, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { 5659, 2281, 0 },
   { 5712, 2289, 0 },
   { 5764, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2751, 2750, 0 },
   { 3565, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3632, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3646, 3644, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3215, 3211, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3215, 3211, 65 },
   { 3226, 3227, 0 },
   { 3230, 268, 0 },
   { 3233, 3234, 0 },
   { 3237, 3238, 0 },
   { 3241, 3242, 0 },
   { 3245, 3246, 0 },
   { 3249, 3250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3215, 3211, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3215, 3211, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 1, 0 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 234, 1, 0 },
   { 4046, 4048, 0 },
   { 4050, 4048, 0 },
   { 4119, 4048, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 234, 1, 0 },
   { 4046, 4048, 0 },
   { 4050, 4048, 0 },
   { 4077, 4048, 0 },
   { 4119, 4048, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 4079, 4082, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 4088, 4092, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 4098, 4101, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 900, 902, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 232, 1, 0 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 232, 1, 0 },
   { 234, 1, 0 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 232, 1, 0 },
   { 234, 1, 0 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 1285, 1255, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6764, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1304, 1305, 0 },
   { 1397, 3, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1304, 1305, 0 },
   { 1313, 1316, 0 },
   { 1397, 3, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1186, 0 },
   { 1204, 1205, 0 },
   { 1318, 1321, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1186, 0 },
   { 1204, 1205, 0 },
   { 1375, 1224, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1186, 0 },
   { 1204, 1205, 0 },
   { 3044, 847, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 794, 796, 24 },
   { 797, 799, 24 },
   { 800, 802, 25 },
   { 3558, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 3037, 1383, 0 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 1650, 1654, 40 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 1642, 1644, 40 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 1637, 1639, 40 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 1621, 42 },
   { 1647, 1648, 40 },
   { 3567, 8, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1613, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1692, 1693, 40 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1613, 9, 0 },
   { 1617, 11, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1623, 235, 40 },
   { 1628, 1626, 40 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1613, 9, 0 },
   { 1615, 11, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1615, 11, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1615, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { 1615, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1613, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1613, 9, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1613, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { 1613, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1385, 1387, 0 },
   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { 1617, 11, 0 },
   { 1680, 1683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1446, 1401, 0 },
   { 1463, 1465, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 1287, 1272, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6762, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1195, 1196, 0 },
   { 1209, 1210, 0 },
   { 1324, 1325, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1195, 1196, 0 },
   { 1209, 1210, 0 },
   { 1377, 1226, 0 },
   { 1377, 1226, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1195, 1196, 0 },
   { 1209, 1210, 0 },
   { 1250, 1248, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 64 },
   { 3251, 9, 0 },
   { 3252, 268, 0 },
   { 3253, 3234, 0 },
   { 3254, 3238, 0 },
   { 3261, 11, 0 },
   { 6733, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1686, 1688, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1611, 9, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1606, 1374, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1389, 1390, 0 },
   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 1606, 1374, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1903, 775, 0 },
   { 1934, 1914, 0 },
   { 2012, 782, 0 },
   { 2040, 2023, 0 },
   { 2106, 787, 0 },
   { 2134, 2117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2608, 2609, 0 },
   { 2613, 2628, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2608, 2609, 0 },
   { 4401, 4399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2608, 2609, 0 },
   { 4404, 4399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { 1607, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { 1612, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 3510, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1614, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1473, 1475, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1614, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 4566, 4562, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1473, 1475, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1473, 1475, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1614, 9, 0 },
   { 1616, 125, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1616, 125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1473, 1475, 0 },
   { 1616, 125, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1614, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1614, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1473, 1475, 0 },
   { 1614, 9, 0 },
   { 1618, 125, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1618, 125, 41 },
   { 3509, 3497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1438, 9, 0 },
   { 1451, 1452, 0 },
   { 1473, 1475, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1219, 1220, 0 },
   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3501, 1248, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2607, 1495, 0 },
   { 3048, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 1165, 0 },
   { 3503, 847, 0 },
   { 3607, 1165, 0 },
   { 3608, 1350, 0 },
   { 3609, 1350, 0 },
   { 1593, 4326, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { 4371, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 1165, 0 },
   { 3504, 847, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { 4371, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 2738, 2739, 0 },
   { 3049, 1165, 0 },
   { 3611, 1350, 0 },
   { 4333, 4330, 97 },
   { 4371, 1165, 0 },
   { 4375, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { 4371, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 2695, 1165, 0 },
   { 3049, 1165, 0 },
   { 4371, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1173, 0 },
   { 2686, 1165, 0 },
   { 3049, 1165, 0 },
   { 4371, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 1165, 0 },
   { 2687, 1165, 0 },
   { 3049, 1165, 0 },
   { 4371, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1350, 0 },
   { 3502, 1248, 0 },
   { 3604, 1350, 0 },
   { 3605, 1165, 0 },
   { 3606, 1165, 0 },
   { 1590, 4327, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 3512, 3497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1448, 1449, 0 },
   { 1468, 1470, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1443, 9, 0 },
   { 1444, 75, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1443, 9, 0 },
   { 1444, 75, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1443, 9, 0 },
   { 1444, 75, 0 },
   { 1448, 1449, 0 },
   { 1468, 1470, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1448, 1449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1448, 1449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 3511, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1448, 1449, 0 },
   { 1468, 1470, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1442, 9, 0 },
   { 1448, 1449, 0 },
   { 1468, 1470, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3193, 2009, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1697, 1696, 0 },
   { 4467, 4470, 110 },
   { 5616, 24, 0 },
   { 5669, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2138, 847, 0 },
   { 2142, 847, 0 },
   { 2158, 847, 0 },
   { 2170, 847, 0 },
   { 2184, 19, 0 },
   { 2198, 19, 0 },
   { 2208, 19, 0 },
   { 2220, 24, 0 },
   { 2230, 24, 0 },
   { 2240, 29, 0 },
   { 2276, 2273, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 4809, 4807, 0 },
   { 4815, 4807, 0 },
   { 4821, 4807, 0 },
   { 4826, 4807, 0 },
   { 4828, 2137, 0 },
   { 4832, 4805, 0 },
   { 4836, 4805, 0 },
   { 4840, 4805, 0 },
   { 4842, 2141, 0 },
   { 4844, 2141, 0 },
   { 4846, 2183, 0 },
   { 4850, 4812, 0 },
   { 4854, 4812, 0 },
   { 4856, 2149, 0 },
   { 4858, 2149, 0 },
   { 4860, 2189, 0 },
   { 4862, 2149, 0 },
   { 4864, 2189, 0 },
   { 4866, 2219, 0 },
   { 4870, 4818, 0 },
   { 4872, 2153, 0 },
   { 4874, 2153, 0 },
   { 4876, 2193, 0 },
   { 4878, 2153, 0 },
   { 4880, 2193, 0 },
   { 4882, 2225, 0 },
   { 4884, 2153, 0 },
   { 4886, 2193, 0 },
   { 4888, 2225, 0 },
   { 4890, 2239, 0 },
   { 5615, 24, 0 },
   { 5668, 29, 0 },
   { 5721, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2138, 847, 0 },
   { 2142, 847, 0 },
   { 2158, 847, 0 },
   { 2170, 847, 0 },
   { 2184, 19, 0 },
   { 2198, 19, 0 },
   { 2208, 19, 0 },
   { 2220, 24, 0 },
   { 2230, 24, 0 },
   { 2240, 29, 0 },
   { 3687, 3688, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { 4809, 4807, 0 },
   { 4815, 4807, 0 },
   { 4821, 4807, 0 },
   { 4826, 4807, 0 },
   { 4828, 2137, 0 },
   { 4832, 4805, 0 },
   { 4836, 4805, 0 },
   { 4840, 4805, 0 },
   { 4842, 2141, 0 },
   { 4844, 2141, 0 },
   { 4846, 2183, 0 },
   { 4850, 4812, 0 },
   { 4854, 4812, 0 },
   { 4856, 2149, 0 },
   { 4858, 2149, 0 },
   { 4860, 2189, 0 },
   { 4862, 2149, 0 },
   { 4864, 2189, 0 },
   { 4866, 2219, 0 },
   { 4870, 4818, 0 },
   { 4872, 2153, 0 },
   { 4874, 2153, 0 },
   { 4876, 2193, 0 },
   { 4878, 2153, 0 },
   { 4880, 2193, 0 },
   { 4882, 2225, 0 },
   { 4884, 2153, 0 },
   { 4886, 2193, 0 },
   { 4888, 2225, 0 },
   { 4890, 2239, 0 },
   { 5615, 24, 0 },
   { 5668, 29, 0 },
   { 5721, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3684, 3686, 0 },
   { 4785, 847, 0 },
   { 4786, 19, 0 },
   { 4787, 24, 0 },
   { 4788, 29, 0 },
   { 4789, 34, 0 },
   { 4806, 4807, 0 },
   { 4813, 4807, 0 },
   { 4819, 4807, 0 },
   { 4824, 4807, 0 },
   { 4830, 4805, 0 },
   { 4834, 4805, 0 },
   { 4838, 4805, 0 },
   { 4848, 4812, 0 },
   { 4852, 4812, 0 },
   { 4868, 4818, 0 },
   { 5643, 24, 0 },
   { 5696, 29, 0 },
   { 5748, 29, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5694, 2351, 0 },
   { 5746, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5693, 2351, 0 },
   { 5745, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5666, 2347, 0 },
   { 5719, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5665, 2347, 0 },
   { 5718, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5641, 2347, 0 },
   { 5694, 2351, 0 },
   { 5746, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5640, 2347, 0 },
   { 5693, 2351, 0 },
   { 5745, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5666, 2347, 0 },
   { 5719, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3066, 9, 0 },
   { 3069, 3059, 0 },
   { 3108, 3110, 57 },
   { 3111, 3113, 57 },
   { 5665, 2347, 0 },
   { 5718, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5642, 2347, 0 },
   { 5694, 2351, 0 },
   { 5695, 2351, 0 },
   { 5746, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5642, 2347, 0 },
   { 5693, 2351, 0 },
   { 5695, 2351, 0 },
   { 5745, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5666, 2347, 0 },
   { 5695, 2351, 0 },
   { 5719, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5642, 2347, 0 },
   { 5665, 2347, 0 },
   { 5695, 2351, 0 },
   { 5718, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5667, 2347, 0 },
   { 5694, 2351, 0 },
   { 5720, 2351, 0 },
   { 5746, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5667, 2347, 0 },
   { 5693, 2351, 0 },
   { 5720, 2351, 0 },
   { 5745, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5666, 2347, 0 },
   { 5667, 2347, 0 },
   { 5719, 2351, 0 },
   { 5720, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5665, 2347, 0 },
   { 5667, 2347, 0 },
   { 5718, 2351, 0 },
   { 5720, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5694, 2351, 0 },
   { 5746, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5693, 2351, 0 },
   { 5745, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5666, 2347, 0 },
   { 5719, 2351, 0 },
   { 5771, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5665, 2347, 0 },
   { 5718, 2351, 0 },
   { 5770, 2351, 0 },
   { 5772, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5694, 2351, 0 },
   { 5746, 2351, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5693, 2351, 0 },
   { 5745, 2351, 0 },
   { 5747, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5666, 2347, 0 },
   { 5719, 2351, 0 },
   { 5747, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5665, 2347, 0 },
   { 5718, 2351, 0 },
   { 5747, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5641, 2347, 0 },
   { 5694, 2351, 0 },
   { 5746, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5640, 2347, 0 },
   { 5693, 2351, 0 },
   { 5745, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5666, 2347, 0 },
   { 5719, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 3068, 1, 0 },
   { 5665, 2347, 0 },
   { 5718, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5641, 2347, 0 },
   { 5693, 2351, 0 },
   { 5694, 2351, 0 },
   { 5745, 2351, 0 },
   { 5746, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5666, 2347, 0 },
   { 5694, 2351, 0 },
   { 5719, 2351, 0 },
   { 5746, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5641, 2347, 0 },
   { 5665, 2347, 0 },
   { 5694, 2351, 0 },
   { 5718, 2351, 0 },
   { 5746, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5693, 2351, 0 },
   { 5745, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5666, 2347, 0 },
   { 5693, 2351, 0 },
   { 5719, 2351, 0 },
   { 5745, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5640, 2347, 0 },
   { 5665, 2347, 0 },
   { 5693, 2351, 0 },
   { 5718, 2351, 0 },
   { 5745, 2351, 0 },
   { 5770, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 73, 0 },
   { 5665, 2347, 0 },
   { 5666, 2347, 0 },
   { 5718, 2351, 0 },
   { 5719, 2351, 0 },
   { 5770, 2351, 0 },
   { 5771, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2414, 19, 0 },
   { 2469, 24, 0 },
   { 2523, 29, 0 },
   { 2577, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4166, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4186, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4168, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4188, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4164, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4167, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4185, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4187, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 471, 473, 8 },
   { 481, 482, 8 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 476, 478, 8 },
   { 481, 482, 8 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 471, 473, 8 },
   { 476, 478, 8 },
   { 481, 482, 8 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4149, 4131, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4160, 4131, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4154, 4155, 80 },
   { 4164, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4161, 4155, 80 },
   { 4167, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4172, 4125, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4181, 4125, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1433, 1263, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4176, 4150, 82 },
   { 4185, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4182, 4150, 82 },
   { 4187, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4157, 4131, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4162, 4131, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4159, 4155, 80 },
   { 4166, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4163, 4155, 80 },
   { 4168, 4155, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4178, 4125, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4183, 4125, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4180, 4150, 82 },
   { 4186, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 4184, 4150, 82 },
   { 4188, 4150, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1440, 73, 0 },
   { 1441, 9, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1456, 1457, 0 },
   { 1483, 1485, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1439, 9, 0 },
   { 1668, 1669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3565, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 117, 5 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 405, 406, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 405, 406, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 282, 8 },
   { 4198, 4199, 0 },
   { 4201, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 8 },
   { 405, 406, 8 },
   { 410, 411, 8 },
   { 412, 413, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 402, 403, 8 },
   { 405, 406, 8 },
   { 416, 417, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4006, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 395, 396, 8 },
   { 402, 403, 8 },
   { 405, 406, 8 },
   { 416, 417, 8 },
   { 418, 419, 8 },
   { 421, 422, 8 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 602, 597, 0 },
   { 671, 666, 0 },
   { 741, 736, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 274, 1, 0 },
   { 275, 1, 0 },
   { 284, 285, 0 },
   { 289, 290, 0 },
   { 602, 597, 0 },
   { 671, 666, 0 },
   { 741, 736, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6739, 6740, 0 },
   { 6742, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 173, 175, 0 },
   { 602, 597, 0 },
   { 671, 666, 0 },
   { 741, 736, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 602, 597, 0 },
   { 671, 666, 0 },
   { 741, 736, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 602, 597, 0 },
   { 612, 613, 0 },
   { 671, 666, 0 },
   { 679, 680, 0 },
   { 741, 736, 0 },
   { 750, 751, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 441, 442, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 461, 462, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 461, 462, 8 },
   { 602, 597, 0 },
   { 671, 666, 0 },
   { 741, 736, 0 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 438, 8 },
   { 441, 442, 8 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 437, 438, 8 },
   { 441, 442, 8 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 437, 438, 8 },
   { 441, 442, 8 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 437, 438, 8 },
   { 441, 442, 8 },
   { 445, 446, 8 },
   { 447, 448, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 8 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 0 },
   { 280, 279, 0 },
   { 435, 436, 8 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { 6744, 6740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { 435, 436, 8 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 158, 0 },
   { 435, 436, 8 },
   { 439, 440, 8 },
   { 441, 442, 8 },
   { 449, 450, 8 },
   { 451, 452, 8 },
   { 453, 454, 8 },
   { 824, 826, 31 },
   { 252, 828, 32 },
   { 829, 831, 33 },
   { 832, 826, 34 },
   { 833, 828, 35 },
   { 834, 831, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3131, 3132, 58 },
   { 3138, 3139, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3144, 3145, 58 },
   { 3149, 3150, 59 },
   { 3187, 3188, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3131, 3132, 58 },
   { 3138, 3139, 59 },
   { 3147, 3145, 58 },
   { 3152, 3150, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3135, 3132, 58 },
   { 3142, 3139, 59 },
   { 3144, 3145, 58 },
   { 3149, 3150, 59 },
   { 3187, 3188, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3131, 3132, 58 },
   { 3138, 3139, 59 },
   { 3144, 3145, 58 },
   { 3149, 3150, 59 },
   { 3187, 3188, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1036, 0 },
   { 1082, 1081, 0 },
   { 1089, 1088, 0 },
   { 1097, 1095, 0 },
   { 1106, 1104, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1083, 0 },
   { 1091, 1090, 0 },
   { 1099, 1098, 0 },
   { 1108, 1107, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1165, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1165, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3680, 3681, 71 },
   { 3760, 3082, 79 },
   { 3834, 3758, 0 },
   { 3838, 3761, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2322, 2324, 0 },
   { 2326, 2328, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2280, 2282, 0 },
   { 2288, 2290, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 2348, 0 },
   { 2350, 2352, 0 },
   { 4790, 847, 0 },
   { 4791, 19, 0 },
   { 4792, 24, 0 },
   { 4793, 29, 0 },
   { 4794, 34, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 1, 0 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 234, 1, 0 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 4046, 4048, 0 },
   { 4050, 4048, 0 },
   { 4119, 4048, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 234, 1, 0 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 4046, 4048, 0 },
   { 4050, 4048, 0 },
   { 4077, 4048, 0 },
   { 4119, 4048, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 589, 579, 17 },
   { 649, 650, 19 },
   { 659, 650, 19 },
   { 718, 719, 21 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 649, 650, 19 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 718, 719, 21 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 232, 1, 0 },
   { 234, 1, 0 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 170, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 170, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 589, 579, 17 },
   { 649, 650, 19 },
   { 659, 650, 19 },
   { 718, 719, 21 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 1, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 1, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 232, 1, 0 },
   { 234, 1, 0 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 815, 794, 26 },
   { 816, 797, 26 },
   { 817, 800, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 8, 0 },
   { 1913, 1914, 43 },
   { 2022, 2023, 43 },
   { 2116, 2117, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 1, 0 },
   { 589, 579, 17 },
   { 659, 650, 19 },
   { 729, 719, 21 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 1, 0 },
   { 589, 579, 17 },
   { 599, 597, 16 },
   { 659, 650, 19 },
   { 668, 666, 18 },
   { 729, 719, 21 },
   { 738, 736, 20 },
   { 805, 806, 26 },
   { 809, 810, 26 },
   { 813, 814, 27 },
   { 4119, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3215, 3211, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3221, 3224, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1080, 1081, 0 },
   { 1087, 1088, 0 },
   { 1094, 1095, 0 },
   { 1103, 1104, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 2614, 2627, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 215, 0 },
   { 1349, 1248, 0 },
   { 1351, 847, 0 },
   { 1525, 1526, 0 },
   { 1530, 1529, 0 },
   { 1547, 1548, 0 },
   { 1552, 1551, 0 },
   { 1569, 1570, 0 },
   { 1574, 1573, 0 },
   { 1589, 1590, 0 },
   { 1594, 1593, 0 },
   { 3047, 1350, 0 },
   { 1351, 847, 0 },
   { 3453, 1248, 0 },
   { 3603, 1165, 0 },
   { 4331, 4332, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3643, 3644, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1216, 0 },
   { 1278, 1279, 0 },
   { 1308, 1309, 0 },
   { 3054, 1350, 0 },
   { 3584, 1165, 0 },
   { 6760, 1165, 0 },
   { 6761, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1267, 1268, 0 },
   { 1310, 1311, 0 },
   { 3055, 1165, 0 },
   { 3583, 1350, 0 },
   { 6766, 1350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1186, 0 },
   { 1204, 1205, 0 },
   { 1284, 1255, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1195, 1196, 0 },
   { 1209, 1210, 0 },
   { 1286, 1272, 0 },
   { 3053, 1350, 0 },
   { 3587, 1350, 0 },
   { 3590, 1165, 0 },
   { 3593, 1165, 0 },
   { 6763, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1658, 1659, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1621, 235, 40 },
   { 1625, 1626, 40 },
   { 1658, 1659, 0 },
   { 3568, 235, 40 },
   { 6748, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1611, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1611, 9, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1609, 1374, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1658, 1659, 0 },
   { 1686, 1688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 1606, 1374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1454, 1403, 0 },
   { 1478, 1480, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1435, 9, 0 },
   { 1606, 1374, 0 },
   { 1658, 1659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1663, 1664, 0 },
   { 4564, 4562, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1612, 9, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1607, 1608, 0 },
   { 1610, 1608, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1437, 9, 0 },
   { 1459, 1460, 0 },
   { 1488, 1490, 0 },
   { 1663, 1664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3519, 3521, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 847, 0 },
   { 1353, 1248, 0 },
   { 3048, 1165, 0 },
   { 3452, 1248, 0 },
   { 1352, 847, 0 },
   { 3523, 3524, 0 },
   { 3602, 1350, 0 },
   { 4328, 4330, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 73, 0 },
   { 1920, 1921, 43 },
   { 2029, 2030, 43 },
   { 2123, 2124, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4381, 4382, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4362, 4353, 0 },
   { 4381, 4382, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4383, 4384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4364, 4350, 0 },
   { 4383, 4384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4387, 4388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4387, 4388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4366, 4367, 0 },
   { 4387, 4388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 466, 468, 8 },
   { 476, 478, 8 },
   { 481, 482, 8 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 466, 468, 8 },
   { 471, 473, 8 },
   { 476, 478, 8 },
   { 481, 482, 8 },
   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6033, 6019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6025, 6019, 0 },
   { 6033, 6019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 9, 0 },
   { 129, 9, 0 },
   { 223, 8, 0 },
   { 626, 627, 17 },
   { 691, 692, 19 },
   { 764, 765, 21 },
   { 6722, 6723, 0 },
   { 6725, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 584, 585, 17 },
   { 655, 656, 19 },
   { 724, 725, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 584, 585, 17 },
   { 589, 579, 17 },
   { 655, 656, 19 },
   { 659, 650, 19 },
   { 724, 725, 21 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 584, 585, 17 },
   { 589, 579, 17 },
   { 649, 650, 19 },
   { 655, 656, 19 },
   { 659, 650, 19 },
   { 718, 719, 21 },
   { 724, 725, 21 },
   { 729, 719, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 589, 579, 17 },
   { 596, 597, 16 },
   { 649, 650, 19 },
   { 659, 650, 19 },
   { 665, 666, 18 },
   { 718, 719, 21 },
   { 729, 719, 21 },
   { 735, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 589, 579, 17 },
   { 596, 597, 16 },
   { 599, 597, 16 },
   { 649, 650, 19 },
   { 659, 650, 19 },
   { 665, 666, 18 },
   { 668, 666, 18 },
   { 718, 719, 21 },
   { 729, 719, 21 },
   { 735, 736, 20 },
   { 738, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 584, 585, 17 },
   { 589, 579, 17 },
   { 596, 597, 16 },
   { 649, 650, 19 },
   { 655, 656, 19 },
   { 659, 650, 19 },
   { 665, 666, 18 },
   { 718, 719, 21 },
   { 724, 725, 21 },
   { 729, 719, 21 },
   { 735, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 584, 585, 17 },
   { 655, 656, 19 },
   { 724, 725, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 146, 0 },
   { 578, 579, 17 },
   { 589, 579, 17 },
   { 596, 597, 16 },
   { 649, 650, 19 },
   { 659, 650, 19 },
   { 665, 666, 18 },
   { 718, 719, 21 },
   { 729, 719, 21 },
   { 735, 736, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3072, 2694, 0 },
   { 3741, 3743, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 211, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3180, 3170, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1304, 1305, 0 },
   { 1313, 1316, 0 },
   { 3051, 1165, 0 },
   { 3572, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1304, 1305, 0 },
   { 1313, 1316, 0 },
   { 1397, 3, 0 },
   { 3051, 1165, 0 },
   { 3576, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1300, 1303, 0 },
   { 2657, 1166, 0 },
   { 3051, 1165, 0 },
   { 3595, 1165, 0 },
   { 3598, 1350, 0 },
   { 3601, 1350, 0 },
   { 6765, 1165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 3579, 3571, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1436, 9, 0 },
   { 1692, 1693, 40 },
   { 3581, 3575, 0 },
   { 6749, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 8, 0 },
   { 240, 8, 0 },
   { 260, 9, 0 },
   { 263, 9, 0 },
   { 266, 118, 0 },
   { 846, 854, 0 },
   { 6730, 6723, 0 },
   { 6731, 6723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2640, 2643, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 2652, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2640, 2643, 0 },
   { 2648, 2652, 0 },
   { 3056, 9, 0 },
   { 3060, 73, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1165, 0 },
   { 3056, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3073, 1, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1431, 1255, 0 },
   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 1889, 1896, 0 },
   { 1998, 2005, 0 },
   { 2092, 2099, 0 },
   { 3487, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1432, 1255, 0 },
   { 1434, 1263, 0 },
   { 3487, 1, 0 },
   { 6025, 6019, 0 },
   { 6033, 6019, 0 },
   { 6040, 6035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1036, 0 },
   { 1082, 1081, 0 },
   { 1089, 1088, 0 },
   { 1097, 1095, 0 },
   { 1106, 1104, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1083, 0 },
   { 1091, 1090, 0 },
   { 1099, 1098, 0 },
   { 1108, 1107, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1080, 1081, 0 },
   { 1087, 1088, 0 },
   { 1094, 1095, 0 },
   { 1103, 1104, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 6063, 6064, 143 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 211, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3180, 3170, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3073, 1, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1036, 0 },
   { 1082, 1081, 0 },
   { 1089, 1088, 0 },
   { 1097, 1095, 0 },
   { 1106, 1104, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1083, 0 },
   { 1091, 1090, 0 },
   { 1099, 1098, 0 },
   { 1108, 1107, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1080, 1081, 0 },
   { 1087, 1088, 0 },
   { 1094, 1095, 0 },
   { 1103, 1104, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 211, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3180, 3170, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3073, 1, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1036, 0 },
   { 1082, 1081, 0 },
   { 1089, 1088, 0 },
   { 1097, 1095, 0 },
   { 1106, 1104, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1083, 0 },
   { 1091, 1090, 0 },
   { 1099, 1098, 0 },
   { 1108, 1107, 0 },
   { 3039, 3040, 0 },
   { 3042, 3043, 0 },
   { 3056, 9, 0 },
   { 3057, 73, 0 },
   { 3058, 9, 0 },
   { 3081, 3085, 57 },
   { 3087, 3091, 57 },
   { 3093, 3094, 57 },
   { 3096, 3097, 57 },
   { 3666, 3667, 71 },
   { 3715, 3716, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 50, 2 },
   { 1080, 1081, 0 },
   { 1087, 1088, 0 },
   { 1094, 1095, 0 },
   { 1103, 1104, 0 },
   { 3121, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 9, 0 },
   { 3655, 3656, 71 },
   { 1107, 512, 71 },
   { 3658, 3660, 71 },
   { 1098, 537, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 211, 0 },
   { 3061, 9, 0 },
   { 3071, 1, 0 },
   { 6015, 5940, 142 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 9, 0 },
   { 3180, 3170, 63 },
   { 5939, 5940, 142 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_fgeu] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         2,
      },
   },
   [nir_op_fltu] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         3,
      },
   },
   [nir_op_fneo] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         4,
         4,
         4,
      },
   },
   [nir_op_fequ] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         5,
         5,
         5,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         10,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         15,
         15,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         7,
         7,
         408,
         409,
         410,
         411,
         412,
         7,
         413,
         414,
         415,
         416,
         2439,
         2440,
         2441,
         2442,
         2443,
         2444,
         6,
         408,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         6,
         409,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         403,
         410,
         403,
         403,
         403,
         403,
         403,
         403,
         417,
         418,
         419,
         420,
         403,
         403,
         2445,
         2446,
         2447,
         2448,
         6,
         411,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         6,
         412,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         6,
         7,
         6,
         6,
         403,
         6,
         6,
         421,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         404,
         413,
         404,
         404,
         417,
         404,
         404,
         404,
         404,
         422,
         423,
         424,
         404,
         404,
         2449,
         2450,
         2451,
         2452,
         405,
         414,
         405,
         405,
         418,
         405,
         405,
         405,
         422,
         405,
         425,
         426,
         405,
         405,
         2453,
         2454,
         2455,
         2456,
         406,
         415,
         406,
         406,
         419,
         406,
         406,
         406,
         423,
         425,
         406,
         427,
         406,
         406,
         2457,
         2458,
         2459,
         2460,
         407,
         416,
         407,
         407,
         420,
         407,
         407,
         407,
         424,
         426,
         427,
         407,
         407,
         407,
         2461,
         2462,
         2463,
         2464,
         6,
         2439,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         6,
         2440,
         6,
         6,
         403,
         6,
         6,
         6,
         404,
         405,
         406,
         407,
         6,
         6,
         2435,
         2436,
         2437,
         2438,
         2435,
         2441,
         2435,
         2435,
         2445,
         2435,
         2435,
         2435,
         2449,
         2453,
         2457,
         2461,
         2435,
         2435,
         2435,
         2465,
         2466,
         2467,
         2436,
         2442,
         2436,
         2436,
         2446,
         2436,
         2436,
         2436,
         2450,
         2454,
         2458,
         2462,
         2436,
         2436,
         2465,
         2436,
         2468,
         2469,
         2437,
         2443,
         2437,
         2437,
         2447,
         2437,
         2437,
         2437,
         2451,
         2455,
         2459,
         2463,
         2437,
         2437,
         2466,
         2468,
         2437,
         2470,
         2438,
         2444,
         2438,
         2438,
         2448,
         2438,
         2438,
         2438,
         2452,
         2456,
         2460,
         2464,
         2438,
         2438,
         2467,
         2469,
         2470,
         2438,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         4,
         15,
         4,
         16,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         4,
         16,
         4,
         15,
         15,
         15,
         15,
         15,
         4,
         4,
         4,
         4,
         0,
         13,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         19,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         22,
         0,
         0,
         0,
         5,
         5,
         3,
         6,
         0,
         23,
         17,
         3,
         6,
         24,
         5,
         5,
         3,
         6,
         25,
         17,
         3,
         6,
         26,
         5,
         5,
         3,
         6,
         0,
         17,
      },
      
      .num_filtered_states = 27,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         10,
         11,
         10,
         10,
         10,
         1116,
         10,
         10,
         10,
         1117,
         10,
         10,
         10,
         10,
         10,
         2472,
         10,
         10,
         10,
         1116,
         10,
         10,
         1116,
         10,
         1116,
         10,
         1116,
         8,
         1118,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         1119,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         1120,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         1121,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         1122,
         1123,
         1122,
         1122,
         1122,
         1124,
         1122,
         1122,
         1122,
         1125,
         1122,
         1122,
         1122,
         1122,
         1122,
         2473,
         1122,
         1122,
         1122,
         1124,
         1122,
         1122,
         1124,
         1122,
         1124,
         1122,
         1124,
         1126,
         1127,
         1126,
         1126,
         1126,
         1128,
         1126,
         1126,
         1126,
         1129,
         1126,
         1126,
         1126,
         1126,
         1126,
         2474,
         1126,
         1126,
         1126,
         1128,
         1126,
         1126,
         1128,
         1126,
         1128,
         1126,
         1128,
         8,
         1130,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         9,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         1131,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         1132,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         1133,
         1134,
         1133,
         1133,
         1133,
         1135,
         1133,
         1133,
         1133,
         1136,
         1133,
         1133,
         1133,
         1133,
         1133,
         2475,
         1133,
         1133,
         1133,
         1135,
         1133,
         1133,
         1135,
         1133,
         1135,
         1133,
         1135,
         8,
         2476,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         2477,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         1120,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         2478,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         2479,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         2480,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3160,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3161,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3234,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3242,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3247,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3252,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3256,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
         8,
         3261,
         8,
         8,
         8,
         1114,
         8,
         8,
         8,
         1115,
         8,
         8,
         8,
         8,
         8,
         2471,
         8,
         8,
         8,
         1114,
         8,
         8,
         1114,
         8,
         1114,
         8,
         1114,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         3,
         0,
         0,
         0,
         3,
         3,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         3,
         3,
         3,
         0,
         4,
         0,
         0,
         0,
         4,
         3,
         3,
         3,
         0,
         4,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         12,
         1384,
         1385,
         1386,
         1387,
         1388,
         1389,
         1390,
         1391,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         14,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         16,
         0,
         0,
         16,
         0,
         428,
         429,
         428,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         17,
         0,
         17,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         18,
         0,
         18,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         19,
         0,
         19,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         0,
         0,
         10,
         11,
         0,
         0,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         18,
         19,
         16,
         16,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         22,
         0,
         0,
         0,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         24,
         6,
         6,
         6,
         6,
         25,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         20,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         22,
         0,
         0,
         23,
         23,
         23,
         23,
         27,
         23,
         22,
         22,
         0,
         22,
         0,
         22,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         29,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         20,
         20,
         20,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         0,
         0,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         12,
         12,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         10,
         0,
         0,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 31,
      .table = (const uint16_t []) {
      
         20,
         21,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         21,
         21,
         1399,
         1400,
         1401,
         1402,
         1403,
         1404,
         1405,
         1406,
         1407,
         1408,
         21,
         1409,
         1410,
         21,
         1407,
         2512,
         1407,
         1407,
         2513,
         2514,
         2515,
         2516,
         2517,
         1403,
         1407,
         3048,
         21,
         3049,
         3227,
         20,
         1399,
         20,
         20,
         1411,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         20,
         1400,
         20,
         20,
         1411,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         1392,
         1401,
         1411,
         1411,
         1392,
         1412,
         1413,
         1392,
         1392,
         1414,
         1392,
         1415,
         1392,
         1416,
         1417,
         1392,
         1392,
         2518,
         1392,
         1392,
         2519,
         2519,
         2520,
         2521,
         2522,
         1413,
         1392,
         3050,
         3051,
         3052,
         1392,
         1393,
         1402,
         1393,
         1393,
         1412,
         1393,
         1418,
         1393,
         1393,
         1419,
         1393,
         1420,
         1393,
         1421,
         1422,
         1393,
         1393,
         2523,
         1393,
         1393,
         2524,
         2524,
         2525,
         2526,
         2527,
         1418,
         1393,
         3053,
         1393,
         3054,
         1393,
         1394,
         1403,
         1394,
         1394,
         1413,
         1418,
         1394,
         1394,
         1394,
         1423,
         1394,
         1424,
         1394,
         1425,
         1426,
         1394,
         1394,
         2528,
         1394,
         1394,
         2529,
         2529,
         2530,
         2531,
         2511,
         1394,
         1394,
         3055,
         1394,
         3056,
         1394,
         20,
         1404,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         20,
         1405,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         1395,
         1406,
         1395,
         1395,
         1414,
         1419,
         1423,
         1395,
         1395,
         1427,
         1395,
         1428,
         1395,
         1429,
         1430,
         1395,
         1395,
         2532,
         1395,
         1395,
         2533,
         2533,
         2534,
         2535,
         2536,
         2537,
         1395,
         3057,
         1395,
         3058,
         1395,
         20,
         1407,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         1396,
         1408,
         1396,
         1396,
         1415,
         1420,
         1424,
         1396,
         1396,
         1428,
         1396,
         1396,
         1396,
         1431,
         1432,
         1396,
         1396,
         2507,
         1396,
         1396,
         2538,
         2538,
         2539,
         2540,
         2541,
         1424,
         1396,
         3059,
         1396,
         3060,
         1396,
         20,
         21,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         1433,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         1397,
         1409,
         1397,
         1397,
         1416,
         1421,
         1425,
         1397,
         1397,
         1429,
         1397,
         1431,
         1397,
         1434,
         1435,
         1397,
         1397,
         2542,
         1397,
         1397,
         2543,
         2543,
         2544,
         2545,
         2546,
         1425,
         1397,
         3061,
         1397,
         3062,
         1397,
         1398,
         1410,
         1398,
         1398,
         1417,
         1422,
         1426,
         1398,
         1398,
         1430,
         1398,
         1432,
         1398,
         1435,
         1398,
         1398,
         1398,
         2547,
         1398,
         1398,
         2548,
         2548,
         2549,
         2550,
         2551,
         1426,
         1398,
         3063,
         1398,
         3064,
         1398,
         20,
         21,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         1436,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         20,
         1407,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         2552,
         2553,
         2554,
         2555,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         3065,
         3046,
         20,
         3047,
         20,
         2507,
         2512,
         2507,
         2507,
         2518,
         2523,
         2528,
         2507,
         2507,
         2532,
         2507,
         2507,
         2507,
         2542,
         2547,
         2507,
         2553,
         2553,
         2556,
         2557,
         2558,
         2558,
         2559,
         2560,
         2561,
         2528,
         3066,
         3067,
         2507,
         3068,
         2507,
         20,
         1407,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         2554,
         2556,
         2562,
         2563,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         3069,
         3046,
         20,
         3047,
         20,
         20,
         1407,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         2555,
         2557,
         2563,
         2564,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         3070,
         3046,
         20,
         3047,
         20,
         2508,
         2513,
         2508,
         2508,
         2519,
         2524,
         2529,
         2508,
         2508,
         2533,
         2508,
         2538,
         2508,
         2543,
         2548,
         2508,
         2508,
         2558,
         2508,
         2508,
         2508,
         2508,
         2565,
         2566,
         2567,
         2529,
         2508,
         3071,
         2508,
         3072,
         2508,
         2508,
         2514,
         2508,
         2508,
         2519,
         2524,
         2529,
         2508,
         2508,
         2533,
         2508,
         2538,
         2508,
         2543,
         2548,
         2508,
         2508,
         2558,
         2508,
         2508,
         2508,
         2508,
         2565,
         2566,
         2567,
         2529,
         2508,
         3071,
         2508,
         3072,
         2508,
         2509,
         2515,
         2509,
         2509,
         2520,
         2525,
         2530,
         2509,
         2509,
         2534,
         2509,
         2539,
         2509,
         2544,
         2549,
         2509,
         2509,
         2559,
         2509,
         2509,
         2565,
         2565,
         2509,
         2510,
         2568,
         2530,
         2509,
         3046,
         2509,
         3073,
         2509,
         2510,
         2516,
         2510,
         2510,
         2521,
         2526,
         2531,
         2510,
         2510,
         2535,
         2510,
         2540,
         2510,
         2545,
         2550,
         2510,
         2510,
         2560,
         2510,
         2510,
         2566,
         2566,
         2510,
         2569,
         2570,
         2531,
         2510,
         3074,
         2510,
         3075,
         2510,
         2511,
         2517,
         2511,
         2511,
         2522,
         2527,
         2511,
         2511,
         2511,
         2536,
         2511,
         2541,
         2511,
         2546,
         2551,
         2511,
         2511,
         2561,
         2511,
         2511,
         2567,
         2567,
         2568,
         2570,
         2511,
         2511,
         2511,
         3076,
         2511,
         3077,
         2511,
         1394,
         1403,
         1394,
         1394,
         1413,
         1418,
         1394,
         1394,
         1394,
         2537,
         1394,
         1424,
         1394,
         1425,
         1426,
         1394,
         1394,
         2528,
         1394,
         1394,
         2529,
         2529,
         2530,
         2531,
         2511,
         1394,
         1394,
         3055,
         1394,
         3078,
         1394,
         20,
         1407,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         3065,
         3066,
         3069,
         3070,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         3079,
         3046,
         20,
         3047,
         20,
         3046,
         3048,
         3046,
         3046,
         3050,
         3053,
         3055,
         3046,
         3046,
         3057,
         3046,
         3059,
         3046,
         3061,
         3063,
         3046,
         3046,
         3067,
         3046,
         3046,
         3071,
         3071,
         3046,
         3074,
         3076,
         3055,
         3046,
         3074,
         3046,
         3080,
         3046,
         20,
         21,
         20,
         20,
         3051,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
         3047,
         3049,
         3047,
         3047,
         3052,
         3054,
         3056,
         3047,
         3047,
         3058,
         3047,
         3060,
         3047,
         3062,
         3064,
         3047,
         3047,
         3068,
         3047,
         3047,
         3072,
         3072,
         3073,
         3075,
         3077,
         3078,
         3047,
         3080,
         3047,
         3058,
         3047,
         20,
         3227,
         20,
         20,
         1392,
         1393,
         1394,
         20,
         20,
         1395,
         20,
         1396,
         20,
         1397,
         1398,
         20,
         20,
         2507,
         20,
         20,
         2508,
         2508,
         2509,
         2510,
         2511,
         1394,
         20,
         3046,
         20,
         3047,
         20,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         23,
         2837,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         9,
         8,
         9,
         8,
         9,
         10,
         11,
         10,
         11,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         15,
         2,
         16,
         17,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         16,
         17,
         2,
         2,
         2,
         15,
         2,
         16,
         17,
         2,
         15,
         2,
         16,
         17,
         15,
         2,
         16,
         17,
         15,
         15,
         18,
         19,
         16,
         17,
         2,
         16,
         20,
         2,
         3,
         21,
         4,
         4,
         4,
         22,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         21,
         3,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         23,
         6,
         6,
         6,
         24,
         25,
         26,
         27,
         28,
         6,
         6,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         29,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         11,
         10,
         10,
         10,
         11,
         10,
         10,
         10,
         11,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         31,
         32,
         2,
         2,
         2,
         2,
         31,
         32,
         2,
         2,
         2,
         31,
         32,
         2,
         2,
         2,
         31,
         32,
         2,
         2,
         2,
         31,
         32,
         15,
         15,
         33,
         34,
         15,
         35,
         2,
         31,
         32,
         2,
         16,
         16,
         36,
         37,
         16,
         17,
         17,
         38,
         39,
         17,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         31,
         32,
         2,
         2,
         2,
         2,
         31,
         32,
         2,
         31,
         32,
         32,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         41,
         4,
         4,
         22,
         22,
         22,
         22,
         22,
         42,
         41,
         21,
         3,
         21,
         3,
         41,
         43,
         6,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         46,
         45,
         46,
         45,
         2,
         46,
         45,
         46,
         45,
         46,
         47,
         46,
         45,
         46,
         48,
         49,
         50,
         51,
         2,
         2,
         45,
         46,
         2,
         2,
         45,
         46,
         52,
         45,
         53,
         45,
         46,
         54,
         2,
         55,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         22,
         3,
         3,
         3,
         3,
         3,
         3,
         21,
         21,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         41,
         41,
         41,
         21,
         3,
         3,
         0,
         0,
         0,
         0,
         56,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         22,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 57,
      .table = (const uint16_t []) {
      
         24,
         25,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         25,
         25,
         25,
         1439,
         1440,
         1441,
         1442,
         25,
         1443,
         1444,
         1445,
         1446,
         25,
         1447,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         2814,
         2815,
         2816,
         2817,
         2818,
         2819,
         2820,
         2821,
         25,
         25,
         3124,
         3124,
         3124,
         3124,
         3125,
         3126,
         3126,
         3124,
         3124,
         3127,
         3128,
         3129,
         3130,
         2820,
         3124,
         25,
         3124,
         3126,
         25,
         3124,
         25,
         3124,
         3124,
         3125,
         3124,
         3210,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         1448,
         1448,
         1448,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         1448,
         3132,
         3134,
         1448,
         3132,
         1448,
         3131,
         3132,
         1448,
         3132,
         1438,
         1437,
         1439,
         1437,
         1437,
         1437,
         1437,
         1450,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         2812,
         2812,
         1450,
         1450,
         1450,
         1450,
         1450,
         2822,
         1437,
         1437,
         3135,
         3135,
         3135,
         3135,
         1437,
         3136,
         3136,
         3135,
         3135,
         1437,
         3123,
         3123,
         1450,
         1450,
         3135,
         1437,
         3135,
         3136,
         1437,
         3135,
         1437,
         3135,
         3135,
         1437,
         3135,
         1450,
         1437,
         1440,
         1437,
         1437,
         1437,
         1437,
         1450,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         1437,
         2812,
         2812,
         1450,
         1450,
         1450,
         1450,
         1450,
         2822,
         1437,
         1437,
         3135,
         3135,
         3135,
         3135,
         1437,
         3136,
         3136,
         3135,
         3135,
         1437,
         3123,
         3123,
         1450,
         1450,
         3135,
         1437,
         3135,
         3136,
         1437,
         3135,
         1437,
         3135,
         3135,
         1437,
         3135,
         1450,
         24,
         1441,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         1438,
         1442,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         24,
         25,
         24,
         1437,
         1437,
         24,
         1438,
         1451,
         24,
         24,
         1452,
         1452,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         1443,
         1449,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         1449,
         1449,
         1449,
         1449,
         1449,
         1449,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3140,
         3140,
         3140,
         3140,
         1449,
         3141,
         3141,
         3140,
         3140,
         24,
         3123,
         3123,
         1438,
         1438,
         3140,
         1449,
         3140,
         3141,
         1449,
         3140,
         1449,
         3140,
         3140,
         1449,
         3140,
         1438,
         24,
         1444,
         1449,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         1449,
         1449,
         1449,
         1449,
         1449,
         1449,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3140,
         3140,
         3140,
         3140,
         1449,
         3141,
         3141,
         3140,
         3140,
         24,
         3123,
         3123,
         1438,
         1438,
         3140,
         1449,
         3140,
         3141,
         1449,
         3140,
         1449,
         3140,
         3140,
         1449,
         3140,
         1438,
         24,
         1445,
         24,
         1437,
         1437,
         24,
         1438,
         1452,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         1446,
         24,
         1437,
         1437,
         24,
         1438,
         1452,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         25,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         2824,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         1447,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         25,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         1453,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         2825,
         2813,
         24,
         1453,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         2825,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         1448,
         1448,
         1448,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         3211,
         3132,
         3134,
         3211,
         3132,
         3211,
         3212,
         3213,
         3211,
         3213,
         1438,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         1448,
         1448,
         1448,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3214,
         1448,
         3214,
         3215,
         1448,
         3214,
         1448,
         3131,
         3132,
         1448,
         3214,
         1438,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         2826,
         1448,
         2826,
         2826,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3142,
         3143,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         1448,
         3132,
         3134,
         1448,
         3143,
         2826,
         3131,
         3132,
         1448,
         3132,
         1438,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         1448,
         1448,
         1448,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3214,
         3211,
         3214,
         3215,
         3211,
         3214,
         3211,
         3212,
         3213,
         3211,
         3216,
         1438,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         2826,
         1448,
         2826,
         2826,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3142,
         3143,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         3211,
         3132,
         3134,
         3211,
         3143,
         3217,
         3212,
         3213,
         3211,
         3213,
         1438,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         2826,
         1448,
         2826,
         2826,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3142,
         3143,
         24,
         3123,
         3123,
         1438,
         1438,
         3214,
         1448,
         3214,
         3215,
         1448,
         3218,
         2826,
         3131,
         3132,
         1448,
         3214,
         1438,
         2812,
         2814,
         2812,
         2812,
         2812,
         2812,
         2823,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2823,
         2823,
         2823,
         2823,
         2823,
         2827,
         2812,
         2812,
         3144,
         3144,
         3144,
         3144,
         2812,
         3145,
         3145,
         3144,
         3144,
         2812,
         3123,
         3123,
         2823,
         2823,
         3144,
         2812,
         3144,
         3145,
         2812,
         3144,
         2812,
         3144,
         3144,
         2812,
         3144,
         2823,
         2812,
         2815,
         2812,
         2812,
         2812,
         2812,
         2823,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2823,
         2823,
         2823,
         2823,
         2823,
         2827,
         2812,
         2812,
         3144,
         3144,
         3144,
         3144,
         2812,
         3145,
         3145,
         3144,
         3144,
         2812,
         3123,
         3123,
         2823,
         2823,
         3144,
         2812,
         3144,
         3145,
         2812,
         3144,
         2812,
         3144,
         3144,
         2812,
         3144,
         2823,
         1438,
         2816,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         1438,
         2817,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         1438,
         2818,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         1438,
         2819,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         1438,
         2820,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2825,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         2825,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         2813,
         2821,
         2813,
         2822,
         2822,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2827,
         2827,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         3146,
         3146,
         3146,
         3146,
         2813,
         3147,
         3147,
         3146,
         3146,
         2813,
         3148,
         3148,
         2813,
         2813,
         3146,
         2813,
         3146,
         3147,
         2813,
         3146,
         2813,
         3146,
         3146,
         2813,
         3146,
         2813,
         24,
         25,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         2824,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         2824,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         24,
         25,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         1453,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         2825,
         2813,
         24,
         1453,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         3149,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         3121,
         3124,
         3131,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3131,
         3131,
         3131,
         3131,
         3131,
         3131,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3131,
         3132,
         3131,
         3132,
         3131,
         3133,
         3134,
         3131,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3131,
         3132,
         3134,
         3131,
         3132,
         3131,
         3131,
         3132,
         3131,
         3132,
         3137,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3132,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3134,
         3134,
         3132,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3132,
         3132,
         3134,
         3132,
         3132,
         3132,
         3132,
         3132,
         3132,
         3132,
         3137,
         3121,
         3124,
         3131,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3131,
         3131,
         3131,
         3131,
         3131,
         3131,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3131,
         3132,
         3131,
         3132,
         3131,
         3133,
         3134,
         3131,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3212,
         3132,
         3134,
         3212,
         3132,
         3212,
         3212,
         3213,
         3212,
         3213,
         3137,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3132,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3134,
         3134,
         3132,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3213,
         3132,
         3134,
         3213,
         3132,
         3213,
         3213,
         3213,
         3213,
         3213,
         3137,
         24,
         3125,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         1448,
         1448,
         1448,
         1448,
         1448,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3131,
         3132,
         1448,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         3211,
         3132,
         3134,
         3211,
         3132,
         3211,
         3212,
         3213,
         3211,
         3213,
         1438,
         3122,
         3126,
         3133,
         3136,
         3136,
         3122,
         3138,
         3122,
         3141,
         3141,
         3122,
         3122,
         3122,
         3122,
         3122,
         3133,
         3133,
         3133,
         3133,
         3133,
         3133,
         3145,
         3145,
         3138,
         3138,
         3138,
         3138,
         3138,
         3147,
         3122,
         3122,
         3133,
         3134,
         3133,
         3134,
         3133,
         3133,
         3134,
         3133,
         3134,
         3122,
         3151,
         3151,
         3138,
         3138,
         3215,
         3133,
         3215,
         3215,
         3133,
         3215,
         3133,
         3133,
         3134,
         3133,
         3215,
         3138,
         3122,
         3126,
         3134,
         3136,
         3136,
         3122,
         3138,
         3122,
         3141,
         3141,
         3122,
         3122,
         3122,
         3122,
         3122,
         3134,
         3134,
         3134,
         3134,
         3134,
         3134,
         3145,
         3145,
         3138,
         3138,
         3138,
         3138,
         3138,
         3147,
         3122,
         3122,
         3134,
         3134,
         3134,
         3134,
         3134,
         3134,
         3134,
         3134,
         3134,
         3122,
         3151,
         3151,
         3138,
         3138,
         3215,
         3134,
         3215,
         3215,
         3134,
         3215,
         3134,
         3134,
         3134,
         3134,
         3215,
         3138,
         3121,
         3124,
         3131,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3131,
         3131,
         3142,
         3131,
         3142,
         3142,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3131,
         3132,
         3131,
         3132,
         3131,
         3133,
         3134,
         3142,
         3143,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3131,
         3132,
         3134,
         3131,
         3143,
         3142,
         3131,
         3132,
         3131,
         3132,
         3137,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3132,
         3132,
         3143,
         3132,
         3143,
         3143,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3134,
         3134,
         3143,
         3143,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3132,
         3132,
         3134,
         3132,
         3143,
         3143,
         3132,
         3132,
         3132,
         3132,
         3137,
         24,
         3127,
         24,
         1437,
         1437,
         24,
         1438,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3121,
         3121,
         3121,
         3121,
         24,
         3122,
         3122,
         3121,
         3121,
         24,
         3123,
         3123,
         1438,
         1438,
         3121,
         24,
         3121,
         3122,
         24,
         3121,
         24,
         3121,
         3121,
         24,
         3121,
         1438,
         3123,
         3128,
         3123,
         3123,
         3123,
         3123,
         3139,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3139,
         3139,
         3139,
         3139,
         3139,
         3148,
         3123,
         3123,
         3150,
         3150,
         3150,
         3150,
         3123,
         3151,
         3151,
         3150,
         3150,
         3123,
         3123,
         3123,
         3139,
         3139,
         3150,
         3123,
         3150,
         3151,
         3123,
         3150,
         3123,
         3150,
         3150,
         3123,
         3150,
         3139,
         3123,
         3129,
         3123,
         3123,
         3123,
         3123,
         3139,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3123,
         3139,
         3139,
         3139,
         3139,
         3139,
         3148,
         3123,
         3123,
         3150,
         3150,
         3150,
         3150,
         3123,
         3151,
         3151,
         3150,
         3150,
         3123,
         3123,
         3123,
         3139,
         3139,
         3150,
         3123,
         3150,
         3151,
         3123,
         3150,
         3123,
         3150,
         3150,
         3123,
         3150,
         3139,
         1438,
         3130,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         1438,
         2820,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2825,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         3149,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3132,
         3214,
         3132,
         3214,
         3132,
         3214,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3215,
         3215,
         3132,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3132,
         3132,
         3215,
         3214,
         3132,
         3132,
         3132,
         3132,
         3132,
         3132,
         3137,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         3211,
         1448,
         1448,
         3211,
         3211,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3212,
         3213,
         3211,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         3211,
         3213,
         3134,
         3211,
         3132,
         3211,
         3212,
         3213,
         3211,
         3213,
         1438,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3132,
         3214,
         3132,
         3214,
         3132,
         3214,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3215,
         3215,
         3132,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3213,
         3132,
         3215,
         3216,
         3132,
         3213,
         3213,
         3213,
         3213,
         3213,
         3137,
         3122,
         3126,
         3134,
         3136,
         3136,
         3122,
         3138,
         3122,
         3141,
         3141,
         3122,
         3122,
         3122,
         3122,
         3122,
         3134,
         3215,
         3134,
         3215,
         3134,
         3215,
         3145,
         3145,
         3138,
         3138,
         3138,
         3138,
         3138,
         3147,
         3122,
         3122,
         3134,
         3134,
         3134,
         3134,
         3134,
         3215,
         3215,
         3134,
         3134,
         3122,
         3151,
         3151,
         3138,
         3138,
         3215,
         3134,
         3215,
         3215,
         3215,
         3215,
         3134,
         3134,
         3134,
         3134,
         3215,
         3138,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         3211,
         1448,
         1448,
         3211,
         3211,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3212,
         3213,
         3211,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3214,
         3211,
         3216,
         3215,
         3211,
         3214,
         3211,
         3212,
         3213,
         3211,
         3216,
         1438,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3132,
         3214,
         3143,
         3214,
         3143,
         3218,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3132,
         3132,
         3132,
         3215,
         3215,
         3143,
         3143,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3132,
         3132,
         3215,
         3214,
         3143,
         3143,
         3132,
         3132,
         3132,
         3132,
         3137,
         24,
         25,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         3211,
         1448,
         2826,
         3211,
         3217,
         2826,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3212,
         3213,
         3211,
         3133,
         3134,
         3142,
         3143,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         3211,
         3213,
         3134,
         3211,
         3143,
         3217,
         3212,
         3213,
         3211,
         3213,
         1438,
         3121,
         3124,
         3131,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3212,
         3131,
         3131,
         3212,
         3212,
         3131,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3131,
         3132,
         3212,
         3213,
         3212,
         3133,
         3134,
         3131,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3212,
         3213,
         3134,
         3212,
         3132,
         3212,
         3212,
         3213,
         3212,
         3213,
         3137,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3213,
         3132,
         3132,
         3213,
         3213,
         3132,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3213,
         3213,
         3213,
         3134,
         3134,
         3132,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3213,
         3213,
         3134,
         3213,
         3132,
         3213,
         3213,
         3213,
         3213,
         3213,
         3137,
         24,
         3125,
         1448,
         1437,
         1437,
         24,
         1438,
         24,
         1449,
         1449,
         24,
         24,
         24,
         24,
         24,
         3211,
         1448,
         1448,
         3211,
         3211,
         1448,
         2812,
         2812,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         24,
         24,
         3131,
         3132,
         3212,
         3213,
         3211,
         3133,
         3134,
         3131,
         3132,
         24,
         3123,
         3123,
         1438,
         1438,
         3132,
         3211,
         3213,
         3134,
         3211,
         3132,
         3211,
         3212,
         3213,
         3211,
         3213,
         1438,
         3121,
         3124,
         3132,
         3135,
         3135,
         3121,
         3137,
         3121,
         3140,
         3140,
         3121,
         3121,
         3121,
         3121,
         3121,
         3213,
         3214,
         3132,
         3216,
         3213,
         3214,
         3144,
         3144,
         3137,
         3137,
         3137,
         3137,
         3137,
         3146,
         3121,
         3121,
         3132,
         3132,
         3213,
         3213,
         3213,
         3215,
         3215,
         3132,
         3132,
         3121,
         3150,
         3150,
         3137,
         3137,
         3132,
         3213,
         3213,
         3215,
         3216,
         3132,
         3213,
         3213,
         3213,
         3213,
         3213,
         3137,
         1438,
         3210,
         1438,
         1450,
         1450,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         1438,
         2823,
         2823,
         1438,
         1438,
         1438,
         1438,
         1438,
         2813,
         1438,
         1438,
         3137,
         3137,
         3137,
         3137,
         1438,
         3138,
         3138,
         3137,
         3137,
         1438,
         3139,
         3139,
         1438,
         1438,
         3137,
         1438,
         3137,
         3138,
         1438,
         3137,
         1438,
         3137,
         3137,
         1438,
         3137,
         1438,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         6,
         6,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         26,
         1454,
         1455,
         1456,
         1457,
         1458,
         1459,
         1460,
         1461,
         2490,
         2491,
         2492,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         14,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         15,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         17,
         1,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         14,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         17,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         27,
         1462,
         1463,
         1464,
         1465,
         1466,
         1467,
         1468,
         1469,
         1470,
         1471,
         1472,
         1473,
         1474,
         2828,
         2829,
         2830,
         3156,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         12,
         5,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         28,
         1746,
         1747,
         1748,
         1749,
         1750,
         1751,
         1752,
         1753,
         1754,
         1755,
         1756,
         3003,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         29,
         2105,
         2106,
         2107,
         2108,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         30,
         1757,
         1758,
         1759,
         2801,
         3045,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         21,
         0,
         0,
         22,
         23,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         26,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         27,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         6,
         6,
         29,
         6,
         6,
         6,
         30,
         31,
         32,
         33,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         0,
         0,
         0,
         17,
         18,
         18,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         27,
         27,
         27,
         27,
         27,
         8,
         8,
         8,
         8,
         26,
         26,
         26,
         26,
         26,
         26,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         26,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         36,
         36,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         14,
         0,
         14,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         4,
         0,
         0,
         14,
         0,
         46,
         0,
         0,
         4,
         0,
         7,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 47,
      .table = (const uint16_t []) {
      
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         32,
         32,
         32,
         442,
         32,
         443,
         444,
         445,
         446,
         447,
         448,
         449,
         450,
         451,
         452,
         453,
         454,
         455,
         456,
         32,
         32,
         32,
         457,
         32,
         457,
         458,
         2175,
         2176,
         2177,
         2178,
         444,
         2179,
         2180,
         2181,
         2182,
         2183,
         2184,
         2185,
         2186,
         32,
         32,
         32,
         32,
         444,
         452,
         445,
         445,
         31,
         32,
         459,
         459,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         442,
         459,
         459,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         460,
         460,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         443,
         31,
         31,
         460,
         460,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         430,
         444,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         31,
         445,
         31,
         31,
         31,
         31,
         461,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         461,
         461,
         461,
         461,
         461,
         461,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         461,
         31,
         31,
         31,
         431,
         446,
         431,
         431,
         431,
         431,
         462,
         431,
         431,
         473,
         474,
         475,
         476,
         477,
         431,
         478,
         479,
         480,
         481,
         431,
         431,
         431,
         431,
         431,
         431,
         482,
         2170,
         2170,
         431,
         462,
         462,
         462,
         462,
         462,
         462,
         2193,
         2194,
         2195,
         2196,
         431,
         431,
         431,
         431,
         462,
         431,
         431,
         431,
         432,
         447,
         432,
         432,
         432,
         432,
         463,
         432,
         473,
         432,
         483,
         484,
         485,
         486,
         432,
         487,
         488,
         489,
         490,
         432,
         432,
         432,
         432,
         432,
         432,
         491,
         2197,
         2198,
         432,
         463,
         463,
         463,
         463,
         463,
         463,
         2199,
         2200,
         2201,
         2202,
         432,
         432,
         432,
         432,
         463,
         432,
         432,
         432,
         433,
         448,
         433,
         433,
         433,
         433,
         464,
         433,
         474,
         483,
         433,
         492,
         493,
         494,
         433,
         495,
         496,
         497,
         498,
         433,
         433,
         433,
         433,
         433,
         433,
         499,
         2203,
         2204,
         433,
         464,
         464,
         464,
         464,
         464,
         464,
         2205,
         2206,
         2207,
         2208,
         433,
         433,
         433,
         433,
         464,
         433,
         433,
         433,
         434,
         449,
         434,
         434,
         434,
         434,
         465,
         434,
         475,
         484,
         492,
         434,
         500,
         501,
         434,
         502,
         503,
         504,
         505,
         434,
         434,
         434,
         434,
         434,
         434,
         506,
         2209,
         2210,
         434,
         465,
         465,
         465,
         465,
         465,
         465,
         2211,
         2212,
         2213,
         2214,
         434,
         434,
         434,
         434,
         465,
         434,
         434,
         434,
         435,
         450,
         435,
         435,
         435,
         435,
         466,
         435,
         476,
         485,
         493,
         500,
         435,
         507,
         435,
         508,
         509,
         510,
         511,
         435,
         435,
         435,
         435,
         435,
         435,
         512,
         2215,
         2216,
         435,
         466,
         466,
         466,
         466,
         466,
         466,
         2217,
         2218,
         2219,
         2220,
         435,
         435,
         435,
         435,
         466,
         435,
         435,
         435,
         436,
         451,
         436,
         436,
         436,
         436,
         467,
         436,
         477,
         486,
         494,
         501,
         507,
         436,
         436,
         513,
         514,
         515,
         516,
         436,
         436,
         436,
         436,
         436,
         436,
         517,
         2221,
         2222,
         436,
         467,
         467,
         467,
         467,
         467,
         467,
         2223,
         2224,
         2225,
         2226,
         436,
         436,
         436,
         436,
         467,
         436,
         436,
         436,
         31,
         452,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         437,
         453,
         437,
         437,
         437,
         437,
         468,
         437,
         478,
         487,
         495,
         502,
         508,
         513,
         437,
         437,
         518,
         519,
         520,
         437,
         437,
         437,
         437,
         437,
         437,
         521,
         2227,
         2228,
         437,
         468,
         2229,
         468,
         468,
         468,
         468,
         2230,
         2231,
         2232,
         2233,
         437,
         437,
         437,
         437,
         468,
         437,
         437,
         437,
         438,
         454,
         438,
         438,
         438,
         438,
         469,
         438,
         479,
         488,
         496,
         503,
         509,
         514,
         438,
         518,
         438,
         522,
         523,
         438,
         438,
         438,
         438,
         438,
         438,
         524,
         2234,
         2235,
         438,
         469,
         469,
         469,
         469,
         469,
         469,
         2236,
         2237,
         2238,
         2239,
         438,
         438,
         438,
         438,
         469,
         438,
         438,
         438,
         439,
         455,
         439,
         439,
         439,
         439,
         470,
         439,
         480,
         489,
         497,
         504,
         510,
         515,
         439,
         519,
         522,
         439,
         525,
         439,
         439,
         439,
         439,
         439,
         439,
         526,
         2240,
         2241,
         439,
         470,
         470,
         470,
         470,
         470,
         470,
         2242,
         2243,
         2244,
         2245,
         439,
         439,
         439,
         439,
         470,
         439,
         439,
         439,
         440,
         456,
         440,
         440,
         440,
         440,
         471,
         440,
         481,
         490,
         498,
         505,
         511,
         516,
         440,
         520,
         523,
         525,
         440,
         440,
         440,
         440,
         440,
         440,
         440,
         527,
         2246,
         2247,
         440,
         471,
         471,
         471,
         471,
         471,
         471,
         2248,
         2249,
         2250,
         2251,
         440,
         440,
         440,
         440,
         471,
         440,
         440,
         440,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         528,
         528,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         528,
         31,
         528,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         528,
         528,
         528,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         457,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         529,
         529,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         529,
         31,
         529,
         441,
         2169,
         2170,
         529,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         31,
         457,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         529,
         529,
         529,
         441,
         2169,
         2170,
         529,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         441,
         458,
         441,
         441,
         441,
         441,
         472,
         441,
         482,
         491,
         499,
         506,
         512,
         517,
         441,
         521,
         524,
         526,
         527,
         441,
         441,
         441,
         441,
         441,
         441,
         441,
         2252,
         2253,
         441,
         472,
         472,
         472,
         472,
         472,
         472,
         2254,
         2255,
         2256,
         2257,
         441,
         441,
         441,
         441,
         472,
         441,
         441,
         441,
         2169,
         2175,
         2169,
         2169,
         2169,
         2169,
         2187,
         2169,
         2170,
         2197,
         2203,
         2209,
         2215,
         2221,
         2169,
         2227,
         2234,
         2240,
         2246,
         2169,
         2169,
         2169,
         2169,
         2169,
         2169,
         2252,
         2169,
         2170,
         2169,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2258,
         2259,
         2260,
         2261,
         2169,
         2169,
         2169,
         2169,
         2187,
         2169,
         2169,
         2169,
         2170,
         2176,
         2170,
         2170,
         2170,
         2170,
         2188,
         2170,
         2170,
         2198,
         2204,
         2210,
         2216,
         2222,
         2170,
         2228,
         2235,
         2241,
         2247,
         2170,
         2170,
         2170,
         2170,
         2170,
         2170,
         2253,
         2170,
         2170,
         2170,
         2188,
         2188,
         2188,
         2188,
         2188,
         2188,
         2262,
         2263,
         2264,
         2265,
         2170,
         2170,
         2170,
         2170,
         2188,
         2170,
         2170,
         2170,
         31,
         2177,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         529,
         529,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         31,
         31,
         31,
         430,
         2178,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         430,
         444,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         2229,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         430,
         2179,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         430,
         2180,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         430,
         2181,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         430,
         2182,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         430,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         2171,
         2183,
         2171,
         2171,
         2171,
         2171,
         2189,
         2171,
         2193,
         2199,
         2205,
         2211,
         2217,
         2223,
         2171,
         2230,
         2236,
         2242,
         2248,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2254,
         2258,
         2262,
         2171,
         2189,
         2189,
         2189,
         2189,
         2189,
         2189,
         2171,
         2266,
         2267,
         2268,
         2171,
         2171,
         2171,
         2171,
         2189,
         2171,
         2171,
         2171,
         2172,
         2184,
         2172,
         2172,
         2172,
         2172,
         2190,
         2172,
         2194,
         2200,
         2206,
         2212,
         2218,
         2224,
         2172,
         2231,
         2237,
         2243,
         2249,
         2172,
         2172,
         2172,
         2172,
         2172,
         2172,
         2255,
         2259,
         2263,
         2172,
         2190,
         2190,
         2190,
         2190,
         2190,
         2190,
         2266,
         2172,
         2269,
         2270,
         2172,
         2172,
         2172,
         2172,
         2190,
         2172,
         2172,
         2172,
         2173,
         2185,
         2173,
         2173,
         2173,
         2173,
         2191,
         2173,
         2195,
         2201,
         2207,
         2213,
         2219,
         2225,
         2173,
         2232,
         2238,
         2244,
         2250,
         2173,
         2173,
         2173,
         2173,
         2173,
         2173,
         2256,
         2260,
         2264,
         2173,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2267,
         2269,
         2173,
         2271,
         2173,
         2173,
         2173,
         2173,
         2191,
         2173,
         2173,
         2173,
         2174,
         2186,
         2174,
         2174,
         2174,
         2174,
         2192,
         2174,
         2196,
         2202,
         2208,
         2214,
         2220,
         2226,
         2174,
         2233,
         2239,
         2245,
         2251,
         2174,
         2174,
         2174,
         2174,
         2174,
         2174,
         2257,
         2261,
         2265,
         2174,
         2192,
         2192,
         2192,
         2192,
         2192,
         2192,
         2268,
         2270,
         2271,
         2174,
         2174,
         2174,
         2174,
         2174,
         2192,
         2174,
         2174,
         2174,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         3197,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         2272,
         2272,
         430,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         2272,
         31,
         2272,
         430,
         31,
         31,
         31,
         31,
         32,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         2272,
         2272,
         2272,
         430,
         31,
         31,
         31,
         430,
         444,
         430,
         430,
         430,
         430,
         430,
         461,
         462,
         463,
         464,
         465,
         466,
         467,
         430,
         468,
         469,
         470,
         471,
         430,
         430,
         430,
         430,
         430,
         430,
         472,
         2187,
         2188,
         430,
         430,
         430,
         430,
         430,
         430,
         430,
         2189,
         2190,
         2191,
         2192,
         3197,
         430,
         430,
         430,
         430,
         430,
         461,
         461,
         31,
         452,
         31,
         31,
         31,
         31,
         430,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         430,
         430,
         430,
         430,
         430,
         430,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         430,
         3233,
         3239,
         3244,
         31,
         445,
         31,
         31,
         31,
         31,
         461,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         461,
         461,
         461,
         461,
         461,
         461,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         461,
         3239,
         31,
         31,
         31,
         445,
         31,
         31,
         31,
         31,
         461,
         31,
         431,
         432,
         433,
         434,
         435,
         436,
         31,
         437,
         438,
         439,
         440,
         31,
         31,
         31,
         31,
         31,
         31,
         441,
         2169,
         2170,
         31,
         461,
         461,
         461,
         461,
         461,
         461,
         2171,
         2172,
         2173,
         2174,
         31,
         31,
         31,
         31,
         461,
         3244,
         31,
         31,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         33,
         34,
         34,
         34,
      },
   },
   [nir_op_isub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         35,
         36,
         35,
         36,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         37,
         38,
         38,
         38,
      },
   },
   [nir_op_usub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         39,
         40,
         39,
         40,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         41,
         41,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         42,
         43,
         1717,
         42,
         42,
         42,
         1718,
         42,
         43,
         43,
         1719,
         1720,
         1721,
         1722,
         1723,
         43,
         1717,
         1719,
         1717,
         1717,
         1717,
         1717,
         1724,
         1717,
         42,
         1720,
         1717,
         42,
         42,
         42,
         1718,
         42,
         42,
         1721,
         1717,
         42,
         42,
         42,
         1718,
         42,
         42,
         1722,
         1717,
         42,
         42,
         42,
         1718,
         42,
         1718,
         1723,
         1724,
         1718,
         1718,
         1718,
         1718,
         1718,
         42,
         43,
         1717,
         42,
         42,
         42,
         1718,
         1725,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         12,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         13,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         14,
         3,
         2,
         2,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         13,
         2,
         13,
         2,
         2,
         13,
         13,
         2,
         0,
         15,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         7,
         7,
         7,
         7,
         7,
         17,
         17,
         17,
         17,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         17,
         17,
         17,
         17,
         7,
         7,
         7,
         7,
         17,
         17,
         17,
         17,
         17,
         18,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         13,
         13,
         13,
         13,
         13,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         18,
         17,
         17,
         17,
         17,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         17,
         17,
         17,
         17,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         15,
         15,
         15,
         15,
         20,
         15,
         15,
         15,
         0,
         15,
         0,
         15,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         13,
         13,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         7,
         7,
         7,
         17,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         48,
         49,
         1484,
         1484,
         48,
         48,
         48,
         1485,
         48,
         48,
         48,
         48,
         48,
         1484,
         1484,
         48,
         48,
         1485,
         1485,
         48,
         48,
         1486,
         1487,
         1488,
         1488,
         1486,
         1486,
         1486,
         1489,
         1486,
         1486,
         1486,
         1486,
         1486,
         1488,
         1488,
         1486,
         1486,
         1489,
         1489,
         1486,
         1486,
         1490,
         1491,
         1492,
         1492,
         1490,
         1490,
         1490,
         1493,
         1490,
         1490,
         1490,
         1490,
         1490,
         1492,
         1492,
         1490,
         1490,
         1493,
         1493,
         1490,
         1490,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         1494,
         1495,
         1496,
         1496,
         1494,
         1494,
         1494,
         1497,
         1494,
         1494,
         1494,
         1494,
         1494,
         1496,
         1496,
         1494,
         1494,
         1497,
         1497,
         1494,
         1494,
         1498,
         1499,
         1500,
         1500,
         1498,
         1498,
         1498,
         1501,
         1498,
         1498,
         1498,
         1498,
         1498,
         1500,
         1500,
         1498,
         1498,
         1501,
         1501,
         1498,
         1498,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         2576,
         46,
         46,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         2577,
         2578,
         2579,
         2579,
         2577,
         2577,
         2577,
         2580,
         2577,
         2577,
         2577,
         2577,
         2577,
         2579,
         2579,
         2577,
         2577,
         2580,
         2580,
         2577,
         2577,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         1486,
         1487,
         1488,
         1488,
         1486,
         1486,
         1486,
         1489,
         1486,
         1486,
         1486,
         1486,
         1486,
         1488,
         1488,
         1486,
         1486,
         1489,
         1489,
         1486,
         1486,
         1490,
         1491,
         1492,
         1492,
         1490,
         1490,
         1490,
         1493,
         1490,
         1490,
         1490,
         1490,
         1490,
         1492,
         1492,
         1490,
         1490,
         1493,
         1493,
         1490,
         1490,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         1494,
         1495,
         1496,
         1496,
         1494,
         1494,
         1494,
         1497,
         1494,
         1494,
         1494,
         1494,
         1494,
         1496,
         1496,
         1494,
         1494,
         1497,
         1497,
         1494,
         1494,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         3082,
         3082,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1486,
         1487,
         1488,
         1488,
         1486,
         1486,
         1486,
         1489,
         1486,
         1486,
         1486,
         1486,
         1486,
         1488,
         1488,
         1486,
         1486,
         1489,
         1489,
         1486,
         1486,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1490,
         1491,
         1492,
         1492,
         1490,
         1490,
         1490,
         1493,
         1490,
         1490,
         1490,
         1490,
         1490,
         1492,
         1492,
         1490,
         1490,
         1493,
         1493,
         1490,
         1490,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2582,
         2583,
         2584,
         2584,
         2582,
         2582,
         2582,
         2585,
         2582,
         2582,
         2582,
         2582,
         2582,
         2584,
         2584,
         2582,
         2582,
         2585,
         2585,
         2582,
         2582,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1494,
         1495,
         1496,
         1496,
         1494,
         1494,
         1494,
         1497,
         1494,
         1494,
         1494,
         1494,
         1494,
         1496,
         1496,
         1494,
         1494,
         1497,
         1497,
         1494,
         1494,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1503,
         1504,
         1505,
         1505,
         1503,
         1503,
         1503,
         1506,
         1503,
         1503,
         1503,
         1503,
         1503,
         1505,
         1505,
         1503,
         1503,
         1506,
         1506,
         1503,
         1503,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1507,
         1508,
         1509,
         1509,
         1507,
         1507,
         1507,
         1510,
         1507,
         1507,
         1507,
         1507,
         1507,
         1509,
         1509,
         1507,
         1507,
         1510,
         2586,
         1507,
         1507,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         2587,
         2588,
         2589,
         2589,
         2587,
         2587,
         2587,
         2590,
         2587,
         2587,
         2587,
         2587,
         2587,
         2589,
         2589,
         2587,
         2587,
         2590,
         2590,
         2587,
         2587,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1503,
         1504,
         1505,
         1505,
         1503,
         1503,
         1503,
         1506,
         1503,
         1503,
         1503,
         1503,
         1503,
         1505,
         1505,
         1503,
         1503,
         1506,
         1506,
         1503,
         1503,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         3084,
         3084,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1498,
         1499,
         1500,
         1500,
         1498,
         1498,
         1498,
         1501,
         1498,
         1498,
         1498,
         1498,
         1498,
         1500,
         1500,
         1498,
         1498,
         1501,
         1501,
         1498,
         1498,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         2576,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         1507,
         1508,
         1509,
         1509,
         1507,
         1507,
         1507,
         1510,
         1507,
         1507,
         1507,
         1507,
         1507,
         1509,
         1509,
         1507,
         1507,
         1510,
         2586,
         1507,
         1507,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2591,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         2592,
         2593,
         2594,
         2594,
         2592,
         2592,
         2592,
         2595,
         2592,
         2592,
         2592,
         2592,
         2592,
         2594,
         2594,
         2592,
         2592,
         2595,
         2596,
         2592,
         2592,
         1507,
         1508,
         1509,
         1509,
         1507,
         1507,
         1507,
         1510,
         1507,
         1507,
         1507,
         1507,
         1507,
         1509,
         1509,
         1507,
         1507,
         1510,
         2586,
         1507,
         1507,
         44,
         45,
         2597,
         2597,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         2597,
         2597,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         2597,
         2597,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         2597,
         2597,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         2592,
         2593,
         2594,
         2594,
         2592,
         2592,
         2592,
         2595,
         2592,
         2592,
         2592,
         2592,
         2592,
         3085,
         3085,
         2592,
         2592,
         2595,
         2596,
         2592,
         2592,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         2598,
         2599,
         2600,
         2600,
         2598,
         2598,
         2598,
         2601,
         2598,
         2598,
         2598,
         2598,
         2598,
         2600,
         2600,
         2598,
         2598,
         2601,
         2601,
         2598,
         2598,
         2602,
         2603,
         2604,
         2604,
         2602,
         2602,
         2602,
         2605,
         2602,
         2602,
         2602,
         2602,
         2602,
         2604,
         2604,
         2602,
         2602,
         2605,
         2605,
         2602,
         2602,
         2606,
         2607,
         2608,
         2608,
         2606,
         2606,
         2606,
         2609,
         2606,
         2606,
         2606,
         2606,
         2606,
         2608,
         2608,
         2606,
         2606,
         2609,
         2609,
         2606,
         2606,
         2610,
         2611,
         2612,
         2612,
         2610,
         2610,
         2610,
         2613,
         2610,
         2610,
         2610,
         2610,
         2610,
         2612,
         2612,
         2610,
         2610,
         2613,
         2613,
         2610,
         2610,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         3086,
         3087,
         3088,
         3088,
         3086,
         3086,
         3086,
         3089,
         3086,
         3086,
         3086,
         3086,
         3086,
         3088,
         3088,
         3086,
         3086,
         3089,
         3089,
         3086,
         3086,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2577,
         2578,
         2579,
         2579,
         2577,
         2577,
         2577,
         2580,
         2577,
         2577,
         2577,
         2577,
         2577,
         2579,
         2579,
         2577,
         2577,
         2580,
         2580,
         2577,
         2577,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2582,
         2583,
         2584,
         2584,
         2582,
         2582,
         2582,
         2585,
         2582,
         2582,
         2582,
         2582,
         2582,
         2584,
         2584,
         2582,
         2582,
         2585,
         2585,
         2582,
         2582,
         2587,
         2588,
         2589,
         2589,
         2587,
         2587,
         2587,
         2590,
         2587,
         2587,
         2587,
         2587,
         2587,
         2589,
         2589,
         2587,
         2587,
         2590,
         2590,
         2587,
         2587,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2591,
         2572,
         2572,
         2602,
         2603,
         2604,
         2604,
         2602,
         2602,
         2602,
         2605,
         2602,
         2602,
         2602,
         2602,
         2602,
         2604,
         2604,
         2602,
         2602,
         2605,
         2605,
         2602,
         2602,
         2602,
         2603,
         2604,
         2604,
         2602,
         2602,
         2602,
         2605,
         2602,
         2602,
         2602,
         2602,
         2602,
         2604,
         2604,
         2602,
         2602,
         2605,
         2605,
         2602,
         2602,
         2614,
         2615,
         2616,
         2616,
         2614,
         2614,
         2614,
         2617,
         2614,
         2614,
         2614,
         2614,
         2614,
         2616,
         2616,
         2614,
         2614,
         2617,
         2617,
         2614,
         2614,
         2618,
         2619,
         2620,
         2620,
         2618,
         2618,
         2618,
         2621,
         2618,
         2618,
         2618,
         2618,
         2618,
         2620,
         2620,
         2618,
         2618,
         2621,
         2621,
         2618,
         2618,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2622,
         2623,
         2624,
         2624,
         2622,
         2622,
         2622,
         2625,
         2622,
         2622,
         2622,
         2622,
         2622,
         2624,
         2624,
         2622,
         2622,
         2625,
         2625,
         2622,
         2622,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         3090,
         3091,
         3092,
         3092,
         3090,
         3090,
         3090,
         3093,
         3090,
         3090,
         3090,
         3090,
         3090,
         3092,
         3092,
         3090,
         3090,
         3093,
         3093,
         3090,
         3090,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         3094,
         3094,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         2606,
         2607,
         2608,
         2608,
         2606,
         2606,
         2606,
         2609,
         2606,
         2606,
         2606,
         2606,
         2606,
         2608,
         2608,
         2606,
         2606,
         2609,
         2609,
         2606,
         2606,
         2614,
         2615,
         2616,
         2616,
         2614,
         2614,
         2614,
         2617,
         2614,
         2614,
         2614,
         2614,
         2614,
         2616,
         2616,
         2614,
         2614,
         2617,
         2617,
         2614,
         2614,
         2626,
         2627,
         2628,
         2628,
         2626,
         2626,
         2626,
         2629,
         2626,
         2626,
         2626,
         2626,
         2626,
         2628,
         2628,
         2626,
         2626,
         2629,
         2629,
         2626,
         2626,
         2630,
         2631,
         2632,
         2632,
         2630,
         2630,
         2630,
         2633,
         2630,
         2630,
         2630,
         2630,
         2630,
         2632,
         2632,
         2630,
         2630,
         2633,
         2633,
         2630,
         2630,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         3095,
         3096,
         3097,
         3097,
         3095,
         3095,
         3095,
         3098,
         3095,
         3095,
         3095,
         3095,
         3095,
         3097,
         3097,
         3095,
         3095,
         3098,
         3098,
         3095,
         3095,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         2610,
         2611,
         2612,
         2612,
         2610,
         2610,
         2610,
         2613,
         2610,
         2610,
         2610,
         2610,
         2610,
         2612,
         2612,
         2610,
         2610,
         2613,
         2613,
         2610,
         2610,
         2618,
         2619,
         2620,
         2620,
         2618,
         2618,
         2618,
         2621,
         2618,
         2618,
         2618,
         2618,
         2618,
         2620,
         2620,
         2618,
         2618,
         2621,
         2621,
         2618,
         2618,
         2630,
         2631,
         2632,
         2632,
         2630,
         2630,
         2630,
         2633,
         2630,
         2630,
         2630,
         2630,
         2630,
         2632,
         2632,
         2630,
         2630,
         2633,
         2633,
         2630,
         2630,
         2634,
         2635,
         2636,
         2636,
         2634,
         2634,
         2634,
         2637,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2636,
         2634,
         2634,
         2637,
         2637,
         2634,
         2634,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         3099,
         3100,
         3101,
         3101,
         3099,
         3099,
         3099,
         3102,
         3099,
         3099,
         3099,
         3099,
         3099,
         3101,
         3101,
         3099,
         3099,
         3102,
         3102,
         3099,
         3099,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1486,
         1487,
         1488,
         1488,
         1486,
         1486,
         1486,
         1489,
         1486,
         1486,
         1486,
         1486,
         1486,
         1488,
         1488,
         1486,
         1486,
         1489,
         1489,
         1486,
         1486,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1490,
         1491,
         1492,
         1492,
         1490,
         1490,
         1490,
         1493,
         1490,
         1490,
         1490,
         1490,
         1490,
         1492,
         1492,
         1490,
         1490,
         1493,
         1493,
         1490,
         1490,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2581,
         2581,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2581,
         2581,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2592,
         2593,
         2594,
         2594,
         2592,
         2592,
         2592,
         2595,
         2592,
         2592,
         2592,
         2592,
         2592,
         2594,
         2594,
         2592,
         2592,
         2595,
         2596,
         2592,
         2592,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1494,
         1495,
         1496,
         1496,
         1494,
         1494,
         1494,
         1497,
         1494,
         1494,
         1494,
         1494,
         1494,
         1496,
         1496,
         1494,
         1494,
         1497,
         1497,
         1494,
         1494,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1503,
         1504,
         1505,
         1505,
         1503,
         1503,
         1503,
         1506,
         1503,
         1503,
         1503,
         1503,
         1503,
         1505,
         1505,
         1503,
         1503,
         1506,
         1506,
         1503,
         1503,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1507,
         1508,
         1509,
         1509,
         1507,
         1507,
         1507,
         1510,
         1507,
         1507,
         1507,
         1507,
         1507,
         1509,
         1509,
         1507,
         1507,
         1510,
         2586,
         1507,
         1507,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         2622,
         2623,
         2624,
         2624,
         2622,
         2622,
         2622,
         2625,
         2622,
         2622,
         2622,
         2622,
         2622,
         2624,
         2624,
         2622,
         2622,
         2625,
         2625,
         2622,
         2622,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1502,
         1502,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1502,
         1502,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1503,
         1504,
         1505,
         1505,
         1503,
         1503,
         1503,
         1506,
         1503,
         1503,
         1503,
         1503,
         1503,
         1505,
         1505,
         1503,
         1503,
         1506,
         1506,
         1503,
         1503,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         3084,
         3084,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         2597,
         2597,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         2597,
         2597,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         2597,
         2597,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         2597,
         2597,
         44,
         44,
         1476,
         2571,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         2574,
         2574,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         1477,
         1477,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         2571,
         44,
         44,
         3086,
         3087,
         3088,
         3088,
         3086,
         3086,
         3086,
         3089,
         3086,
         3086,
         3086,
         3086,
         3086,
         3088,
         3088,
         3086,
         3086,
         3089,
         3089,
         3086,
         3086,
         3090,
         3091,
         3092,
         3092,
         3090,
         3090,
         3090,
         3093,
         3090,
         3090,
         3090,
         3090,
         3090,
         3092,
         3092,
         3090,
         3090,
         3093,
         3093,
         3090,
         3090,
         3095,
         3096,
         3097,
         3097,
         3095,
         3095,
         3095,
         3098,
         3095,
         3095,
         3095,
         3095,
         3095,
         3097,
         3097,
         3095,
         3095,
         3098,
         3098,
         3095,
         3095,
         3099,
         3100,
         3101,
         3101,
         3099,
         3099,
         3099,
         3102,
         3099,
         3099,
         3099,
         3099,
         3099,
         3101,
         3101,
         3099,
         3099,
         3102,
         3102,
         3099,
         3099,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1479,
         1479,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         1482,
         1482,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         1475,
         1475,
         44,
         44,
         1476,
         1476,
         44,
         44,
         3103,
         3104,
         3105,
         3105,
         3103,
         3103,
         3103,
         3106,
         3103,
         3103,
         3103,
         3103,
         3103,
         3105,
         3105,
         3103,
         3103,
         3106,
         3106,
         3103,
         3103,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         46,
         47,
         1477,
         1477,
         46,
         46,
         46,
         1478,
         46,
         46,
         46,
         46,
         46,
         3082,
         3082,
         46,
         46,
         1478,
         1478,
         46,
         46,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         3084,
         3084,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2592,
         2593,
         2594,
         2594,
         2592,
         2592,
         2592,
         2595,
         2592,
         2592,
         2592,
         2592,
         2592,
         3085,
         3085,
         2592,
         2592,
         2595,
         2596,
         2592,
         2592,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         2572,
         2573,
         2574,
         2574,
         2572,
         2572,
         2572,
         2575,
         2572,
         2572,
         2572,
         2572,
         2572,
         3094,
         3094,
         2572,
         2572,
         2575,
         2575,
         2572,
         2572,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1479,
         1479,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3083,
         3083,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         1480,
         1481,
         1482,
         1482,
         1480,
         1480,
         1480,
         1483,
         1480,
         1480,
         1480,
         1480,
         1480,
         3084,
         3084,
         1480,
         1480,
         1483,
         1483,
         1480,
         1480,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
         44,
         45,
         1475,
         1475,
         44,
         44,
         44,
         1476,
         44,
         44,
         44,
         44,
         44,
         3081,
         3081,
         44,
         44,
         1476,
         1476,
         44,
         44,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         50,
         51,
         50,
         1726,
         1726,
         1727,
         52,
         53,
         52,
         1728,
         1728,
         1729,
         50,
         51,
         50,
         1726,
         1726,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1726,
         1726,
         1727,
         52,
         53,
         52,
         1728,
         1728,
         1729,
         54,
         55,
         54,
         1731,
         1731,
         1732,
         52,
         53,
         52,
         1728,
         1728,
         1729,
         1733,
         1734,
         1733,
         1735,
         1735,
         1736,
         1737,
         1738,
         1737,
         1739,
         1739,
         1740,
         52,
         53,
         52,
         1728,
         1728,
         1729,
         50,
         51,
         50,
         1726,
         1726,
         1727,
         52,
         53,
         52,
         1728,
         1728,
         1729,
         1741,
         1742,
         1741,
         1743,
         1743,
         1744,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1726,
         1726,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         1733,
         1734,
         1733,
         1735,
         1735,
         1736,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         1737,
         1738,
         1737,
         1739,
         1739,
         1740,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1726,
         1726,
         1727,
         52,
         53,
         52,
         1728,
         1728,
         1729,
         50,
         51,
         50,
         1726,
         1726,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1730,
         1730,
         1727,
         50,
         51,
         50,
         1726,
         1726,
         1727,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         32,
         33,
         34,
         34,
         34,
         34,
         35,
         35,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         42,
         43,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         46,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         46,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         47,
         9,
         9,
         9,
         9,
         9,
         46,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         46,
         9,
         9,
         9,
         9,
         9,
         9,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         15,
         14,
         14,
         15,
         15,
         15,
         19,
         19,
         20,
         19,
         20,
         19,
         20,
         20,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         40,
         40,
         40,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         22,
         22,
         22,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         22,
         23,
         22,
         22,
         22,
         23,
         23,
         22,
         23,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         22,
         26,
         26,
         26,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         26,
         27,
         26,
         26,
         26,
         27,
         27,
         26,
         27,
         27,
         27,
         26,
         27,
         26,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         26,
         26,
         30,
         30,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         30,
         30,
         30,
         30,
         30,
         12,
         12,
         48,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         49,
         0,
         0,
         0,
         0,
         50,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         51,
         11,
         11,
         11,
         11,
         11,
         11,
         52,
         53,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         54,
         55,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         0,
         0,
         0,
         42,
         44,
         44,
         44,
         44,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         21,
         21,
         21,
         58,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         32,
         33,
         32,
         32,
         33,
         32,
         33,
         32,
         32,
         33,
         33,
         32,
         33,
         32,
         33,
         32,
         33,
         32,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         59,
         4,
         14,
         14,
         14,
         14,
         14,
         14,
         60,
         15,
         15,
         0,
         0,
         0,
         17,
         17,
         17,
         17,
         17,
         16,
         16,
         31,
         31,
         31,
         31,
         31,
         30,
         30,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         46,
         46,
         46,
         46,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         61,
         11,
         21,
         21,
         21,
         21,
         21,
         21,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         27,
         27,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         12,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         38,
         55,
         55,
         57,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         62,
         63,
         64,
         4,
         4,
         15,
         65,
         0,
         17,
         31,
         23,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         66,
         23,
         23,
         23,
         0,
         0,
         5,
         7,
         7,
         7,
         7,
         0,
         0,
         67,
         68,
         8,
         0,
         0,
         0,
         8,
         8,
         4,
         15,
         0,
         9,
         69,
         70,
         71,
         8,
         8,
         8,
         4,
         15,
         9,
         72,
         73,
         74,
         8,
         8,
         8,
         4,
         15,
         9,
         72,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         57,
         57,
         1144,
         57,
         1145,
         57,
         1146,
         1147,
         1148,
         1149,
         57,
         57,
         57,
         57,
         57,
         1150,
         57,
         57,
         1151,
         57,
         57,
         1152,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1153,
         57,
         1154,
         57,
         1155,
         57,
         1156,
         1157,
         2715,
         2716,
         57,
         2717,
         2718,
         2719,
         57,
         57,
         2720,
         2721,
         2722,
         2723,
         2724,
         3113,
         3114,
         57,
         1152,
         1152,
         1152,
         57,
         3236,
         3240,
         3241,
         3249,
         3250,
         3251,
         3258,
         3259,
         3260,
         56,
         1144,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         1158,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         1158,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         56,
         1145,
         56,
         1158,
         1158,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         1158,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         2725,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         1146,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1137,
         1147,
         1137,
         1137,
         1137,
         1137,
         1137,
         1159,
         1159,
         1160,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1161,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1162,
         1137,
         1163,
         1137,
         1164,
         1137,
         1165,
         1137,
         2726,
         1160,
         1137,
         1137,
         1137,
         2727,
         1137,
         1137,
         2728,
         2729,
         2730,
         2731,
         2732,
         1137,
         1137,
         1137,
         1161,
         1161,
         1161,
         1137,
         1160,
         1137,
         1137,
         1160,
         1137,
         1137,
         1160,
         1137,
         1137,
         1137,
         1148,
         1137,
         1137,
         1137,
         1137,
         1137,
         1159,
         1159,
         1160,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1166,
         1137,
         1137,
         1161,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1137,
         1162,
         1137,
         1163,
         1137,
         1164,
         1137,
         1165,
         1137,
         2726,
         1160,
         1137,
         1137,
         1137,
         2727,
         1137,
         1137,
         2728,
         2729,
         2730,
         2731,
         2732,
         1137,
         1137,
         1137,
         1161,
         1161,
         1161,
         1137,
         1160,
         1137,
         1137,
         1160,
         1137,
         1137,
         1160,
         1137,
         1137,
         1138,
         1149,
         1138,
         1138,
         1138,
         1138,
         1138,
         1160,
         1160,
         1167,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1168,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1169,
         1138,
         1170,
         1138,
         1171,
         1138,
         1172,
         1138,
         2733,
         1167,
         1138,
         1138,
         1138,
         2734,
         1138,
         1138,
         2735,
         2736,
         2737,
         2738,
         2739,
         1138,
         1138,
         1138,
         1168,
         1168,
         1168,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         1173,
         1173,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         1173,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         1174,
         1173,
         1173,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         1173,
         56,
         56,
         2740,
         1174,
         1174,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         1174,
         1139,
         1139,
         1139,
         1174,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         1173,
         1173,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2741,
         1173,
         1173,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         1173,
         1139,
         1139,
         1139,
         1173,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         1173,
         1173,
         56,
         1175,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         1175,
         56,
         56,
         2741,
         1173,
         1173,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         3115,
         1139,
         1139,
         1139,
         3115,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         1176,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         1176,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         56,
         1150,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         1176,
         1176,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         1176,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1177,
         1177,
         56,
         56,
         56,
         1139,
         1178,
         1178,
         1178,
         1178,
         1179,
         1179,
         1179,
         1179,
         1180,
         1180,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1177,
         1181,
         56,
         56,
         56,
         1139,
         1178,
         1178,
         1178,
         1178,
         1179,
         1179,
         1179,
         1179,
         1180,
         1180,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         1151,
         56,
         56,
         56,
         56,
         56,
         1137,
         1166,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1182,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1183,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1183,
         1183,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1139,
         1152,
         1139,
         1139,
         1139,
         1139,
         1139,
         1161,
         1161,
         1168,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1184,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1185,
         1139,
         1186,
         1139,
         1187,
         1139,
         1188,
         1139,
         2742,
         1168,
         1139,
         1139,
         1139,
         2743,
         1139,
         1139,
         2744,
         2745,
         2746,
         2747,
         2748,
         1139,
         1139,
         1139,
         1184,
         1184,
         1184,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1178,
         1178,
         56,
         56,
         56,
         1139,
         1189,
         1189,
         1189,
         1189,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1178,
         1178,
         56,
         56,
         56,
         1139,
         1189,
         1190,
         1191,
         1192,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1178,
         1178,
         56,
         56,
         56,
         1139,
         1189,
         1191,
         1193,
         1194,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1178,
         1178,
         56,
         56,
         56,
         1139,
         1189,
         1192,
         1194,
         1195,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1179,
         1179,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         1196,
         1196,
         1196,
         1196,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1179,
         1179,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         1196,
         1197,
         1198,
         1199,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1179,
         1179,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         1196,
         1198,
         1200,
         1201,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1179,
         1179,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         1196,
         1199,
         1201,
         1202,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1180,
         1180,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1203,
         1203,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         1180,
         1180,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1203,
         1204,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1205,
         1205,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1205,
         1205,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         3228,
         3229,
         3230,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1206,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1207,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1208,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1209,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1140,
         1153,
         1140,
         1140,
         1140,
         1140,
         1140,
         1162,
         1162,
         1169,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1185,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1209,
         1209,
         1140,
         1210,
         1140,
         1211,
         1140,
         1212,
         1140,
         2749,
         1169,
         1140,
         1140,
         1140,
         2750,
         1140,
         1140,
         2751,
         2752,
         2753,
         2754,
         2755,
         1140,
         1140,
         1140,
         1185,
         1185,
         1185,
         1140,
         1169,
         1140,
         1140,
         1169,
         1140,
         1140,
         1169,
         1140,
         1140,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1213,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1141,
         1154,
         1141,
         1141,
         1141,
         1141,
         1141,
         1163,
         1163,
         1170,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1186,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1210,
         1213,
         1213,
         1141,
         1214,
         1141,
         1215,
         1141,
         2756,
         1170,
         1141,
         1141,
         1141,
         2757,
         1141,
         1141,
         2758,
         2759,
         2760,
         2761,
         2762,
         1141,
         1141,
         1141,
         1186,
         1186,
         1186,
         1141,
         1170,
         1141,
         1141,
         1170,
         1141,
         1141,
         1170,
         1141,
         1141,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1216,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1142,
         1155,
         1142,
         1142,
         1142,
         1142,
         1142,
         1164,
         1164,
         1171,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1187,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1142,
         1211,
         1142,
         1214,
         1216,
         1216,
         1142,
         1217,
         1142,
         2763,
         1171,
         1142,
         1142,
         1142,
         2764,
         1142,
         1142,
         2765,
         2766,
         2767,
         2768,
         2769,
         1142,
         1142,
         1142,
         1187,
         1187,
         1187,
         1142,
         1171,
         1142,
         1142,
         1171,
         1142,
         1142,
         1171,
         1142,
         1142,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1218,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1143,
         1156,
         1143,
         1143,
         1143,
         1143,
         1143,
         1165,
         1165,
         1172,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1188,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1212,
         1143,
         1215,
         1143,
         1217,
         1218,
         1218,
         1143,
         2770,
         1172,
         1143,
         1143,
         1143,
         2771,
         1143,
         1143,
         2772,
         2773,
         2774,
         2775,
         2776,
         1143,
         1143,
         1143,
         1188,
         1188,
         1188,
         1143,
         1172,
         1143,
         1143,
         1172,
         1143,
         1143,
         1172,
         1143,
         1143,
         56,
         1157,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         2708,
         2715,
         2708,
         2708,
         2708,
         2708,
         2708,
         2726,
         2726,
         2733,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2742,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2708,
         2749,
         2708,
         2756,
         2708,
         2763,
         2708,
         2770,
         2708,
         2733,
         2733,
         2708,
         2708,
         2708,
         2777,
         2708,
         2708,
         2778,
         2779,
         2780,
         2781,
         2782,
         2708,
         2708,
         2708,
         2742,
         2742,
         2742,
         2708,
         2733,
         2708,
         2708,
         2733,
         2708,
         2708,
         2733,
         2708,
         2708,
         1138,
         2716,
         1138,
         1138,
         1138,
         1138,
         1138,
         1160,
         1160,
         1167,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1168,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1169,
         1138,
         1170,
         1138,
         1171,
         1138,
         1172,
         1138,
         2733,
         1167,
         1138,
         1138,
         1138,
         2734,
         1138,
         1138,
         2735,
         2736,
         2737,
         2738,
         2739,
         1138,
         1138,
         1138,
         1168,
         1168,
         1168,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         1173,
         1173,
         56,
         1175,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         1175,
         56,
         56,
         2741,
         1173,
         1173,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         3116,
         1139,
         1139,
         1139,
         3231,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         2717,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         2718,
         56,
         56,
         56,
         2725,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         2783,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         2709,
         2719,
         2709,
         2709,
         2709,
         2709,
         2709,
         2727,
         2727,
         2734,
         2709,
         2740,
         2741,
         2741,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2743,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2750,
         2709,
         2757,
         2709,
         2764,
         2709,
         2771,
         2709,
         2777,
         2734,
         2741,
         2709,
         2709,
         2740,
         2740,
         2740,
         2784,
         2785,
         2786,
         2787,
         2788,
         2709,
         2709,
         2740,
         2743,
         2743,
         2743,
         2740,
         2734,
         2709,
         2709,
         2734,
         2709,
         2709,
         2734,
         2709,
         2709,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         1174,
         1173,
         1173,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         1173,
         56,
         56,
         2740,
         1174,
         2789,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         1174,
         1139,
         1139,
         1139,
         1174,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         1174,
         1173,
         1173,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         1173,
         56,
         56,
         2740,
         2789,
         1174,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         1174,
         1139,
         1139,
         1139,
         1174,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         2710,
         2720,
         2710,
         2710,
         2710,
         2710,
         2710,
         2728,
         2728,
         2735,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2744,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2710,
         2751,
         2710,
         2758,
         2710,
         2765,
         2710,
         2772,
         2710,
         2778,
         2735,
         2710,
         2710,
         2710,
         2784,
         2710,
         2710,
         2710,
         2790,
         2791,
         2792,
         2793,
         2710,
         2710,
         2710,
         2744,
         2744,
         2744,
         2710,
         2735,
         2710,
         2710,
         2735,
         2710,
         2710,
         2735,
         2710,
         2710,
         2711,
         2721,
         2711,
         2711,
         2711,
         2711,
         2711,
         2729,
         2729,
         2736,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2745,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2711,
         2752,
         2711,
         2759,
         2711,
         2766,
         2711,
         2773,
         2711,
         2779,
         2736,
         2711,
         2711,
         2711,
         2785,
         2711,
         2711,
         2790,
         2794,
         2795,
         2796,
         2797,
         2711,
         2711,
         2711,
         2745,
         2745,
         2745,
         2711,
         2736,
         2711,
         2711,
         2736,
         2711,
         2711,
         2736,
         2711,
         2711,
         2712,
         2722,
         2712,
         2712,
         2712,
         2712,
         2712,
         2730,
         2730,
         2737,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2746,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2753,
         2712,
         2760,
         2712,
         2767,
         2712,
         2774,
         2712,
         2780,
         2737,
         2712,
         2712,
         2712,
         2786,
         2712,
         2712,
         2791,
         2795,
         2712,
         2798,
         2799,
         2712,
         2712,
         2712,
         2746,
         2746,
         2746,
         2712,
         2737,
         2712,
         2712,
         2737,
         2712,
         2712,
         2737,
         2712,
         2712,
         2713,
         2723,
         2713,
         2713,
         2713,
         2713,
         2713,
         2731,
         2731,
         2738,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2747,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2713,
         2754,
         2713,
         2761,
         2713,
         2768,
         2713,
         2775,
         2713,
         2781,
         2738,
         2713,
         2713,
         2713,
         2787,
         2713,
         2713,
         2792,
         2796,
         2798,
         2713,
         2800,
         2713,
         2713,
         2713,
         2747,
         2747,
         2747,
         2713,
         2738,
         2713,
         2713,
         2738,
         2713,
         2713,
         2738,
         2713,
         2713,
         2714,
         2724,
         2714,
         2714,
         2714,
         2714,
         2714,
         2732,
         2732,
         2739,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2748,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2714,
         2755,
         2714,
         2762,
         2714,
         2769,
         2714,
         2776,
         2714,
         2782,
         2739,
         2714,
         2714,
         2714,
         2788,
         2714,
         2714,
         2793,
         2797,
         2799,
         2800,
         2748,
         2714,
         2714,
         2714,
         2748,
         2748,
         2748,
         2714,
         2739,
         2714,
         2714,
         2739,
         2714,
         2714,
         2739,
         2714,
         2714,
         56,
         3113,
         56,
         1158,
         1158,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         1158,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         56,
         3114,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         1176,
         1176,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         1176,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         1174,
         1173,
         3115,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         3116,
         56,
         56,
         2740,
         1174,
         1174,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         1174,
         1139,
         1139,
         1139,
         1174,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1139,
         1152,
         1139,
         1139,
         1139,
         1139,
         1139,
         1161,
         1161,
         1168,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1184,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         3228,
         1139,
         1139,
         1139,
         1139,
         1185,
         1139,
         1186,
         1139,
         1187,
         1139,
         1188,
         1139,
         2742,
         1168,
         1139,
         1139,
         1139,
         2743,
         1139,
         1139,
         2744,
         2745,
         2746,
         2747,
         2748,
         1139,
         1139,
         1139,
         1184,
         1184,
         1184,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         1139,
         1152,
         1139,
         1139,
         1139,
         1139,
         1139,
         1161,
         1161,
         1168,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1184,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         3229,
         1139,
         1139,
         1139,
         1139,
         1185,
         1139,
         1186,
         1139,
         1187,
         1139,
         1188,
         1139,
         2742,
         1168,
         1139,
         1139,
         1139,
         2743,
         1139,
         1139,
         2744,
         2745,
         2746,
         2747,
         2748,
         1139,
         1139,
         1139,
         1184,
         1184,
         1184,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         1139,
         1152,
         1139,
         1139,
         1139,
         1139,
         1139,
         1161,
         1161,
         1168,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1184,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         1139,
         3230,
         1139,
         1139,
         1139,
         1139,
         1185,
         1139,
         1186,
         1139,
         1187,
         1139,
         1188,
         1139,
         2742,
         1168,
         1139,
         1139,
         1139,
         2743,
         1139,
         1139,
         2744,
         2745,
         2746,
         2747,
         2748,
         1139,
         1139,
         1139,
         1184,
         1184,
         1184,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         1168,
         1139,
         1139,
         56,
         57,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         1174,
         1173,
         3115,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         3231,
         56,
         56,
         2740,
         1174,
         1174,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         56,
         1174,
         1139,
         1139,
         1139,
         1174,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         56,
         56,
         1138,
         3236,
         1138,
         1138,
         1138,
         1138,
         1138,
         1160,
         1160,
         1167,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1168,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1169,
         1138,
         1170,
         1138,
         1171,
         1138,
         1172,
         1138,
         2733,
         1167,
         1138,
         1138,
         1138,
         2734,
         1138,
         1138,
         2735,
         2736,
         2737,
         2738,
         2739,
         1138,
         1138,
         1138,
         1168,
         1168,
         1168,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         56,
         3240,
         56,
         1158,
         1158,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         1158,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         56,
         3241,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         1176,
         1176,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         1176,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         3249,
         1138,
         1138,
         1138,
         1138,
         1138,
         1160,
         1160,
         1167,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1168,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1169,
         1138,
         1170,
         1138,
         1171,
         1138,
         1172,
         1138,
         2733,
         1167,
         1138,
         1138,
         1138,
         2734,
         1138,
         1138,
         2735,
         2736,
         2737,
         2738,
         2739,
         1138,
         1138,
         1138,
         1168,
         1168,
         1168,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         56,
         3250,
         56,
         1158,
         1158,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         1158,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         56,
         3251,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         1176,
         1176,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         1176,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         3258,
         1138,
         1138,
         1138,
         1138,
         1138,
         1160,
         1160,
         1167,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1168,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1138,
         1169,
         1138,
         1170,
         1138,
         1171,
         1138,
         1172,
         1138,
         2733,
         1167,
         1138,
         1138,
         1138,
         2734,
         1138,
         1138,
         2735,
         2736,
         2737,
         2738,
         2739,
         1138,
         1138,
         1138,
         1168,
         1168,
         1168,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         1167,
         1138,
         1138,
         56,
         3259,
         56,
         1158,
         1158,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         1158,
         56,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         1138,
         1158,
         56,
         56,
         3260,
         56,
         56,
         56,
         56,
         56,
         1137,
         1137,
         1138,
         56,
         56,
         56,
         56,
         1176,
         1176,
         56,
         56,
         56,
         56,
         56,
         1139,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1140,
         56,
         1141,
         56,
         1142,
         56,
         1143,
         56,
         2708,
         1138,
         56,
         56,
         56,
         2709,
         56,
         56,
         2710,
         2711,
         2712,
         2713,
         2714,
         56,
         1176,
         56,
         1139,
         1139,
         1139,
         56,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
         1138,
         56,
         1176,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         6,
         7,
         0,
         8,
         0,
         9,
         10,
         11,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         28,
         29,
         29,
         29,
         29,
         30,
         30,
         31,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         34,
         0,
         0,
         0,
         0,
         35,
         0,
         0,
         36,
         37,
         38,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         43,
         44,
         0,
         0,
         45,
         46,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         48,
         2,
         48,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         48,
         2,
         3,
         2,
         48,
         49,
         3,
         3,
         2,
         3,
         2,
         48,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         6,
         6,
         6,
         6,
         50,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         51,
         7,
         7,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         50,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         50,
         6,
         6,
         6,
         6,
         6,
         6,
         50,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         50,
         6,
         6,
         6,
         6,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         52,
         10,
         52,
         10,
         11,
         10,
         52,
         11,
         11,
         11,
         15,
         15,
         16,
         15,
         16,
         15,
         16,
         16,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         37,
         37,
         37,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         12,
         12,
         12,
         12,
         12,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         18,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         22,
         23,
         22,
         22,
         22,
         23,
         23,
         22,
         23,
         23,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         22,
         26,
         26,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         26,
         26,
         26,
         26,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         31,
         31,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         54,
         55,
         35,
         35,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         0,
         0,
         0,
         39,
         41,
         41,
         41,
         41,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         58,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         61,
         61,
         61,
         61,
         61,
         3,
         3,
         3,
         3,
         3,
         62,
         10,
         62,
         10,
         62,
         10,
         11,
         11,
         11,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         12,
         12,
         27,
         27,
         27,
         27,
         27,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         50,
         50,
         50,
         50,
         50,
         6,
         6,
         6,
         6,
         63,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         63,
         63,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         8,
         8,
         17,
         17,
         17,
         17,
         17,
         17,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         19,
         19,
         19,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         28,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         34,
         55,
         55,
         57,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         64,
         6,
         6,
         65,
         66,
         4,
         4,
         35,
         35,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         67,
         3,
         68,
         8,
         0,
         13,
         27,
         19,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         19,
         19,
         19,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         3,
         11,
         5,
         0,
         0,
         0,
         69,
         70,
         71,
         72,
         0,
         6,
         6,
         3,
         11,
         5,
         73,
         74,
         75,
         76,
         6,
         6,
         3,
         11,
         5,
         77,
         78,
         79,
         80,
         6,
         6,
      },
      
      .num_filtered_states = 81,
      .table = (const uint16_t []) {
      
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         59,
         59,
         59,
         59,
         1228,
         1228,
         1229,
         1230,
         1231,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         1232,
         1233,
         1233,
         1233,
         1233,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         1234,
         59,
         59,
         1235,
         59,
         1236,
         59,
         1237,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         59,
         1229,
         1230,
         59,
         59,
         2642,
         2643,
         2644,
         2645,
         59,
         59,
         59,
         59,
         59,
         1229,
         1229,
         1228,
         1228,
         59,
         59,
         1228,
         1228,
         59,
         59,
         1228,
         1228,
         59,
         59,
         1228,
         1228,
         59,
         59,
         58,
         59,
         58,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1220,
         1220,
         2646,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         3107,
         1220,
         1220,
         1219,
         1219,
         1238,
         58,
         1219,
         1219,
         1238,
         58,
         1219,
         1219,
         1238,
         58,
         1219,
         1219,
         1238,
         58,
         58,
         59,
         1238,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1239,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1240,
         1241,
         58,
         1225,
         58,
         1226,
         58,
         1242,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1238,
         1220,
         1220,
         2646,
         58,
         2647,
         2648,
         2640,
         2641,
         58,
         58,
         58,
         1238,
         3107,
         1220,
         1220,
         1219,
         1219,
         1238,
         1239,
         1219,
         1219,
         1238,
         1239,
         1219,
         1219,
         1238,
         1239,
         1219,
         1219,
         1238,
         1239,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1220,
         1229,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1253,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1254,
         1255,
         1255,
         1255,
         1255,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1256,
         1220,
         1220,
         1257,
         1220,
         1258,
         1220,
         1259,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         2653,
         2654,
         2655,
         2656,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1220,
         1230,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1253,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1254,
         1255,
         1255,
         1255,
         1255,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1256,
         1220,
         1220,
         1257,
         1220,
         1258,
         1220,
         1259,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         2653,
         2654,
         2655,
         2656,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1221,
         1231,
         1221,
         1221,
         1245,
         1245,
         1253,
         1253,
         1260,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1261,
         1262,
         1262,
         1262,
         1262,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1263,
         1221,
         1264,
         1221,
         1221,
         1265,
         1221,
         1266,
         1221,
         1267,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1253,
         1253,
         1221,
         1221,
         2657,
         2658,
         2659,
         2660,
         1221,
         1221,
         1221,
         1221,
         1221,
         1253,
         1253,
         1245,
         1245,
         1221,
         1221,
         1245,
         1245,
         1221,
         1221,
         1245,
         1245,
         1221,
         1221,
         1245,
         1245,
         1221,
         1221,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         1268,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2661,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3108,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         1269,
         1219,
         1219,
         58,
         1269,
         1219,
         1219,
         58,
         1269,
         1219,
         1219,
         58,
         1269,
         58,
         59,
         58,
         1239,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         1269,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2661,
         1239,
         1220,
         1220,
         1269,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3108,
         1269,
         1220,
         1220,
         1219,
         1219,
         1239,
         1269,
         1219,
         1219,
         1239,
         1269,
         1219,
         1219,
         1239,
         1269,
         1219,
         1219,
         1239,
         1269,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         1270,
         1270,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         1271,
         1271,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         1270,
         1272,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         1271,
         1271,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1252,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         1273,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1252,
         1252,
         58,
         58,
         1252,
         1252,
         58,
         58,
         1252,
         1252,
         58,
         58,
         1252,
         1252,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1274,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         1274,
         1274,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1222,
         1232,
         1222,
         1222,
         1246,
         1246,
         1254,
         1254,
         1261,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1275,
         1276,
         1276,
         1276,
         1276,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1277,
         1222,
         1222,
         1278,
         1222,
         1279,
         1222,
         1280,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1222,
         1254,
         1254,
         1222,
         1222,
         2662,
         2663,
         2664,
         2665,
         1222,
         1222,
         1222,
         1222,
         1222,
         1254,
         1254,
         1246,
         1246,
         1222,
         1222,
         1246,
         1246,
         1222,
         1222,
         1246,
         1246,
         1222,
         1222,
         1246,
         1246,
         1222,
         1222,
         1223,
         1233,
         1223,
         1223,
         1247,
         1247,
         1255,
         1255,
         1262,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1276,
         1281,
         1281,
         1281,
         1281,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1282,
         1223,
         1223,
         1283,
         1223,
         1284,
         1223,
         1285,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         2666,
         2666,
         1223,
         1223,
         2667,
         2668,
         2669,
         2670,
         1223,
         1223,
         1223,
         1223,
         1223,
         1255,
         1255,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1223,
         1233,
         1223,
         1223,
         1247,
         1247,
         1255,
         1255,
         1262,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1276,
         1281,
         1286,
         1287,
         1288,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1282,
         1223,
         1223,
         1283,
         1223,
         1284,
         1223,
         1285,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         2666,
         2666,
         1223,
         1223,
         2667,
         2668,
         2669,
         2670,
         1223,
         1223,
         1223,
         1223,
         1223,
         1255,
         1255,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1223,
         1233,
         1223,
         1223,
         1247,
         1247,
         1255,
         1255,
         1262,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1276,
         1281,
         1287,
         1289,
         1290,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1282,
         1223,
         1223,
         1283,
         1223,
         1284,
         1223,
         1285,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         2666,
         2666,
         1223,
         1223,
         2667,
         2668,
         2669,
         2670,
         1223,
         1223,
         1223,
         1223,
         1223,
         1255,
         1255,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1223,
         1233,
         1223,
         1223,
         1247,
         1247,
         1255,
         1255,
         1262,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1276,
         1281,
         1288,
         1290,
         1291,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1282,
         1223,
         1223,
         1283,
         1223,
         1284,
         1223,
         1285,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         2666,
         2666,
         1223,
         1223,
         2667,
         2668,
         2669,
         2670,
         1223,
         1223,
         1223,
         1223,
         1223,
         1255,
         1255,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         1247,
         1247,
         1223,
         1223,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         1292,
         1292,
         1292,
         1292,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         1292,
         1293,
         1294,
         1295,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         1292,
         1294,
         1296,
         1297,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         1292,
         1295,
         1297,
         1298,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         1271,
         1271,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         1299,
         1299,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         1271,
         1271,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         1299,
         1300,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         1301,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1302,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1303,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1304,
         1304,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1263,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1304,
         1304,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1305,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1224,
         1234,
         1224,
         1240,
         1248,
         1248,
         1256,
         1256,
         1264,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1277,
         1282,
         1282,
         1282,
         1282,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1305,
         1305,
         1224,
         1224,
         1306,
         1224,
         1307,
         1224,
         1308,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1240,
         1256,
         1256,
         1224,
         1224,
         2671,
         2672,
         2673,
         2674,
         1224,
         1224,
         1224,
         1224,
         1224,
         1256,
         1256,
         1248,
         1248,
         1240,
         1224,
         1248,
         1248,
         1240,
         1224,
         1248,
         1248,
         1240,
         1224,
         1248,
         1248,
         1240,
         1224,
         58,
         59,
         58,
         1241,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         2675,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         1241,
         58,
         1219,
         1219,
         1241,
         58,
         1219,
         1219,
         1241,
         58,
         1219,
         1219,
         1241,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1309,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1225,
         1235,
         1225,
         1225,
         1249,
         1249,
         1257,
         1257,
         1265,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1278,
         1283,
         1283,
         1283,
         1283,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1306,
         1225,
         1309,
         1309,
         1225,
         1310,
         1225,
         1311,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1225,
         1257,
         1257,
         1225,
         1225,
         2676,
         2677,
         2678,
         2679,
         1225,
         1225,
         1225,
         1225,
         1225,
         1257,
         1257,
         1249,
         1249,
         1225,
         1225,
         1249,
         1249,
         1225,
         1225,
         1249,
         1249,
         1225,
         1225,
         1249,
         1249,
         1225,
         1225,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1312,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1226,
         1236,
         1226,
         1226,
         1250,
         1250,
         1258,
         1258,
         1266,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1279,
         1284,
         1284,
         1284,
         1284,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1307,
         1226,
         1226,
         1310,
         1312,
         1312,
         1226,
         1313,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1258,
         1258,
         1226,
         1226,
         2680,
         2681,
         2682,
         2683,
         1226,
         1226,
         1226,
         1226,
         1226,
         1258,
         1258,
         1250,
         1250,
         1226,
         1226,
         1250,
         1250,
         1226,
         1226,
         1250,
         1250,
         1226,
         1226,
         1250,
         1250,
         1226,
         1226,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1314,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1227,
         1237,
         1227,
         1242,
         1251,
         1251,
         1259,
         1259,
         1267,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1280,
         1285,
         1285,
         1285,
         1285,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1308,
         1227,
         1227,
         1311,
         1227,
         1313,
         1314,
         1314,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1242,
         1259,
         1259,
         1227,
         1227,
         2684,
         2685,
         2686,
         2687,
         1227,
         1227,
         1227,
         1227,
         1227,
         1259,
         1259,
         1251,
         1251,
         1242,
         1227,
         1251,
         1251,
         1242,
         1227,
         1251,
         1251,
         1242,
         1227,
         1251,
         1251,
         1242,
         1227,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         1315,
         1315,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         1315,
         58,
         1315,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         1315,
         1315,
         1315,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         1316,
         1316,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         1316,
         58,
         1316,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         1316,
         1316,
         1316,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         2661,
         2661,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1220,
         1220,
         2688,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         3109,
         1220,
         1220,
         1219,
         1219,
         1238,
         2661,
         1219,
         1219,
         1238,
         2661,
         1219,
         1219,
         1238,
         2661,
         1219,
         1219,
         1238,
         2661,
         58,
         59,
         1238,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1239,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1240,
         2675,
         58,
         1225,
         58,
         1226,
         58,
         1242,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1238,
         1220,
         1220,
         2646,
         58,
         2689,
         2690,
         2640,
         2641,
         58,
         58,
         58,
         1238,
         3107,
         3110,
         3219,
         1219,
         1219,
         1238,
         1239,
         1219,
         1219,
         1238,
         1239,
         1219,
         1219,
         1238,
         1239,
         1219,
         1219,
         1238,
         1239,
         1220,
         1229,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1253,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1254,
         2666,
         2666,
         2666,
         2666,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1256,
         1220,
         1220,
         1257,
         1220,
         1258,
         1220,
         1259,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         2653,
         2654,
         2655,
         2656,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1220,
         1230,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1253,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1254,
         2666,
         2666,
         2666,
         2666,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1256,
         1220,
         1220,
         1257,
         1220,
         1258,
         1220,
         1259,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         2653,
         2654,
         2655,
         2656,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         58,
         59,
         2646,
         2646,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2688,
         2646,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3111,
         58,
         1220,
         1220,
         1219,
         1219,
         2646,
         1269,
         1219,
         1219,
         2646,
         1269,
         1219,
         1219,
         2646,
         1269,
         1219,
         1219,
         2646,
         1269,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         2691,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         2638,
         2642,
         2638,
         2647,
         2649,
         2649,
         2653,
         2653,
         2657,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2662,
         2667,
         2667,
         2667,
         2667,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2671,
         2638,
         2638,
         2676,
         2638,
         2680,
         2638,
         2684,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2638,
         2689,
         2653,
         2653,
         2638,
         2638,
         2638,
         2692,
         2693,
         2694,
         2638,
         2638,
         2638,
         2638,
         2638,
         2653,
         2653,
         2649,
         2649,
         2647,
         2638,
         2649,
         2649,
         2647,
         2638,
         2649,
         2649,
         2647,
         2638,
         2649,
         2649,
         2647,
         2638,
         2639,
         2643,
         2639,
         2648,
         2650,
         2650,
         2654,
         2654,
         2658,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2663,
         2668,
         2668,
         2668,
         2668,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2672,
         2639,
         2639,
         2677,
         2639,
         2681,
         2639,
         2685,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2690,
         2654,
         2654,
         2639,
         2639,
         2692,
         2695,
         2696,
         2697,
         2639,
         2639,
         2639,
         2639,
         2639,
         2654,
         2654,
         2650,
         2650,
         2648,
         2639,
         2650,
         2650,
         2648,
         2639,
         2650,
         2650,
         2648,
         2639,
         2650,
         2650,
         2648,
         2639,
         2640,
         2644,
         2640,
         2640,
         2651,
         2651,
         2655,
         2655,
         2659,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2664,
         2669,
         2669,
         2669,
         2669,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2673,
         2640,
         2640,
         2678,
         2640,
         2682,
         2640,
         2686,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2655,
         2655,
         2640,
         2640,
         2693,
         2696,
         2640,
         2698,
         2640,
         2640,
         2640,
         2640,
         2640,
         2655,
         2655,
         2651,
         2651,
         2640,
         2640,
         2651,
         2651,
         2640,
         2640,
         2651,
         2651,
         2640,
         2640,
         2651,
         2651,
         2640,
         2640,
         2641,
         2645,
         2641,
         2641,
         2652,
         2652,
         2656,
         2656,
         2660,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2665,
         2670,
         2670,
         2670,
         2670,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2674,
         2641,
         2641,
         2679,
         2641,
         2683,
         2641,
         2687,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2656,
         2656,
         2641,
         2641,
         2694,
         2697,
         2698,
         2641,
         2641,
         2641,
         2641,
         2641,
         2641,
         2656,
         2656,
         2652,
         2652,
         2641,
         2641,
         2652,
         2652,
         2641,
         2641,
         2652,
         2652,
         2641,
         2641,
         2652,
         2652,
         2641,
         2641,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         2699,
         2699,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         2699,
         58,
         2699,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         58,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         2699,
         2699,
         2699,
         58,
         58,
         1220,
         1220,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         1219,
         1219,
         58,
         58,
         58,
         59,
         58,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         3108,
         3108,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1220,
         1220,
         3111,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         58,
         3112,
         1220,
         1220,
         1219,
         1219,
         1238,
         3108,
         1219,
         1219,
         1238,
         3108,
         1219,
         1219,
         1238,
         3108,
         1219,
         1219,
         1238,
         3108,
         58,
         59,
         3107,
         3107,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         3109,
         3107,
         1220,
         1220,
         58,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3112,
         58,
         1220,
         1220,
         1219,
         1219,
         3107,
         1269,
         1219,
         1219,
         3107,
         1269,
         1219,
         1219,
         3107,
         1269,
         1219,
         1219,
         3107,
         1269,
         1220,
         1229,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1253,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1254,
         1255,
         1255,
         1255,
         1255,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1256,
         1220,
         1220,
         1257,
         1220,
         1258,
         1220,
         1259,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         3110,
         1220,
         1220,
         1220,
         1220,
         2653,
         2654,
         2655,
         2656,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1220,
         1229,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1253,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1254,
         1255,
         1255,
         1255,
         1255,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1256,
         1220,
         1220,
         1257,
         1220,
         1258,
         1220,
         1259,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         3219,
         1220,
         1220,
         1220,
         1220,
         2653,
         2654,
         2655,
         2656,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1244,
         1244,
         1220,
         1220,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         3220,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         3220,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         58,
         59,
         1238,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1239,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1240,
         1241,
         58,
         1225,
         58,
         1226,
         58,
         1242,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1238,
         1220,
         1220,
         2646,
         58,
         2647,
         2648,
         2640,
         2641,
         58,
         58,
         58,
         1238,
         3107,
         1220,
         1220,
         1219,
         1219,
         1238,
         3221,
         1219,
         1219,
         1238,
         3221,
         1219,
         1219,
         1238,
         3221,
         1219,
         1219,
         1238,
         3221,
         58,
         59,
         58,
         1239,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         1269,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2661,
         1239,
         1220,
         1220,
         1269,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3108,
         1269,
         1220,
         1220,
         1219,
         1219,
         3221,
         1269,
         1219,
         1219,
         3221,
         1269,
         1219,
         1219,
         3221,
         1269,
         1219,
         1219,
         3221,
         1269,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         3245,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         3245,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         58,
         59,
         1238,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1239,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1240,
         1241,
         58,
         1225,
         58,
         1226,
         58,
         1242,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1238,
         1220,
         1220,
         2646,
         58,
         2647,
         2648,
         2640,
         2641,
         58,
         58,
         58,
         1238,
         3107,
         1220,
         1220,
         1219,
         1219,
         1238,
         3221,
         1219,
         1219,
         1238,
         3246,
         1219,
         1219,
         1238,
         3246,
         1219,
         1219,
         1238,
         3246,
         58,
         59,
         58,
         1239,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         1269,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2661,
         1239,
         1220,
         1220,
         1269,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3108,
         1269,
         1220,
         1220,
         1219,
         1219,
         3221,
         1269,
         1219,
         1219,
         3246,
         1269,
         1219,
         1219,
         3246,
         1269,
         1219,
         1219,
         3246,
         1269,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         3254,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         3254,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         58,
         59,
         1238,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1239,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1240,
         1241,
         58,
         1225,
         58,
         1226,
         58,
         1242,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1238,
         1220,
         1220,
         2646,
         58,
         2647,
         2648,
         2640,
         2641,
         58,
         58,
         58,
         1238,
         3107,
         1220,
         1220,
         1219,
         1219,
         1238,
         3221,
         1219,
         1219,
         1238,
         3246,
         1219,
         1219,
         1238,
         3255,
         1219,
         1219,
         1238,
         3255,
         58,
         59,
         58,
         1239,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         1269,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2661,
         1239,
         1220,
         1220,
         1269,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3108,
         1269,
         1220,
         1220,
         1219,
         1219,
         3221,
         1269,
         1219,
         1219,
         3246,
         1269,
         1219,
         1219,
         3255,
         1269,
         1219,
         1219,
         3255,
         1269,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         3263,
         1219,
         1219,
         1219,
         1228,
         1219,
         1219,
         1243,
         1243,
         1244,
         1244,
         1245,
         1219,
         1219,
         1219,
         1219,
         1219,
         1252,
         1219,
         1219,
         1246,
         1247,
         1247,
         1247,
         1247,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1248,
         1219,
         1219,
         1249,
         1219,
         1250,
         1219,
         1251,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1219,
         1219,
         2649,
         2650,
         2651,
         2652,
         1219,
         1219,
         1219,
         1219,
         1219,
         1244,
         1244,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         1243,
         1243,
         1219,
         1219,
         3263,
         1243,
         1219,
         1219,
         58,
         59,
         1238,
         1238,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         58,
         1239,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1240,
         1241,
         58,
         1225,
         58,
         1226,
         58,
         1242,
         58,
         58,
         58,
         58,
         58,
         58,
         1238,
         1238,
         1220,
         1220,
         2646,
         58,
         2647,
         2648,
         2640,
         2641,
         58,
         58,
         58,
         1238,
         3107,
         1220,
         1220,
         1219,
         1219,
         1238,
         3221,
         1219,
         1219,
         1238,
         3246,
         1219,
         1219,
         1238,
         3255,
         1219,
         1219,
         1238,
         3264,
         58,
         59,
         58,
         1239,
         1219,
         1219,
         1220,
         1220,
         1221,
         58,
         1269,
         1269,
         58,
         58,
         58,
         58,
         58,
         1222,
         1223,
         1223,
         1223,
         1223,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1224,
         58,
         58,
         1225,
         58,
         1226,
         58,
         1227,
         58,
         58,
         58,
         58,
         58,
         58,
         2661,
         1239,
         1220,
         1220,
         1269,
         58,
         2638,
         2639,
         2640,
         2641,
         58,
         58,
         58,
         3108,
         1269,
         1220,
         1220,
         1219,
         1219,
         3221,
         1269,
         1219,
         1219,
         3246,
         1269,
         1219,
         1219,
         3255,
         1269,
         1219,
         1219,
         3264,
         1269,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         0,
         19,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         23,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         28,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         29,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         13,
         13,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         6,
         5,
         0,
         0,
         4,
         5,
         5,
         0,
         6,
         4,
         0,
         0,
         0,
         6,
         5,
         5,
         5,
         0,
         6,
         0,
         0,
         0,
         6,
         5,
         5,
         5,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 30,
      .table = (const uint16_t []) {
      
         60,
         61,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         61,
         61,
         1762,
         1763,
         1764,
         1765,
         1766,
         1767,
         1768,
         1769,
         1770,
         1771,
         1772,
         1773,
         1774,
         1775,
         1776,
         1777,
         1778,
         1779,
         1780,
         1781,
         1782,
         1783,
         1784,
         1785,
         1786,
         2700,
         2701,
         3163,
         60,
         1762,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1763,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         1760,
         1764,
         1760,
         1760,
         1760,
         1787,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1787,
         1760,
         1787,
         1761,
         1765,
         1761,
         1761,
         1787,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         60,
         1766,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1767,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1768,
         60,
         60,
         1760,
         1761,
         60,
         60,
         1788,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1769,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1770,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1771,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1772,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         1789,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1773,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1790,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1774,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1791,
         60,
         1791,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1775,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1792,
         1792,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1776,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1791,
         1792,
         1793,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1777,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1778,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1779,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1780,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1781,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1782,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1783,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1784,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1785,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         60,
         1786,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         1761,
         2700,
         1761,
         1761,
         1787,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         60,
         2701,
         60,
         60,
         1760,
         1761,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         60,
         1761,
         60,
         1761,
         1761,
         3163,
         1761,
         1761,
         1787,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
         1761,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         22,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         26,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         0,
         27,
         0,
         27,
         0,
         27,
         27,
         0,
         27,
         27,
         28,
         0,
         0,
         28,
         0,
         0,
         28,
         0,
         28,
         28,
         28,
         0,
         0,
         0,
         12,
         12,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         27,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         7,
         6,
         0,
         0,
         5,
         6,
         6,
         0,
         7,
         5,
         0,
         0,
         0,
         7,
         6,
         6,
         6,
         0,
         7,
         0,
         0,
         0,
         7,
         6,
         6,
         6,
         0,
         7,
         0,
         0,
      },
      
      .num_filtered_states = 29,
      .table = (const uint16_t []) {
      
         62,
         63,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         63,
         63,
         1655,
         1656,
         1657,
         1658,
         1659,
         1660,
         1661,
         1662,
         1663,
         1664,
         1665,
         1666,
         1667,
         1668,
         1669,
         1670,
         1671,
         1672,
         1673,
         1674,
         1675,
         1676,
         1677,
         1678,
         2928,
         3195,
         3196,
         62,
         1655,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1656,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1657,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1653,
         1658,
         1653,
         1653,
         1653,
         1653,
         1679,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1653,
         1654,
         1659,
         1654,
         1654,
         1654,
         1679,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         1654,
         62,
         1660,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1661,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1662,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         1680,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1663,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1664,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         1681,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1665,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         1682,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1666,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         1683,
         62,
         1683,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1667,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1684,
         1684,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1668,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         1683,
         1684,
         1685,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1669,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1670,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1671,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1672,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1673,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1674,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1675,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1676,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1677,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         1678,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         2928,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         2929,
         62,
         62,
         62,
         3195,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         3196,
         62,
         62,
         62,
         1653,
         1654,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         9,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         13,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         15,
         0,
         0,
         0,
         3,
         3,
         9,
         4,
         0,
         16,
         10,
         2,
         4,
         17,
         3,
         3,
         9,
         4,
         18,
         10,
         2,
         4,
         19,
         3,
         3,
         9,
         4,
         0,
         10,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         64,
         65,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         66,
         67,
         66,
         1347,
         66,
         1348,
         66,
         66,
         2483,
         2484,
         66,
         66,
         66,
         1347,
         66,
         1347,
         66,
         1347,
         66,
         1347,
         1349,
         1350,
         1349,
         1351,
         1349,
         1352,
         1349,
         1349,
         2485,
         2486,
         1349,
         1349,
         1349,
         1351,
         1349,
         1351,
         1349,
         1351,
         1349,
         1351,
         64,
         65,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1353,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         65,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1354,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1355,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         65,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         1349,
         1350,
         1349,
         1351,
         1349,
         1352,
         1349,
         1349,
         2485,
         2486,
         1349,
         1349,
         1349,
         1351,
         1349,
         1351,
         1349,
         1351,
         1349,
         1351,
         64,
         2487,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         2488,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         2489,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3162,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3235,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3243,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3248,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3253,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3257,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         3262,
         64,
         1345,
         64,
         1346,
         64,
         64,
         2481,
         2482,
         64,
         64,
         64,
         1345,
         64,
         1345,
         64,
         1345,
         64,
         1345,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         2,
         2,
         10,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         68,
         1535,
         1536,
         1537,
         1538,
         2838,
         2839,
         2840,
         2841,
         2842,
         2843,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         69,
         69,
         69,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         70,
         71,
         70,
         70,
         1511,
         72,
         73,
         72,
         72,
         1512,
         1513,
         1514,
         1513,
         1513,
         1515,
         1516,
         1517,
         1516,
         1516,
         1518,
         70,
         71,
         70,
         70,
         1511,
         74,
         75,
         74,
         74,
         1519,
         76,
         77,
         76,
         76,
         1520,
         1521,
         1522,
         1521,
         1521,
         1523,
         1524,
         1525,
         1524,
         1524,
         1526,
         74,
         75,
         74,
         74,
         1519,
         70,
         71,
         70,
         70,
         1511,
         72,
         73,
         72,
         72,
         1512,
         1527,
         1528,
         1527,
         1527,
         1529,
         1516,
         1517,
         1516,
         1516,
         1518,
         70,
         71,
         70,
         70,
         1511,
         70,
         71,
         70,
         70,
         1511,
         72,
         73,
         72,
         72,
         1512,
         1513,
         1514,
         1513,
         1513,
         1515,
         1530,
         1531,
         1530,
         1530,
         1532,
         70,
         71,
         70,
         70,
         1511,
         70,
         71,
         70,
         70,
         1511,
         72,
         73,
         72,
         72,
         1512,
         1513,
         1514,
         1513,
         1513,
         1515,
         1516,
         1517,
         1516,
         1516,
         1518,
         70,
         71,
         70,
         70,
         1511,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         78,
         79,
         80,
         81,
         80,
         81,
         82,
         83,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         84,
         85,
         86,
         87,
         86,
         87,
         88,
         89,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         90,
         90,
         91,
         91,
         91,
         91,
         92,
         92,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         93,
         94,
         95,
         96,
         95,
         96,
         97,
         98,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         99,
         100,
         101,
         102,
         101,
         102,
         103,
         104,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         105,
         106,
         107,
         108,
         107,
         108,
         109,
         110,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         111,
         111,
         112,
         112,
         112,
         112,
         113,
         113,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         114,
         114,
         115,
         115,
         115,
         115,
         116,
         116,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         117,
         118,
         119,
         120,
         121,
         122,
         123,
         124,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         125,
         125,
         126,
         126,
         127,
         127,
         128,
         128,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         11,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         18,
         19,
         20,
         21,
         20,
         21,
         22,
         22,
         22,
         22,
         0,
         0,
         23,
         24,
         25,
         25,
         25,
         25,
         26,
         26,
         27,
         27,
         28,
         28,
         0,
         29,
         29,
         30,
         30,
         31,
         31,
         32,
         32,
         33,
         33,
         0,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         0,
         36,
         0,
         37,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         40,
         40,
         40,
         41,
         42,
         43,
         0,
         0,
         0,
         0,
         44,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         46,
         0,
         46,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         48,
         49,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         55,
         56,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         57,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         57,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         58,
         7,
         7,
         7,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         35,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         59,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         60,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         21,
         20,
         20,
         20,
         21,
         21,
         20,
         21,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         20,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         61,
         62,
         63,
         64,
         65,
         66,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         67,
         0,
         0,
         0,
         0,
         0,
         68,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         69,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         70,
         71,
         72,
         73,
         74,
         75,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         76,
         76,
         76,
         76,
         76,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         77,
         77,
         77,
         77,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         78,
         79,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         80,
         81,
         0,
         0,
         0,
         36,
         37,
         37,
         37,
         37,
         37,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         24,
         23,
         24,
         23,
         23,
         24,
         23,
         24,
         23,
         23,
         24,
         24,
         23,
         24,
         23,
         24,
         23,
         24,
         23,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         82,
         83,
         84,
         85,
         86,
         0,
         39,
         39,
         39,
         39,
         39,
         41,
         42,
         42,
         42,
         42,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         48,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         51,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         87,
         57,
         88,
         89,
         90,
         91,
         7,
         7,
         7,
         7,
         57,
         57,
         57,
         57,
         57,
         57,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         57,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         11,
         11,
         19,
         19,
         19,
         19,
         19,
         19,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         92,
         93,
         60,
         60,
         94,
         92,
         93,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         20,
         21,
         21,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         22,
         22,
         22,
         22,
         40,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         12,
         0,
         24,
         25,
         25,
         25,
         25,
         76,
         25,
         25,
         25,
         26,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         34,
         79,
         79,
         81,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         95,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         9,
         96,
         97,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         98,
         99,
         98,
         16,
         6,
         19,
         19,
         19,
         0,
         0,
         0,
         11,
         0,
         15,
         0,
         21,
         22,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         12,
         12,
         57,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         21,
         21,
         21,
         29,
         29,
         3,
         9,
         9,
         9,
         100,
         101,
         7,
         0,
         0,
         9,
         14,
         14,
         7,
         9,
         9,
         0,
         0,
         7,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
      },
      
      .num_filtered_states = 102,
      .table = (const uint16_t []) {
      
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         135,
         136,
         135,
         135,
         135,
         135,
         592,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         593,
         135,
         135,
         594,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         592,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         133,
         134,
         595,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         596,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         597,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         598,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         599,
         600,
         599,
         599,
         599,
         599,
         601,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         602,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         601,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         604,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         605,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         605,
         605,
         133,
         133,
         605,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         606,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         607,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         608,
         609,
         608,
         608,
         608,
         608,
         610,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         611,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         610,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         613,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         614,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         615,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         616,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         617,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         618,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         619,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         620,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         621,
         622,
         621,
         621,
         621,
         621,
         623,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         624,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         623,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         625,
         626,
         625,
         625,
         625,
         625,
         627,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         628,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         627,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         629,
         630,
         629,
         629,
         629,
         629,
         631,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         632,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         631,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         633,
         634,
         633,
         633,
         633,
         633,
         635,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         636,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         635,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         633,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         637,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         638,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         639,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         640,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         641,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         642,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         643,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         644,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         645,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         646,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         647,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         648,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         649,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         599,
         600,
         599,
         599,
         599,
         599,
         601,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         602,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         601,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         2289,
         2290,
         2289,
         2289,
         2289,
         2289,
         2291,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2292,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2291,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2289,
         2293,
         2294,
         2293,
         2293,
         2293,
         2293,
         2295,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2296,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2295,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2293,
         2297,
         2298,
         2297,
         2297,
         2297,
         2297,
         2299,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2300,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2299,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2297,
         2301,
         2302,
         2301,
         2301,
         2301,
         2301,
         2303,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2304,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2303,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         2301,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         603,
         603,
         603,
         603,
         603,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         605,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         605,
         605,
         133,
         133,
         605,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         605,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         605,
         605,
         133,
         133,
         605,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         612,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         612,
         612,
         612,
         133,
         133,
         133,
         612,
         612,
         133,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         605,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         605,
         605,
         133,
         133,
         605,
         133,
         133,
         134,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         591,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         590,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         133,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3004,
         131,
         3005,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3008,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3009,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3010,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3011,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         655,
         656,
         655,
         655,
         655,
         657,
         658,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         659,
         655,
         655,
         660,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         2305,
         2306,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         3012,
         3013,
         3014,
         655,
         655,
         655,
         3205,
         3206,
         655,
         3237,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         665,
         666,
         665,
         665,
         665,
         665,
         667,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         668,
         665,
         665,
         669,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         667,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         665,
         661,
         662,
         670,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         671,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         672,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         673,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         674,
         675,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         679,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         680,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         680,
         680,
         661,
         661,
         680,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         681,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         682,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         683,
         684,
         683,
         683,
         683,
         683,
         685,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         686,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         685,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         688,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         689,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         690,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         691,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         692,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         693,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         694,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         695,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         696,
         697,
         696,
         696,
         696,
         696,
         698,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         699,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         698,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         700,
         701,
         700,
         700,
         700,
         700,
         702,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         703,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         702,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         704,
         705,
         704,
         704,
         704,
         704,
         706,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         707,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         706,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         704,
         708,
         709,
         708,
         708,
         708,
         708,
         710,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         711,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         710,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         712,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         713,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         714,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         715,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         716,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         717,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         718,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         719,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         720,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         721,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         722,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         723,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         724,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         674,
         675,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         2307,
         2308,
         2307,
         2307,
         2307,
         2307,
         2309,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2310,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2309,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2307,
         2311,
         2312,
         2311,
         2311,
         2311,
         2311,
         2313,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2314,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2313,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2315,
         2316,
         2315,
         2315,
         2315,
         2315,
         2317,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2318,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2317,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2319,
         2320,
         2319,
         2319,
         2319,
         2319,
         2321,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2322,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2321,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         678,
         678,
         678,
         678,
         678,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         680,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         680,
         680,
         661,
         661,
         680,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         680,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         680,
         680,
         661,
         661,
         680,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         687,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         687,
         687,
         687,
         661,
         661,
         661,
         687,
         687,
         661,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         680,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         680,
         680,
         661,
         661,
         680,
         661,
         661,
         662,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         729,
         730,
         729,
         729,
         729,
         729,
         731,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         732,
         729,
         729,
         733,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         731,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         725,
         726,
         734,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         735,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         736,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         737,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         738,
         739,
         738,
         738,
         738,
         738,
         740,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         741,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         740,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         743,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         745,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         746,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         747,
         748,
         747,
         747,
         747,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         752,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         753,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         754,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         755,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         756,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         757,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         758,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         759,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         760,
         761,
         760,
         760,
         760,
         760,
         762,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         763,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         762,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         764,
         765,
         764,
         764,
         764,
         764,
         766,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         767,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         766,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         768,
         769,
         768,
         768,
         768,
         768,
         770,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         771,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         770,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         772,
         773,
         772,
         772,
         772,
         772,
         774,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         775,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         774,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         776,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         777,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         778,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         779,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         780,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         781,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         782,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         783,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         784,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         785,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         786,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         787,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         788,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         738,
         739,
         738,
         738,
         738,
         738,
         740,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         741,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         740,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         738,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         2323,
         2324,
         2323,
         2323,
         2323,
         2323,
         2325,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2326,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2325,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2327,
         2328,
         2327,
         2327,
         2327,
         2327,
         2329,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2330,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2329,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2331,
         2332,
         2331,
         2331,
         2331,
         2331,
         2333,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2334,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2333,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2335,
         2336,
         2335,
         2335,
         2335,
         2335,
         2337,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2338,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2337,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         729,
         730,
         729,
         729,
         729,
         729,
         731,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         732,
         729,
         729,
         733,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         789,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         731,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         725,
         726,
         734,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         735,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         736,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         737,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         790,
         791,
         790,
         790,
         790,
         790,
         792,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         793,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         792,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         743,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         745,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         746,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         747,
         748,
         747,
         747,
         747,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         752,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         753,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         754,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         755,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         756,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         757,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         758,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         759,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         760,
         761,
         760,
         760,
         760,
         760,
         762,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         763,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         762,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         760,
         764,
         765,
         764,
         764,
         764,
         764,
         766,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         767,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         766,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         764,
         768,
         769,
         768,
         768,
         768,
         768,
         770,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         771,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         770,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         768,
         772,
         773,
         772,
         772,
         772,
         772,
         774,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         775,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         774,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         776,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         777,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         778,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         779,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         780,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         781,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         782,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         783,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         784,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         785,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         786,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         787,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         788,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         790,
         791,
         790,
         790,
         790,
         790,
         792,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         793,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         792,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         790,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         2323,
         2324,
         2323,
         2323,
         2323,
         2323,
         2325,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2326,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2325,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2323,
         2327,
         2328,
         2327,
         2327,
         2327,
         2327,
         2329,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2330,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2329,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2327,
         2331,
         2332,
         2331,
         2331,
         2331,
         2331,
         2333,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2334,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2333,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2331,
         2335,
         2336,
         2335,
         2335,
         2335,
         2335,
         2337,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2338,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2337,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         2335,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         742,
         742,
         742,
         742,
         742,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         751,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         751,
         751,
         751,
         725,
         725,
         725,
         751,
         751,
         725,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         744,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         744,
         744,
         725,
         725,
         744,
         725,
         725,
         726,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         728,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         727,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         725,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         798,
         799,
         798,
         798,
         798,
         798,
         800,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         801,
         798,
         798,
         802,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         800,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         798,
         794,
         795,
         803,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         804,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         805,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         806,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         807,
         808,
         807,
         807,
         807,
         807,
         809,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         810,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         809,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         812,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         813,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         813,
         813,
         794,
         794,
         813,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         814,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         815,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         816,
         817,
         816,
         816,
         816,
         816,
         818,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         819,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         818,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         816,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         821,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         822,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         823,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         824,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         825,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         826,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         827,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         828,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         829,
         830,
         829,
         829,
         829,
         829,
         831,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         832,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         831,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         833,
         834,
         833,
         833,
         833,
         833,
         835,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         836,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         835,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         833,
         837,
         838,
         837,
         837,
         837,
         837,
         839,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         840,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         839,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         837,
         841,
         842,
         841,
         841,
         841,
         841,
         843,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         844,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         843,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         841,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         845,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         846,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         847,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         848,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         849,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         850,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         851,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         852,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         853,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         854,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         855,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         856,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         857,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         807,
         808,
         807,
         807,
         807,
         807,
         809,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         810,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         809,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         807,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         2339,
         2340,
         2339,
         2339,
         2339,
         2339,
         2341,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2342,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2341,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2339,
         2343,
         2344,
         2343,
         2343,
         2343,
         2343,
         2345,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2346,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2345,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2343,
         2347,
         2348,
         2347,
         2347,
         2347,
         2347,
         2349,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2350,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2349,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2347,
         2351,
         2352,
         2351,
         2351,
         2351,
         2351,
         2353,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2354,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2353,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         2351,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         811,
         811,
         811,
         811,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         813,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         813,
         813,
         794,
         794,
         813,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         813,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         813,
         813,
         794,
         794,
         813,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         820,
         820,
         794,
         794,
         794,
         820,
         820,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         813,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         813,
         813,
         794,
         794,
         813,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         862,
         863,
         862,
         862,
         862,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         865,
         862,
         862,
         866,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         858,
         859,
         867,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         868,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         869,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         870,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         871,
         872,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         874,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         876,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         878,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         879,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         880,
         881,
         880,
         880,
         880,
         880,
         882,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         883,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         882,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         885,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         886,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         887,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         888,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         889,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         890,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         891,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         892,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         893,
         894,
         893,
         893,
         893,
         893,
         895,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         896,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         895,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         897,
         898,
         897,
         897,
         897,
         897,
         899,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         900,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         899,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         901,
         902,
         901,
         901,
         901,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         905,
         905,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         909,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         910,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         911,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         912,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         913,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         914,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         915,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         916,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         917,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         918,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         919,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         920,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         921,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         871,
         872,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         874,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         2355,
         2356,
         2355,
         2355,
         2355,
         2355,
         2357,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2358,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2357,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2359,
         2360,
         2359,
         2359,
         2359,
         2359,
         2361,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2362,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2361,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2363,
         2364,
         2363,
         2363,
         2363,
         2363,
         2365,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2366,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2365,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2367,
         2368,
         2367,
         2367,
         2367,
         2367,
         2369,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2370,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2369,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         862,
         863,
         862,
         862,
         862,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         865,
         862,
         862,
         866,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         858,
         859,
         867,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         868,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         869,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         870,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         871,
         872,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         874,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         876,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         878,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         879,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         880,
         881,
         880,
         880,
         880,
         880,
         882,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         883,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         882,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         885,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         886,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         887,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         888,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         889,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         890,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         891,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         892,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         893,
         894,
         893,
         893,
         893,
         893,
         895,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         896,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         895,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         893,
         897,
         898,
         897,
         897,
         897,
         897,
         899,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         900,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         899,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         897,
         901,
         902,
         901,
         901,
         901,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         905,
         905,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         909,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         910,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         911,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         912,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         913,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         914,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         915,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         916,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         917,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         918,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         919,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         920,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         921,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         871,
         872,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         874,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         873,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         871,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         2371,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         2355,
         2356,
         2355,
         2355,
         2355,
         2355,
         2357,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2358,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2357,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2355,
         2359,
         2360,
         2359,
         2359,
         2359,
         2359,
         2361,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2362,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2361,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2359,
         2363,
         2364,
         2363,
         2363,
         2363,
         2363,
         2365,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2366,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2365,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2363,
         2367,
         2368,
         2367,
         2367,
         2367,
         2367,
         2369,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2370,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2369,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         2367,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         875,
         875,
         875,
         875,
         875,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         884,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         884,
         884,
         884,
         858,
         858,
         858,
         884,
         884,
         858,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         877,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         877,
         877,
         858,
         858,
         877,
         858,
         858,
         859,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         861,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         860,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         858,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         926,
         927,
         926,
         926,
         926,
         926,
         928,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         929,
         926,
         926,
         930,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         2372,
         926,
         928,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         2372,
         2372,
         2372,
         2372,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         922,
         923,
         931,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         932,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         933,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         934,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         935,
         936,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         938,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         940,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         942,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         943,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         944,
         945,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         949,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         950,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         951,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         952,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         953,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         954,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         955,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         956,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         957,
         958,
         957,
         957,
         957,
         957,
         959,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         960,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         959,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         961,
         962,
         961,
         961,
         961,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         965,
         965,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         969,
         970,
         969,
         969,
         969,
         969,
         971,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         972,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         971,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         973,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         974,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         975,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         976,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         977,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         978,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         979,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         980,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         981,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         982,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         983,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         984,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         985,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         935,
         936,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         938,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         2373,
         2374,
         2373,
         2373,
         2373,
         2373,
         2375,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2376,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2375,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2377,
         2378,
         2377,
         2377,
         2377,
         2377,
         2379,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2380,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2379,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2381,
         2382,
         2381,
         2381,
         2381,
         2381,
         2383,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2384,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2383,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2385,
         2386,
         2385,
         2385,
         2385,
         2385,
         2387,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2388,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2387,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         990,
         991,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         993,
         990,
         990,
         994,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         986,
         987,
         995,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         996,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         997,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         998,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         1004,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         1006,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         1007,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1008,
         1009,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         1013,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         1014,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1015,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1016,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1017,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1018,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1019,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1020,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1029,
         1030,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1032,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1033,
         1034,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1036,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1037,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1038,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1039,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1040,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1041,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1042,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1043,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1044,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1045,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1046,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1047,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1048,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1049,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2389,
         2390,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2392,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2393,
         2394,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2396,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2397,
         2398,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2400,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2401,
         2402,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2404,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1054,
         1055,
         1054,
         1054,
         1054,
         1054,
         1056,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1057,
         1054,
         1054,
         1058,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1056,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1050,
         1051,
         1059,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1060,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1061,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1062,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1063,
         1064,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1066,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1068,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1070,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1071,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1072,
         1073,
         1072,
         1072,
         1072,
         1072,
         1074,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1075,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1074,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1077,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1078,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1079,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1080,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1081,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1082,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1083,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1084,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1085,
         1086,
         1085,
         1085,
         1085,
         1085,
         1087,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1088,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1087,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1089,
         1090,
         1089,
         1089,
         1089,
         1089,
         1091,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1092,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1091,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1093,
         1094,
         1093,
         1093,
         1093,
         1093,
         1095,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1096,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1095,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1097,
         1098,
         1097,
         1097,
         1097,
         1097,
         1099,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1100,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1099,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1101,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1102,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1103,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1104,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1105,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1106,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1107,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1108,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1109,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1110,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1111,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1112,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1113,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2405,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1063,
         1064,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1066,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2406,
         2407,
         2406,
         2406,
         2406,
         2406,
         2408,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2409,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2408,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2410,
         2411,
         2410,
         2410,
         2410,
         2410,
         2412,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2413,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2412,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2414,
         2415,
         2414,
         2414,
         2414,
         2414,
         2416,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2417,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2416,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2418,
         2419,
         2418,
         2418,
         2418,
         2418,
         2420,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2421,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2420,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2405,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2405,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2405,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2405,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3015,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3016,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3008,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3009,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3010,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3011,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3017,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3018,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3010,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3011,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3008,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3009,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3019,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3020,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3010,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3011,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3008,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3009,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3021,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3022,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         2422,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         2422,
         2422,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         2422,
         2422,
         2422,
         2422,
         2422,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3008,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3009,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3010,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3011,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         2423,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         2423,
         2423,
         2423,
         2423,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         650,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         651,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         652,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         653,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         654,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3008,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3009,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3010,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3011,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3004,
         131,
         3005,
         131,
         131,
         131,
         3207,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3023,
         3004,
         131,
         3005,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3024,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3025,
         131,
         3005,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3026,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3004,
         3027,
         3005,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3028,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3004,
         131,
         3029,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3030,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3004,
         131,
         3005,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2424,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         3004,
         131,
         3005,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3006,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3007,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2425,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2425,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2425,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2425,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2425,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         926,
         927,
         926,
         926,
         926,
         926,
         928,
         2426,
         926,
         926,
         926,
         926,
         926,
         926,
         929,
         926,
         926,
         930,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         2427,
         2426,
         928,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         2426,
         2427,
         2427,
         2427,
         2427,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         922,
         923,
         931,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         932,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         933,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         934,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         935,
         936,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         938,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         940,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         942,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         943,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         944,
         945,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         949,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         950,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         951,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         952,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         953,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         954,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         955,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         956,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         957,
         958,
         957,
         957,
         957,
         957,
         959,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         960,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         959,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         957,
         961,
         962,
         961,
         961,
         961,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         965,
         965,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         969,
         970,
         969,
         969,
         969,
         969,
         971,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         972,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         971,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         969,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         973,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         974,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         975,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         976,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         977,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         978,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         979,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         980,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         981,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         982,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         983,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         984,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         985,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         935,
         936,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         938,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         2373,
         2374,
         2373,
         2373,
         2373,
         2373,
         2375,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2376,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2375,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2373,
         2377,
         2378,
         2377,
         2377,
         2377,
         2377,
         2379,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2380,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2379,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2381,
         2382,
         2381,
         2381,
         2381,
         2381,
         2383,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2384,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2383,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2381,
         2385,
         2386,
         2385,
         2385,
         2385,
         2385,
         2387,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2388,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2387,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         2385,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         939,
         939,
         939,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         948,
         948,
         948,
         922,
         922,
         922,
         948,
         948,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         941,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         941,
         941,
         922,
         922,
         941,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1054,
         1055,
         1054,
         1054,
         1054,
         1054,
         1056,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1057,
         1054,
         1054,
         1058,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1056,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1050,
         1051,
         1059,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1060,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1061,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1062,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1063,
         1064,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1066,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1050,
         2428,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1068,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1070,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1071,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1072,
         1073,
         1072,
         1072,
         1072,
         1072,
         1074,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1075,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1074,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1072,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1077,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1078,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1079,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1080,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1081,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1082,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1083,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1084,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1085,
         1086,
         1085,
         1085,
         1085,
         1085,
         1087,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1088,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1087,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1085,
         1089,
         1090,
         1089,
         1089,
         1089,
         1089,
         1091,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1092,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1091,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1089,
         1093,
         1094,
         1093,
         1093,
         1093,
         1093,
         1095,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1096,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1095,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1097,
         1098,
         1097,
         1097,
         1097,
         1097,
         1099,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1100,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1099,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1097,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1101,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1102,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1103,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1104,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1105,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1106,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1107,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1108,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1109,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1110,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1111,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1112,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1113,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2429,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2428,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1063,
         1064,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1066,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1065,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1063,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2406,
         2407,
         2406,
         2406,
         2406,
         2406,
         2408,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2409,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2408,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2406,
         2410,
         2411,
         2410,
         2410,
         2410,
         2410,
         2412,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2413,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2412,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2410,
         2414,
         2415,
         2414,
         2414,
         2414,
         2414,
         2416,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2417,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2416,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2414,
         2418,
         2419,
         2418,
         2418,
         2418,
         2418,
         2420,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2421,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2420,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         2418,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2428,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2429,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2429,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2429,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         2429,
         1050,
         1050,
         1050,
         1050,
         1052,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1067,
         1067,
         1067,
         1067,
         1067,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1076,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1076,
         1076,
         1076,
         1050,
         1050,
         1050,
         1076,
         1076,
         1050,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1069,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1069,
         1069,
         1050,
         1050,
         1069,
         1050,
         1050,
         1051,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1053,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1052,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         990,
         991,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         993,
         990,
         990,
         994,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         986,
         987,
         995,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         996,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         997,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         998,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         1004,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         1006,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         1007,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1008,
         1009,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         1013,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         1014,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1015,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1016,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1017,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1018,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1019,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1020,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1029,
         1030,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1032,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1033,
         1034,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1036,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1037,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1038,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1039,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1040,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1041,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1042,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1043,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1044,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2430,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1045,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1046,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1047,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1048,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1049,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2389,
         2390,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2392,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2393,
         2394,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2396,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2397,
         2398,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2400,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2401,
         2402,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2404,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         990,
         991,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         993,
         990,
         990,
         994,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         986,
         987,
         995,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         996,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         997,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         998,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         1004,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         1006,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         1007,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1008,
         1009,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         1013,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         1014,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1015,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1016,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1017,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1018,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1019,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1020,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1029,
         1030,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1032,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1033,
         1034,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1036,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1037,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1038,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1039,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1040,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1041,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1042,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1043,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1044,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2431,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1045,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1046,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1047,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1048,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1049,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2389,
         2390,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2392,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2393,
         2394,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2396,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2397,
         2398,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2400,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2401,
         2402,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2404,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         990,
         991,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         993,
         990,
         990,
         994,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         986,
         987,
         995,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         996,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         997,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         998,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         1004,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         1006,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         1007,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1008,
         1009,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         1013,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         1014,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1015,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1016,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1017,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1018,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1019,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1020,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1029,
         1030,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1032,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1033,
         1034,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1036,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1037,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1038,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1039,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1040,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1041,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1042,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1043,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1044,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2432,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1045,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1046,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1047,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1048,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1049,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2389,
         2390,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2392,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2393,
         2394,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2396,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2397,
         2398,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2400,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2401,
         2402,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2404,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         990,
         991,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         993,
         990,
         990,
         994,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         986,
         987,
         995,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         996,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         997,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         998,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         1004,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         1006,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         1007,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1008,
         1009,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         1013,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         1014,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1015,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1016,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1017,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1018,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1019,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1020,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1029,
         1030,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1032,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1033,
         1034,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1036,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1037,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1038,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1039,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1040,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1041,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1042,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1043,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1044,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2433,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1045,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1046,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1047,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1048,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1049,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2389,
         2390,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2392,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2393,
         2394,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2396,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2397,
         2398,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2400,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2401,
         2402,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2404,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         990,
         991,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         993,
         990,
         990,
         994,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         992,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         990,
         986,
         987,
         995,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         996,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         997,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         998,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         1004,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         1006,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         1007,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1008,
         1009,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         1013,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         1014,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1015,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1016,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1017,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1018,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1019,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1020,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1029,
         1030,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1032,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1031,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1029,
         1033,
         1034,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1036,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1035,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         1033,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1037,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1038,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1039,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1040,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1041,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1042,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1043,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1044,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2434,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1045,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1046,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1047,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1048,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1049,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         999,
         1000,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1002,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         1001,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         999,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         2389,
         2390,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2392,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2391,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2389,
         2393,
         2394,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2396,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2395,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2393,
         2397,
         2398,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2400,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2399,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2397,
         2401,
         2402,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2404,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2403,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         2401,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1003,
         1003,
         1003,
         1003,
         1003,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         1012,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1012,
         1012,
         1012,
         986,
         986,
         986,
         1012,
         1012,
         986,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         1005,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         1005,
         1005,
         986,
         986,
         1005,
         986,
         986,
         987,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         989,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         988,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         986,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3208,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3208,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3208,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3208,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3209,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         3238,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         131,
         132,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         533,
         131,
         131,
         534,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         532,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         129,
         130,
         535,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         536,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         537,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         538,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         544,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         546,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         547,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         548,
         549,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         551,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         553,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         554,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         555,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         556,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         557,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         558,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         559,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         560,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         561,
         562,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         564,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         563,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         561,
         565,
         566,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         569,
         570,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         573,
         574,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         576,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         575,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         573,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         577,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         578,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         579,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         580,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         581,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         582,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         583,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         584,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         585,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         586,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         587,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         588,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         589,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         539,
         540,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         542,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         541,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         539,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         2273,
         2274,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2276,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2275,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2273,
         2277,
         2278,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2280,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2279,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2277,
         2281,
         2282,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2284,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2283,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2281,
         2285,
         2286,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2288,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2287,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         2285,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         543,
         543,
         543,
         543,
         543,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         552,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         552,
         552,
         552,
         129,
         129,
         129,
         552,
         552,
         129,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         545,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         545,
         545,
         129,
         129,
         545,
         129,
         129,
         130,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         531,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         530,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         14,
         14,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         19,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         21,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         14,
         14,
         14,
         14,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         22,
         2,
         2,
         5,
         5,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         22,
         2,
         2,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         137,
         138,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         138,
         138,
         1548,
         1549,
         1550,
         1551,
         1552,
         1553,
         1554,
         1555,
         1556,
         138,
         1557,
         1558,
         1559,
         1560,
         2493,
         2494,
         2495,
         2496,
         2497,
         1551,
         3165,
         1546,
         1548,
         1546,
         1546,
         1546,
         1561,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1561,
         1561,
         1546,
         1546,
         1549,
         1546,
         1546,
         1546,
         1561,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1561,
         1561,
         1546,
         137,
         1550,
         1546,
         1546,
         1562,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         1547,
         1551,
         1561,
         1561,
         1547,
         1563,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1561,
         1563,
         1563,
         1561,
         137,
         1552,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1553,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1554,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1555,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         1564,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         2498,
         1546,
         137,
         1556,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         138,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         1565,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1557,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1558,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1559,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         1560,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         2493,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         2494,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         137,
         2495,
         1546,
         1546,
         137,
         1547,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         137,
         1546,
         1547,
         1547,
         1546,
         1546,
         2496,
         1546,
         1546,
         1546,
         1561,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1561,
         1561,
         1546,
         1547,
         2497,
         1561,
         1561,
         1547,
         1563,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1561,
         1563,
         1563,
         1561,
         1547,
         1551,
         1561,
         1561,
         1547,
         1563,
         1547,
         1547,
         1547,
         2498,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1547,
         1561,
         1563,
         2499,
         1561,
         1546,
         3165,
         1546,
         1546,
         1546,
         1561,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1546,
         1561,
         1561,
         1546,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         3,
         4,
         1,
         1,
         1,
         5,
         1,
         1,
         1,
         3,
         4,
         1,
         1,
         1,
         1,
         1,
         1,
         6,
         1,
         3,
         4,
         1,
         1,
         1,
         5,
         7,
         3,
         3,
         3,
         8,
         4,
         4,
         4,
         9,
         1,
         1,
         1,
         5,
         1,
         5,
         1,
         1,
         5,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         10,
         1,
         1,
         1,
         1,
         1,
         10,
         1,
         1,
         1,
         1,
         10,
         3,
         3,
         3,
         3,
         11,
         4,
         4,
         4,
         4,
         1,
         1,
         1,
         1,
         10,
         4,
         1,
         1,
         1,
         10,
         1,
         1,
         1,
         1,
         10,
         5,
         5,
         5,
         5,
         12,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         10,
         1,
         1,
         1,
         1,
         1,
         10,
         10,
         1,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         4,
         4,
         1,
         1,
         1,
         1,
         1,
         1,
         5,
         5,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         10,
         10,
         4,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 14,
      .table = (const uint16_t []) {
      
         139,
         1533,
         1534,
         2805,
         2806,
         2807,
         2808,
         2809,
         2810,
         2811,
         3152,
         3153,
         3154,
         3155,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         140,
         2143,
         2144,
         2145,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         141,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         142,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         143,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         5,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         6,
         6,
         7,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         144,
         2014,
         2015,
         2016,
         2017,
         2895,
         2896,
         2897,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         145,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         146,
         147,
         2128,
         2129,
         2130,
         147,
         147,
         2131,
         2132,
         2133,
         2128,
         2131,
         2128,
         2129,
         2130,
         2129,
         2132,
         2129,
         2129,
         2130,
         2130,
         2133,
         2130,
         2130,
         2130,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         148,
         149,
         2134,
         2135,
         149,
         149,
         2136,
         2137,
         2134,
         2136,
         2134,
         2135,
         2135,
         2137,
         2135,
         2135,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         150,
         151,
         2138,
         151,
         151,
         2139,
         2138,
         2139,
         2138,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         152,
         153,
         152,
         154,
         152,
         153,
         152,
         155,
         152,
         153,
         152,
         154,
         152,
         153,
         152,
         155,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         156,
         157,
         156,
         158,
         156,
         157,
         156,
         158,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         159,
         160,
         159,
         159,
         159,
         161,
         162,
         161,
         161,
         161,
         159,
         160,
         159,
         1380,
         159,
         159,
         160,
         159,
         159,
         159,
         159,
         160,
         159,
         159,
         1381,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         163,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         0,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         164,
         165,
         164,
         164,
         1356,
         164,
         166,
         167,
         166,
         166,
         1357,
         166,
         164,
         1358,
         164,
         164,
         1356,
         164,
         1359,
         1360,
         1359,
         1359,
         1361,
         1359,
         164,
         1362,
         164,
         164,
         1356,
         164,
         164,
         1363,
         164,
         164,
         1356,
         164,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         6,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         9,
         9,
         10,
         10,
         11,
         11,
         11,
         11,
         12,
         12,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         15,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         6,
         6,
         6,
         6,
         6,
         6,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         21,
         21,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         22,
         20,
         20,
         20,
         20,
         20,
         0,
         21,
         21,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         1,
         0,
         4,
         9,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         168,
         1991,
         1992,
         1993,
         1994,
         1995,
         1996,
         1997,
         1998,
         1999,
         2000,
         2001,
         2002,
         2003,
         2702,
         2703,
         2704,
         2705,
         2706,
         2707,
         3157,
         3158,
         3159,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         3,
         3,
         3,
         14,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         13,
         2,
         2,
         15,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         16,
         17,
         5,
         5,
         5,
         5,
         5,
         18,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         3,
         3,
         14,
         14,
         14,
         14,
         14,
         14,
         13,
         13,
         2,
         13,
         2,
         13,
         5,
         19,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         20,
         3,
         3,
         3,
         3,
         21,
         2,
         2,
         2,
         2,
         2,
         2,
         13,
         13,
         13,
         2,
         2,
         2,
         2,
         2,
         2,
         13,
         13,
         13,
         13,
         2,
         2,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         169,
         170,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         171,
         172,
         171,
         171,
         1569,
         1570,
         1571,
         1572,
         1573,
         1574,
         1575,
         1576,
         171,
         171,
         171,
         2831,
         1570,
         1570,
         1570,
         1570,
         171,
         171,
         1574,
         1577,
         1578,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         1577,
         1582,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         169,
         170,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         169,
         1583,
         169,
         169,
         169,
         1584,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1584,
         1584,
         1584,
         1584,
         169,
         169,
         1567,
         169,
         1585,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         169,
         170,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         169,
         1586,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         1587,
         1588,
         1587,
         1587,
         1587,
         1589,
         1587,
         1587,
         1587,
         1590,
         1587,
         1591,
         1587,
         1587,
         1587,
         1587,
         1589,
         1589,
         1589,
         1589,
         1587,
         1587,
         1590,
         169,
         1592,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         1593,
         1594,
         1593,
         1593,
         1593,
         1595,
         1593,
         1593,
         1593,
         1596,
         1593,
         1597,
         1593,
         1593,
         1593,
         1593,
         1595,
         1595,
         1595,
         1595,
         1593,
         1593,
         1596,
         169,
         170,
         169,
         169,
         169,
         1566,
         169,
         169,
         169,
         1567,
         169,
         1568,
         1598,
         169,
         169,
         169,
         1566,
         1566,
         1566,
         1566,
         169,
         169,
         1567,
         1577,
         2832,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         1577,
         2833,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         1577,
         1578,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         169,
         2834,
         169,
         169,
         169,
         1584,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1584,
         1584,
         1584,
         1584,
         169,
         169,
         1567,
         169,
         2835,
         169,
         169,
         169,
         1584,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1584,
         1584,
         1584,
         1584,
         169,
         169,
         1567,
         169,
         2836,
         169,
         169,
         169,
         1584,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1584,
         1584,
         1584,
         1584,
         169,
         169,
         1567,
         169,
         3167,
         169,
         169,
         169,
         1584,
         169,
         169,
         169,
         1567,
         169,
         1568,
         169,
         169,
         169,
         169,
         1584,
         1584,
         1584,
         1584,
         169,
         169,
         1567,
         1577,
         3222,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         1577,
         3223,
         1577,
         1577,
         1577,
         1579,
         1577,
         1577,
         1577,
         1580,
         1577,
         1581,
         1577,
         1577,
         1577,
         1577,
         1579,
         1579,
         1579,
         1579,
         1577,
         1577,
         1580,
         1587,
         3224,
         1587,
         1587,
         1587,
         1589,
         1587,
         1587,
         1587,
         1590,
         1587,
         1591,
         1587,
         1587,
         1587,
         1587,
         1589,
         1589,
         1589,
         1589,
         1587,
         1587,
         1590,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         15,
         16,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         5,
         18,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         173,
         174,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         175,
         176,
         175,
         175,
         1602,
         1603,
         1604,
         175,
         1605,
         1606,
         1607,
         1608,
         1609,
         175,
         2870,
         1603,
         1603,
         1603,
         1603,
         1610,
         1611,
         1610,
         1610,
         1610,
         1612,
         1610,
         1610,
         1610,
         1610,
         1613,
         1610,
         1614,
         1610,
         1610,
         1612,
         1612,
         1612,
         1612,
         1610,
         1615,
         1610,
         1610,
         1610,
         1612,
         1610,
         1610,
         1610,
         1610,
         1613,
         1610,
         1614,
         1610,
         1610,
         1612,
         1612,
         1612,
         1612,
         173,
         174,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         173,
         1616,
         173,
         173,
         173,
         1617,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1617,
         1617,
         1617,
         1617,
         173,
         1618,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         173,
         1619,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         173,
         1620,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         173,
         174,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         1621,
         1622,
         1621,
         1621,
         1621,
         1623,
         1621,
         1621,
         1621,
         1621,
         1624,
         1621,
         1625,
         1621,
         1621,
         1623,
         1623,
         1623,
         1623,
         173,
         1626,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1599,
         1599,
         1599,
         1599,
         1627,
         1628,
         1627,
         1627,
         1627,
         1629,
         1627,
         1627,
         1627,
         1627,
         1630,
         1627,
         1631,
         1627,
         1627,
         1629,
         1629,
         1629,
         1629,
         173,
         174,
         173,
         173,
         173,
         1599,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         1632,
         173,
         1599,
         1599,
         1599,
         1599,
         1610,
         1611,
         1610,
         1610,
         1610,
         1612,
         1610,
         1610,
         1610,
         1610,
         1613,
         1610,
         1614,
         1610,
         1610,
         1612,
         1612,
         1612,
         1612,
         173,
         2871,
         173,
         173,
         173,
         1617,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1617,
         1617,
         1617,
         1617,
         173,
         2872,
         173,
         173,
         173,
         1617,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1617,
         1617,
         1617,
         1617,
         173,
         2873,
         173,
         173,
         173,
         1617,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1617,
         1617,
         1617,
         1617,
         173,
         3168,
         173,
         173,
         173,
         1617,
         173,
         173,
         173,
         173,
         1600,
         173,
         1601,
         173,
         173,
         1617,
         1617,
         1617,
         1617,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         14,
         14,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         19,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         21,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         14,
         14,
         14,
         14,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         22,
         2,
         2,
         5,
         5,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         22,
         2,
         2,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         177,
         178,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         178,
         178,
         1635,
         1636,
         1637,
         1638,
         1639,
         1640,
         1641,
         1642,
         1643,
         178,
         1644,
         1645,
         1646,
         1647,
         2500,
         2501,
         2502,
         2503,
         2504,
         1638,
         3166,
         1633,
         1635,
         1633,
         1633,
         1633,
         1648,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1648,
         1648,
         1633,
         1633,
         1636,
         1633,
         1633,
         1633,
         1648,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1648,
         1648,
         1633,
         177,
         1637,
         1633,
         1633,
         1649,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         1634,
         1638,
         1648,
         1648,
         1634,
         1650,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1648,
         1650,
         1650,
         1648,
         177,
         1639,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1640,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1641,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1642,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         1651,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         2505,
         1633,
         177,
         1643,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         178,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         1652,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1644,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1645,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1646,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         1647,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         2500,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         2501,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         177,
         2502,
         1633,
         1633,
         177,
         1634,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1633,
         1634,
         1634,
         1633,
         1633,
         2503,
         1633,
         1633,
         1633,
         1648,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1648,
         1648,
         1633,
         1634,
         2504,
         1648,
         1648,
         1634,
         1650,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1648,
         1650,
         1650,
         1648,
         1634,
         1638,
         1648,
         1648,
         1634,
         1650,
         1634,
         1634,
         1634,
         2505,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1634,
         1648,
         1650,
         2506,
         1648,
         1633,
         3166,
         1633,
         1633,
         1633,
         1648,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1633,
         1648,
         1648,
         1633,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         179,
         180,
         179,
         2028,
         2028,
         2029,
         2029,
         179,
         179,
         179,
         179,
         179,
         179,
         180,
         2030,
         2028,
         2031,
         2029,
         2032,
         2033,
         2034,
         2035,
         2036,
         179,
         179,
         2037,
         179,
         2028,
         2028,
         2029,
         2029,
         179,
         179,
         179,
         179,
         179,
         2038,
         2039,
         2038,
         2040,
         2040,
         2041,
         2041,
         2038,
         2038,
         2038,
         2038,
         2038,
         2038,
         2042,
         2038,
         2040,
         2040,
         2041,
         2041,
         2038,
         2038,
         2038,
         2038,
         2038,
         2043,
         2044,
         2043,
         2045,
         2045,
         2046,
         2046,
         2043,
         2043,
         2043,
         2043,
         2043,
         2043,
         2047,
         2043,
         2045,
         2045,
         2046,
         2046,
         2043,
         2043,
         2043,
         2043,
         2043,
         179,
         2048,
         179,
         2028,
         2028,
         2029,
         2029,
         2049,
         179,
         179,
         179,
         179,
         179,
         2050,
         179,
         2028,
         2028,
         2029,
         2029,
         179,
         2051,
         179,
         2051,
         179,
         179,
         2052,
         179,
         2028,
         2028,
         2029,
         2029,
         179,
         179,
         2053,
         2053,
         179,
         179,
         2054,
         179,
         2028,
         2028,
         2029,
         2029,
         179,
         2051,
         2053,
         2055,
         179,
         179,
         2930,
         179,
         2028,
         2028,
         2029,
         2029,
         179,
         179,
         179,
         179,
         179,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         15,
         6,
         6,
         16,
         7,
         7,
         15,
         15,
         15,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         15,
         15,
         6,
         6,
         6,
         6,
         6,
         8,
         8,
         8,
         9,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         15,
         15,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         2,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         181,
         182,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         181,
         181,
         181,
         181,
         2931,
         2931,
         183,
         184,
         183,
         1845,
         183,
         1846,
         1847,
         1848,
         1849,
         1850,
         1851,
         1852,
         1853,
         1854,
         2932,
         2933,
         2934,
         1855,
         1856,
         1855,
         1857,
         1855,
         1855,
         1858,
         1858,
         1859,
         1859,
         1855,
         1855,
         1855,
         1855,
         1855,
         2935,
         2935,
         181,
         182,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         181,
         181,
         181,
         181,
         2931,
         2931,
         1860,
         1861,
         1860,
         1862,
         1860,
         1860,
         1863,
         1863,
         1864,
         1864,
         1860,
         1860,
         1860,
         1860,
         1860,
         2936,
         2936,
         181,
         1865,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         181,
         181,
         181,
         181,
         2931,
         2931,
         1866,
         1867,
         1866,
         1868,
         1866,
         1866,
         1869,
         1869,
         1870,
         1870,
         1866,
         1866,
         1866,
         1866,
         1866,
         2937,
         2937,
         1866,
         1871,
         1866,
         1868,
         1866,
         1866,
         1869,
         1869,
         1870,
         1870,
         1866,
         1866,
         1866,
         1866,
         1866,
         2937,
         2937,
         1872,
         1873,
         1872,
         1874,
         1872,
         1872,
         1875,
         1875,
         1876,
         1876,
         1872,
         1872,
         1872,
         1872,
         1872,
         2938,
         2938,
         1872,
         1877,
         1872,
         1874,
         1872,
         1872,
         1875,
         1875,
         1876,
         1876,
         1872,
         1872,
         1872,
         1872,
         1872,
         2938,
         2938,
         181,
         1878,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         1879,
         181,
         181,
         181,
         181,
         2931,
         2931,
         181,
         1880,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         1881,
         181,
         1881,
         181,
         2931,
         2931,
         181,
         1882,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         181,
         1883,
         1883,
         181,
         2931,
         2931,
         181,
         1884,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         1881,
         1883,
         1885,
         181,
         2931,
         2931,
         181,
         182,
         181,
         1842,
         181,
         181,
         1843,
         1843,
         1844,
         1844,
         181,
         181,
         181,
         181,
         181,
         2931,
         2931,
         1866,
         1867,
         1866,
         1868,
         1866,
         1866,
         1869,
         1869,
         1870,
         1870,
         1866,
         1866,
         1866,
         1866,
         1866,
         2937,
         2937,
         1866,
         1871,
         1866,
         1868,
         1866,
         1866,
         1869,
         1869,
         1870,
         1870,
         1866,
         1866,
         1866,
         1866,
         1866,
         2937,
         2937,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         185,
         186,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         186,
         2058,
         2056,
         2059,
         2057,
         2060,
         2061,
         2062,
         2063,
         2064,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2065,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2066,
         2067,
         2066,
         2068,
         2068,
         2069,
         2069,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2070,
         2066,
         2068,
         2068,
         2069,
         2069,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2066,
         2071,
         2072,
         2071,
         2073,
         2073,
         2074,
         2074,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2075,
         2071,
         2073,
         2073,
         2074,
         2074,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         2071,
         185,
         2076,
         185,
         2056,
         2056,
         2057,
         2057,
         2077,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2078,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         2079,
         185,
         2079,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2080,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         2081,
         2081,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2082,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         2079,
         2081,
         2083,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2084,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2085,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2086,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2087,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2088,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2939,
         185,
         2056,
         2056,
         2057,
         2057,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         6,
         6,
         6,
         7,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         8,
         8,
         8,
         9,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         2,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
      },
      
      .num_filtered_states = 14,
      .table = (const uint16_t []) {
      
         187,
         187,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         187,
         187,
         187,
         187,
         188,
         188,
         188,
         1889,
         188,
         1890,
         1891,
         1892,
         1893,
         1894,
         1895,
         1896,
         1897,
         1898,
         1899,
         1899,
         1899,
         1900,
         1899,
         1899,
         1901,
         1901,
         1902,
         1902,
         1899,
         1899,
         1899,
         1899,
         187,
         187,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         187,
         187,
         187,
         187,
         1903,
         1903,
         1903,
         1904,
         1903,
         1903,
         1905,
         1905,
         1906,
         1906,
         1903,
         1903,
         1903,
         1903,
         187,
         1907,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         187,
         187,
         187,
         187,
         1908,
         1908,
         1908,
         1909,
         1908,
         1908,
         1910,
         1910,
         1911,
         1911,
         1908,
         1908,
         1908,
         1908,
         1908,
         1912,
         1908,
         1909,
         1908,
         1908,
         1910,
         1910,
         1911,
         1911,
         1908,
         1908,
         1908,
         1908,
         1913,
         1913,
         1913,
         1914,
         1913,
         1913,
         1915,
         1915,
         1916,
         1916,
         1913,
         1913,
         1913,
         1913,
         1913,
         1917,
         1913,
         1914,
         1913,
         1913,
         1915,
         1915,
         1916,
         1916,
         1913,
         1913,
         1913,
         1913,
         187,
         1918,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         1919,
         187,
         187,
         187,
         187,
         1920,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         187,
         1921,
         187,
         1921,
         187,
         1922,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         187,
         187,
         1923,
         1923,
         187,
         1924,
         187,
         1886,
         187,
         187,
         1887,
         1887,
         1888,
         1888,
         187,
         1921,
         1923,
         1925,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         9,
         3,
         3,
         3,
         3,
         3,
         10,
         3,
         3,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         13,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         7,
         7,
         14,
         7,
         8,
         8,
         8,
         15,
         15,
         8,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         14,
         7,
         14,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         189,
         190,
         1686,
         1687,
         189,
         189,
         1688,
         1689,
         1689,
         2875,
         1687,
         2876,
         2877,
         3169,
         3170,
         3170,
         190,
         190,
         1690,
         1691,
         1692,
         1693,
         1694,
         1695,
         1696,
         2878,
         1691,
         2879,
         2880,
         3171,
         3172,
         3173,
         1686,
         1690,
         1686,
         1697,
         1686,
         1686,
         1698,
         1699,
         1699,
         2881,
         1697,
         2882,
         2883,
         3174,
         3175,
         3175,
         1687,
         1691,
         1697,
         1687,
         1687,
         1687,
         1700,
         1701,
         1701,
         2875,
         1687,
         2876,
         2884,
         3169,
         3176,
         3176,
         189,
         1692,
         1686,
         1687,
         189,
         189,
         1688,
         1689,
         1689,
         2875,
         1687,
         2876,
         2877,
         3169,
         3170,
         3170,
         189,
         1693,
         1686,
         1687,
         189,
         1702,
         1688,
         1689,
         1689,
         2875,
         1687,
         2876,
         2877,
         3169,
         3170,
         3170,
         1688,
         1694,
         1698,
         1700,
         1688,
         1688,
         1688,
         1703,
         1703,
         2885,
         1700,
         2886,
         2877,
         3177,
         3178,
         3178,
         1689,
         1695,
         1699,
         1701,
         1689,
         1689,
         1703,
         1689,
         1689,
         2887,
         1701,
         2888,
         2889,
         3179,
         3170,
         3170,
         1689,
         1696,
         1699,
         1701,
         1689,
         1689,
         1703,
         1689,
         1689,
         2887,
         1701,
         2888,
         2889,
         3179,
         3170,
         3170,
         2875,
         2878,
         2881,
         2875,
         2875,
         2875,
         2885,
         2887,
         2887,
         2875,
         2875,
         2890,
         2891,
         3180,
         3181,
         3181,
         1687,
         1691,
         1697,
         1687,
         1687,
         1687,
         1700,
         1701,
         1701,
         2875,
         2892,
         2876,
         2884,
         3169,
         3176,
         3176,
         2876,
         2879,
         2882,
         2876,
         2876,
         2876,
         2886,
         2888,
         2888,
         2890,
         2876,
         2876,
         2893,
         3182,
         3183,
         3183,
         2877,
         2880,
         2883,
         2884,
         2877,
         2877,
         2877,
         2889,
         2889,
         2891,
         2884,
         2893,
         2877,
         3184,
         3185,
         3185,
         3169,
         3171,
         3174,
         3169,
         3169,
         3169,
         3177,
         3179,
         3179,
         3180,
         3169,
         3182,
         3184,
         3169,
         3186,
         3186,
         3170,
         3172,
         3175,
         3176,
         3170,
         3170,
         3178,
         3170,
         3170,
         3181,
         3176,
         3183,
         3185,
         3186,
         3170,
         3170,
         3170,
         3173,
         3175,
         3176,
         3170,
         3170,
         3178,
         3170,
         3170,
         3181,
         3176,
         3183,
         3185,
         3186,
         3170,
         3170,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         191,
         2109,
         2110,
         2111,
         2112,
         2894,
         3232,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         9,
         3,
         3,
         3,
         3,
         3,
         10,
         3,
         11,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         13,
         13,
         0,
         12,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         192,
         193,
         1704,
         1705,
         192,
         192,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
         193,
         193,
         1707,
         1708,
         1709,
         193,
         1710,
         1711,
         2848,
         2849,
         1708,
         2850,
         2851,
         2852,
         2853,
         3225,
         3226,
         1704,
         1707,
         1704,
         1712,
         1704,
         1704,
         1704,
         1713,
         1704,
         2854,
         1712,
         2855,
         2856,
         2856,
         2857,
         1704,
         1704,
         1705,
         1708,
         1712,
         1705,
         1705,
         1705,
         1705,
         1714,
         1705,
         2844,
         1705,
         2845,
         2858,
         2858,
         2859,
         1705,
         1705,
         192,
         1709,
         1704,
         1705,
         1715,
         192,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
         192,
         193,
         1704,
         1705,
         192,
         1716,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
         192,
         1710,
         1704,
         1705,
         192,
         192,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
         1706,
         1711,
         1713,
         1714,
         1706,
         1706,
         1706,
         1706,
         1706,
         2860,
         1714,
         2861,
         2862,
         2862,
         2847,
         1706,
         1706,
         192,
         2848,
         1704,
         1705,
         192,
         192,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
         2844,
         2849,
         2854,
         2844,
         2844,
         2844,
         2844,
         2860,
         2844,
         2844,
         2844,
         2863,
         2864,
         2864,
         2865,
         2844,
         2844,
         1705,
         1708,
         1712,
         1705,
         1705,
         1705,
         1705,
         1714,
         1705,
         2844,
         2866,
         2845,
         2858,
         2858,
         2859,
         1705,
         1705,
         2845,
         2850,
         2855,
         2845,
         2845,
         2845,
         2845,
         2861,
         2845,
         2863,
         2845,
         2845,
         2867,
         2867,
         2868,
         2845,
         2845,
         2846,
         2851,
         2856,
         2858,
         2846,
         2846,
         2846,
         2862,
         2846,
         2864,
         2858,
         2867,
         2846,
         2846,
         2869,
         2846,
         2846,
         2846,
         2852,
         2856,
         2858,
         2846,
         2846,
         2846,
         2862,
         2846,
         2864,
         2858,
         2867,
         2846,
         2846,
         2869,
         2846,
         2846,
         2847,
         2853,
         2857,
         2859,
         2847,
         2847,
         2847,
         2847,
         2847,
         2865,
         2859,
         2868,
         2869,
         2869,
         2847,
         2847,
         2847,
         192,
         3225,
         1704,
         1705,
         192,
         192,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
         192,
         3226,
         1704,
         1705,
         192,
         192,
         192,
         1706,
         192,
         2844,
         1705,
         2845,
         2846,
         2846,
         2847,
         192,
         192,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         194,
         195,
         1794,
         1795,
         1796,
         1797,
         1797,
         2898,
         1794,
         2899,
         3187,
         3187,
         195,
         195,
         1798,
         1799,
         1800,
         1801,
         1802,
         2900,
         1798,
         2901,
         3188,
         3189,
         1794,
         1798,
         1794,
         1803,
         1804,
         1805,
         1805,
         2898,
         1794,
         2902,
         3190,
         3190,
         1795,
         1799,
         1803,
         1795,
         1806,
         1807,
         1807,
         2903,
         1803,
         2904,
         3191,
         3191,
         1796,
         1800,
         1804,
         1806,
         1796,
         1808,
         1808,
         2905,
         1804,
         2899,
         3192,
         3192,
         1797,
         1801,
         1805,
         1807,
         1808,
         1797,
         1797,
         2906,
         1805,
         2907,
         3187,
         3187,
         1797,
         1802,
         1805,
         1807,
         1808,
         1797,
         1797,
         2906,
         1805,
         2907,
         3187,
         3187,
         2898,
         2900,
         2898,
         2903,
         2905,
         2906,
         2906,
         2898,
         2898,
         2908,
         3193,
         3193,
         1794,
         1798,
         1794,
         1803,
         1804,
         1805,
         1805,
         2898,
         2909,
         2902,
         3190,
         3190,
         2899,
         2901,
         2902,
         2904,
         2899,
         2907,
         2907,
         2908,
         2902,
         2899,
         3194,
         3194,
         3187,
         3188,
         3190,
         3191,
         3192,
         3187,
         3187,
         3193,
         3190,
         3194,
         3187,
         3187,
         3187,
         3189,
         3190,
         3191,
         3192,
         3187,
         3187,
         3193,
         3190,
         3194,
         3187,
         3187,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         2,
         7,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         196,
         197,
         1809,
         1810,
         196,
         1811,
         2910,
         1809,
         2911,
         2911,
         2912,
         197,
         197,
         1812,
         1813,
         1814,
         1815,
         2913,
         1812,
         2914,
         2915,
         2916,
         1809,
         1812,
         1809,
         1816,
         1809,
         1817,
         2910,
         1809,
         2917,
         2917,
         2918,
         1810,
         1813,
         1816,
         1810,
         1810,
         1818,
         2919,
         1816,
         2920,
         2920,
         2921,
         196,
         1814,
         1809,
         1810,
         196,
         1811,
         2910,
         1809,
         2911,
         2911,
         2912,
         1811,
         1815,
         1817,
         1818,
         1811,
         1811,
         2922,
         1817,
         2923,
         2923,
         2912,
         2910,
         2913,
         2910,
         2919,
         2910,
         2922,
         2910,
         2910,
         2924,
         2924,
         2925,
         1809,
         1812,
         1809,
         1816,
         1809,
         1817,
         2910,
         2926,
         2917,
         2917,
         2918,
         2911,
         2914,
         2917,
         2920,
         2911,
         2923,
         2924,
         2917,
         2911,
         2911,
         2927,
         2911,
         2915,
         2917,
         2920,
         2911,
         2923,
         2924,
         2917,
         2911,
         2911,
         2927,
         2912,
         2916,
         2918,
         2921,
         2912,
         2912,
         2925,
         2918,
         2927,
         2927,
         2912,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         8,
         5,
         5,
         8,
         5,
         5,
         8,
         5,
         5,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         8,
         5,
         8,
         5,
         8,
         8,
         5,
         8,
         5,
         8,
         6,
         10,
         6,
         6,
         10,
         6,
         6,
         10,
         6,
         10,
         6,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         8,
         8,
         5,
         5,
         5,
         8,
         8,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         198,
         199,
         1940,
         1940,
         198,
         1941,
         1942,
         2940,
         2941,
         3031,
         3032,
         199,
         199,
         1943,
         1943,
         199,
         1944,
         1945,
         2942,
         2943,
         3033,
         3034,
         1940,
         1943,
         1940,
         1946,
         1940,
         1947,
         1948,
         2944,
         2945,
         3035,
         3036,
         1940,
         1943,
         1946,
         1946,
         1940,
         1947,
         1948,
         2944,
         2945,
         3035,
         3036,
         198,
         199,
         1940,
         1940,
         1949,
         1941,
         1942,
         2940,
         2941,
         3031,
         3032,
         1941,
         1944,
         1947,
         1947,
         1941,
         1941,
         1950,
         2946,
         2941,
         3037,
         3038,
         1942,
         1945,
         1948,
         1948,
         1942,
         1950,
         1942,
         2947,
         2948,
         3039,
         3032,
         2940,
         2942,
         2944,
         2944,
         2940,
         2946,
         2947,
         2949,
         2950,
         3040,
         3041,
         2941,
         2943,
         2945,
         2945,
         2941,
         2941,
         2948,
         2950,
         2941,
         3042,
         3043,
         3031,
         3033,
         3035,
         3035,
         3031,
         3037,
         3039,
         3040,
         3042,
         3031,
         3044,
         3032,
         3034,
         3036,
         3036,
         3032,
         3038,
         3032,
         3041,
         3043,
         3044,
         3032,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         5,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         3,
         3,
         6,
         3,
         3,
         6,
         6,
         6,
         3,
         3,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         5,
         5,
         0,
         5,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         200,
         201,
         200,
         2113,
         2951,
         2952,
         2953,
         201,
         201,
         201,
         2114,
         2954,
         2955,
         2956,
         200,
         201,
         2115,
         2113,
         2951,
         2952,
         2953,
         2113,
         2114,
         2113,
         2113,
         2957,
         2958,
         2953,
         2951,
         2954,
         2951,
         2957,
         2959,
         2960,
         2961,
         2952,
         2955,
         2952,
         2958,
         2960,
         2952,
         2962,
         2953,
         2956,
         2953,
         2953,
         2961,
         2962,
         2953,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         3,
         0,
         0,
         0,
         3,
         3,
         2,
         4,
         0,
         0,
         0,
         2,
         4,
         3,
         3,
         3,
         2,
         4,
         0,
         0,
         2,
         4,
         3,
         3,
         3,
         2,
         4,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         202,
         203,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         203,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1364,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1365,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1366,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1367,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1368,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1369,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1370,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         1371,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         2964,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
         202,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         204,
         1539,
         1540,
         1541,
         1542,
         1543,
         1544,
         1545,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         205,
         1819,
         1820,
         1821,
         1822,
         1823,
         1824,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         206,
         1825,
         1826,
         1827,
         1828,
         1829,
         1830,
         1831,
         1832,
         1833,
         1834,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         207,
         1951,
         1952,
         1953,
         1954,
         1955,
         1956,
         1957,
         1958,
         1959,
         1960,
         2967,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         9,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         15,
         10,
         10,
         10,
         10,
         10,
         16,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         17,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         10,
         10,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         3,
         2,
         0,
         0,
         1,
         2,
         2,
         0,
         3,
         1,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         0,
         3,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         0,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         208,
         1926,
         1927,
         1928,
         1929,
         1930,
         1931,
         1932,
         1933,
         1934,
         1935,
         1936,
         1937,
         1938,
         1939,
         2965,
         2966,
         3117,
         3118,
         3119,
         3120,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         209,
         1835,
         1836,
         1837,
         1838,
         1839,
         1840,
         1841,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         210,
         2116,
         2117,
         2118,
         2119,
         2120,
         2121,
         2122,
         2123,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         3,
         3,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         3,
         3,
         2,
         0,
         0,
         0,
         2,
         0,
         3,
         3,
         3,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         211,
         212,
         211,
         211,
         211,
         211,
         212,
         211,
         211,
         211,
         211,
         1372,
         211,
         211,
         211,
         211,
         1373,
         211,
         211,
         211,
         211,
         1374,
         211,
         211,
         211,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         213,
         214,
         213,
         213,
         214,
         213,
         213,
         1961,
         213,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         215,
         216,
         215,
         215,
         215,
         215,
         215,
         215,
         216,
         215,
         215,
         215,
         215,
         215,
         215,
         1962,
         215,
         215,
         215,
         215,
         215,
         215,
         1963,
         215,
         215,
         215,
         215,
         215,
         215,
         1964,
         215,
         215,
         215,
         215,
         215,
         215,
         1965,
         215,
         215,
         215,
         215,
         215,
         215,
         1966,
         215,
         215,
         215,
         215,
         215,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         13,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         19,
         19,
         21,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         217,
         218,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         1322,
         218,
         1323,
         218,
         1324,
         218,
         1325,
         1326,
         1327,
         2972,
         2973,
         2974,
         2975,
         217,
         218,
         217,
         1328,
         217,
         217,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         217,
         218,
         1328,
         1328,
         217,
         217,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         217,
         218,
         217,
         217,
         217,
         1329,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         217,
         218,
         217,
         217,
         1329,
         1329,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         217,
         218,
         217,
         217,
         217,
         217,
         217,
         1330,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         217,
         218,
         217,
         217,
         217,
         217,
         1330,
         1330,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         217,
         218,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1331,
         217,
         1318,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         1317,
         1322,
         1317,
         1317,
         1317,
         1317,
         1317,
         1317,
         1331,
         1331,
         1317,
         1332,
         1317,
         1333,
         1317,
         1334,
         1335,
         1335,
         2976,
         2977,
         2978,
         2979,
         217,
         218,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1317,
         217,
         1336,
         217,
         1319,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         1318,
         1323,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1332,
         1336,
         1336,
         1318,
         1337,
         1318,
         1338,
         1339,
         1339,
         2980,
         2981,
         2982,
         2983,
         217,
         218,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1340,
         217,
         1320,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         1319,
         1324,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1333,
         1319,
         1337,
         1340,
         1340,
         1319,
         1341,
         1342,
         1342,
         2984,
         2985,
         2986,
         2987,
         217,
         218,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1317,
         217,
         1318,
         217,
         1319,
         217,
         1343,
         1321,
         1321,
         2968,
         2969,
         2970,
         2971,
         1320,
         1325,
         1320,
         1320,
         1320,
         1320,
         1320,
         1320,
         1320,
         1334,
         1320,
         1338,
         1320,
         1341,
         1343,
         1343,
         1344,
         1344,
         2988,
         2989,
         2990,
         2991,
         1321,
         1326,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1335,
         1321,
         1339,
         1321,
         1342,
         1321,
         1344,
         1321,
         1321,
         2992,
         2993,
         2994,
         2995,
         1321,
         1327,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1335,
         1321,
         1339,
         1321,
         1342,
         1321,
         1344,
         1321,
         1321,
         2992,
         2993,
         2994,
         2995,
         2968,
         2972,
         2968,
         2968,
         2968,
         2968,
         2968,
         2968,
         2968,
         2976,
         2968,
         2980,
         2968,
         2984,
         2968,
         2988,
         2992,
         2992,
         2968,
         2996,
         2997,
         2998,
         2969,
         2973,
         2969,
         2969,
         2969,
         2969,
         2969,
         2969,
         2969,
         2977,
         2969,
         2981,
         2969,
         2985,
         2969,
         2989,
         2993,
         2993,
         2996,
         2999,
         3000,
         3001,
         2970,
         2974,
         2970,
         2970,
         2970,
         2970,
         2970,
         2970,
         2970,
         2978,
         2970,
         2982,
         2970,
         2986,
         2970,
         2990,
         2994,
         2994,
         2997,
         3000,
         2970,
         3002,
         2971,
         2975,
         2971,
         2971,
         2971,
         2971,
         2971,
         2971,
         2971,
         2979,
         2971,
         2983,
         2971,
         2987,
         2971,
         2991,
         2995,
         2995,
         2998,
         3001,
         3002,
         2971,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         219,
         220,
         221,
         222,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         223,
         224,
         225,
         226,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         227,
         228,
         227,
         227,
         227,
         227,
         228,
         228,
         2147,
         2148,
         2149,
         2150,
         227,
         2147,
         227,
         227,
         227,
         227,
         227,
         2148,
         227,
         227,
         227,
         227,
         227,
         2149,
         227,
         227,
         227,
         227,
         227,
         2150,
         227,
         227,
         227,
         227,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         229,
         230,
         229,
         229,
         229,
         229,
         230,
         230,
         2151,
         2152,
         2153,
         2154,
         229,
         2151,
         229,
         229,
         229,
         229,
         229,
         2152,
         229,
         229,
         229,
         229,
         229,
         2153,
         229,
         229,
         229,
         229,
         229,
         2154,
         229,
         229,
         229,
         229,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         231,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         232,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         233,
      },
   },
   [nir_op_fall_equal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_fall_equal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         238,
      },
   },
   [nir_op_fany_nequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         239,
      },
   },
   [nir_op_fany_nequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         240,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         241,
         241,
         241,
         241,
         241,
         241,
         2004,
         2005,
         241,
         2004,
         241,
         241,
         241,
         2005,
         241,
         241,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         242,
         242,
         242,
         242,
         242,
         242,
         2006,
         2007,
         242,
         2006,
         242,
         242,
         242,
         2007,
         242,
         242,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         243,
         243,
         243,
         243,
         243,
         243,
         2008,
         2009,
         243,
         2008,
         243,
         243,
         243,
         2009,
         243,
         243,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         244,
         244,
         244,
         244,
         244,
         244,
         2010,
         2011,
         244,
         2010,
         244,
         244,
         244,
         2011,
         244,
         244,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         245,
         245,
         245,
         245,
         245,
         245,
         2012,
         2013,
         245,
         2012,
         245,
         245,
         245,
         2013,
         245,
         245,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         246,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         247,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         248,
      },
   },
   [nir_op_ball_fequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         249,
      },
   },
   [nir_op_ball_fequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         250,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         251,
         251,
         251,
         251,
         251,
         251,
         2018,
         2019,
         251,
         2018,
         251,
         251,
         251,
         2019,
         251,
         251,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         252,
         252,
         252,
         252,
         252,
         252,
         2020,
         2021,
         252,
         2020,
         252,
         252,
         252,
         2021,
         252,
         252,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         253,
         253,
         253,
         253,
         253,
         253,
         2022,
         2023,
         253,
         2022,
         253,
         253,
         253,
         2023,
         253,
         253,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         254,
         254,
         254,
         254,
         254,
         254,
         2024,
         2025,
         254,
         2024,
         254,
         254,
         254,
         2025,
         254,
         254,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         255,
         255,
         255,
         255,
         255,
         255,
         2026,
         2027,
         255,
         2026,
         255,
         255,
         255,
         2027,
         255,
         255,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         256,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         257,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         258,
      },
   },
   [nir_op_bany_fnequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         259,
      },
   },
   [nir_op_bany_fnequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         260,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         261,
         261,
         262,
         262,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         263,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         264,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         2,
         4,
         3,
         0,
         0,
         0,
         3,
         3,
         2,
         4,
         0,
         0,
         0,
         2,
         4,
         3,
         3,
         3,
         2,
         4,
         0,
         0,
         2,
         4,
         3,
         3,
         3,
         2,
         4,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         1377,
         1378,
         1379,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         1375,
         1376,
         1375,
         1375,
         1375,
         1375,
         1375,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
         0,
         265,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_bfi] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         266,
         267,
         266,
         266,
         267,
         266,
         266,
         267,
         266,
         2963,
         2963,
         2963,
         2963,
         2963,
         2963,
         2963,
         2963,
         2963,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         268,
         2090,
         2091,
         2092,
         2093,
         2094,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         269,
         270,
         269,
         269,
         271,
         272,
         271,
         271,
         269,
         2155,
         269,
         269,
         269,
         2874,
         269,
         269,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         273,
         2095,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         274,
         2096,
         2097,
         2098,
         2099,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         2100,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         276,
         277,
         278,
         279,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         280,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         281,
      },
   },
   [nir_op_fcsel] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         282,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         283,
         2101,
         2102,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         284,
         2103,
         2104,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         285,
         2124,
         2125,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         286,
         2126,
         2127,
      },
   },
   [nir_op_fround_even] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         287,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         288,
         289,
         288,
         288,
         288,
         290,
         291,
         290,
         290,
         290,
         288,
         289,
         288,
         1382,
         288,
         288,
         289,
         288,
         288,
         288,
         288,
         289,
         288,
         288,
         1383,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         292,
         1967,
         1968,
         1969,
         1970,
         1971,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         293,
         2158,
         2802,
         2803,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         294,
         2156,
         2157,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         295,
         2160,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         296,
         2159,
      },
   },
   [nir_op_unpack_64_4x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         297,
         2162,
         2804,
         3164,
      },
   },
   [nir_op_pack_64_4x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         298,
         2161,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         299,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         300,
         1972,
         1973,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         301,
         1974,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         302,
         1975,
         3198,
         0,
         303,
         1975,
         3198,
         1976,
         1977,
         1978,
         3199,
         0,
         302,
         1975,
         3198,
         0,
         302,
         1975,
         3198,
         0,
         303,
         1975,
         3198,
         1976,
         1977,
         1978,
         3199,
         0,
         302,
         1975,
         3198,
         0,
         302,
         1975,
         3198,
         0,
         303,
         1975,
         3198,
         1976,
         1977,
         1978,
         3199,
         0,
         302,
         1975,
         3198,
         0,
         302,
         1975,
         3198,
         0,
         303,
         1975,
         3198,
         1976,
         1977,
         1978,
         3199,
         0,
         302,
         1975,
         3198,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         304,
         1979,
         3200,
         0,
         305,
         1979,
         3200,
         1980,
         1981,
         1982,
         3201,
         0,
         304,
         1979,
         3200,
         0,
         304,
         1979,
         3200,
         0,
         305,
         1979,
         3200,
         1980,
         1981,
         1982,
         3201,
         0,
         304,
         1979,
         3200,
         0,
         304,
         1979,
         3200,
         0,
         305,
         1979,
         3200,
         1980,
         1981,
         1982,
         3201,
         0,
         304,
         1979,
         3200,
         0,
         304,
         1979,
         3200,
         0,
         305,
         1979,
         3200,
         1980,
         1981,
         1982,
         3201,
         0,
         304,
         1979,
         3200,
      },
   },
   [nir_op_unpack_32_4x8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         306,
         2164,
      },
   },
   [nir_op_pack_32_4x8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         307,
         2163,
      },
   },
   [nir_op_unpack_32_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         308,
         2166,
      },
   },
   [nir_op_pack_32_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         309,
         2165,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         310,
         311,
         312,
         313,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         314,
         1983,
         1984,
         1985,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         315,
         1986,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         2140,
         2141,
         2142,
      },
   },
   [nir_op_pack_half_2x16_rtz_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         316,
         0,
         317,
         318,
         317,
         0,
         1745,
         0,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         319,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         320,
         0,
         320,
      },
   },
   [nir_op_fsub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         321,
         322,
         323,
         324,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_bitz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_find_lsb] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         328,
         2167,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         329,
         2146,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_ifind_msb_rev] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         331,
      },
   },
   [nir_op_ufind_msb_rev] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         332,
         2168,
      },
   },
   [nir_op_bitfield_reverse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         333,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         334,
         335,
         336,
         337,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         338,
         339,
         340,
         341,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         342,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         343,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         344,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         345,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         346,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         347,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         348,
      },
   },
   [nir_op_imul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         349,
      },
   },
   [nir_op_umul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         350,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         351,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         352,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         353,
         1987,
         0,
         0,
         353,
         1987,
         0,
         1988,
         1989,
         1990,
         1988,
         3202,
         3203,
         3204,
         3202,
      },
   },
   [nir_op_uclz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         354,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         355,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         356,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         357,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         358,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         359,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         360,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         361,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         362,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         363,
         2089,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         364,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         365,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         366,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         367,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         368,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         369,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         370,
         371,
         372,
         371,
         372,
         373,
         374,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         375,
         375,
         375,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         376,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         377,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         378,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         379,
      },
   },
   [nir_op_ldexp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         380,
         380,
         381,
         381,
      },
   },
   [nir_op_msad_4x8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         382,
         0,
         382,
         0,
         382,
         0,
         382,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         383,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         384,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         385,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         386,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         387,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         388,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         389,
         389,
         389,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         390,
         390,
         391,
         391,
         392,
         392,
      },
   },
   [nir_op_fsin_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         393,
      },
   },
   [nir_op_fcos_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         394,
      },
   },
   [nir_op_fsin_mdg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         395,
      },
   },
   [nir_op_fcos_mdg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         396,
      },
   },
   [nir_op_fsin_agx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         397,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         398,
      },
   },
   [nir_op_fquantize2f16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         399,
      },
   },
   [nir_op_fdot5] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         400,
         400,
         400,
      },
   },
   [nir_op_fdot8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         401,
         401,
         401,
      },
   },
   [nir_op_fdot16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         402,
         402,
         402,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   1,
   3,
   5,
   7,
   0,
   9,
   0,
   20,
   23,
   25,
   29,
   31,
   33,
   35,
   38,
   42,
   45,
   50,
   0,
   55,
   63,
   66,
   0,
   71,
   76,
   0,
   0,
   0,
   78,
   0,
   80,
   82,
   88,
   95,
   101,
   108,
   111,
   115,
   118,
   122,
   125,
   129,
   135,
   142,
   152,
   165,
   181,
   195,
   212,
   218,
   225,
   234,
   244,
   254,
   265,
   267,
   279,
   281,
   289,
   291,
   299,
   301,
   0,
   309,
   315,
   317,
   324,
   327,
   330,
   332,
   337,
   341,
   348,
   352,
   359,
   365,
   374,
   376,
   378,
   381,
   384,
   388,
   392,
   394,
   396,
   399,
   402,
   406,
   410,
   412,
   415,
   419,
   421,
   424,
   427,
   431,
   435,
   440,
   442,
   444,
   447,
   450,
   454,
   458,
   460,
   462,
   465,
   468,
   472,
   476,
   478,
   481,
   485,
   487,
   490,
   494,
   496,
   498,
   501,
   504,
   507,
   510,
   515,
   520,
   522,
   525,
   528,
   533,
   537,
   542,
   547,
   571,
   577,
   584,
   591,
   617,
   619,
   0,
   0,
   625,
   630,
   635,
   0,
   638,
   640,
   642,
   646,
   648,
   652,
   654,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   659,
   0,
   661,
   667,
   670,
   0,
   678,
   683,
   690,
   697,
   706,
   711,
   718,
   725,
   734,
   736,
   741,
   746,
   752,
   754,
   757,
   761,
   766,
   771,
   777,
   779,
   781,
   783,
   0,
   787,
   789,
   792,
   794,
   796,
   798,
   800,
   802,
   806,
   808,
   812,
   814,
   0,
   0,
   818,
   822,
   828,
   0,
   0,
   834,
   836,
   840,
   842,
   845,
   847,
   850,
   852,
   858,
   860,
   863,
   866,
   870,
   872,
   875,
   878,
   882,
   884,
   888,
   890,
   893,
   895,
   897,
   899,
   901,
   903,
   905,
   907,
   909,
   911,
   913,
   915,
   917,
   919,
   921,
   923,
   925,
   927,
   929,
   931,
   933,
   935,
   937,
   939,
   941,
   943,
   945,
   947,
   949,
   951,
   953,
   955,
   957,
   962,
   967,
   969,
   973,
   0,
   1009,
   1011,
   1018,
   1022,
   1031,
   0,
   0,
   1033,
   1035,
   1038,
   1042,
   1047,
   1049,
   1051,
   0,
   0,
   0,
   0,
   1053,
   1055,
   1057,
   1059,
   1061,
   1063,
   0,
   0,
   0,
   0,
   0,
   0,
   1065,
   1067,
   1069,
   1071,
   1073,
   1082,
   1084,
   0,
   0,
   0,
   0,
   1092,
   1095,
   1098,
   1101,
   1104,
   1107,
   0,
   0,
   0,
   0,
   1110,
   1113,
   1115,
   1118,
   1121,
   1125,
   1127,
   1129,
   1131,
   1134,
   1138,
   0,
   0,
   0,
   1141,
   1143,
   1146,
   1149,
   1153,
   1155,
   1158,
   1161,
   1165,
   1167,
   1169,
   1173,
   1176,
   1179,
   1182,
   1185,
   1187,
   1189,
   1192,
   0,
   1195,
   1197,
   1199,
   1202,
   1204,
   1207,
   1209,
   1211,
   1213,
   1215,
   1217,
   1219,
   1221,
   1223,
   1226,
   1229,
   1232,
   1234,
   1237,
   1241,
   1245,
   1250,
   1254,
   1256,
   1258,
   1260,
   1262,
   1266,
   0,
   1271,
   1273,
   1275,
   1277,
   1279,
   1281,
   1283,
   1285,
   1287,
   1289,
   0,
   0,
   0,
   0,
   0,
   1292,
   1296,
   1298,
   1300,
   1302,
   1304,
   1306,
   1309,
   1312,
   1314,
   1316,
   1328,
   1341,
   1353,
   1365,
   1377,
   1390,
   1403,
   1415,
   1427,
   1431,
   1435,
   1438,
   1441,
   1443,
   1448,
   1452,
   1456,
   1460,
   1464,
   1467,
   1469,
   1474,
   0,
   1476,
   1478,
   1480,
   1482,
   1484,
   1487,
   1490,
   1493,
   1495,
   1497,
   1499,
   1501,
   1504,
   1507,
   1510,
   1514,
   1518,
   1522,
   1526,
   1530,
   1535,
   1538,
   1542,
   1546,
   1549,
   1552,
   1554,
   1557,
   1559,
   1561,
   1564,
   1567,
   1570,
   1573,
   1576,
   1579,
   1583,
   1587,
   1591,
   1594,
   1597,
   1600,
   1602,
   1604,
   1606,
   1608,
   1611,
   1614,
   1617,
   1619,
   1621,
   1623,
   1626,
   1629,
   1632,
   1636,
   1640,
   1644,
   1647,
   1650,
   1653,
   1656,
   1659,
   1663,
   1667,
   1671,
   1674,
   1677,
   1680,
   1683,
   1687,
   1691,
   1695,
   1698,
   1701,
   1704,
   1708,
   1712,
   1716,
   1719,
   1722,
   1725,
   1730,
   1735,
   1739,
   1743,
   1747,
   1752,
   1756,
   1760,
   1764,
   1768,
   1772,
   1776,
   1779,
   1782,
   1785,
   1787,
   1789,
   1793,
   1799,
   1804,
   1811,
   1816,
   1824,
   1832,
   1838,
   1843,
   1847,
   1852,
   1857,
   1863,
   1871,
   1879,
   1887,
   1895,
   1905,
   1911,
   1918,
   1924,
   1936,
   1941,
   1946,
   1953,
   1961,
   1969,
   1977,
   1985,
   1993,
   2001,
   2007,
   2014,
   2020,
   2028,
   2034,
   2041,
   2047,
   2055,
   2060,
   2066,
   2071,
   2078,
   2083,
   2089,
   2094,
   2101,
   2109,
   2114,
   2122,
   2127,
   2132,
   2137,
   2142,
   2147,
   2152,
   2157,
   2162,
   2167,
   2172,
   2178,
   2186,
   2193,
   2202,
   2209,
   2219,
   2229,
   2237,
   2244,
   2250,
   2257,
   2264,
   2272,
   2282,
   2292,
   2302,
   2312,
   2324,
   2332,
   2341,
   2349,
   2363,
   2370,
   2377,
   2386,
   2396,
   2406,
   2416,
   2426,
   2436,
   2446,
   2454,
   2463,
   2471,
   2481,
   2489,
   2498,
   2506,
   2516,
   2523,
   2531,
   2538,
   2547,
   2554,
   2562,
   2569,
   2578,
   2588,
   2595,
   2605,
   2612,
   2619,
   2626,
   2633,
   2640,
   2647,
   2654,
   2661,
   2668,
   2675,
   2681,
   2688,
   2694,
   2701,
   2707,
   2712,
   2736,
   2741,
   2746,
   2753,
   2758,
   2763,
   2769,
   2774,
   2781,
   2787,
   2812,
   2818,
   2826,
   2832,
   2841,
   2850,
   2857,
   2863,
   2868,
   2874,
   2880,
   2887,
   2896,
   2905,
   2914,
   2923,
   2934,
   2941,
   2949,
   2956,
   2969,
   2975,
   2981,
   2989,
   2998,
   3007,
   3016,
   3025,
   3034,
   3043,
   3050,
   3058,
   3065,
   3074,
   3081,
   3089,
   3096,
   3105,
   3111,
   3118,
   3124,
   3132,
   3138,
   3145,
   3151,
   3159,
   3168,
   3174,
   3183,
   3189,
   3195,
   3201,
   3207,
   3213,
   3219,
   3225,
   3231,
   3237,
   3243,
   3249,
   3256,
   3262,
   3270,
   3277,
   3303,
   3310,
   3319,
   3326,
   3336,
   3346,
   3354,
   3361,
   3367,
   3374,
   3381,
   3389,
   3399,
   3409,
   3419,
   3429,
   3441,
   3449,
   3458,
   3466,
   3480,
   3487,
   3494,
   3503,
   3513,
   3523,
   3533,
   3543,
   3553,
   3563,
   3571,
   3580,
   3588,
   3598,
   3606,
   3615,
   3623,
   3633,
   3640,
   3648,
   3655,
   3664,
   3671,
   3679,
   3686,
   3695,
   3705,
   3712,
   3722,
   3729,
   3736,
   3743,
   3750,
   3757,
   3764,
   3771,
   3778,
   3785,
   3792,
   3800,
   3807,
   3815,
   3823,
   3832,
   3838,
   3845,
   3851,
   3859,
   3866,
   3892,
   3899,
   3908,
   3915,
   3925,
   3935,
   3943,
   3950,
   3956,
   3963,
   3970,
   3978,
   3988,
   3998,
   4008,
   4018,
   4030,
   4038,
   4047,
   4055,
   4069,
   4076,
   4083,
   4092,
   4102,
   4112,
   4122,
   4132,
   4142,
   4152,
   4160,
   4169,
   4177,
   4187,
   4195,
   4204,
   4212,
   4222,
   4229,
   4237,
   4244,
   4253,
   4260,
   4268,
   4275,
   4284,
   4294,
   4301,
   4311,
   4318,
   4325,
   4332,
   4339,
   4346,
   4353,
   4360,
   4367,
   4374,
   4381,
   4393,
   4406,
   4418,
   4432,
   4445,
   4477,
   4490,
   4505,
   4518,
   4534,
   4550,
   4564,
   4577,
   4589,
   4602,
   4615,
   4629,
   4645,
   4661,
   4677,
   4693,
   4711,
   4725,
   4740,
   4754,
   4774,
   4787,
   4800,
   4815,
   4831,
   4847,
   4863,
   4879,
   4895,
   4911,
   4925,
   4940,
   4954,
   4970,
   4984,
   4999,
   5013,
   5029,
   5042,
   5056,
   5069,
   5084,
   5097,
   5111,
   5124,
   5139,
   5155,
   5168,
   5184,
   5197,
   5210,
   5223,
   5236,
   5249,
   5262,
   5275,
   5288,
   5301,
   5314,
   5326,
   5339,
   5351,
   5365,
   5378,
   5410,
   5423,
   5438,
   5451,
   5467,
   5483,
   5497,
   5510,
   5522,
   5535,
   5548,
   5562,
   5578,
   5594,
   5610,
   5626,
   5644,
   5658,
   5673,
   5687,
   5707,
   5720,
   5733,
   5748,
   5764,
   5780,
   5796,
   5812,
   5828,
   5844,
   5858,
   5873,
   5887,
   5903,
   5917,
   5932,
   5946,
   5962,
   5975,
   5989,
   6002,
   6017,
   6030,
   6044,
   6057,
   6072,
   6088,
   6101,
   6117,
   6130,
   6143,
   6156,
   6169,
   6182,
   6195,
   6208,
   6221,
   6234,
   6247,
   6259,
   6272,
   6284,
   6298,
   6311,
   6343,
   6356,
   6371,
   6384,
   6400,
   6416,
   6430,
   6443,
   6455,
   6468,
   6481,
   6495,
   6511,
   6527,
   6543,
   6559,
   6577,
   6591,
   6606,
   6620,
   6640,
   6653,
   6666,
   6681,
   6697,
   6713,
   6729,
   6745,
   6761,
   6777,
   6791,
   6806,
   6820,
   6836,
   6850,
   6865,
   6879,
   6895,
   6908,
   6922,
   6935,
   6950,
   6963,
   6977,
   6990,
   7005,
   7021,
   7034,
   7050,
   7063,
   7076,
   7089,
   7102,
   7115,
   7128,
   7141,
   7154,
   7167,
   7180,
   7192,
   7205,
   7217,
   7231,
   7244,
   7276,
   7289,
   7304,
   7317,
   7333,
   7349,
   7363,
   7376,
   7388,
   7401,
   7414,
   7428,
   7444,
   7460,
   7476,
   7492,
   7510,
   7524,
   7539,
   7553,
   7573,
   7586,
   7599,
   7614,
   7630,
   7646,
   7662,
   7678,
   7694,
   7710,
   7724,
   7739,
   7753,
   7769,
   7783,
   7798,
   7812,
   7828,
   7841,
   7855,
   7868,
   7883,
   7896,
   7910,
   7923,
   7938,
   7954,
   7967,
   7983,
   7996,
   8009,
   8022,
   8035,
   8048,
   8061,
   8074,
   8087,
   8100,
   8113,
   0,
   8118,
   8124,
   8126,
   8130,
   8137,
   8141,
   8148,
   8153,
   8160,
   8169,
   8174,
   8179,
   8186,
   8195,
   8200,
   8203,
   8207,
   8211,
   8213,
   8217,
   8223,
   8225,
   8228,
   8231,
   8234,
   8238,
   8242,
   8245,
   8248,
   8261,
   8278,
   8296,
   8309,
   8323,
   8336,
   8352,
   8365,
   8378,
   8392,
   8406,
   8419,
   8432,
   8444,
   8447,
   8451,
   8455,
   8459,
   8464,
   8469,
   8473,
   8477,
   8481,
   8485,
   8489,
   8494,
   8499,
   8503,
   8507,
   8510,
   8520,
   8526,
   8529,
   8533,
   8537,
   8541,
   8544,
   8551,
   8554,
   8557,
   8561,
   8566,
   8571,
   8575,
   8579,
   8584,
   8590,
   8601,
   8613,
   8619,
   8631,
   8644,
   8648,
   8653,
   8664,
   8676,
   8681,
   8693,
   8706,
   8708,
   8713,
   8718,
   8723,
   8727,
   8731,
   8736,
   8742,
   8747,
   8752,
   8757,
   8762,
   8767,
   8771,
   8775,
   8779,
   8782,
   8785,
   8788,
   8791,
   8793,
   8797,
   8801,
   8804,
   8807,
   8816,
   8825,
   8835,
   8844,
   8853,
   8861,
   8871,
   8881,
   8890,
   8899,
   8902,
   8905,
   8910,
   8912,
   8916,
   8920,
   8924,
   8928,
   8932,
   8935,
   8940,
   8945,
   8949,
   8953,
   8957,
   8961,
   8965,
   8968,
   8973,
   8978,
   8982,
   8986,
   8994,
   8998,
   9001,
   9006,
   9011,
   9016,
   9020,
   9024,
   9034,
   9037,
   9039,
   9041,
   9046,
   9049,
   9052,
   9056,
   9059,
   9064,
   9069,
   9073,
   9077,
   9082,
   9086,
   9090,
   9093,
   9096,
   9102,
   9113,
   9125,
   9131,
   9143,
   9156,
   9160,
   9165,
   9175,
   9186,
   9191,
   9202,
   9214,
   9216,
   9221,
   9225,
   9229,
   9233,
   9237,
   9242,
   9248,
   9253,
   9258,
   9263,
   9268,
   9273,
   9277,
   9281,
   9285,
   9288,
   9291,
   9295,
   9299,
   9302,
   9305,
   9308,
   9316,
   9324,
   9331,
   9338,
   9345,
   9353,
   9356,
   9359,
   9362,
   9367,
   9373,
   9378,
   9383,
   9388,
   9393,
   9398,
   9403,
   9408,
   9412,
   9416,
   9420,
   9424,
   9428,
   0,
   9433,
   9439,
   9441,
   9446,
   9457,
   9466,
   9471,
   9481,
   9488,
   9495,
   9500,
   9507,
   0,
   9514,
   9520,
   9525,
   9533,
   9543,
   9558,
   9565,
   9580,
   9595,
   9600,
   9605,
   9610,
   9618,
   9633,
   9640,
   9648,
   9650,
   9653,
   9655,
   9657,
   0,
   0,
   9659,
   9662,
   9664,
   9667,
   9670,
   9673,
   9676,
   9679,
   9682,
   9685,
   0,
   0,
   9688,
   0,
   9690,
   0,
   0,
   9693,
   9702,
   9712,
   9720,
   9728,
   9737,
   9746,
   9756,
   9764,
   9773,
   9784,
   9792,
   9800,
   0,
   9802,
   0,
   9804,
   0,
   0,
   9807,
   0,
   9809,
   0,
   0,
   9812,
   9814,
   9818,
   9820,
   0,
   9822,
   0,
   0,
   9825,
   9828,
   9831,
   9833,
   0,
   9835,
   9837,
   9839,
   9841,
   9849,
   9858,
   9863,
   9869,
   9875,
   9882,
   9888,
   9895,
   9901,
   9903,
   9905,
   9909,
   9911,
   0,
   9913,
   9915,
   9918,
   9921,
   9924,
   9927,
   9930,
   9933,
   0,
   0,
   0,
   0,
   9935,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   9937,
   9945,
   9953,
   9967,
   9981,
   9990,
   9997,
   10007,
   10015,
   10023,
   10038,
   10053,
   10067,
   10084,
   10100,
   10115,
   10130,
   10148,
   10165,
   10181,
   10194,
   10210,
   10224,
   10238,
   10252,
   10269,
   10284,
   10299,
   10308,
   10316,
   10327,
   10336,
   10345,
   10352,
   10362,
   10370,
   10378,
   10383,
   10390,
   10395,
   10403,
   10411,
   10417,
   10426,
   10435,
   10442,
   10451,
   10458,
   10468,
   10478,
   10486,
   10497,
   10508,
   10514,
   10523,
   10532,
   10541,
   10553,
   0,
   10565,
   10567,
   10571,
   10574,
   10578,
   0,
   10582,
   10586,
   10588,
   10590,
   10594,
   10601,
   10604,
   10607,
   10610,
   10617,
   10625,
   10632,
   10640,
   10647,
   10654,
   10661,
   10668,
   10675,
   10683,
   10691,
   10699,
   10707,
   10711,
   10714,
   10718,
   10724,
   10730,
   10736,
   10742,
   10748,
   10756,
   10765,
   10773,
   10782,
   10790,
   10798,
   10806,
   10814,
   10820,
   10828,
   10835,
   10842,
   10849,
   10858,
   10866,
   10873,
   10881,
   10889,
   10895,
   10903,
   10910,
   10917,
   10924,
   10932,
   10938,
   10946,
   10953,
   10960,
   10967,
   10980,
   10986,
   10992,
   10998,
   11006,
   11015,
   11023,
   11031,
   11039,
   11047,
   11055,
   11063,
   11069,
   11077,
   11084,
   11091,
   11098,
   11107,
   11115,
   11122,
   11130,
   11139,
   11147,
   11153,
   11161,
   11168,
   11175,
   11182,
   11190,
   11196,
   11204,
   11211,
   11218,
   11225,
   11238,
   11241,
   11244,
   11250,
   11257,
   11263,
   11270,
   11276,
   11282,
   11288,
   11294,
   11300,
   11307,
   11314,
   11321,
   11328,
   11332,
   11335,
   11339,
   11345,
   11351,
   11354,
   11357,
   11365,
   11374,
   11383,
   11392,
   11409,
   11426,
   11435,
   11444,
   11460,
   11474,
   11488,
   11498,
   11508,
   11520,
   11528,
   11537,
   11545,
   11554,
   11562,
   11570,
   11578,
   11586,
   11594,
   11602,
   11606,
   11612,
   11624,
   11636,
   11639,
   11642,
   11646,
   11649,
   11652,
   11655,
   11657,
   11662,
   11667,
   11672,
   11677,
   11682,
   11686,
   11692,
   11696,
   11700,
   11703,
   11707,
   11710,
   11713,
   11716,
   11719,
   11722,
   11725,
   11730,
   11734,
   11738,
   11743,
   11747,
   11751,
   11755,
   11759,
   11762,
   11765,
   11770,
   11776,
   11783,
   11790,
   11798,
   11805,
   11814,
   11821,
   11826,
   11833,
   11840,
   11850,
   11860,
   11868,
   11879,
   11890,
   11900,
   11911,
   11923,
   11934,
   11946,
   11959,
   11973,
   11986,
   11993,
   12001,
   12009,
   0,
   12017,
   0,
   0,
   12019,
   12021,
   0,
   0,
   0,
   0,
   0,
   0,
   12026,
   12029,
   12032,
   12035,
   12038,
   12041,
   12050,
   12059,
   12068,
   12085,
   12102,
   12111,
   12120,
   12136,
   12144,
   12152,
   12166,
   12180,
   12190,
   12200,
   12212,
   12220,
   12228,
   12237,
   12246,
   12254,
   12262,
   12270,
   12278,
   12286,
   12294,
   12298,
   12304,
   12316,
   12328,
   12331,
   12334,
   12338,
   12341,
   12344,
   12347,
   12349,
   12352,
   12355,
   12358,
   12360,
   12363,
   12367,
   12371,
   12374,
   12378,
   12381,
   12384,
   12387,
   12390,
   12393,
   12396,
   12399,
   12402,
   12405,
   12409,
   12413,
   12417,
   12421,
   12423,
   12425,
   12429,
   12436,
   12439,
   12449,
   12454,
   12459,
   12464,
   12469,
   12479,
   12489,
   12494,
   12499,
   12504,
   12506,
   12508,
   12510,
   12512,
   12514,
   12516,
   12518,
   12521,
   12524,
   12527,
   12532,
   12537,
   12542,
   12549,
   12554,
   12560,
   12570,
   12575,
   12580,
   12586,
   12588,
   12591,
   12594,
   12597,
   12600,
   12603,
   12607,
   12611,
   12615,
   12619,
   12623,
   12626,
   12630,
   12634,
   12638,
   12642,
   12647,
   12650,
   12654,
   12658,
   12662,
   12666,
   12671,
   12680,
   12702,
   12706,
   12709,
   12713,
   12716,
   12721,
   12725,
   12728,
   12731,
   12734,
   12737,
   12740,
   12743,
   12747,
   12750,
   12754,
   12762,
   12765,
   12768,
   12772,
   12774,
   12777,
   12780,
   12783,
   12786,
   12790,
   12794,
   12798,
   12801,
   12804,
   12808,
   12812,
   12816,
   12820,
   12823,
   12827,
   12831,
   12835,
   12839,
   12847,
   12869,
   12872,
   12875,
   12878,
   12881,
   12885,
   12889,
   12896,
   12902,
   12910,
   12917,
   12924,
   12931,
   12938,
   12944,
   12960,
   13009,
   13016,
   13023,
   13030,
   13042,
   13044,
   13047,
   13049,
   13053,
   13058,
   13062,
   13065,
   13068,
   13070,
   13073,
   13076,
   13088,
   13095,
   13102,
   13109,
   13116,
   13162,
   13181,
   13188,
   13195,
   13207,
   13211,
   13215,
   13219,
   13223,
   13227,
   13231,
   13234,
   13237,
   13240,
   13243,
   13246,
   13249,
   13253,
   13256,
   13258,
   13260,
   13263,
   13266,
   13268,
   13270,
   13273,
   13276,
   13280,
   13284,
   13289,
   13293,
   13295,
   13297,
   13299,
   13302,
   13304,
   13306,
   13308,
   0,
   13310,
   13312,
   13314,
   13316,
   13318,
   13320,
   13322,
   13324,
   13326,
   13329,
   13332,
   13335,
   13338,
   13341,
   13344,
   13347,
   13350,
   13353,
   13356,
   0,
   0,
   0,
   13358,
   13361,
   13364,
   13367,
   13370,
   13373,
   13376,
   13379,
   13382,
   13385,
   13388,
   13394,
   13400,
   13406,
   13413,
   13420,
   13431,
   13437,
   13443,
   13450,
   13457,
   13463,
   13471,
   13478,
   13485,
   13494,
   13500,
   13508,
   13515,
   13522,
   13531,
   13543,
   13568,
   13575,
   13581,
   13588,
   13594,
   13602,
   13609,
   13615,
   13621,
   13627,
   13634,
   13641,
   13652,
   13658,
   13664,
   13671,
   13678,
   13684,
   13692,
   13699,
   13706,
   13715,
   13721,
   13729,
   13736,
   13743,
   13752,
   13764,
   13789,
   13796,
   13802,
   13809,
   13815,
   13823,
   13830,
   13836,
   13842,
   13848,
   13854,
   13860,
   13863,
   13865,
   13867,
   13869,
   13871,
   13873,
   13876,
   13878,
   13880,
   13882,
   13884,
   13886,
   13888,
   13890,
   13892,
   13894,
   13896,
   13923,
   13925,
   13928,
   13930,
   13934,
   13961,
   13964,
   13967,
   13972,
   13975,
   13978,
   13980,
   13982,
   13984,
   13986,
   13988,
   13990,
   13992,
   13994,
   13996,
   13998,
   14000,
   14004,
   14009,
   14015,
   14021,
   14028,
   14036,
   14039,
   14043,
   14048,
   14054,
   14057,
   0,
   0,
   0,
   0,
   0,
   0,
   14063,
   14068,
   14074,
   14080,
   14086,
   14092,
   14097,
   14102,
   14107,
   14112,
   14120,
   14122,
   14125,
   14128,
   14130,
   14132,
   14134,
   14137,
   14139,
   14141,
   14143,
   14145,
   14149,
   14151,
   14153,
   14155,
   14159,
   14163,
   14167,
   14171,
   14175,
   14180,
   14182,
   14185,
   14188,
   14191,
   14194,
   14197,
   14202,
   14207,
   14212,
   14217,
   14221,
   14225,
   14230,
   14235,
   14240,
   14245,
   14249,
   14253,
   14257,
   14261,
   14264,
   14267,
   14272,
   14277,
   14282,
   14287,
   14290,
   14293,
   14298,
   14303,
   14308,
   14313,
   14316,
   14319,
   14324,
   14329,
   14334,
   14339,
   14342,
   14345,
   14350,
   14355,
   14360,
   14365,
   14369,
   14373,
   14379,
   14385,
   14391,
   14397,
   14401,
   14405,
   14409,
   14415,
   14421,
   14427,
   14433,
   14437,
   14441,
   14447,
   14453,
   14459,
   14465,
   14468,
   14471,
   14476,
   14481,
   14486,
   14491,
   14494,
   14497,
   14502,
   14507,
   14512,
   14517,
   14520,
   14523,
   14528,
   14533,
   14538,
   14543,
   14548,
   14553,
   14558,
   14563,
   14568,
   14573,
   14578,
   14583,
   14590,
   14597,
   14604,
   14611,
   14618,
   14625,
   14627,
   14634,
   14642,
   14649,
   14658,
   14665,
   14673,
   14680,
   14689,
   14696,
   14704,
   14711,
   14720,
   14727,
   14735,
   14742,
   14751,
   14760,
   14770,
   14779,
   14790,
   14799,
   14809,
   14818,
   14829,
   14838,
   14848,
   14857,
   14868,
   14877,
   14887,
   14896,
   14907,
   14912,
   14918,
   14926,
   14935,
   14943,
   14953,
   14961,
   14970,
   14978,
   14988,
   14996,
   15005,
   15013,
   15023,
   15031,
   15040,
   15048,
   15058,
   15067,
   15077,
   15086,
   15097,
   15106,
   15116,
   15125,
   15136,
   15145,
   15155,
   15164,
   15175,
   15184,
   15194,
   15203,
   15214,
   15223,
   15233,
   15242,
   15253,
   15262,
   15272,
   15281,
   15292,
   15301,
   15311,
   15320,
   15331,
   15340,
   15350,
   15359,
   15370,
   15385,
   15401,
   15416,
   15433,
   15448,
   15464,
   15479,
   15496,
   15511,
   15527,
   15542,
   15559,
   15574,
   15590,
   15605,
   15622,
   15635,
   15652,
   15667,
   15683,
   15698,
   15715,
   15730,
   15746,
   15761,
   15778,
   15793,
   15809,
   15824,
   15841,
   15856,
   15872,
   15887,
   15904,
   15919,
   15935,
   15950,
   15967,
   15982,
   15998,
   16013,
   16030,
   16045,
   16061,
   16076,
   16093,
   16108,
   16124,
   16139,
   16156,
   16173,
   16188,
   16204,
   16219,
   16236,
   16251,
   16267,
   16282,
   16299,
   16314,
   16330,
   16345,
   16362,
   16377,
   16393,
   16408,
   16425,
   16434,
   16443,
   16452,
   16461,
   16478,
   16499,
   16516,
   16537,
   16551,
   16565,
   16579,
   16593,
   16607,
   16611,
   16615,
   16619,
   16623,
   16635,
   16648,
   16662,
   16676,
   16690,
   16704,
   16709,
   16714,
   16719,
   16724,
   16730,
   16736,
   16742,
   16748,
   16754,
   16760,
   16766,
   16772,
   16777,
   16782,
   16787,
   16792,
   16797,
   16802,
   16807,
   16812,
   16819,
   16826,
   16833,
   16840,
   16847,
   0,
   16854,
   16856,
   16861,
   16866,
   16868,
   16872,
   16877,
   16882,
   16885,
   0,
   16889,
   16894,
   16896,
   16902,
   16907,
   16916,
   16922,
   16928,
   16935,
   16938,
   16941,
   16945,
   16952,
   16959,
   16966,
   16974,
   16983,
   16987,
   16992,
   16998,
   17004,
   17010,
   17017,
   17025,
   17029,
   17034,
   17038,
   0,
   0,
   17040,
   17042,
   17054,
   17064,
   17075,
   17083,
   17091,
   17100,
   17104,
   0,
   0,
   17107,
   17109,
   17114,
   0,
   0,
   17116,
   17118,
   17124,
   17127,
   17129,
   17131,
   17135,
   0,
   0,
   17137,
   17139,
   17141,
   17145,
   17148,
   17151,
   17155,
   17159,
   0,
   0,
   17161,
   17163,
   17167,
   0,
   0,
   17169,
   17171,
   17173,
   17178,
   17181,
   17184,
   17190,
   17196,
   17201,
   17205,
   17209,
   17216,
   17220,
   17225,
   17229,
   17231,
   17233,
   17236,
   0,
   17238,
   17240,
   17251,
   17259,
   17270,
   17279,
   17288,
   17305,
   17319,
   17336,
   17351,
   17366,
   17376,
   17385,
   17397,
   17407,
   17417,
   17428,
   17437,
   17449,
   17459,
   17469,
   17481,
   17491,
   17504,
   17515,
   17526,
   17540,
   17551,
   17559,
   17570,
   17579,
   17588,
   17597,
   17609,
   17619,
   17629,
   17638,
   17650,
   17660,
   17670,
   17679,
   17691,
   17701,
   17711,
   17721,
   17734,
   17745,
   17756,
   17766,
   17779,
   17790,
   17801,
   17811,
   17824,
   17835,
   17846,
   17856,
   17869,
   17880,
   17891,
   17902,
   17916,
   17928,
   17940,
   17950,
   17963,
   17974,
   17985,
   17990,
   17995,
   18000,
   18005,
   18016,
   18027,
   18038,
   18049,
   18053,
   18058,
   18063,
   18069,
   18075,
   18081,
   18087,
   18093,
   18099,
   18105,
   18111,
   18117,
   18123,
   18129,
   18135,
   18139,
   18145,
   18151,
   18157,
   18163,
   18170,
   18175,
   18180,
   18185,
   18190,
   18197,
   18204,
   18211,
   18218,
   18220,
   18227,
   18234,
   18241,
   18248,
   18254,
   18260,
   18266,
   18272,
   18278,
   18284,
   18290,
   18296,
   18302,
   18307,
   18312,
   18315,
   18323,
   18331,
   18339,
   18344,
   18352,
   18360,
   18368,
   18371,
   18388,
   18398,
   18400,
   18402,
   18404,
   18406,
   18408,
   18410,
   18413,
   18415,
   18420,
   18425,
   18430,
   18435,
   18442,
   18455,
   18468,
   18480,
   18494,
   18506,
   18521,
   18537,
   18552,
   18567,
   18584,
   18586,
   18590,
   18593,
   18599,
   18605,
   18611,
   18617,
   18625,
   18629,
   18632,
   18638,
   18644,
   18650,
   18656,
   18664,
   18674,
   18677,
   18681,
   18684,
   18690,
   18696,
   18702,
   18708,
   18716,
   18721,
   18725,
   18732,
   18739,
   18746,
   18753,
   18762,
   18767,
   18771,
   18778,
   18785,
   18792,
   18799,
   18808,
   18812,
   18815,
   18821,
   18827,
   18833,
   18839,
   18847,
   18851,
   18854,
   18860,
   18866,
   18872,
   18878,
   18886,
   18889,
   18895,
   18901,
   18907,
   18913,
   18921,
   18924,
   18929,
   18934,
   18939,
   18944,
   18951,
   18962,
   18970,
   18978,
   18986,
   18996,
   19001,
   19009,
   19017,
   19027,
   19035,
   19045,
   19055,
   19058,
   0,
   19060,
   0,
   0,
   19062,
   19064,
   0,
   19073,
   19075,
   19077,
   19080,
   19085,
   19094,
   19104,
   19111,
   19118,
   19125,
   19132,
   19138,
   19147,
   19154,
   19159,
   19161,
   19163,
   19165,
   0,
   0,
   0,
   19173,
   19181,
   19190,
   19200,
   19209,
   19218,
   19227,
   19232,
   19235,
   19239,
   19243,
   19247,
   19251,
   19255,
   19259,
   19263,
   19265,
   19269,
   19273,
   19278,
   19283,
   19286,
   19291,
   19296,
   19301,
   19306,
   19309,
   19314,
   19317,
   19322,
   19327,
   19332,
   19335,
   19340,
   19344,
   19350,
   19354,
   19358,
   19364,
   19368,
   19376,
   19385,
   19395,
   19404,
   19412,
   19416,
   19420,
   19424,
   19430,
   19436,
   19442,
   19447,
   19452,
   19457,
   19462,
   19467,
   19472,
   19476,
   19480,
   19484,
   19489,
   19495,
   19499,
   19505,
   19512,
   19515,
   19518,
   19521,
   19525,
   19529,
   19533,
   19537,
   19542,
   19547,
   19552,
   19557,
   19561,
   19565,
   19571,
   19575,
   19579,
   19581,
   19585,
   19589,
   19591,
   19594,
   19598,
   19601,
   19606,
   19611,
   19614,
   19619,
   19624,
   19627,
   19631,
   19637,
   19641,
   19645,
   19655,
   19658,
   19665,
   19669,
   19674,
   19680,
   19688,
   19692,
   19697,
   19702,
   19707,
   19714,
   19716,
   19720,
   19724,
   19730,
   19732,
   19736,
   19739,
   19741,
   19745,
   19748,
   19752,
   19754,
   19756,
   19760,
   19764,
   19768,
   19774,
   19777,
   19780,
   19783,
   19785,
   19789,
   19793,
   19795,
   19800,
   19850,
   19900,
   19920,
   19925,
   19930,
   19935,
   19940,
   19949,
   19958,
   19967,
   19976,
   19983,
   19990,
   19997,
   20004,
   20011,
   20018,
   20025,
   20032,
   20038,
   20044,
   20050,
   20056,
   20062,
   20068,
   20074,
   20080,
   20086,
   20092,
   20098,
   20104,
   20112,
   20120,
   20128,
   20133,
   20141,
   20149,
   20157,
   20162,
   20168,
   20174,
   20179,
   20184,
   20190,
   20195,
   20201,
   20206,
   20213,
   20220,
   20228,
   20234,
   20239,
   20246,
   20252,
   20258,
   20263,
   20270,
   20276,
   20282,
   20287,
   20294,
   20300,
   20306,
   20311,
   20318,
   20324,
   20326,
   20329,
   20333,
   20338,
   20340,
   20343,
   20346,
   20350,
   20352,
   20354,
   20357,
   20361,
   20366,
   20369,
   0,
   0,
   20371,
   20379,
   0,
   20387,
   0,
   0,
   0,
   20389,
   20391,
   0,
   0,
   20393,
   20396,
   0,
   0,
   0,
   0,
   20399,
   20403,
   20410,
   20414,
   20418,
   20425,
   20431,
   20433,
   0,
   0,
   0,
   20435,
   20437,
   20439,
   20441,
   0,
   20448,
   20459,
   20476,
   20488,
   20499,
   20513,
   20523,
   20536,
   20547,
   20558,
   20569,
   20583,
   20595,
   20607,
   20619,
   20632,
   20648,
   20662,
   20676,
   20688,
   20703,
   20716,
   20729,
   20742,
   20758,
   20772,
   20786,
   20790,
   20795,
   20801,
   20804,
   20811,
   20818,
   20835,
   20851,
   20854,
   20857,
   20867,
   20875,
   20883,
   20891,
   20895,
   20902,
   20908,
   20916,
   20921,
   20932,
   20937,
   20949,
   20962,
   20968,
   20973,
   20981,
   20989,
   21000,
   21005,
   21013,
   21018,
   21026,
   21034,
   21039,
   21047,
   21052,
   21060,
   21066,
   21075,
   21083,
   21094,
   21105,
   21110,
   21119,
   0,
   0,
   21131,
   21133,
   0,
   0,
   0,
   0,
   21135,
   21142,
   21146,
   21152,
   21169,
   21171,
   21179,
   21186,
   21195,
   21204,
   21207,
   21210,
   21215,
   21220,
   21227,
   21231,
   21235,
   21239,
   21243,
   21247,
   21250,
   21254,
   21259,
   21263,
   21268,
   21273,
   21278,
   21282,
   21285,
   21288,
   21292,
   21296,
   21300,
   21304,
   21309,
   21314,
   21323,
   21332,
   21337,
   21339,
   21342,
   21344,
   21347,
   21349,
   21351,
   21354,
   21362,
   21371,
   21376,
   21381,
   21387,
   21396,
   21401,
   21409,
   21420,
   21431,
   21445,
   21459,
   21464,
   21475,
   21479,
   21483,
   21486,
   21496,
   21507,
   21516,
   21520,
   21525,
   21534,
   21538,
   21542,
   21547,
   0,
   0,
   21550,
   21553,
   21559,
   21572,
   21580,
   0,
   21587,
   21604,
   21620,
   21627,
   21633,
   21635,
   21639,
   21642,
   21645,
   21651,
   21664,
   21681,
   21697,
   21704,
   21710,
   21714,
   21717,
   21720,
   21726,
   21739,
   21756,
   21772,
   21779,
   21785,
   21790,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(
   nir_shader *shader
) {
   bool progress = false;
   bool condition_flags[149];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(6818 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !options->lower_ftrunc || options->lower_ffloor;
   condition_flags[6] = !options->lower_iadd_sat;
   condition_flags[7] = !options->lower_uadd_sat;
   condition_flags[8] = (options->has_fmulz ||               (options->has_fmulz_no_denorms &&                !nir_is_denorm_preserve(info->float_controls_execution_mode, 32)));
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = !options->has_udot_4x8_sat;
   condition_flags[14] = !options->has_sdot_4x8_sat;
   condition_flags[15] = !options->has_sudot_4x8_sat;
   condition_flags[16] = options->lower_flrp16;
   condition_flags[17] = !options->lower_flrp16;
   condition_flags[18] = options->lower_flrp32;
   condition_flags[19] = !options->lower_flrp32;
   condition_flags[20] = options->lower_flrp64;
   condition_flags[21] = !options->lower_flrp64;
   condition_flags[22] = options->lower_ftrunc;
   condition_flags[23] = (options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[24] = options->lower_ffloor;
   condition_flags[25] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[26] = !options->lower_ffloor;
   condition_flags[27] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[28] = options->lower_ffract;
   condition_flags[29] = (options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[30] = options->lower_fceil;
   condition_flags[31] = options->lower_ffma16;
   condition_flags[32] = options->lower_ffma32;
   condition_flags[33] = options->lower_ffma64;
   condition_flags[34] = options->fuse_ffma16;
   condition_flags[35] = options->fuse_ffma32;
   condition_flags[36] = options->fuse_ffma64;
   condition_flags[37] = options->lower_fdph;
   condition_flags[38] = !options->lower_fdph;
   condition_flags[39] = options->lower_fdot;
   condition_flags[40] = !options->lower_fsat;
   condition_flags[41] = !options->lower_iabs;
   condition_flags[42] = options->lower_fsat;
   condition_flags[43] = !options->lower_fsign;
   condition_flags[44] = !options->lower_fsign & !(options->lower_doubles_options & nir_lower_dsign);
   condition_flags[45] = options->lower_umax && !options->lower_bitops;
   condition_flags[46] = options->lower_umin && !options->lower_bitops;
   condition_flags[47] = !options->lower_umax;
   condition_flags[48] = !options->lower_umin;
   condition_flags[49] = !false;
   condition_flags[50] = (options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[51] = (options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[52] = !(options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[53] = !(options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[54] = !((options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[55] = options->lower_scmp;
   condition_flags[56] = options->lower_vector_cmp;
   condition_flags[57] = !options->lower_pack_64_2x32_split;
   condition_flags[58] = options->has_rotate16;
   condition_flags[59] = options->has_rotate32;
   condition_flags[60] = !options->has_rotate8;
   condition_flags[61] = !options->has_rotate16;
   condition_flags[62] = !options->has_rotate32;
   condition_flags[63] = options->has_shfr32;
   condition_flags[64] = options->lower_fpow;
   condition_flags[65] = !options->lower_fpow;
   condition_flags[66] = options->lower_fdiv;
   condition_flags[67] = options->lower_fsqrt;
   condition_flags[68] = !options->lower_fsqrt;
   condition_flags[69] = options->lower_sincos;
   condition_flags[70] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[71] = !options->lower_extract_byte;
   condition_flags[72] = !options->lower_extract_word;
   condition_flags[73] = options->has_pack_32_4x8;
   condition_flags[74] = options->lower_pack_64_2x32_split;
   condition_flags[75] = options->lower_pack_32_2x16_split || options->lower_pack_split;
   condition_flags[76] = options->has_pack_half_2x16_rtz;
   condition_flags[77] = options->lower_unpack_64_2x32_split;
   condition_flags[78] = options->lower_unpack_32_2x16_split || options->lower_pack_split;
   condition_flags[79] = !options->lower_unpack_64_2x32_split;
   condition_flags[80] = options->has_find_msb_rev;
   condition_flags[81] = !options->lower_ifind_msb;
   condition_flags[82] = !options->lower_ufind_msb;
   condition_flags[83] = !options->lower_find_lsb;
   condition_flags[84] = options->lower_fmod;
   condition_flags[85] = options->lower_uadd_carry;
   condition_flags[86] = options->lower_usub_borrow;
   condition_flags[87] = options->lower_bitfield_insert && options->has_bfm && options->has_bfi;
   condition_flags[88] = options->lower_hadd;
   condition_flags[89] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[90] = options->lower_mul_32x16;
   condition_flags[91] = options->lower_uadd_sat || (options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64)) != 0;
   condition_flags[92] = options->lower_uadd_sat;
   condition_flags[93] = options->lower_usub_sat;
   condition_flags[94] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[95] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[96] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[97] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[98] = options->lower_bitfield_insert && (!options->has_bfm || (!options->has_bfi && !options->has_bitfield_select));
   condition_flags[99] = options->lower_bitfield_insert && options->has_bfm && options->has_bitfield_select;
   condition_flags[100] = options->lower_bitfield_extract && options->has_bfe;
   condition_flags[101] = options->has_bfm;
   condition_flags[102] = options->lower_bitfield_extract && !options->has_bfe;
   condition_flags[103] = options->lower_ifind_msb && !options->has_find_msb_rev && !options->has_uclz;
   condition_flags[104] = options->lower_ifind_msb && options->has_find_msb_rev;
   condition_flags[105] = options->lower_ifind_msb && options->has_uclz;
   condition_flags[106] = options->lower_ufind_msb && options->has_find_msb_rev;
   condition_flags[107] = options->lower_ufind_msb && options->has_uclz;
   condition_flags[108] = !options->has_uclz && options->has_find_msb_rev;
   condition_flags[109] = options->lower_find_lsb;
   condition_flags[110] = options->lower_extract_byte;
   condition_flags[111] = options->lower_extract_word;
   condition_flags[112] = options->lower_pack_unorm_2x16;
   condition_flags[113] = options->lower_pack_unorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[114] = options->lower_pack_unorm_4x8 && options->has_pack_32_4x8;
   condition_flags[115] = options->lower_pack_snorm_2x16;
   condition_flags[116] = options->lower_pack_snorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[117] = options->lower_pack_snorm_4x8 && options->has_pack_32_4x8;
   condition_flags[118] = options->lower_unpack_unorm_2x16;
   condition_flags[119] = options->lower_unpack_unorm_4x8;
   condition_flags[120] = options->lower_unpack_snorm_2x16;
   condition_flags[121] = options->lower_unpack_snorm_4x8;
   condition_flags[122] = options->lower_pack_split;
   condition_flags[123] = options->lower_pack_split && !nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[124] = options->lower_pack_split && nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[125] = options->lower_isign;
   condition_flags[126] = !options->lower_isign;
   condition_flags[127] = options->lower_fsign;
   condition_flags[128] = options->lower_doubles_options & nir_lower_dsign;
   condition_flags[129] = !options->has_imul24;
   condition_flags[130] = !options->has_umul24;
   condition_flags[131] = !options->has_umad24;
   condition_flags[132] = options->has_imul24;
   condition_flags[133] = options->has_umad24;
   condition_flags[134] = options->has_umul24;
   condition_flags[135] = !options->lower_uadd_sat && !(options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64));
   condition_flags[136] = !options->lower_usub_sat;
   condition_flags[137] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[138] = options->lower_iadd_sat;
   condition_flags[139] = options->support_8bit_alu;
   condition_flags[140] = options->support_16bit_alu;
   condition_flags[141] = options->lower_ldexp;
   condition_flags[142] = !options->lower_bitfield_reverse;
   condition_flags[143] = options->has_msad;
   condition_flags[144] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[145] = options->lower_fisnormal;
   condition_flags[146] = options->lower_fquantize2f16;
   condition_flags[147] = options->avoid_ternary_with_two_constants;
   condition_flags[148] = !options->vectorize_vec2_16bit;

   nir_foreach_function_impl(impl, shader) {
     progress |= nir_algebraic_impl(impl, condition_flags, &nir_opt_algebraic_table);
   }

   return progress;
}

#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search2389_0_0 -> 0 in the cache */
   /* search2389_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2389_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace2389_0_0 -> 5 in the cache */
   /* replace2389_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2389_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search2390_0_0 -> 0 in the cache */
   /* search2390_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2390_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace2390_0_0 -> 5 in the cache */
   /* replace2390_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2390_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search2391_0_0 -> 0 in the cache */
   /* search2391_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2391_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace2391_0_0 -> 5 in the cache */
   /* replace2391_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2391_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search2392_0_0 -> 5 in the cache */
   /* search2392_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2392_1_0 -> 5 in the cache */
   /* search2392_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace2392_0 -> 5 in the cache */
   /* replace2392_1_0 -> 8 in the cache */
   /* replace2392_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search2393_0_0 -> 5 in the cache */
   /* search2393_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2393_1_0 -> 5 in the cache */
   /* search2393_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace2393_0 -> 5 in the cache */
   /* replace2393_1_0 -> 8 in the cache */
   /* replace2393_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2394_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search2395_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2395_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2396_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace2396 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search2397_0 -> 39 in the cache */
   /* search2397_1_0_0 -> 39 in the cache */
   /* search2397_1_0 -> 40 in the cache */
   /* search2397_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace2397 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search2398_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2398_1_0 -> 39 in the cache */
   /* search2398_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace2398 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search2399_0 -> 39 in the cache */
   /* search2399_1_0_0 -> 39 in the cache */
   /* search2399_1_0 -> 46 in the cache */
   /* search2399_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace2399 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search2400_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search2400_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace2400_0_0 -> 51 in the cache */
   /* replace2400_0_1 -> 53 in the cache */
   /* replace2400_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace2400_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search2401_0_0 -> 39 in the cache */
   /* search2401_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search2401_1_0 -> 39 in the cache */
   /* search2401_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search2401_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace2401_0_0 -> 53 in the cache */
   /* replace2401_0_1 -> 51 in the cache */
   /* replace2401_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace2401_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search2402_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace2402_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace2402_1_0 -> 64 in the cache */
   /* replace2402_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   is_used_once,
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(
   nir_shader *shader
) {
   bool progress = false;
   bool condition_flags[149];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !options->lower_ftrunc || options->lower_ffloor;
   condition_flags[6] = !options->lower_iadd_sat;
   condition_flags[7] = !options->lower_uadd_sat;
   condition_flags[8] = (options->has_fmulz ||               (options->has_fmulz_no_denorms &&                !nir_is_denorm_preserve(info->float_controls_execution_mode, 32)));
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = !options->has_udot_4x8_sat;
   condition_flags[14] = !options->has_sdot_4x8_sat;
   condition_flags[15] = !options->has_sudot_4x8_sat;
   condition_flags[16] = options->lower_flrp16;
   condition_flags[17] = !options->lower_flrp16;
   condition_flags[18] = options->lower_flrp32;
   condition_flags[19] = !options->lower_flrp32;
   condition_flags[20] = options->lower_flrp64;
   condition_flags[21] = !options->lower_flrp64;
   condition_flags[22] = options->lower_ftrunc;
   condition_flags[23] = (options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[24] = options->lower_ffloor;
   condition_flags[25] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[26] = !options->lower_ffloor;
   condition_flags[27] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[28] = options->lower_ffract;
   condition_flags[29] = (options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[30] = options->lower_fceil;
   condition_flags[31] = options->lower_ffma16;
   condition_flags[32] = options->lower_ffma32;
   condition_flags[33] = options->lower_ffma64;
   condition_flags[34] = options->fuse_ffma16;
   condition_flags[35] = options->fuse_ffma32;
   condition_flags[36] = options->fuse_ffma64;
   condition_flags[37] = options->lower_fdph;
   condition_flags[38] = !options->lower_fdph;
   condition_flags[39] = options->lower_fdot;
   condition_flags[40] = !options->lower_fsat;
   condition_flags[41] = !options->lower_iabs;
   condition_flags[42] = options->lower_fsat;
   condition_flags[43] = !options->lower_fsign;
   condition_flags[44] = !options->lower_fsign & !(options->lower_doubles_options & nir_lower_dsign);
   condition_flags[45] = options->lower_umax && !options->lower_bitops;
   condition_flags[46] = options->lower_umin && !options->lower_bitops;
   condition_flags[47] = !options->lower_umax;
   condition_flags[48] = !options->lower_umin;
   condition_flags[49] = !false;
   condition_flags[50] = (options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[51] = (options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[52] = !(options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[53] = !(options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[54] = !((options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[55] = options->lower_scmp;
   condition_flags[56] = options->lower_vector_cmp;
   condition_flags[57] = !options->lower_pack_64_2x32_split;
   condition_flags[58] = options->has_rotate16;
   condition_flags[59] = options->has_rotate32;
   condition_flags[60] = !options->has_rotate8;
   condition_flags[61] = !options->has_rotate16;
   condition_flags[62] = !options->has_rotate32;
   condition_flags[63] = options->has_shfr32;
   condition_flags[64] = options->lower_fpow;
   condition_flags[65] = !options->lower_fpow;
   condition_flags[66] = options->lower_fdiv;
   condition_flags[67] = options->lower_fsqrt;
   condition_flags[68] = !options->lower_fsqrt;
   condition_flags[69] = options->lower_sincos;
   condition_flags[70] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[71] = !options->lower_extract_byte;
   condition_flags[72] = !options->lower_extract_word;
   condition_flags[73] = options->has_pack_32_4x8;
   condition_flags[74] = options->lower_pack_64_2x32_split;
   condition_flags[75] = options->lower_pack_32_2x16_split || options->lower_pack_split;
   condition_flags[76] = options->has_pack_half_2x16_rtz;
   condition_flags[77] = options->lower_unpack_64_2x32_split;
   condition_flags[78] = options->lower_unpack_32_2x16_split || options->lower_pack_split;
   condition_flags[79] = !options->lower_unpack_64_2x32_split;
   condition_flags[80] = options->has_find_msb_rev;
   condition_flags[81] = !options->lower_ifind_msb;
   condition_flags[82] = !options->lower_ufind_msb;
   condition_flags[83] = !options->lower_find_lsb;
   condition_flags[84] = options->lower_fmod;
   condition_flags[85] = options->lower_uadd_carry;
   condition_flags[86] = options->lower_usub_borrow;
   condition_flags[87] = options->lower_bitfield_insert && options->has_bfm && options->has_bfi;
   condition_flags[88] = options->lower_hadd;
   condition_flags[89] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[90] = options->lower_mul_32x16;
   condition_flags[91] = options->lower_uadd_sat || (options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64)) != 0;
   condition_flags[92] = options->lower_uadd_sat;
   condition_flags[93] = options->lower_usub_sat;
   condition_flags[94] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[95] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[96] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[97] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[98] = options->lower_bitfield_insert && (!options->has_bfm || (!options->has_bfi && !options->has_bitfield_select));
   condition_flags[99] = options->lower_bitfield_insert && options->has_bfm && options->has_bitfield_select;
   condition_flags[100] = options->lower_bitfield_extract && options->has_bfe;
   condition_flags[101] = options->has_bfm;
   condition_flags[102] = options->lower_bitfield_extract && !options->has_bfe;
   condition_flags[103] = options->lower_ifind_msb && !options->has_find_msb_rev && !options->has_uclz;
   condition_flags[104] = options->lower_ifind_msb && options->has_find_msb_rev;
   condition_flags[105] = options->lower_ifind_msb && options->has_uclz;
   condition_flags[106] = options->lower_ufind_msb && options->has_find_msb_rev;
   condition_flags[107] = options->lower_ufind_msb && options->has_uclz;
   condition_flags[108] = !options->has_uclz && options->has_find_msb_rev;
   condition_flags[109] = options->lower_find_lsb;
   condition_flags[110] = options->lower_extract_byte;
   condition_flags[111] = options->lower_extract_word;
   condition_flags[112] = options->lower_pack_unorm_2x16;
   condition_flags[113] = options->lower_pack_unorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[114] = options->lower_pack_unorm_4x8 && options->has_pack_32_4x8;
   condition_flags[115] = options->lower_pack_snorm_2x16;
   condition_flags[116] = options->lower_pack_snorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[117] = options->lower_pack_snorm_4x8 && options->has_pack_32_4x8;
   condition_flags[118] = options->lower_unpack_unorm_2x16;
   condition_flags[119] = options->lower_unpack_unorm_4x8;
   condition_flags[120] = options->lower_unpack_snorm_2x16;
   condition_flags[121] = options->lower_unpack_snorm_4x8;
   condition_flags[122] = options->lower_pack_split;
   condition_flags[123] = options->lower_pack_split && !nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[124] = options->lower_pack_split && nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[125] = options->lower_isign;
   condition_flags[126] = !options->lower_isign;
   condition_flags[127] = options->lower_fsign;
   condition_flags[128] = options->lower_doubles_options & nir_lower_dsign;
   condition_flags[129] = !options->has_imul24;
   condition_flags[130] = !options->has_umul24;
   condition_flags[131] = !options->has_umad24;
   condition_flags[132] = options->has_imul24;
   condition_flags[133] = options->has_umad24;
   condition_flags[134] = options->has_umul24;
   condition_flags[135] = !options->lower_uadd_sat && !(options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64));
   condition_flags[136] = !options->lower_usub_sat;
   condition_flags[137] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[138] = options->lower_iadd_sat;
   condition_flags[139] = options->support_8bit_alu;
   condition_flags[140] = options->support_16bit_alu;
   condition_flags[141] = options->lower_ldexp;
   condition_flags[142] = !options->lower_bitfield_reverse;
   condition_flags[143] = options->has_msad;
   condition_flags[144] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[145] = options->lower_fisnormal;
   condition_flags[146] = options->lower_fquantize2f16;
   condition_flags[147] = options->avoid_ternary_with_two_constants;
   condition_flags[148] = !options->vectorize_vec2_16bit;

   nir_foreach_function_impl(impl, shader) {
     progress |= nir_algebraic_impl(impl, condition_flags, &nir_opt_algebraic_before_ffma_table);
   }

   return progress;
}

#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 10
 * transforms:
 *    ('ishl', ('i2i64', 'a'), 'b') => ('bcsel', ('ieq', ('iand', 'b', 63), 0), ('i2i64', 'a'), ('bcsel', ('ilt', ('iand', 'b', 63), 32), ('pack_64_2x32_split', ('ishl', ('i2i32', 'a'), 'b'), ('ishr', ('i2i32', 'a'), ('iadd', ('ineg', 'b'), 32))), ('pack_64_2x32_split', 0, ('ishl', ('i2i32', 'a'), ('iabs', ('iadd', ('ineg', 'b'), 32))))))
 *    ('ishl', ('u2u64', 'a'), 'b') => ('bcsel', ('ieq', ('iand', 'b', 63), 0), ('u2u64', 'a'), ('bcsel', ('ilt', ('iand', 'b', 63), 32), ('pack_64_2x32_split', ('ishl', ('u2u32', 'a'), 'b'), ('ushr', ('u2u32', 'a'), ('iadd', ('ineg', 'b'), 32))), ('pack_64_2x32_split', 0, ('ishl', ('u2u32', 'a'), ('iabs', ('iadd', ('ineg', 'b'), 32))))))
 *    ('iadd@64', ('ineg', 'a'), ('ineg(is_used_once)', 'b')) => ('isub', ('ineg', 'a'), 'b')
 *    ('iadd@64', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('isub@64', 'a', ('ineg', 'b')) => ('iadd', 'a', 'b')
 *    ('isub@64', ('ineg', 'a'), ('ineg', 'b')) => ('isub', 'b', 'a')
 *    ('imul@64', ('ineg', 'a'), ('ineg', 'b')) => ('imul', 'a', 'b')
 *    ('idiv@64', ('ineg', 'a'), ('ineg', 'b')) => ('idiv', 'a', 'b')
 *    ('iadd', ('i2i64', 'a'), ('i2i64', 'a')) => ('ishl', ('i2i64', 'a'), 1)
 *    ('iadd', ('u2u64', 'a'), ('u2u64', 'a')) => ('ishl', ('u2u64', 'a'), 1)
 */


static const nir_search_value_union nir_opt_algebraic_before_lower_int64_values[] = {
   /* ('ishl', ('i2i64', 'a'), 'b') => ('bcsel', ('ieq', ('iand', 'b', 63), 0), ('i2i64', 'a'), ('bcsel', ('ilt', ('iand', 'b', 63), 32), ('pack_64_2x32_split', ('ishl', ('i2i32', 'a'), 'b'), ('ishr', ('i2i32', 'a'), ('iadd', ('ineg', 'b'), 32))), ('pack_64_2x32_split', 0, ('ishl', ('i2i32', 'a'), ('iabs', ('iadd', ('ineg', 'b'), 32)))))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1, 2 },
      -1,
   } },

   /* replace2403_0_0_0 -> 2 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3full /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 2, 4 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 5, 6 },
      -1,
   } },
   /* replace2403_1_0 -> 0 in the cache */
   /* replace2403_1 -> 1 in the cache */
   /* replace2403_2_0_0_0 -> 2 in the cache */
   /* replace2403_2_0_0_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 2, 4 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20ull /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 8, 9 },
      -1,
   } },
   /* replace2403_2_1_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2403_2_1_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2 },
      -1,
   } },
   /* replace2403_2_1_1_0_0 -> 0 in the cache */
   /* replace2403_2_1_1_0 -> 11 in the cache */
   /* replace2403_2_1_1_1_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2 },
      -1,
   } },
   /* replace2403_2_1_1_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 13, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 12, 15 },
      -1,
   } },
   /* replace2403_2_2_0 -> 6 in the cache */
   /* replace2403_2_2_1_0_0 -> 0 in the cache */
   /* replace2403_2_2_1_0 -> 11 in the cache */
   /* replace2403_2_2_1_1_0_0_0 -> 2 in the cache */
   /* replace2403_2_2_1_1_0_0 -> 13 in the cache */
   /* replace2403_2_2_1_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      4, 1,
      { 13, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 1,
      { 17 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 18 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 6, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 10, 16, 20 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 5,
      { 7, 1, 21 },
      -1,
   } },

   /* ('ishl', ('u2u64', 'a'), 'b') => ('bcsel', ('ieq', ('iand', 'b', 63), 0), ('u2u64', 'a'), ('bcsel', ('ilt', ('iand', 'b', 63), 32), ('pack_64_2x32_split', ('ishl', ('u2u32', 'a'), 'b'), ('ushr', ('u2u32', 'a'), ('iadd', ('ineg', 'b'), 32))), ('pack_64_2x32_split', 0, ('ishl', ('u2u32', 'a'), ('iabs', ('iadd', ('ineg', 'b'), 32)))))) */
   /* search2404_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search2404_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 23, 2 },
      -1,
   } },

   /* replace2404_0_0_0 -> 2 in the cache */
   /* replace2404_0_0_1 -> 4 in the cache */
   /* replace2404_0_0 -> 5 in the cache */
   /* replace2404_0_1 -> 6 in the cache */
   /* replace2404_0 -> 7 in the cache */
   /* replace2404_1_0 -> 0 in the cache */
   /* replace2404_1 -> 23 in the cache */
   /* replace2404_2_0_0_0 -> 2 in the cache */
   /* replace2404_2_0_0_1 -> 4 in the cache */
   /* replace2404_2_0_0 -> 8 in the cache */
   /* replace2404_2_0_1 -> 9 in the cache */
   /* replace2404_2_0 -> 10 in the cache */
   /* replace2404_2_1_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2404_2_1_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 25, 2 },
      -1,
   } },
   /* replace2404_2_1_1_0_0 -> 0 in the cache */
   /* replace2404_2_1_1_0 -> 25 in the cache */
   /* replace2404_2_1_1_1_0_0 -> 2 in the cache */
   /* replace2404_2_1_1_1_0 -> 13 in the cache */
   /* replace2404_2_1_1_1_1 -> 9 in the cache */
   /* replace2404_2_1_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 25, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 26, 27 },
      -1,
   } },
   /* replace2404_2_2_0 -> 6 in the cache */
   /* replace2404_2_2_1_0_0 -> 0 in the cache */
   /* replace2404_2_2_1_0 -> 25 in the cache */
   /* replace2404_2_2_1_1_0_0_0 -> 2 in the cache */
   /* replace2404_2_2_1_1_0_0 -> 13 in the cache */
   /* replace2404_2_2_1_1_0_1 -> 9 in the cache */
   /* replace2404_2_2_1_1_0 -> 17 in the cache */
   /* replace2404_2_2_1_1 -> 18 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 25, 18 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 6, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 10, 28, 30 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 5,
      { 7, 23, 31 },
      -1,
   } },

   /* ('iadd@64', ('ineg', 'a'), ('ineg(is_used_once)', 'b')) => ('isub', ('ineg', 'a'), 'b') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 33 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 35 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 34, 36 },
      -1,
   } },

   /* replace2405_0_0 -> 33 in the cache */
   /* replace2405_0 -> 34 in the cache */
   /* replace2405_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 34, 35 },
      -1,
   } },

   /* ('iadd@64', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search2406_0 -> 33 in the cache */
   /* search2406_1_0 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 33, 39 },
      -1,
   } },

   /* replace2406_0 -> 33 in the cache */
   /* replace2406_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 33, 35 },
      -1,
   } },

   /* ('isub@64', 'a', ('ineg', 'b')) => ('iadd', 'a', 'b') */
   /* search2407_0 -> 33 in the cache */
   /* search2407_1_0 -> 35 in the cache */
   /* search2407_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 33, 39 },
      -1,
   } },

   /* replace2407_0 -> 33 in the cache */
   /* replace2407_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 33, 35 },
      -1,
   } },

   /* ('isub@64', ('ineg', 'a'), ('ineg', 'b')) => ('isub', 'b', 'a') */
   /* search2408_0_0 -> 33 in the cache */
   /* search2408_0 -> 34 in the cache */
   /* search2408_1_0 -> 35 in the cache */
   /* search2408_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 34, 39 },
      -1,
   } },

   /* replace2408_0 -> 35 in the cache */
   /* replace2408_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 35, 33 },
      -1,
   } },

   /* ('imul@64', ('ineg', 'a'), ('ineg', 'b')) => ('imul', 'a', 'b') */
   /* search2409_0_0 -> 33 in the cache */
   /* search2409_0 -> 34 in the cache */
   /* search2409_1_0 -> 35 in the cache */
   /* search2409_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 34, 39 },
      -1,
   } },

   /* replace2409_0 -> 33 in the cache */
   /* replace2409_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 33, 35 },
      -1,
   } },

   /* ('idiv@64', ('ineg', 'a'), ('ineg', 'b')) => ('idiv', 'a', 'b') */
   /* search2410_0_0 -> 33 in the cache */
   /* search2410_0 -> 34 in the cache */
   /* search2410_1_0 -> 35 in the cache */
   /* search2410_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 34, 39 },
      -1,
   } },

   /* replace2410_0 -> 33 in the cache */
   /* replace2410_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 33, 35 },
      -1,
   } },

   /* ('iadd', ('i2i64', 'a'), ('i2i64', 'a')) => ('ishl', ('i2i64', 'a'), 1) */
   /* search2411_0_0 -> 0 in the cache */
   /* search2411_0 -> 1 in the cache */
   /* search2411_1_0 -> 0 in the cache */
   /* search2411_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      -1, 0,
      { 1, 1 },
      -1,
   } },

   /* replace2411_0_0 -> 0 in the cache */
   /* replace2411_0 -> 1 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1, 51 },
      -1,
   } },

   /* ('iadd', ('u2u64', 'a'), ('u2u64', 'a')) => ('ishl', ('u2u64', 'a'), 1) */
   /* search2412_0_0 -> 0 in the cache */
   /* search2412_0 -> 23 in the cache */
   /* search2412_1_0 -> 0 in the cache */
   /* search2412_1 -> 23 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      -1, 0,
      { 23, 23 },
      -1,
   } },

   /* replace2412_0_0 -> 0 in the cache */
   /* replace2412_0 -> 23 in the cache */
   /* replace2412_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 23, 51 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_lower_int64_expression_cond[] = {
   is_used_once,
};


static const struct transform nir_opt_algebraic_before_lower_int64_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3, 22, 149 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 32, 149 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 150 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 52, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 150 },
   { 40, 41, 150 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 42, 43, 150 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 42, 43, 150 },
   { 44, 45, 150 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_lower_int64_pass_op_table[nir_num_search_ops] = {
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         5,
         5,
         5,
         6,
         6,
         6,
      },
   },
   [nir_search_op_i2i] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         2,
      },
   },
   [nir_search_op_u2u] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         3,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         7,
         0,
         0,
         9,
         7,
         7,
         7,
         7,
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         4,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         12,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         13,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         14,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_lower_int64_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   16,
   19,
   21,
};

static const nir_algebraic_table nir_opt_algebraic_before_lower_int64_table = {
   .transforms = nir_opt_algebraic_before_lower_int64_transforms,
   .transform_offsets = nir_opt_algebraic_before_lower_int64_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_lower_int64_pass_op_table,
   .values = nir_opt_algebraic_before_lower_int64_values,
   .expression_cond = nir_opt_algebraic_before_lower_int64_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_before_lower_int64(
   nir_shader *shader
) {
   bool progress = false;
   bool condition_flags[151];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(55 == ARRAY_SIZE(nir_opt_algebraic_before_lower_int64_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !options->lower_ftrunc || options->lower_ffloor;
   condition_flags[6] = !options->lower_iadd_sat;
   condition_flags[7] = !options->lower_uadd_sat;
   condition_flags[8] = (options->has_fmulz ||               (options->has_fmulz_no_denorms &&                !nir_is_denorm_preserve(info->float_controls_execution_mode, 32)));
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = !options->has_udot_4x8_sat;
   condition_flags[14] = !options->has_sdot_4x8_sat;
   condition_flags[15] = !options->has_sudot_4x8_sat;
   condition_flags[16] = options->lower_flrp16;
   condition_flags[17] = !options->lower_flrp16;
   condition_flags[18] = options->lower_flrp32;
   condition_flags[19] = !options->lower_flrp32;
   condition_flags[20] = options->lower_flrp64;
   condition_flags[21] = !options->lower_flrp64;
   condition_flags[22] = options->lower_ftrunc;
   condition_flags[23] = (options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[24] = options->lower_ffloor;
   condition_flags[25] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[26] = !options->lower_ffloor;
   condition_flags[27] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[28] = options->lower_ffract;
   condition_flags[29] = (options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[30] = options->lower_fceil;
   condition_flags[31] = options->lower_ffma16;
   condition_flags[32] = options->lower_ffma32;
   condition_flags[33] = options->lower_ffma64;
   condition_flags[34] = options->fuse_ffma16;
   condition_flags[35] = options->fuse_ffma32;
   condition_flags[36] = options->fuse_ffma64;
   condition_flags[37] = options->lower_fdph;
   condition_flags[38] = !options->lower_fdph;
   condition_flags[39] = options->lower_fdot;
   condition_flags[40] = !options->lower_fsat;
   condition_flags[41] = !options->lower_iabs;
   condition_flags[42] = options->lower_fsat;
   condition_flags[43] = !options->lower_fsign;
   condition_flags[44] = !options->lower_fsign & !(options->lower_doubles_options & nir_lower_dsign);
   condition_flags[45] = options->lower_umax && !options->lower_bitops;
   condition_flags[46] = options->lower_umin && !options->lower_bitops;
   condition_flags[47] = !options->lower_umax;
   condition_flags[48] = !options->lower_umin;
   condition_flags[49] = !false;
   condition_flags[50] = (options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[51] = (options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[52] = !(options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[53] = !(options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[54] = !((options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[55] = options->lower_scmp;
   condition_flags[56] = options->lower_vector_cmp;
   condition_flags[57] = !options->lower_pack_64_2x32_split;
   condition_flags[58] = options->has_rotate16;
   condition_flags[59] = options->has_rotate32;
   condition_flags[60] = !options->has_rotate8;
   condition_flags[61] = !options->has_rotate16;
   condition_flags[62] = !options->has_rotate32;
   condition_flags[63] = options->has_shfr32;
   condition_flags[64] = options->lower_fpow;
   condition_flags[65] = !options->lower_fpow;
   condition_flags[66] = options->lower_fdiv;
   condition_flags[67] = options->lower_fsqrt;
   condition_flags[68] = !options->lower_fsqrt;
   condition_flags[69] = options->lower_sincos;
   condition_flags[70] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[71] = !options->lower_extract_byte;
   condition_flags[72] = !options->lower_extract_word;
   condition_flags[73] = options->has_pack_32_4x8;
   condition_flags[74] = options->lower_pack_64_2x32_split;
   condition_flags[75] = options->lower_pack_32_2x16_split || options->lower_pack_split;
   condition_flags[76] = options->has_pack_half_2x16_rtz;
   condition_flags[77] = options->lower_unpack_64_2x32_split;
   condition_flags[78] = options->lower_unpack_32_2x16_split || options->lower_pack_split;
   condition_flags[79] = !options->lower_unpack_64_2x32_split;
   condition_flags[80] = options->has_find_msb_rev;
   condition_flags[81] = !options->lower_ifind_msb;
   condition_flags[82] = !options->lower_ufind_msb;
   condition_flags[83] = !options->lower_find_lsb;
   condition_flags[84] = options->lower_fmod;
   condition_flags[85] = options->lower_uadd_carry;
   condition_flags[86] = options->lower_usub_borrow;
   condition_flags[87] = options->lower_bitfield_insert && options->has_bfm && options->has_bfi;
   condition_flags[88] = options->lower_hadd;
   condition_flags[89] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[90] = options->lower_mul_32x16;
   condition_flags[91] = options->lower_uadd_sat || (options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64)) != 0;
   condition_flags[92] = options->lower_uadd_sat;
   condition_flags[93] = options->lower_usub_sat;
   condition_flags[94] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[95] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[96] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[97] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[98] = options->lower_bitfield_insert && (!options->has_bfm || (!options->has_bfi && !options->has_bitfield_select));
   condition_flags[99] = options->lower_bitfield_insert && options->has_bfm && options->has_bitfield_select;
   condition_flags[100] = options->lower_bitfield_extract && options->has_bfe;
   condition_flags[101] = options->has_bfm;
   condition_flags[102] = options->lower_bitfield_extract && !options->has_bfe;
   condition_flags[103] = options->lower_ifind_msb && !options->has_find_msb_rev && !options->has_uclz;
   condition_flags[104] = options->lower_ifind_msb && options->has_find_msb_rev;
   condition_flags[105] = options->lower_ifind_msb && options->has_uclz;
   condition_flags[106] = options->lower_ufind_msb && options->has_find_msb_rev;
   condition_flags[107] = options->lower_ufind_msb && options->has_uclz;
   condition_flags[108] = !options->has_uclz && options->has_find_msb_rev;
   condition_flags[109] = options->lower_find_lsb;
   condition_flags[110] = options->lower_extract_byte;
   condition_flags[111] = options->lower_extract_word;
   condition_flags[112] = options->lower_pack_unorm_2x16;
   condition_flags[113] = options->lower_pack_unorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[114] = options->lower_pack_unorm_4x8 && options->has_pack_32_4x8;
   condition_flags[115] = options->lower_pack_snorm_2x16;
   condition_flags[116] = options->lower_pack_snorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[117] = options->lower_pack_snorm_4x8 && options->has_pack_32_4x8;
   condition_flags[118] = options->lower_unpack_unorm_2x16;
   condition_flags[119] = options->lower_unpack_unorm_4x8;
   condition_flags[120] = options->lower_unpack_snorm_2x16;
   condition_flags[121] = options->lower_unpack_snorm_4x8;
   condition_flags[122] = options->lower_pack_split;
   condition_flags[123] = options->lower_pack_split && !nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[124] = options->lower_pack_split && nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[125] = options->lower_isign;
   condition_flags[126] = !options->lower_isign;
   condition_flags[127] = options->lower_fsign;
   condition_flags[128] = options->lower_doubles_options & nir_lower_dsign;
   condition_flags[129] = !options->has_imul24;
   condition_flags[130] = !options->has_umul24;
   condition_flags[131] = !options->has_umad24;
   condition_flags[132] = options->has_imul24;
   condition_flags[133] = options->has_umad24;
   condition_flags[134] = options->has_umul24;
   condition_flags[135] = !options->lower_uadd_sat && !(options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64));
   condition_flags[136] = !options->lower_usub_sat;
   condition_flags[137] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[138] = options->lower_iadd_sat;
   condition_flags[139] = options->support_8bit_alu;
   condition_flags[140] = options->support_16bit_alu;
   condition_flags[141] = options->lower_ldexp;
   condition_flags[142] = !options->lower_bitfield_reverse;
   condition_flags[143] = options->has_msad;
   condition_flags[144] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[145] = options->lower_fisnormal;
   condition_flags[146] = options->lower_fquantize2f16;
   condition_flags[147] = options->avoid_ternary_with_two_constants;
   condition_flags[148] = !options->vectorize_vec2_16bit;
   condition_flags[149] = (options->lower_int64_options & nir_lower_shift64) != 0;
   condition_flags[150] = (options->lower_int64_options & nir_lower_ineg64) != 0;

   nir_foreach_function_impl(impl, shader) {
     progress |= nir_algebraic_impl(impl, condition_flags, &nir_opt_algebraic_before_lower_int64_table);
   }

   return progress;
}

#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 360
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('!flt', ('fneg', ('fabs', 'b')), ('fneg', ('fabs', 'a'))))
 *    ('iand', ('fneu', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fneg', ('fabs', 'a'))))
 *    ('iand', ('fneu', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', ('fabs', 'a'))))
 *    ('iand', ('fneu', ('fneg', ('fabs', 'a')), 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), 'b'), ('!flt', 'b', ('fneg', ('fabs', 'a'))))
 *    ('iand', ('fneu', ('fabs', 'a'), ('fabs', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fabs', 'a'), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fabs', 'a')))
 *    ('iand', ('fneu', ('fabs', 'a'), ('fneg', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fabs', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fabs', 'a')))
 *    ('iand', ('fneu', ('fabs', 'a'), 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fabs', 'a'), 'b'), ('!flt', 'b', ('fabs', 'a')))
 *    ('iand', ('fneu', ('fneg', 'a'), ('fneg', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', 'a')))
 *    ('iand', ('fneu', ('fneg', 'a'), 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', 'a'), 'b'), ('!flt', 'b', ('fneg', 'a')))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('!flt', ('fneg', ('fabs', 'b')), ('fneg', ('fabs', 'a')))))
 *    ('ior', ('feq', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fneg', ('fabs', 'a')))))
 *    ('ior', ('feq', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', ('fabs', 'a')))))
 *    ('ior', ('feq', ('fneg', ('fabs', 'a')), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), 'b'), ('!flt', 'b', ('fneg', ('fabs', 'a')))))
 *    ('ior', ('feq', ('fabs', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fabs', 'a'), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fabs', 'a'))))
 *    ('ior', ('feq', ('fabs', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fabs', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fabs', 'a'))))
 *    ('ior', ('feq', ('fabs', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fabs', 'a'), 'b'), ('!flt', 'b', ('fabs', 'a'))))
 *    ('ior', ('feq', ('fneg', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', 'a'))))
 *    ('ior', ('feq', ('fneg', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', 'a'), 'b'), ('!flt', 'b', ('fneg', 'a'))))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('ior', ('flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))))
 *    ('ior', ('flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), ('fabs', 'b')))
 *    ('ior', ('flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), ('fneg', 'b')))
 *    ('ior', ('flt', ('fneg', ('fabs', 'a')), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), 'b'))
 *    ('ior', ('flt', ('fabs', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), ('fneg', ('fabs', 'b'))))
 *    ('ior', ('flt', ('fabs', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), ('fabs', 'b')))
 *    ('ior', ('flt', ('fabs', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), ('fneg', 'b')))
 *    ('ior', ('flt', ('fabs', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), 'b'))
 *    ('ior', ('flt', ('fneg', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), ('fneg', ('fabs', 'b'))))
 *    ('ior', ('flt', ('fneg', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), ('fabs', 'b')))
 *    ('ior', ('flt', ('fneg', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), ('fneg', 'b')))
 *    ('ior', ('flt', ('fneg', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), 'b'))
 *    ('ior', ('flt', 'a', ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', ('fneg', ('fabs', 'b'))))
 *    ('ior', ('flt', 'a', ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', ('fabs', 'b')))
 *    ('ior', ('flt', 'a', ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', 'b'))
 *    ('ior', ('fge', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))))
 *    ('ior', ('fge', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')))
 *    ('ior', ('fge', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')))
 *    ('ior', ('fge', ('fneg', ('fabs', 'a')), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), 'b'))
 *    ('ior', ('fge', ('fabs', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), ('fneg', ('fabs', 'b'))))
 *    ('ior', ('fge', ('fabs', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), ('fabs', 'b')))
 *    ('ior', ('fge', ('fabs', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), ('fneg', 'b')))
 *    ('ior', ('fge', ('fabs', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), 'b'))
 *    ('ior', ('fge', ('fneg', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), ('fneg', ('fabs', 'b'))))
 *    ('ior', ('fge', ('fneg', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), ('fabs', 'b')))
 *    ('ior', ('fge', ('fneg', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), ('fneg', 'b')))
 *    ('ior', ('fge', ('fneg', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), 'b'))
 *    ('ior', ('fge', 'a', ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', ('fneg', ('fabs', 'b'))))
 *    ('ior', ('fge', 'a', ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', ('fabs', 'b')))
 *    ('ior', ('fge', 'a', ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', 'b'))
 *    ('ior', ('flt', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', ('fneg', ('fabs', 'a')), 'b'))
 *    ('ior', ('flt', ('fabs', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', ('fabs', 'a'), 'b'))
 *    ('ior', ('flt', ('fneg', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', ('fneg', 'a'), 'b'))
 *    ('ior', ('flt', 'a', 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', 'a', 'b'))
 *    ('ior', ('fge', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', ('fneg', ('fabs', 'a')), 'b'))
 *    ('ior', ('fge', ('fabs', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', ('fabs', 'a'), 'b'))
 *    ('ior', ('fge', ('fneg', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', ('fneg', 'a'), 'b'))
 *    ('ior', ('fge', 'a', 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', 'a', 'b'))
 *    ('ior', ('flt', 'a(is_a_number)', ('fneg', ('fabs', 'b'))), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', ('fneg', ('fabs', 'b'))))
 *    ('ior', ('flt', 'a(is_a_number)', ('fabs', 'b')), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', ('fabs', 'b')))
 *    ('ior', ('flt', 'a(is_a_number)', ('fneg', 'b')), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 'a(is_a_number)', 'b'), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', 'b'))
 *    ('ior', ('fge', 'a(is_a_number)', ('fneg', ('fabs', 'b'))), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', ('fneg', ('fabs', 'b'))))
 *    ('ior', ('fge', 'a(is_a_number)', ('fabs', 'b')), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', ('fabs', 'b')))
 *    ('ior', ('fge', 'a(is_a_number)', ('fneg', 'b')), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 'a(is_a_number)', 'b'), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', 'b'))
 *    ('iand', ('fneu', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', ('fneg', ('fabs', 'a')), 'b')
 *    ('iand', ('fneu', ('fabs', 'a'), 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', ('fabs', 'a'), 'b')
 *    ('iand', ('fneu', ('fneg', 'a'), 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', ('fneg', 'a'), 'b')
 *    ('iand', ('fneu', 'a', 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', 'a', 'b')
 *    ('ior', ('feq', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', ('fneg', ('fabs', 'a')), 'b')
 *    ('ior', ('feq', ('fabs', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', ('fabs', 'a'), 'b')
 *    ('ior', ('feq', ('fneg', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', ('fneg', 'a'), 'b')
 *    ('ior', ('feq', 'a', 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', 'a', 'b')
 *    ('ior', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => ('fneo', 'a', 'b')
 *    ('flt', 0.0, ('fabs', 'a')) => ('fneo', 0.0, 'a')
 *    ('ior', ('fneu', 'a@16', 'a'), ('fneu', 'b@16', 'b')) => ('funord', 'a', 'b')
 *    ('iand', ('feq', 'a@16', 'a'), ('feq', 'b@16', 'b')) => ('ford', 'a', 'b')
 *    ('ior', ('fneu', 'a@32', 'a'), ('fneu', 'b@32', 'b')) => ('funord', 'a', 'b')
 *    ('iand', ('feq', 'a@32', 'a'), ('feq', 'b@32', 'b')) => ('ford', 'a', 'b')
 *    ('ior', ('fneu', 'a@64', 'a'), ('fneu', 'b@64', 'b')) => ('funord', 'a', 'b')
 *    ('iand', ('feq', 'a@64', 'a'), ('feq', 'b@64', 'b')) => ('ford', 'a', 'b')
 *    ('inot', ('ford(is_used_once)', 'a', 'b')) => ('funord', 'a', 'b')
 *    ('inot', ('funord(is_used_once)', 'a', 'b')) => ('ford', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('fequ(is_used_once)', 'a', 'b')) => ('fneo', 'a', 'b')
 *    ('inot', ('fneo(is_used_once)', 'a', 'b')) => ('fequ', 'a', 'b')
 *    ('inot', ('flt(is_used_once)', 'a', 'b')) => ('fgeu', 'a', 'b')
 *    ('inot', ('fgeu(is_used_once)', 'a', 'b')) => ('flt', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a', 'b')) => ('fltu', 'a', 'b')
 *    ('inot', ('fltu(is_used_once)', 'a', 'b')) => ('fge', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('iadd@32', ('imul(is_only_used_by_iadd)', 'a', 'b'), 'c') => ('imad', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd@8', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@8', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@8', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@8', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@8', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@8', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@8', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@8', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@8', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('iadd@8', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('ishl@8', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b'))
 *    ('ishl@8', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b')))
 *    ('iadd@16', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@16', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@16', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@16', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@16', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@16', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@16', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@16', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@16', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('iadd@16', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('ishl@16', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b'))
 *    ('ishl@16', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b')))
 *    ('iadd@32', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@32', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@32', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@32', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@32', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@32', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@32', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@32', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@32', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('iadd@32', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('ishl@32', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b'))
 *    ('ishl@32', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b')))
 *    ('iadd@64', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@64', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@64', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd@64', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@64', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@64', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c')
 *    ('iadd@64', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@64', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b')
 *    ('iadd@64', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('iadd@64', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b')
 *    ('ishl@64', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b'))
 *    ('ishl@64', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b')))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5)))
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 0) => ('bitnz', 'a', ('find_lsb', 'b'))
 *    ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 0) => ('bitz', 'a', ('find_lsb', 'b'))
 *    ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('bitz', 'a', ('find_lsb', 'b'))
 *    ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('bitnz', 'a', ('find_lsb', 'b'))
 *    ('ine', ('iand', 'a', ('ishl', 1, 'b')), 0) => ('bitnz', 'a', 'b')
 *    ('ieq', ('iand', 'a', ('ishl', 1, 'b')), 0) => ('bitz', 'a', 'b')
 *    ('ine', ('iand', 'a', ('ishl', 1, 'b')), ('ishl', 1, 'b')) => ('bitz', 'a', 'b')
 *    ('ieq', ('iand', 'a', ('ishl', 1, 'b')), ('ishl', 1, 'b')) => ('bitnz', 'a', 'b')
 *    ('bitz', ('ushr', 'a', 'b'), 0) => ('bitz', 'a', 'b')
 *    ('bitz', ('ishr', 'a', 'b'), 0) => ('bitz', 'a', 'b')
 *    ('bitnz', ('ushr', 'a', 'b'), 0) => ('bitnz', 'a', 'b')
 *    ('bitnz', ('ishr', 'a', 'b'), 0) => ('bitnz', 'a', 'b')
 *    ('ine', ('ubfe', 'a', 'b', 1), 0) => ('bitnz', 'a', 'b')
 *    ('ieq', ('ubfe', 'a', 'b', 1), 0) => ('bitz', 'a', 'b')
 *    ('ine', ('ubfe', 'a', 'b', 1), 1) => ('bitz', 'a', 'b')
 *    ('ieq', ('ubfe', 'a', 'b', 1), 1) => ('bitnz', 'a', 'b')
 *    ('ine', ('ibfe', 'a', 'b', 1), 0) => ('bitnz', 'a', 'b')
 *    ('ieq', ('ibfe', 'a', 'b', 1), 0) => ('bitz', 'a', 'b')
 *    ('ine', ('ibfe', 'a', 'b', 1), -1) => ('bitz', 'a', 'b')
 *    ('ieq', ('ibfe', 'a', 'b', 1), -1) => ('bitnz', 'a', 'b')
 *    ('inot', ('bitnz', 'a', 'b')) => ('bitz', 'a', 'b')
 *    ('inot', ('bitz', 'a', 'b')) => ('bitnz', 'a', 'b')
 *    ('bitnz', ('inot', 'a'), 'b') => ('bitz', 'a', 'b')
 *    ('bitz', ('inot', 'a'), 'b') => ('bitnz', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 *    ('f2f16', 'a') => ('f2f16_rtz', 'a')
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2413_0 -> 0 in the cache */
   /* replace2413_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search2414_0_0_0 -> 0 in the cache */
   /* search2414_0_0_1 -> 1 in the cache */
   /* search2414_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search2414_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2414_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2414_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search2415_0 -> 3 in the cache */
   /* search2415_1_0 -> 0 in the cache */
   /* search2415_1_1 -> 1 in the cache */
   /* search2415_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2415_0_0 -> 0 in the cache */
   /* replace2415_0 -> 9 in the cache */
   /* replace2415_1 -> 1 in the cache */
   /* replace2415 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search2416_0 -> 3 in the cache */
   /* search2416_1_0_0 -> 0 in the cache */
   /* search2416_1_0_1 -> 1 in the cache */
   /* search2416_1_0 -> 2 in the cache */
   /* search2416_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2416_0 -> 0 in the cache */
   /* replace2416_1_0 -> 1 in the cache */
   /* replace2416_1 -> 5 in the cache */
   /* replace2416 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search2417_0_0 -> 0 in the cache */
   /* search2417_0_1 -> 1 in the cache */
   /* search2417_0 -> 2 in the cache */
   /* search2417_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2417_0 -> 0 in the cache */
   /* replace2417_1_0 -> 1 in the cache */
   /* replace2417_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2418_0_0_0 -> 0 in the cache */
   /* search2418_0_0_1 -> 1 in the cache */
   /* search2418_0_0 -> 2 in the cache */
   /* search2418_0 -> 7 in the cache */
   /* search2418_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2418_0_0 -> 0 in the cache */
   /* replace2418_0 -> 9 in the cache */
   /* replace2418_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2419_0 -> 3 in the cache */
   /* search2419_1_0 -> 0 in the cache */
   /* search2419_1_1 -> 1 in the cache */
   /* search2419_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2419_0_0 -> 0 in the cache */
   /* replace2419_0 -> 9 in the cache */
   /* replace2419_1 -> 1 in the cache */
   /* replace2419 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2420_0 -> 3 in the cache */
   /* search2420_1_0_0 -> 0 in the cache */
   /* search2420_1_0_1 -> 1 in the cache */
   /* search2420_1_0 -> 2 in the cache */
   /* search2420_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2420_0 -> 0 in the cache */
   /* replace2420_1_0 -> 1 in the cache */
   /* replace2420_1 -> 5 in the cache */
   /* replace2420 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2421_0_0 -> 0 in the cache */
   /* search2421_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2421_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2421_0 -> 0 in the cache */
   /* replace2421_1_0 -> 1 in the cache */
   /* replace2421_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2422_0_0 -> 0 in the cache */
   /* search2422_0_1 -> 1 in the cache */
   /* search2422_0 -> 19 in the cache */
   /* search2422_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2422_0 -> 0 in the cache */
   /* replace2422_1_0 -> 1 in the cache */
   /* replace2422_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2423_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search2423_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace2423_0 -> 0 in the cache */
   /* replace2423_1_0 -> 1 in the cache */
   /* replace2423_1 -> 5 in the cache */
   /* replace2423 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2424_0_0_0 -> 24 in the cache */
   /* search2424_0_0_1 -> 1 in the cache */
   /* search2424_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search2424_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace2424_0_0 -> 0 in the cache */
   /* replace2424_0 -> 9 in the cache */
   /* replace2424_1 -> 1 in the cache */
   /* replace2424 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2425_0 -> 3 in the cache */
   /* search2425_1_0 -> 24 in the cache */
   /* search2425_1_1 -> 1 in the cache */
   /* search2425_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace2425_0_0 -> 0 in the cache */
   /* replace2425_0 -> 9 in the cache */
   /* replace2425_1 -> 1 in the cache */
   /* replace2425 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2426_0 -> 3 in the cache */
   /* search2426_1_0_0 -> 24 in the cache */
   /* search2426_1_0_1 -> 1 in the cache */
   /* search2426_1_0 -> 25 in the cache */
   /* search2426_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace2426_0 -> 0 in the cache */
   /* replace2426_1_0 -> 1 in the cache */
   /* replace2426_1 -> 5 in the cache */
   /* replace2426 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2427_0_0 -> 24 in the cache */
   /* search2427_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search2427_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2427_0 -> 0 in the cache */
   /* replace2427_1_0 -> 1 in the cache */
   /* replace2427_1 -> 5 in the cache */
   /* replace2427 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2428_0_0 -> 24 in the cache */
   /* search2428_0_1 -> 1 in the cache */
   /* search2428_0 -> 31 in the cache */
   /* search2428_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2428_0 -> 0 in the cache */
   /* replace2428_1_0 -> 1 in the cache */
   /* replace2428_1 -> 5 in the cache */
   /* replace2428 -> 23 in the cache */

   /* ('iand', ('fneu', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('!flt', ('fneg', ('fabs', 'b')), ('fneg', ('fabs', 'a')))) */
   /* search2429_0_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 34 },
      -1,
   } },
   /* search2429_0_1_0_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 35, 37 },
      -1,
   } },
   /* search2429_1_0_0 -> 0 in the cache */
   /* search2429_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2429_1_1_0 -> 1 in the cache */
   /* search2429_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 39, 40 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 38, 41 },
      -1,
   } },

   /* replace2429_0_0_0_0 -> 0 in the cache */
   /* replace2429_0_0_0 -> 34 in the cache */
   /* replace2429_0_0 -> 35 in the cache */
   /* replace2429_0_1_0_0 -> 1 in the cache */
   /* replace2429_0_1_0 -> 36 in the cache */
   /* replace2429_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 37 },
      -1,
   } },
   /* replace2429_1_0_0_0 -> 1 in the cache */
   /* replace2429_1_0_0 -> 36 in the cache */
   /* replace2429_1_0 -> 37 in the cache */
   /* replace2429_1_1_0_0 -> 0 in the cache */
   /* replace2429_1_1_0 -> 34 in the cache */
   /* replace2429_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 37, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 43, 44 },
      -1,
   } },

   /* ('iand', ('fneu', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fneg', ('fabs', 'a')))) */
   /* search2430_0_0_0_0 -> 0 in the cache */
   /* search2430_0_0_0 -> 34 in the cache */
   /* search2430_0_0 -> 35 in the cache */
   /* search2430_0_1_0 -> 1 in the cache */
   /* search2430_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 35, 36 },
      -1,
   } },
   /* search2430_1_0_0 -> 0 in the cache */
   /* search2430_1_0_1 -> 0 in the cache */
   /* search2430_1_0 -> 39 in the cache */
   /* search2430_1_1_0 -> 1 in the cache */
   /* search2430_1_1_1 -> 1 in the cache */
   /* search2430_1_1 -> 40 in the cache */
   /* search2430_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 46, 41 },
      -1,
   } },

   /* replace2430_0_0_0_0 -> 0 in the cache */
   /* replace2430_0_0_0 -> 34 in the cache */
   /* replace2430_0_0 -> 35 in the cache */
   /* replace2430_0_1_0 -> 1 in the cache */
   /* replace2430_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   /* replace2430_1_0_0 -> 1 in the cache */
   /* replace2430_1_0 -> 36 in the cache */
   /* replace2430_1_1_0_0 -> 0 in the cache */
   /* replace2430_1_1_0 -> 34 in the cache */
   /* replace2430_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 48, 49 },
      -1,
   } },

   /* ('iand', ('fneu', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', ('fabs', 'a')))) */
   /* search2431_0_0_0_0 -> 0 in the cache */
   /* search2431_0_0_0 -> 34 in the cache */
   /* search2431_0_0 -> 35 in the cache */
   /* search2431_0_1_0 -> 1 in the cache */
   /* search2431_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 35, 5 },
      -1,
   } },
   /* search2431_1_0_0 -> 0 in the cache */
   /* search2431_1_0_1 -> 0 in the cache */
   /* search2431_1_0 -> 39 in the cache */
   /* search2431_1_1_0 -> 1 in the cache */
   /* search2431_1_1_1 -> 1 in the cache */
   /* search2431_1_1 -> 40 in the cache */
   /* search2431_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 51, 41 },
      -1,
   } },

   /* replace2431_0_0_0_0 -> 0 in the cache */
   /* replace2431_0_0_0 -> 34 in the cache */
   /* replace2431_0_0 -> 35 in the cache */
   /* replace2431_0_1_0 -> 1 in the cache */
   /* replace2431_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 5 },
      -1,
   } },
   /* replace2431_1_0_0 -> 1 in the cache */
   /* replace2431_1_0 -> 5 in the cache */
   /* replace2431_1_1_0_0 -> 0 in the cache */
   /* replace2431_1_1_0 -> 34 in the cache */
   /* replace2431_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 53, 54 },
      -1,
   } },

   /* ('iand', ('fneu', ('fneg', ('fabs', 'a')), 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', ('fabs', 'a')), 'b'), ('!flt', 'b', ('fneg', ('fabs', 'a')))) */
   /* search2432_0_0_0_0 -> 0 in the cache */
   /* search2432_0_0_0 -> 34 in the cache */
   /* search2432_0_0 -> 35 in the cache */
   /* search2432_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 35, 1 },
      -1,
   } },
   /* search2432_1_0_0 -> 0 in the cache */
   /* search2432_1_0_1 -> 0 in the cache */
   /* search2432_1_0 -> 39 in the cache */
   /* search2432_1_1_0 -> 1 in the cache */
   /* search2432_1_1_1 -> 1 in the cache */
   /* search2432_1_1 -> 40 in the cache */
   /* search2432_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 56, 41 },
      -1,
   } },

   /* replace2432_0_0_0_0 -> 0 in the cache */
   /* replace2432_0_0_0 -> 34 in the cache */
   /* replace2432_0_0 -> 35 in the cache */
   /* replace2432_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 1 },
      -1,
   } },
   /* replace2432_1_0 -> 1 in the cache */
   /* replace2432_1_1_0_0 -> 0 in the cache */
   /* replace2432_1_1_0 -> 34 in the cache */
   /* replace2432_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 58, 59 },
      -1,
   } },

   /* ('iand', ('fneu', ('fabs', 'a'), ('fabs', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fabs', 'a'), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fabs', 'a'))) */
   /* search2433_0_0_0 -> 0 in the cache */
   /* search2433_0_0 -> 34 in the cache */
   /* search2433_0_1_0 -> 1 in the cache */
   /* search2433_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 34, 36 },
      -1,
   } },
   /* search2433_1_0_0 -> 0 in the cache */
   /* search2433_1_0_1 -> 0 in the cache */
   /* search2433_1_0 -> 39 in the cache */
   /* search2433_1_1_0 -> 1 in the cache */
   /* search2433_1_1_1 -> 1 in the cache */
   /* search2433_1_1 -> 40 in the cache */
   /* search2433_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 61, 41 },
      -1,
   } },

   /* replace2433_0_0_0 -> 0 in the cache */
   /* replace2433_0_0 -> 34 in the cache */
   /* replace2433_0_1_0 -> 1 in the cache */
   /* replace2433_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 36 },
      -1,
   } },
   /* replace2433_1_0_0 -> 1 in the cache */
   /* replace2433_1_0 -> 36 in the cache */
   /* replace2433_1_1_0 -> 0 in the cache */
   /* replace2433_1_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 63, 64 },
      -1,
   } },

   /* ('iand', ('fneu', ('fabs', 'a'), ('fneg', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fabs', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fabs', 'a'))) */
   /* search2434_0_0_0 -> 0 in the cache */
   /* search2434_0_0 -> 34 in the cache */
   /* search2434_0_1_0 -> 1 in the cache */
   /* search2434_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 34, 5 },
      -1,
   } },
   /* search2434_1_0_0 -> 0 in the cache */
   /* search2434_1_0_1 -> 0 in the cache */
   /* search2434_1_0 -> 39 in the cache */
   /* search2434_1_1_0 -> 1 in the cache */
   /* search2434_1_1_1 -> 1 in the cache */
   /* search2434_1_1 -> 40 in the cache */
   /* search2434_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 66, 41 },
      -1,
   } },

   /* replace2434_0_0_0 -> 0 in the cache */
   /* replace2434_0_0 -> 34 in the cache */
   /* replace2434_0_1_0 -> 1 in the cache */
   /* replace2434_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 5 },
      -1,
   } },
   /* replace2434_1_0_0 -> 1 in the cache */
   /* replace2434_1_0 -> 5 in the cache */
   /* replace2434_1_1_0 -> 0 in the cache */
   /* replace2434_1_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5, 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 68, 69 },
      -1,
   } },

   /* ('iand', ('fneu', ('fabs', 'a'), 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fabs', 'a'), 'b'), ('!flt', 'b', ('fabs', 'a'))) */
   /* search2435_0_0_0 -> 0 in the cache */
   /* search2435_0_0 -> 34 in the cache */
   /* search2435_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 34, 1 },
      -1,
   } },
   /* search2435_1_0_0 -> 0 in the cache */
   /* search2435_1_0_1 -> 0 in the cache */
   /* search2435_1_0 -> 39 in the cache */
   /* search2435_1_1_0 -> 1 in the cache */
   /* search2435_1_1_1 -> 1 in the cache */
   /* search2435_1_1 -> 40 in the cache */
   /* search2435_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 71, 41 },
      -1,
   } },

   /* replace2435_0_0_0 -> 0 in the cache */
   /* replace2435_0_0 -> 34 in the cache */
   /* replace2435_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 1 },
      -1,
   } },
   /* replace2435_1_0 -> 1 in the cache */
   /* replace2435_1_1_0 -> 0 in the cache */
   /* replace2435_1_1 -> 34 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 34 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 73, 74 },
      -1,
   } },

   /* ('iand', ('fneu', ('fneg', 'a'), ('fneg', 'b')), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', 'a'))) */
   /* search2436_0_0_0 -> 0 in the cache */
   /* search2436_0_0 -> 9 in the cache */
   /* search2436_0_1_0 -> 1 in the cache */
   /* search2436_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 9, 5 },
      -1,
   } },
   /* search2436_1_0_0 -> 0 in the cache */
   /* search2436_1_0_1 -> 0 in the cache */
   /* search2436_1_0 -> 39 in the cache */
   /* search2436_1_1_0 -> 1 in the cache */
   /* search2436_1_1_1 -> 1 in the cache */
   /* search2436_1_1 -> 40 in the cache */
   /* search2436_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 76, 41 },
      -1,
   } },

   /* replace2436_0_0_0 -> 0 in the cache */
   /* replace2436_0_0 -> 9 in the cache */
   /* replace2436_0_1_0 -> 1 in the cache */
   /* replace2436_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },
   /* replace2436_1_0_0 -> 1 in the cache */
   /* replace2436_1_0 -> 5 in the cache */
   /* replace2436_1_1_0 -> 0 in the cache */
   /* replace2436_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 78, 79 },
      -1,
   } },

   /* ('iand', ('fneu', ('fneg', 'a'), 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', ('fneg', 'a'), 'b'), ('!flt', 'b', ('fneg', 'a'))) */
   /* search2437_0_0_0 -> 0 in the cache */
   /* search2437_0_0 -> 9 in the cache */
   /* search2437_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 9, 1 },
      -1,
   } },
   /* search2437_1_0_0 -> 0 in the cache */
   /* search2437_1_0_1 -> 0 in the cache */
   /* search2437_1_0 -> 39 in the cache */
   /* search2437_1_1_0 -> 1 in the cache */
   /* search2437_1_1_1 -> 1 in the cache */
   /* search2437_1_1 -> 40 in the cache */
   /* search2437_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 81, 41 },
      -1,
   } },

   /* replace2437_0_0_0 -> 0 in the cache */
   /* replace2437_0_0 -> 9 in the cache */
   /* replace2437_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },
   /* replace2437_1_0 -> 1 in the cache */
   /* replace2437_1_1_0 -> 0 in the cache */
   /* replace2437_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 83, 84 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search2438_0_0 -> 0 in the cache */
   /* search2438_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2438_1_0_0 -> 0 in the cache */
   /* search2438_1_0_1 -> 0 in the cache */
   /* search2438_1_0 -> 39 in the cache */
   /* search2438_1_1_0 -> 1 in the cache */
   /* search2438_1_1_1 -> 1 in the cache */
   /* search2438_1_1 -> 40 in the cache */
   /* search2438_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 86, 41 },
      -1,
   } },

   /* replace2438_0_0 -> 0 in the cache */
   /* replace2438_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace2438_1_0 -> 1 in the cache */
   /* replace2438_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 88, 89 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 91, 92 },
      -1,
   } },
   /* search2439_1_0 -> 91 in the cache */
   /* search2439_1_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 91, 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 93, 94 },
      -1,
   } },

   /* replace2439_0 -> 92 in the cache */
   /* replace2439_1_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 92, 96 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('!flt', ('fneg', ('fabs', 'b')), ('fneg', ('fabs', 'a'))))) */
   /* search2440_0_0_0_0 -> 0 in the cache */
   /* search2440_0_0_0 -> 34 in the cache */
   /* search2440_0_0 -> 35 in the cache */
   /* search2440_0_1_0_0 -> 1 in the cache */
   /* search2440_0_1_0 -> 36 in the cache */
   /* search2440_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 35, 37 },
      -1,
   } },
   /* search2440_1_0_0 -> 0 in the cache */
   /* search2440_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2440_1_1_0 -> 1 in the cache */
   /* search2440_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 99, 100 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 98, 101 },
      -1,
   } },

   /* replace2440_0_0_0_0_0 -> 0 in the cache */
   /* replace2440_0_0_0_0 -> 34 in the cache */
   /* replace2440_0_0_0 -> 35 in the cache */
   /* replace2440_0_0_1_0_0 -> 1 in the cache */
   /* replace2440_0_0_1_0 -> 36 in the cache */
   /* replace2440_0_0_1 -> 37 in the cache */
   /* replace2440_0_0 -> 43 in the cache */
   /* replace2440_0_1_0_0_0 -> 1 in the cache */
   /* replace2440_0_1_0_0 -> 36 in the cache */
   /* replace2440_0_1_0 -> 37 in the cache */
   /* replace2440_0_1_1_0_0 -> 0 in the cache */
   /* replace2440_0_1_1_0 -> 34 in the cache */
   /* replace2440_0_1_1 -> 35 in the cache */
   /* replace2440_0_1 -> 44 in the cache */
   /* replace2440_0 -> 45 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 45 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fneg', ('fabs', 'a'))))) */
   /* search2441_0_0_0_0 -> 0 in the cache */
   /* search2441_0_0_0 -> 34 in the cache */
   /* search2441_0_0 -> 35 in the cache */
   /* search2441_0_1_0 -> 1 in the cache */
   /* search2441_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 35, 36 },
      -1,
   } },
   /* search2441_1_0_0 -> 0 in the cache */
   /* search2441_1_0_1 -> 0 in the cache */
   /* search2441_1_0 -> 99 in the cache */
   /* search2441_1_1_0 -> 1 in the cache */
   /* search2441_1_1_1 -> 1 in the cache */
   /* search2441_1_1 -> 100 in the cache */
   /* search2441_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 104, 101 },
      -1,
   } },

   /* replace2441_0_0_0_0_0 -> 0 in the cache */
   /* replace2441_0_0_0_0 -> 34 in the cache */
   /* replace2441_0_0_0 -> 35 in the cache */
   /* replace2441_0_0_1_0 -> 1 in the cache */
   /* replace2441_0_0_1 -> 36 in the cache */
   /* replace2441_0_0 -> 48 in the cache */
   /* replace2441_0_1_0_0 -> 1 in the cache */
   /* replace2441_0_1_0 -> 36 in the cache */
   /* replace2441_0_1_1_0_0 -> 0 in the cache */
   /* replace2441_0_1_1_0 -> 34 in the cache */
   /* replace2441_0_1_1 -> 35 in the cache */
   /* replace2441_0_1 -> 49 in the cache */
   /* replace2441_0 -> 50 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 50 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', ('fabs', 'a'))))) */
   /* search2442_0_0_0_0 -> 0 in the cache */
   /* search2442_0_0_0 -> 34 in the cache */
   /* search2442_0_0 -> 35 in the cache */
   /* search2442_0_1_0 -> 1 in the cache */
   /* search2442_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 35, 5 },
      -1,
   } },
   /* search2442_1_0_0 -> 0 in the cache */
   /* search2442_1_0_1 -> 0 in the cache */
   /* search2442_1_0 -> 99 in the cache */
   /* search2442_1_1_0 -> 1 in the cache */
   /* search2442_1_1_1 -> 1 in the cache */
   /* search2442_1_1 -> 100 in the cache */
   /* search2442_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 107, 101 },
      -1,
   } },

   /* replace2442_0_0_0_0_0 -> 0 in the cache */
   /* replace2442_0_0_0_0 -> 34 in the cache */
   /* replace2442_0_0_0 -> 35 in the cache */
   /* replace2442_0_0_1_0 -> 1 in the cache */
   /* replace2442_0_0_1 -> 5 in the cache */
   /* replace2442_0_0 -> 53 in the cache */
   /* replace2442_0_1_0_0 -> 1 in the cache */
   /* replace2442_0_1_0 -> 5 in the cache */
   /* replace2442_0_1_1_0_0 -> 0 in the cache */
   /* replace2442_0_1_1_0 -> 34 in the cache */
   /* replace2442_0_1_1 -> 35 in the cache */
   /* replace2442_0_1 -> 54 in the cache */
   /* replace2442_0 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 55 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', ('fabs', 'a')), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', ('fabs', 'a')), 'b'), ('!flt', 'b', ('fneg', ('fabs', 'a'))))) */
   /* search2443_0_0_0_0 -> 0 in the cache */
   /* search2443_0_0_0 -> 34 in the cache */
   /* search2443_0_0 -> 35 in the cache */
   /* search2443_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 35, 1 },
      -1,
   } },
   /* search2443_1_0_0 -> 0 in the cache */
   /* search2443_1_0_1 -> 0 in the cache */
   /* search2443_1_0 -> 99 in the cache */
   /* search2443_1_1_0 -> 1 in the cache */
   /* search2443_1_1_1 -> 1 in the cache */
   /* search2443_1_1 -> 100 in the cache */
   /* search2443_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 110, 101 },
      -1,
   } },

   /* replace2443_0_0_0_0_0 -> 0 in the cache */
   /* replace2443_0_0_0_0 -> 34 in the cache */
   /* replace2443_0_0_0 -> 35 in the cache */
   /* replace2443_0_0_1 -> 1 in the cache */
   /* replace2443_0_0 -> 58 in the cache */
   /* replace2443_0_1_0 -> 1 in the cache */
   /* replace2443_0_1_1_0_0 -> 0 in the cache */
   /* replace2443_0_1_1_0 -> 34 in the cache */
   /* replace2443_0_1_1 -> 35 in the cache */
   /* replace2443_0_1 -> 59 in the cache */
   /* replace2443_0 -> 60 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 60 },
      -1,
   } },

   /* ('ior', ('feq', ('fabs', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fabs', 'a'), ('fabs', 'b')), ('!flt', ('fabs', 'b'), ('fabs', 'a')))) */
   /* search2444_0_0_0 -> 0 in the cache */
   /* search2444_0_0 -> 34 in the cache */
   /* search2444_0_1_0 -> 1 in the cache */
   /* search2444_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 34, 36 },
      -1,
   } },
   /* search2444_1_0_0 -> 0 in the cache */
   /* search2444_1_0_1 -> 0 in the cache */
   /* search2444_1_0 -> 99 in the cache */
   /* search2444_1_1_0 -> 1 in the cache */
   /* search2444_1_1_1 -> 1 in the cache */
   /* search2444_1_1 -> 100 in the cache */
   /* search2444_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 113, 101 },
      -1,
   } },

   /* replace2444_0_0_0_0 -> 0 in the cache */
   /* replace2444_0_0_0 -> 34 in the cache */
   /* replace2444_0_0_1_0 -> 1 in the cache */
   /* replace2444_0_0_1 -> 36 in the cache */
   /* replace2444_0_0 -> 63 in the cache */
   /* replace2444_0_1_0_0 -> 1 in the cache */
   /* replace2444_0_1_0 -> 36 in the cache */
   /* replace2444_0_1_1_0 -> 0 in the cache */
   /* replace2444_0_1_1 -> 34 in the cache */
   /* replace2444_0_1 -> 64 in the cache */
   /* replace2444_0 -> 65 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 65 },
      -1,
   } },

   /* ('ior', ('feq', ('fabs', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fabs', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fabs', 'a')))) */
   /* search2445_0_0_0 -> 0 in the cache */
   /* search2445_0_0 -> 34 in the cache */
   /* search2445_0_1_0 -> 1 in the cache */
   /* search2445_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 34, 5 },
      -1,
   } },
   /* search2445_1_0_0 -> 0 in the cache */
   /* search2445_1_0_1 -> 0 in the cache */
   /* search2445_1_0 -> 99 in the cache */
   /* search2445_1_1_0 -> 1 in the cache */
   /* search2445_1_1_1 -> 1 in the cache */
   /* search2445_1_1 -> 100 in the cache */
   /* search2445_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 116, 101 },
      -1,
   } },

   /* replace2445_0_0_0_0 -> 0 in the cache */
   /* replace2445_0_0_0 -> 34 in the cache */
   /* replace2445_0_0_1_0 -> 1 in the cache */
   /* replace2445_0_0_1 -> 5 in the cache */
   /* replace2445_0_0 -> 68 in the cache */
   /* replace2445_0_1_0_0 -> 1 in the cache */
   /* replace2445_0_1_0 -> 5 in the cache */
   /* replace2445_0_1_1_0 -> 0 in the cache */
   /* replace2445_0_1_1 -> 34 in the cache */
   /* replace2445_0_1 -> 69 in the cache */
   /* replace2445_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 70 },
      -1,
   } },

   /* ('ior', ('feq', ('fabs', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fabs', 'a'), 'b'), ('!flt', 'b', ('fabs', 'a')))) */
   /* search2446_0_0_0 -> 0 in the cache */
   /* search2446_0_0 -> 34 in the cache */
   /* search2446_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 34, 1 },
      -1,
   } },
   /* search2446_1_0_0 -> 0 in the cache */
   /* search2446_1_0_1 -> 0 in the cache */
   /* search2446_1_0 -> 99 in the cache */
   /* search2446_1_1_0 -> 1 in the cache */
   /* search2446_1_1_1 -> 1 in the cache */
   /* search2446_1_1 -> 100 in the cache */
   /* search2446_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 119, 101 },
      -1,
   } },

   /* replace2446_0_0_0_0 -> 0 in the cache */
   /* replace2446_0_0_0 -> 34 in the cache */
   /* replace2446_0_0_1 -> 1 in the cache */
   /* replace2446_0_0 -> 73 in the cache */
   /* replace2446_0_1_0 -> 1 in the cache */
   /* replace2446_0_1_1_0 -> 0 in the cache */
   /* replace2446_0_1_1 -> 34 in the cache */
   /* replace2446_0_1 -> 74 in the cache */
   /* replace2446_0 -> 75 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 75 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', 'a'), ('fneg', 'b')), ('!flt', ('fneg', 'b'), ('fneg', 'a')))) */
   /* search2447_0_0_0 -> 0 in the cache */
   /* search2447_0_0 -> 9 in the cache */
   /* search2447_0_1_0 -> 1 in the cache */
   /* search2447_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 9, 5 },
      -1,
   } },
   /* search2447_1_0_0 -> 0 in the cache */
   /* search2447_1_0_1 -> 0 in the cache */
   /* search2447_1_0 -> 99 in the cache */
   /* search2447_1_1_0 -> 1 in the cache */
   /* search2447_1_1_1 -> 1 in the cache */
   /* search2447_1_1 -> 100 in the cache */
   /* search2447_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 122, 101 },
      -1,
   } },

   /* replace2447_0_0_0_0 -> 0 in the cache */
   /* replace2447_0_0_0 -> 9 in the cache */
   /* replace2447_0_0_1_0 -> 1 in the cache */
   /* replace2447_0_0_1 -> 5 in the cache */
   /* replace2447_0_0 -> 78 in the cache */
   /* replace2447_0_1_0_0 -> 1 in the cache */
   /* replace2447_0_1_0 -> 5 in the cache */
   /* replace2447_0_1_1_0 -> 0 in the cache */
   /* replace2447_0_1_1 -> 9 in the cache */
   /* replace2447_0_1 -> 79 in the cache */
   /* replace2447_0 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 80 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', ('fneg', 'a'), 'b'), ('!flt', 'b', ('fneg', 'a')))) */
   /* search2448_0_0_0 -> 0 in the cache */
   /* search2448_0_0 -> 9 in the cache */
   /* search2448_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 9, 1 },
      -1,
   } },
   /* search2448_1_0_0 -> 0 in the cache */
   /* search2448_1_0_1 -> 0 in the cache */
   /* search2448_1_0 -> 99 in the cache */
   /* search2448_1_1_0 -> 1 in the cache */
   /* search2448_1_1_1 -> 1 in the cache */
   /* search2448_1_1 -> 100 in the cache */
   /* search2448_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 125, 101 },
      -1,
   } },

   /* replace2448_0_0_0_0 -> 0 in the cache */
   /* replace2448_0_0_0 -> 9 in the cache */
   /* replace2448_0_0_1 -> 1 in the cache */
   /* replace2448_0_0 -> 83 in the cache */
   /* replace2448_0_1_0 -> 1 in the cache */
   /* replace2448_0_1_1_0 -> 0 in the cache */
   /* replace2448_0_1_1 -> 9 in the cache */
   /* replace2448_0_1 -> 84 in the cache */
   /* replace2448_0 -> 85 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 85 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search2449_0_0 -> 0 in the cache */
   /* search2449_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2449_1_0_0 -> 0 in the cache */
   /* search2449_1_0_1 -> 0 in the cache */
   /* search2449_1_0 -> 99 in the cache */
   /* search2449_1_1_0 -> 1 in the cache */
   /* search2449_1_1_1 -> 1 in the cache */
   /* search2449_1_1 -> 100 in the cache */
   /* search2449_1 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 128, 101 },
      -1,
   } },

   /* replace2449_0_0_0 -> 0 in the cache */
   /* replace2449_0_0_1 -> 1 in the cache */
   /* replace2449_0_0 -> 88 in the cache */
   /* replace2449_0_1_0 -> 1 in the cache */
   /* replace2449_0_1_1 -> 0 in the cache */
   /* replace2449_0_1 -> 89 in the cache */
   /* replace2449_0 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 90 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search2450_0_0 -> 91 in the cache */
   /* search2450_0_1 -> 92 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 91, 92 },
      -1,
   } },
   /* search2450_1_0 -> 91 in the cache */
   /* search2450_1_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 91, 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 131, 132 },
      -1,
   } },

   /* replace2450_0_0 -> 92 in the cache */
   /* replace2450_0_1_0 -> 91 in the cache */
   /* replace2450_0_1 -> 96 in the cache */
   /* replace2450_0 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 97 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b')))) */
   /* search2451_0_0_0_0 -> 0 in the cache */
   /* search2451_0_0_0 -> 34 in the cache */
   /* search2451_0_0 -> 35 in the cache */
   /* search2451_0_1_0_0 -> 1 in the cache */
   /* search2451_0_1_0 -> 36 in the cache */
   /* search2451_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 37 },
      -1,
   } },
   /* search2451_1_0_0 -> 0 in the cache */
   /* search2451_1_0_1 -> 0 in the cache */
   /* search2451_1_0 -> 99 in the cache */
   /* search2451_1_1_0 -> 1 in the cache */
   /* search2451_1_1_1 -> 1 in the cache */
   /* search2451_1_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 99, 100 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 135, 136 },
      -1,
   } },

   /* replace2451_0_0_0_0 -> 0 in the cache */
   /* replace2451_0_0_0 -> 34 in the cache */
   /* replace2451_0_0 -> 35 in the cache */
   /* replace2451_0_1_0_0 -> 1 in the cache */
   /* replace2451_0_1_0 -> 36 in the cache */
   /* replace2451_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 35, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 138 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), ('fabs', 'b'))) */
   /* search2452_0_0_0_0 -> 0 in the cache */
   /* search2452_0_0_0 -> 34 in the cache */
   /* search2452_0_0 -> 35 in the cache */
   /* search2452_0_1_0 -> 1 in the cache */
   /* search2452_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   /* search2452_1_0_0 -> 0 in the cache */
   /* search2452_1_0_1 -> 0 in the cache */
   /* search2452_1_0 -> 99 in the cache */
   /* search2452_1_1_0 -> 1 in the cache */
   /* search2452_1_1_1 -> 1 in the cache */
   /* search2452_1_1 -> 100 in the cache */
   /* search2452_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 140, 136 },
      -1,
   } },

   /* replace2452_0_0_0_0 -> 0 in the cache */
   /* replace2452_0_0_0 -> 34 in the cache */
   /* replace2452_0_0 -> 35 in the cache */
   /* replace2452_0_1_0 -> 1 in the cache */
   /* replace2452_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 142 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), ('fneg', 'b'))) */
   /* search2453_0_0_0_0 -> 0 in the cache */
   /* search2453_0_0_0 -> 34 in the cache */
   /* search2453_0_0 -> 35 in the cache */
   /* search2453_0_1_0 -> 1 in the cache */
   /* search2453_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 5 },
      -1,
   } },
   /* search2453_1_0_0 -> 0 in the cache */
   /* search2453_1_0_1 -> 0 in the cache */
   /* search2453_1_0 -> 99 in the cache */
   /* search2453_1_1_0 -> 1 in the cache */
   /* search2453_1_1_1 -> 1 in the cache */
   /* search2453_1_1 -> 100 in the cache */
   /* search2453_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 144, 136 },
      -1,
   } },

   /* replace2453_0_0_0_0 -> 0 in the cache */
   /* replace2453_0_0_0 -> 34 in the cache */
   /* replace2453_0_0 -> 35 in the cache */
   /* replace2453_0_1_0 -> 1 in the cache */
   /* replace2453_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 35, 5 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 146 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', ('fabs', 'a')), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', ('fabs', 'a')), 'b')) */
   /* search2454_0_0_0_0 -> 0 in the cache */
   /* search2454_0_0_0 -> 34 in the cache */
   /* search2454_0_0 -> 35 in the cache */
   /* search2454_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 1 },
      -1,
   } },
   /* search2454_1_0_0 -> 0 in the cache */
   /* search2454_1_0_1 -> 0 in the cache */
   /* search2454_1_0 -> 99 in the cache */
   /* search2454_1_1_0 -> 1 in the cache */
   /* search2454_1_1_1 -> 1 in the cache */
   /* search2454_1_1 -> 100 in the cache */
   /* search2454_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 148, 136 },
      -1,
   } },

   /* replace2454_0_0_0_0 -> 0 in the cache */
   /* replace2454_0_0_0 -> 34 in the cache */
   /* replace2454_0_0 -> 35 in the cache */
   /* replace2454_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 35, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 150 },
      -1,
   } },

   /* ('ior', ('flt', ('fabs', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), ('fneg', ('fabs', 'b')))) */
   /* search2455_0_0_0 -> 0 in the cache */
   /* search2455_0_0 -> 34 in the cache */
   /* search2455_0_1_0_0 -> 1 in the cache */
   /* search2455_0_1_0 -> 36 in the cache */
   /* search2455_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 37 },
      -1,
   } },
   /* search2455_1_0_0 -> 0 in the cache */
   /* search2455_1_0_1 -> 0 in the cache */
   /* search2455_1_0 -> 99 in the cache */
   /* search2455_1_1_0 -> 1 in the cache */
   /* search2455_1_1_1 -> 1 in the cache */
   /* search2455_1_1 -> 100 in the cache */
   /* search2455_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 152, 136 },
      -1,
   } },

   /* replace2455_0_0_0 -> 0 in the cache */
   /* replace2455_0_0 -> 34 in the cache */
   /* replace2455_0_1_0_0 -> 1 in the cache */
   /* replace2455_0_1_0 -> 36 in the cache */
   /* replace2455_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 34, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 154 },
      -1,
   } },

   /* ('ior', ('flt', ('fabs', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search2456_0_0_0 -> 0 in the cache */
   /* search2456_0_0 -> 34 in the cache */
   /* search2456_0_1_0 -> 1 in the cache */
   /* search2456_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 36 },
      -1,
   } },
   /* search2456_1_0_0 -> 0 in the cache */
   /* search2456_1_0_1 -> 0 in the cache */
   /* search2456_1_0 -> 99 in the cache */
   /* search2456_1_1_0 -> 1 in the cache */
   /* search2456_1_1_1 -> 1 in the cache */
   /* search2456_1_1 -> 100 in the cache */
   /* search2456_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 156, 136 },
      -1,
   } },

   /* replace2456_0_0_0 -> 0 in the cache */
   /* replace2456_0_0 -> 34 in the cache */
   /* replace2456_0_1_0 -> 1 in the cache */
   /* replace2456_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 34, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 158 },
      -1,
   } },

   /* ('ior', ('flt', ('fabs', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), ('fneg', 'b'))) */
   /* search2457_0_0_0 -> 0 in the cache */
   /* search2457_0_0 -> 34 in the cache */
   /* search2457_0_1_0 -> 1 in the cache */
   /* search2457_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 5 },
      -1,
   } },
   /* search2457_1_0_0 -> 0 in the cache */
   /* search2457_1_0_1 -> 0 in the cache */
   /* search2457_1_0 -> 99 in the cache */
   /* search2457_1_1_0 -> 1 in the cache */
   /* search2457_1_1_1 -> 1 in the cache */
   /* search2457_1_1 -> 100 in the cache */
   /* search2457_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 160, 136 },
      -1,
   } },

   /* replace2457_0_0_0 -> 0 in the cache */
   /* replace2457_0_0 -> 34 in the cache */
   /* replace2457_0_1_0 -> 1 in the cache */
   /* replace2457_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 34, 5 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 162 },
      -1,
   } },

   /* ('ior', ('flt', ('fabs', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fabs', 'a'), 'b')) */
   /* search2458_0_0_0 -> 0 in the cache */
   /* search2458_0_0 -> 34 in the cache */
   /* search2458_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 1 },
      -1,
   } },
   /* search2458_1_0_0 -> 0 in the cache */
   /* search2458_1_0_1 -> 0 in the cache */
   /* search2458_1_0 -> 99 in the cache */
   /* search2458_1_1_0 -> 1 in the cache */
   /* search2458_1_1_1 -> 1 in the cache */
   /* search2458_1_1 -> 100 in the cache */
   /* search2458_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 164, 136 },
      -1,
   } },

   /* replace2458_0_0_0 -> 0 in the cache */
   /* replace2458_0_0 -> 34 in the cache */
   /* replace2458_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 34, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 166 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), ('fneg', ('fabs', 'b')))) */
   /* search2459_0_0_0 -> 0 in the cache */
   /* search2459_0_0 -> 9 in the cache */
   /* search2459_0_1_0_0 -> 1 in the cache */
   /* search2459_0_1_0 -> 36 in the cache */
   /* search2459_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 37 },
      -1,
   } },
   /* search2459_1_0_0 -> 0 in the cache */
   /* search2459_1_0_1 -> 0 in the cache */
   /* search2459_1_0 -> 99 in the cache */
   /* search2459_1_1_0 -> 1 in the cache */
   /* search2459_1_1_1 -> 1 in the cache */
   /* search2459_1_1 -> 100 in the cache */
   /* search2459_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 168, 136 },
      -1,
   } },

   /* replace2459_0_0_0 -> 0 in the cache */
   /* replace2459_0_0 -> 9 in the cache */
   /* replace2459_0_1_0_0 -> 1 in the cache */
   /* replace2459_0_1_0 -> 36 in the cache */
   /* replace2459_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 170 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), ('fabs', 'b'))) */
   /* search2460_0_0_0 -> 0 in the cache */
   /* search2460_0_0 -> 9 in the cache */
   /* search2460_0_1_0 -> 1 in the cache */
   /* search2460_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 36 },
      -1,
   } },
   /* search2460_1_0_0 -> 0 in the cache */
   /* search2460_1_0_1 -> 0 in the cache */
   /* search2460_1_0 -> 99 in the cache */
   /* search2460_1_1_0 -> 1 in the cache */
   /* search2460_1_1_1 -> 1 in the cache */
   /* search2460_1_1 -> 100 in the cache */
   /* search2460_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 172, 136 },
      -1,
   } },

   /* replace2460_0_0_0 -> 0 in the cache */
   /* replace2460_0_0 -> 9 in the cache */
   /* replace2460_0_1_0 -> 1 in the cache */
   /* replace2460_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 174 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search2461_0_0_0 -> 0 in the cache */
   /* search2461_0_0 -> 9 in the cache */
   /* search2461_0_1_0 -> 1 in the cache */
   /* search2461_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },
   /* search2461_1_0_0 -> 0 in the cache */
   /* search2461_1_0_1 -> 0 in the cache */
   /* search2461_1_0 -> 99 in the cache */
   /* search2461_1_1_0 -> 1 in the cache */
   /* search2461_1_1_1 -> 1 in the cache */
   /* search2461_1_1 -> 100 in the cache */
   /* search2461_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 176, 136 },
      -1,
   } },

   /* replace2461_0_0_0 -> 0 in the cache */
   /* replace2461_0_0 -> 9 in the cache */
   /* replace2461_0_1_0 -> 1 in the cache */
   /* replace2461_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 178 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', ('fneg', 'a'), 'b')) */
   /* search2462_0_0_0 -> 0 in the cache */
   /* search2462_0_0 -> 9 in the cache */
   /* search2462_0_1 -> 1 in the cache */
   /* search2462_0 -> 10 in the cache */
   /* search2462_1_0_0 -> 0 in the cache */
   /* search2462_1_0_1 -> 0 in the cache */
   /* search2462_1_0 -> 99 in the cache */
   /* search2462_1_1_0 -> 1 in the cache */
   /* search2462_1_1_1 -> 1 in the cache */
   /* search2462_1_1 -> 100 in the cache */
   /* search2462_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 10, 136 },
      -1,
   } },

   /* replace2462_0_0_0 -> 0 in the cache */
   /* replace2462_0_0 -> 9 in the cache */
   /* replace2462_0_1 -> 1 in the cache */
   /* replace2462_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt', 'a', ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', ('fneg', ('fabs', 'b')))) */
   /* search2463_0_0 -> 0 in the cache */
   /* search2463_0_1_0_0 -> 1 in the cache */
   /* search2463_0_1_0 -> 36 in the cache */
   /* search2463_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 37 },
      -1,
   } },
   /* search2463_1_0_0 -> 0 in the cache */
   /* search2463_1_0_1 -> 0 in the cache */
   /* search2463_1_0 -> 99 in the cache */
   /* search2463_1_1_0 -> 1 in the cache */
   /* search2463_1_1_1 -> 1 in the cache */
   /* search2463_1_1 -> 100 in the cache */
   /* search2463_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 182, 136 },
      -1,
   } },

   /* replace2463_0_0 -> 0 in the cache */
   /* replace2463_0_1_0_0 -> 1 in the cache */
   /* replace2463_0_1_0 -> 36 in the cache */
   /* replace2463_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 37 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 184 },
      -1,
   } },

   /* ('ior', ('flt', 'a', ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', ('fabs', 'b'))) */
   /* search2464_0_0 -> 0 in the cache */
   /* search2464_0_1_0 -> 1 in the cache */
   /* search2464_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 36 },
      -1,
   } },
   /* search2464_1_0_0 -> 0 in the cache */
   /* search2464_1_0_1 -> 0 in the cache */
   /* search2464_1_0 -> 99 in the cache */
   /* search2464_1_1_0 -> 1 in the cache */
   /* search2464_1_1_1 -> 1 in the cache */
   /* search2464_1_1 -> 100 in the cache */
   /* search2464_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 186, 136 },
      -1,
   } },

   /* replace2464_0_0 -> 0 in the cache */
   /* replace2464_0_1_0 -> 1 in the cache */
   /* replace2464_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 188 },
      -1,
   } },

   /* ('ior', ('flt', 'a', ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', ('fneg', 'b'))) */
   /* search2465_0_0 -> 0 in the cache */
   /* search2465_0_1_0 -> 1 in the cache */
   /* search2465_0_1 -> 5 in the cache */
   /* search2465_0 -> 6 in the cache */
   /* search2465_1_0_0 -> 0 in the cache */
   /* search2465_1_0_1 -> 0 in the cache */
   /* search2465_1_0 -> 99 in the cache */
   /* search2465_1_1_0 -> 1 in the cache */
   /* search2465_1_1_1 -> 1 in the cache */
   /* search2465_1_1 -> 100 in the cache */
   /* search2465_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 6, 136 },
      -1,
   } },

   /* replace2465_0_0 -> 0 in the cache */
   /* replace2465_0_1_0 -> 1 in the cache */
   /* replace2465_0_1 -> 5 in the cache */
   /* replace2465_0 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 14 },
      -1,
   } },

   /* ('ior', ('flt', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('fge', 'a', 'b')) */
   /* search2466_0_0 -> 0 in the cache */
   /* search2466_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2466_1_0_0 -> 0 in the cache */
   /* search2466_1_0_1 -> 0 in the cache */
   /* search2466_1_0 -> 99 in the cache */
   /* search2466_1_1_0 -> 1 in the cache */
   /* search2466_1_1_1 -> 1 in the cache */
   /* search2466_1_1 -> 100 in the cache */
   /* search2466_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 192, 136 },
      -1,
   } },

   /* replace2466_0_0 -> 0 in the cache */
   /* replace2466_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 194 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), ('fneg', ('fabs', 'b')))) */
   /* search2467_0_0_0_0 -> 0 in the cache */
   /* search2467_0_0_0 -> 34 in the cache */
   /* search2467_0_0 -> 35 in the cache */
   /* search2467_0_1_0_0 -> 1 in the cache */
   /* search2467_0_1_0 -> 36 in the cache */
   /* search2467_0_1 -> 37 in the cache */
   /* search2467_0 -> 138 in the cache */
   /* search2467_1_0_0 -> 0 in the cache */
   /* search2467_1_0_1 -> 0 in the cache */
   /* search2467_1_0 -> 99 in the cache */
   /* search2467_1_1_0 -> 1 in the cache */
   /* search2467_1_1_1 -> 1 in the cache */
   /* search2467_1_1 -> 100 in the cache */
   /* search2467_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 138, 136 },
      -1,
   } },

   /* replace2467_0_0_0_0 -> 0 in the cache */
   /* replace2467_0_0_0 -> 34 in the cache */
   /* replace2467_0_0 -> 35 in the cache */
   /* replace2467_0_1_0_0 -> 1 in the cache */
   /* replace2467_0_1_0 -> 36 in the cache */
   /* replace2467_0_1 -> 37 in the cache */
   /* replace2467_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 135 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', ('fabs', 'a')), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), ('fabs', 'b'))) */
   /* search2468_0_0_0_0 -> 0 in the cache */
   /* search2468_0_0_0 -> 34 in the cache */
   /* search2468_0_0 -> 35 in the cache */
   /* search2468_0_1_0 -> 1 in the cache */
   /* search2468_0_1 -> 36 in the cache */
   /* search2468_0 -> 142 in the cache */
   /* search2468_1_0_0 -> 0 in the cache */
   /* search2468_1_0_1 -> 0 in the cache */
   /* search2468_1_0 -> 99 in the cache */
   /* search2468_1_1_0 -> 1 in the cache */
   /* search2468_1_1_1 -> 1 in the cache */
   /* search2468_1_1 -> 100 in the cache */
   /* search2468_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 142, 136 },
      -1,
   } },

   /* replace2468_0_0_0_0 -> 0 in the cache */
   /* replace2468_0_0_0 -> 34 in the cache */
   /* replace2468_0_0 -> 35 in the cache */
   /* replace2468_0_1_0 -> 1 in the cache */
   /* replace2468_0_1 -> 36 in the cache */
   /* replace2468_0 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 140 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', ('fabs', 'a')), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), ('fneg', 'b'))) */
   /* search2469_0_0_0_0 -> 0 in the cache */
   /* search2469_0_0_0 -> 34 in the cache */
   /* search2469_0_0 -> 35 in the cache */
   /* search2469_0_1_0 -> 1 in the cache */
   /* search2469_0_1 -> 5 in the cache */
   /* search2469_0 -> 146 in the cache */
   /* search2469_1_0_0 -> 0 in the cache */
   /* search2469_1_0_1 -> 0 in the cache */
   /* search2469_1_0 -> 99 in the cache */
   /* search2469_1_1_0 -> 1 in the cache */
   /* search2469_1_1_1 -> 1 in the cache */
   /* search2469_1_1 -> 100 in the cache */
   /* search2469_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 146, 136 },
      -1,
   } },

   /* replace2469_0_0_0_0 -> 0 in the cache */
   /* replace2469_0_0_0 -> 34 in the cache */
   /* replace2469_0_0 -> 35 in the cache */
   /* replace2469_0_1_0 -> 1 in the cache */
   /* replace2469_0_1 -> 5 in the cache */
   /* replace2469_0 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 144 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', ('fabs', 'a')), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', ('fabs', 'a')), 'b')) */
   /* search2470_0_0_0_0 -> 0 in the cache */
   /* search2470_0_0_0 -> 34 in the cache */
   /* search2470_0_0 -> 35 in the cache */
   /* search2470_0_1 -> 1 in the cache */
   /* search2470_0 -> 150 in the cache */
   /* search2470_1_0_0 -> 0 in the cache */
   /* search2470_1_0_1 -> 0 in the cache */
   /* search2470_1_0 -> 99 in the cache */
   /* search2470_1_1_0 -> 1 in the cache */
   /* search2470_1_1_1 -> 1 in the cache */
   /* search2470_1_1 -> 100 in the cache */
   /* search2470_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 150, 136 },
      -1,
   } },

   /* replace2470_0_0_0_0 -> 0 in the cache */
   /* replace2470_0_0_0 -> 34 in the cache */
   /* replace2470_0_0 -> 35 in the cache */
   /* replace2470_0_1 -> 1 in the cache */
   /* replace2470_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 148 },
      -1,
   } },

   /* ('ior', ('fge', ('fabs', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), ('fneg', ('fabs', 'b')))) */
   /* search2471_0_0_0 -> 0 in the cache */
   /* search2471_0_0 -> 34 in the cache */
   /* search2471_0_1_0_0 -> 1 in the cache */
   /* search2471_0_1_0 -> 36 in the cache */
   /* search2471_0_1 -> 37 in the cache */
   /* search2471_0 -> 154 in the cache */
   /* search2471_1_0_0 -> 0 in the cache */
   /* search2471_1_0_1 -> 0 in the cache */
   /* search2471_1_0 -> 99 in the cache */
   /* search2471_1_1_0 -> 1 in the cache */
   /* search2471_1_1_1 -> 1 in the cache */
   /* search2471_1_1 -> 100 in the cache */
   /* search2471_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 154, 136 },
      -1,
   } },

   /* replace2471_0_0_0 -> 0 in the cache */
   /* replace2471_0_0 -> 34 in the cache */
   /* replace2471_0_1_0_0 -> 1 in the cache */
   /* replace2471_0_1_0 -> 36 in the cache */
   /* replace2471_0_1 -> 37 in the cache */
   /* replace2471_0 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 152 },
      -1,
   } },

   /* ('ior', ('fge', ('fabs', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search2472_0_0_0 -> 0 in the cache */
   /* search2472_0_0 -> 34 in the cache */
   /* search2472_0_1_0 -> 1 in the cache */
   /* search2472_0_1 -> 36 in the cache */
   /* search2472_0 -> 158 in the cache */
   /* search2472_1_0_0 -> 0 in the cache */
   /* search2472_1_0_1 -> 0 in the cache */
   /* search2472_1_0 -> 99 in the cache */
   /* search2472_1_1_0 -> 1 in the cache */
   /* search2472_1_1_1 -> 1 in the cache */
   /* search2472_1_1 -> 100 in the cache */
   /* search2472_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 158, 136 },
      -1,
   } },

   /* replace2472_0_0_0 -> 0 in the cache */
   /* replace2472_0_0 -> 34 in the cache */
   /* replace2472_0_1_0 -> 1 in the cache */
   /* replace2472_0_1 -> 36 in the cache */
   /* replace2472_0 -> 156 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 156 },
      -1,
   } },

   /* ('ior', ('fge', ('fabs', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), ('fneg', 'b'))) */
   /* search2473_0_0_0 -> 0 in the cache */
   /* search2473_0_0 -> 34 in the cache */
   /* search2473_0_1_0 -> 1 in the cache */
   /* search2473_0_1 -> 5 in the cache */
   /* search2473_0 -> 162 in the cache */
   /* search2473_1_0_0 -> 0 in the cache */
   /* search2473_1_0_1 -> 0 in the cache */
   /* search2473_1_0 -> 99 in the cache */
   /* search2473_1_1_0 -> 1 in the cache */
   /* search2473_1_1_1 -> 1 in the cache */
   /* search2473_1_1 -> 100 in the cache */
   /* search2473_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 162, 136 },
      -1,
   } },

   /* replace2473_0_0_0 -> 0 in the cache */
   /* replace2473_0_0 -> 34 in the cache */
   /* replace2473_0_1_0 -> 1 in the cache */
   /* replace2473_0_1 -> 5 in the cache */
   /* replace2473_0 -> 160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 160 },
      -1,
   } },

   /* ('ior', ('fge', ('fabs', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fabs', 'a'), 'b')) */
   /* search2474_0_0_0 -> 0 in the cache */
   /* search2474_0_0 -> 34 in the cache */
   /* search2474_0_1 -> 1 in the cache */
   /* search2474_0 -> 166 in the cache */
   /* search2474_1_0_0 -> 0 in the cache */
   /* search2474_1_0_1 -> 0 in the cache */
   /* search2474_1_0 -> 99 in the cache */
   /* search2474_1_1_0 -> 1 in the cache */
   /* search2474_1_1_1 -> 1 in the cache */
   /* search2474_1_1 -> 100 in the cache */
   /* search2474_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 166, 136 },
      -1,
   } },

   /* replace2474_0_0_0 -> 0 in the cache */
   /* replace2474_0_0 -> 34 in the cache */
   /* replace2474_0_1 -> 1 in the cache */
   /* replace2474_0 -> 164 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 164 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', 'a'), ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), ('fneg', ('fabs', 'b')))) */
   /* search2475_0_0_0 -> 0 in the cache */
   /* search2475_0_0 -> 9 in the cache */
   /* search2475_0_1_0_0 -> 1 in the cache */
   /* search2475_0_1_0 -> 36 in the cache */
   /* search2475_0_1 -> 37 in the cache */
   /* search2475_0 -> 170 in the cache */
   /* search2475_1_0_0 -> 0 in the cache */
   /* search2475_1_0_1 -> 0 in the cache */
   /* search2475_1_0 -> 99 in the cache */
   /* search2475_1_1_0 -> 1 in the cache */
   /* search2475_1_1_1 -> 1 in the cache */
   /* search2475_1_1 -> 100 in the cache */
   /* search2475_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 170, 136 },
      -1,
   } },

   /* replace2475_0_0_0 -> 0 in the cache */
   /* replace2475_0_0 -> 9 in the cache */
   /* replace2475_0_1_0_0 -> 1 in the cache */
   /* replace2475_0_1_0 -> 36 in the cache */
   /* replace2475_0_1 -> 37 in the cache */
   /* replace2475_0 -> 168 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 168 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', 'a'), ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), ('fabs', 'b'))) */
   /* search2476_0_0_0 -> 0 in the cache */
   /* search2476_0_0 -> 9 in the cache */
   /* search2476_0_1_0 -> 1 in the cache */
   /* search2476_0_1 -> 36 in the cache */
   /* search2476_0 -> 174 in the cache */
   /* search2476_1_0_0 -> 0 in the cache */
   /* search2476_1_0_1 -> 0 in the cache */
   /* search2476_1_0 -> 99 in the cache */
   /* search2476_1_1_0 -> 1 in the cache */
   /* search2476_1_1_1 -> 1 in the cache */
   /* search2476_1_1 -> 100 in the cache */
   /* search2476_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 174, 136 },
      -1,
   } },

   /* replace2476_0_0_0 -> 0 in the cache */
   /* replace2476_0_0 -> 9 in the cache */
   /* replace2476_0_1_0 -> 1 in the cache */
   /* replace2476_0_1 -> 36 in the cache */
   /* replace2476_0 -> 172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 172 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', 'a'), ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search2477_0_0_0 -> 0 in the cache */
   /* search2477_0_0 -> 9 in the cache */
   /* search2477_0_1_0 -> 1 in the cache */
   /* search2477_0_1 -> 5 in the cache */
   /* search2477_0 -> 178 in the cache */
   /* search2477_1_0_0 -> 0 in the cache */
   /* search2477_1_0_1 -> 0 in the cache */
   /* search2477_1_0 -> 99 in the cache */
   /* search2477_1_1_0 -> 1 in the cache */
   /* search2477_1_1_1 -> 1 in the cache */
   /* search2477_1_1 -> 100 in the cache */
   /* search2477_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 178, 136 },
      -1,
   } },

   /* replace2477_0_0_0 -> 0 in the cache */
   /* replace2477_0_0 -> 9 in the cache */
   /* replace2477_0_1_0 -> 1 in the cache */
   /* replace2477_0_1 -> 5 in the cache */
   /* replace2477_0 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 176 },
      -1,
   } },

   /* ('ior', ('fge', ('fneg', 'a'), 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', ('fneg', 'a'), 'b')) */
   /* search2478_0_0_0 -> 0 in the cache */
   /* search2478_0_0 -> 9 in the cache */
   /* search2478_0_1 -> 1 in the cache */
   /* search2478_0 -> 16 in the cache */
   /* search2478_1_0_0 -> 0 in the cache */
   /* search2478_1_0_1 -> 0 in the cache */
   /* search2478_1_0 -> 99 in the cache */
   /* search2478_1_1_0 -> 1 in the cache */
   /* search2478_1_1_1 -> 1 in the cache */
   /* search2478_1_1 -> 100 in the cache */
   /* search2478_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 16, 136 },
      -1,
   } },

   /* replace2478_0_0_0 -> 0 in the cache */
   /* replace2478_0_0 -> 9 in the cache */
   /* replace2478_0_1 -> 1 in the cache */
   /* replace2478_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 10 },
      -1,
   } },

   /* ('ior', ('fge', 'a', ('fneg', ('fabs', 'b'))), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', ('fneg', ('fabs', 'b')))) */
   /* search2479_0_0 -> 0 in the cache */
   /* search2479_0_1_0_0 -> 1 in the cache */
   /* search2479_0_1_0 -> 36 in the cache */
   /* search2479_0_1 -> 37 in the cache */
   /* search2479_0 -> 184 in the cache */
   /* search2479_1_0_0 -> 0 in the cache */
   /* search2479_1_0_1 -> 0 in the cache */
   /* search2479_1_0 -> 99 in the cache */
   /* search2479_1_1_0 -> 1 in the cache */
   /* search2479_1_1_1 -> 1 in the cache */
   /* search2479_1_1 -> 100 in the cache */
   /* search2479_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 184, 136 },
      -1,
   } },

   /* replace2479_0_0 -> 0 in the cache */
   /* replace2479_0_1_0_0 -> 1 in the cache */
   /* replace2479_0_1_0 -> 36 in the cache */
   /* replace2479_0_1 -> 37 in the cache */
   /* replace2479_0 -> 182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 182 },
      -1,
   } },

   /* ('ior', ('fge', 'a', ('fabs', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', ('fabs', 'b'))) */
   /* search2480_0_0 -> 0 in the cache */
   /* search2480_0_1_0 -> 1 in the cache */
   /* search2480_0_1 -> 36 in the cache */
   /* search2480_0 -> 188 in the cache */
   /* search2480_1_0_0 -> 0 in the cache */
   /* search2480_1_0_1 -> 0 in the cache */
   /* search2480_1_0 -> 99 in the cache */
   /* search2480_1_1_0 -> 1 in the cache */
   /* search2480_1_1_1 -> 1 in the cache */
   /* search2480_1_1 -> 100 in the cache */
   /* search2480_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 188, 136 },
      -1,
   } },

   /* replace2480_0_0 -> 0 in the cache */
   /* replace2480_0_1_0 -> 1 in the cache */
   /* replace2480_0_1 -> 36 in the cache */
   /* replace2480_0 -> 186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 186 },
      -1,
   } },

   /* ('ior', ('fge', 'a', ('fneg', 'b')), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', ('fneg', 'b'))) */
   /* search2481_0_0 -> 0 in the cache */
   /* search2481_0_1_0 -> 1 in the cache */
   /* search2481_0_1 -> 5 in the cache */
   /* search2481_0 -> 14 in the cache */
   /* search2481_1_0_0 -> 0 in the cache */
   /* search2481_1_0_1 -> 0 in the cache */
   /* search2481_1_0 -> 99 in the cache */
   /* search2481_1_1_0 -> 1 in the cache */
   /* search2481_1_1_1 -> 1 in the cache */
   /* search2481_1_1 -> 100 in the cache */
   /* search2481_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 14, 136 },
      -1,
   } },

   /* replace2481_0_0 -> 0 in the cache */
   /* replace2481_0_1_0 -> 1 in the cache */
   /* replace2481_0_1 -> 5 in the cache */
   /* replace2481_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('ior', ('fge', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('flt', 'a', 'b')) */
   /* search2482_0_0 -> 0 in the cache */
   /* search2482_0_1 -> 1 in the cache */
   /* search2482_0 -> 194 in the cache */
   /* search2482_1_0_0 -> 0 in the cache */
   /* search2482_1_0_1 -> 0 in the cache */
   /* search2482_1_0 -> 99 in the cache */
   /* search2482_1_1_0 -> 1 in the cache */
   /* search2482_1_1_1 -> 1 in the cache */
   /* search2482_1_1 -> 100 in the cache */
   /* search2482_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 194, 136 },
      -1,
   } },

   /* replace2482_0_0 -> 0 in the cache */
   /* replace2482_0_1 -> 1 in the cache */
   /* replace2482_0 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 192 },
      -1,
   } },

   /* ('ior', ('flt', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', ('fneg', ('fabs', 'a')), 'b')) */
   /* search2483_0_0_0_0 -> 0 in the cache */
   /* search2483_0_0_0 -> 34 in the cache */
   /* search2483_0_0 -> 35 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 35, 228 },
      -1,
   } },
   /* search2483_1_0 -> 0 in the cache */
   /* search2483_1_1 -> 0 in the cache */
   /* search2483_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 229, 99 },
      -1,
   } },

   /* replace2483_0_0_0_0 -> 0 in the cache */
   /* replace2483_0_0_0 -> 34 in the cache */
   /* replace2483_0_0 -> 35 in the cache */
   /* replace2483_0_1 -> 1 in the cache */
   /* replace2483_0 -> 150 in the cache */
   /* replace2483 -> 151 in the cache */

   /* ('ior', ('flt', ('fabs', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', ('fabs', 'a'), 'b')) */
   /* search2484_0_0_0 -> 0 in the cache */
   /* search2484_0_0 -> 34 in the cache */
   /* search2484_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 34, 228 },
      -1,
   } },
   /* search2484_1_0 -> 0 in the cache */
   /* search2484_1_1 -> 0 in the cache */
   /* search2484_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 231, 99 },
      -1,
   } },

   /* replace2484_0_0_0 -> 0 in the cache */
   /* replace2484_0_0 -> 34 in the cache */
   /* replace2484_0_1 -> 1 in the cache */
   /* replace2484_0 -> 166 in the cache */
   /* replace2484 -> 167 in the cache */

   /* ('ior', ('flt', ('fneg', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', ('fneg', 'a'), 'b')) */
   /* search2485_0_0_0 -> 0 in the cache */
   /* search2485_0_0 -> 9 in the cache */
   /* search2485_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 228 },
      -1,
   } },
   /* search2485_1_0 -> 0 in the cache */
   /* search2485_1_1 -> 0 in the cache */
   /* search2485_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 233, 99 },
      -1,
   } },

   /* replace2485_0_0_0 -> 0 in the cache */
   /* replace2485_0_0 -> 9 in the cache */
   /* replace2485_0_1 -> 1 in the cache */
   /* replace2485_0 -> 16 in the cache */
   /* replace2485 -> 181 in the cache */

   /* ('ior', ('flt', 'a', 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('fge', 'a', 'b')) */
   /* search2486_0_0 -> 0 in the cache */
   /* search2486_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 228 },
      -1,
   } },
   /* search2486_1_0 -> 0 in the cache */
   /* search2486_1_1 -> 0 in the cache */
   /* search2486_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 235, 99 },
      -1,
   } },

   /* replace2486_0_0 -> 0 in the cache */
   /* replace2486_0_1 -> 1 in the cache */
   /* replace2486_0 -> 194 in the cache */
   /* replace2486 -> 195 in the cache */

   /* ('ior', ('fge', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', ('fneg', ('fabs', 'a')), 'b')) */
   /* search2487_0_0_0_0 -> 0 in the cache */
   /* search2487_0_0_0 -> 34 in the cache */
   /* search2487_0_0 -> 35 in the cache */
   /* search2487_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 35, 228 },
      -1,
   } },
   /* search2487_1_0 -> 0 in the cache */
   /* search2487_1_1 -> 0 in the cache */
   /* search2487_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 237, 99 },
      -1,
   } },

   /* replace2487_0_0_0_0 -> 0 in the cache */
   /* replace2487_0_0_0 -> 34 in the cache */
   /* replace2487_0_0 -> 35 in the cache */
   /* replace2487_0_1 -> 1 in the cache */
   /* replace2487_0 -> 148 in the cache */
   /* replace2487 -> 203 in the cache */

   /* ('ior', ('fge', ('fabs', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', ('fabs', 'a'), 'b')) */
   /* search2488_0_0_0 -> 0 in the cache */
   /* search2488_0_0 -> 34 in the cache */
   /* search2488_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 34, 228 },
      -1,
   } },
   /* search2488_1_0 -> 0 in the cache */
   /* search2488_1_1 -> 0 in the cache */
   /* search2488_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 239, 99 },
      -1,
   } },

   /* replace2488_0_0_0 -> 0 in the cache */
   /* replace2488_0_0 -> 34 in the cache */
   /* replace2488_0_1 -> 1 in the cache */
   /* replace2488_0 -> 164 in the cache */
   /* replace2488 -> 211 in the cache */

   /* ('ior', ('fge', ('fneg', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', ('fneg', 'a'), 'b')) */
   /* search2489_0_0_0 -> 0 in the cache */
   /* search2489_0_0 -> 9 in the cache */
   /* search2489_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 228 },
      -1,
   } },
   /* search2489_1_0 -> 0 in the cache */
   /* search2489_1_1 -> 0 in the cache */
   /* search2489_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 241, 99 },
      -1,
   } },

   /* replace2489_0_0_0 -> 0 in the cache */
   /* replace2489_0_0 -> 9 in the cache */
   /* replace2489_0_1 -> 1 in the cache */
   /* replace2489_0 -> 10 in the cache */
   /* replace2489 -> 219 in the cache */

   /* ('ior', ('fge', 'a', 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('inot', ('flt', 'a', 'b')) */
   /* search2490_0_0 -> 0 in the cache */
   /* search2490_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 228 },
      -1,
   } },
   /* search2490_1_0 -> 0 in the cache */
   /* search2490_1_1 -> 0 in the cache */
   /* search2490_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 243, 99 },
      -1,
   } },

   /* replace2490_0_0 -> 0 in the cache */
   /* replace2490_0_1 -> 1 in the cache */
   /* replace2490_0 -> 192 in the cache */
   /* replace2490 -> 227 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', ('fneg', ('fabs', 'b'))), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', ('fneg', ('fabs', 'b')))) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2491_0_1_0_0 -> 1 in the cache */
   /* search2491_0_1_0 -> 36 in the cache */
   /* search2491_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 245, 37 },
      -1,
   } },
   /* search2491_1_0 -> 1 in the cache */
   /* search2491_1_1 -> 1 in the cache */
   /* search2491_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 246, 100 },
      -1,
   } },

   /* replace2491_0_0 -> 0 in the cache */
   /* replace2491_0_1_0_0 -> 1 in the cache */
   /* replace2491_0_1_0 -> 36 in the cache */
   /* replace2491_0_1 -> 37 in the cache */
   /* replace2491_0 -> 184 in the cache */
   /* replace2491 -> 185 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', ('fabs', 'b')), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', ('fabs', 'b'))) */
   /* search2492_0_0 -> 245 in the cache */
   /* search2492_0_1_0 -> 1 in the cache */
   /* search2492_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 245, 36 },
      -1,
   } },
   /* search2492_1_0 -> 1 in the cache */
   /* search2492_1_1 -> 1 in the cache */
   /* search2492_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 248, 100 },
      -1,
   } },

   /* replace2492_0_0 -> 0 in the cache */
   /* replace2492_0_1_0 -> 1 in the cache */
   /* replace2492_0_1 -> 36 in the cache */
   /* replace2492_0 -> 188 in the cache */
   /* replace2492 -> 189 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', ('fneg', 'b')), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', ('fneg', 'b'))) */
   /* search2493_0_0 -> 245 in the cache */
   /* search2493_0_1_0 -> 1 in the cache */
   /* search2493_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 245, 5 },
      -1,
   } },
   /* search2493_1_0 -> 1 in the cache */
   /* search2493_1_1 -> 1 in the cache */
   /* search2493_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 250, 100 },
      -1,
   } },

   /* replace2493_0_0 -> 0 in the cache */
   /* replace2493_0_1_0 -> 1 in the cache */
   /* replace2493_0_1 -> 5 in the cache */
   /* replace2493_0 -> 14 in the cache */
   /* replace2493 -> 191 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b'), ('fneu', 'b', 'b')) => ('inot', ('fge', 'a', 'b')) */
   /* search2494_0_0 -> 245 in the cache */
   /* search2494_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 245, 1 },
      -1,
   } },
   /* search2494_1_0 -> 1 in the cache */
   /* search2494_1_1 -> 1 in the cache */
   /* search2494_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 252, 100 },
      -1,
   } },

   /* replace2494_0_0 -> 0 in the cache */
   /* replace2494_0_1 -> 1 in the cache */
   /* replace2494_0 -> 194 in the cache */
   /* replace2494 -> 195 in the cache */

   /* ('ior', ('fge', 'a(is_a_number)', ('fneg', ('fabs', 'b'))), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', ('fneg', ('fabs', 'b')))) */
   /* search2495_0_0 -> 245 in the cache */
   /* search2495_0_1_0_0 -> 1 in the cache */
   /* search2495_0_1_0 -> 36 in the cache */
   /* search2495_0_1 -> 37 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 245, 37 },
      -1,
   } },
   /* search2495_1_0 -> 1 in the cache */
   /* search2495_1_1 -> 1 in the cache */
   /* search2495_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 254, 100 },
      -1,
   } },

   /* replace2495_0_0 -> 0 in the cache */
   /* replace2495_0_1_0_0 -> 1 in the cache */
   /* replace2495_0_1_0 -> 36 in the cache */
   /* replace2495_0_1 -> 37 in the cache */
   /* replace2495_0 -> 182 in the cache */
   /* replace2495 -> 221 in the cache */

   /* ('ior', ('fge', 'a(is_a_number)', ('fabs', 'b')), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', ('fabs', 'b'))) */
   /* search2496_0_0 -> 245 in the cache */
   /* search2496_0_1_0 -> 1 in the cache */
   /* search2496_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 245, 36 },
      -1,
   } },
   /* search2496_1_0 -> 1 in the cache */
   /* search2496_1_1 -> 1 in the cache */
   /* search2496_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 256, 100 },
      -1,
   } },

   /* replace2496_0_0 -> 0 in the cache */
   /* replace2496_0_1_0 -> 1 in the cache */
   /* replace2496_0_1 -> 36 in the cache */
   /* replace2496_0 -> 186 in the cache */
   /* replace2496 -> 223 in the cache */

   /* ('ior', ('fge', 'a(is_a_number)', ('fneg', 'b')), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', ('fneg', 'b'))) */
   /* search2497_0_0 -> 245 in the cache */
   /* search2497_0_1_0 -> 1 in the cache */
   /* search2497_0_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 245, 5 },
      -1,
   } },
   /* search2497_1_0 -> 1 in the cache */
   /* search2497_1_1 -> 1 in the cache */
   /* search2497_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 258, 100 },
      -1,
   } },

   /* replace2497_0_0 -> 0 in the cache */
   /* replace2497_0_1_0 -> 1 in the cache */
   /* replace2497_0_1 -> 5 in the cache */
   /* replace2497_0 -> 6 in the cache */
   /* replace2497 -> 225 in the cache */

   /* ('ior', ('fge', 'a(is_a_number)', 'b'), ('fneu', 'b', 'b')) => ('inot', ('flt', 'a', 'b')) */
   /* search2498_0_0 -> 245 in the cache */
   /* search2498_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 245, 1 },
      -1,
   } },
   /* search2498_1_0 -> 1 in the cache */
   /* search2498_1_1 -> 1 in the cache */
   /* search2498_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 260, 100 },
      -1,
   } },

   /* replace2498_0_0 -> 0 in the cache */
   /* replace2498_0_1 -> 1 in the cache */
   /* replace2498_0 -> 192 in the cache */
   /* replace2498 -> 227 in the cache */

   /* ('iand', ('fneu', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', ('fneg', ('fabs', 'a')), 'b') */
   /* search2499_0_0_0_0 -> 0 in the cache */
   /* search2499_0_0_0 -> 34 in the cache */
   /* search2499_0_0 -> 35 in the cache */
   /* search2499_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 35, 228 },
      -1,
   } },
   /* search2499_1_0 -> 0 in the cache */
   /* search2499_1_1 -> 0 in the cache */
   /* search2499_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 262, 39 },
      -1,
   } },

   /* replace2499_0_0_0 -> 0 in the cache */
   /* replace2499_0_0 -> 34 in the cache */
   /* replace2499_0 -> 35 in the cache */
   /* replace2499_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 35, 1 },
      -1,
   } },

   /* ('iand', ('fneu', ('fabs', 'a'), 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', ('fabs', 'a'), 'b') */
   /* search2500_0_0_0 -> 0 in the cache */
   /* search2500_0_0 -> 34 in the cache */
   /* search2500_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 34, 228 },
      -1,
   } },
   /* search2500_1_0 -> 0 in the cache */
   /* search2500_1_1 -> 0 in the cache */
   /* search2500_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 265, 39 },
      -1,
   } },

   /* replace2500_0_0 -> 0 in the cache */
   /* replace2500_0 -> 34 in the cache */
   /* replace2500_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 34, 1 },
      -1,
   } },

   /* ('iand', ('fneu', ('fneg', 'a'), 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', ('fneg', 'a'), 'b') */
   /* search2501_0_0_0 -> 0 in the cache */
   /* search2501_0_0 -> 9 in the cache */
   /* search2501_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 9, 228 },
      -1,
   } },
   /* search2501_1_0 -> 0 in the cache */
   /* search2501_1_1 -> 0 in the cache */
   /* search2501_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 268, 39 },
      -1,
   } },

   /* replace2501_0_0 -> 0 in the cache */
   /* replace2501_0 -> 9 in the cache */
   /* replace2501_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 9, 1 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 'b(is_a_number)'), ('feq', 'a', 'a')) => ('fneo', 'a', 'b') */
   /* search2502_0_0 -> 0 in the cache */
   /* search2502_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 228 },
      -1,
   } },
   /* search2502_1_0 -> 0 in the cache */
   /* search2502_1_1 -> 0 in the cache */
   /* search2502_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 271, 39 },
      -1,
   } },

   /* replace2502_0 -> 0 in the cache */
   /* replace2502_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', ('fabs', 'a')), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', ('fneg', ('fabs', 'a')), 'b') */
   /* search2503_0_0_0_0 -> 0 in the cache */
   /* search2503_0_0_0 -> 34 in the cache */
   /* search2503_0_0 -> 35 in the cache */
   /* search2503_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 35, 228 },
      -1,
   } },
   /* search2503_1_0 -> 0 in the cache */
   /* search2503_1_1 -> 0 in the cache */
   /* search2503_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 274, 99 },
      -1,
   } },

   /* replace2503_0_0_0 -> 0 in the cache */
   /* replace2503_0_0 -> 34 in the cache */
   /* replace2503_0 -> 35 in the cache */
   /* replace2503_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fequ,
      0, 1,
      { 35, 1 },
      -1,
   } },

   /* ('ior', ('feq', ('fabs', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', ('fabs', 'a'), 'b') */
   /* search2504_0_0_0 -> 0 in the cache */
   /* search2504_0_0 -> 34 in the cache */
   /* search2504_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 34, 228 },
      -1,
   } },
   /* search2504_1_0 -> 0 in the cache */
   /* search2504_1_1 -> 0 in the cache */
   /* search2504_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 277, 99 },
      -1,
   } },

   /* replace2504_0_0 -> 0 in the cache */
   /* replace2504_0 -> 34 in the cache */
   /* replace2504_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fequ,
      0, 1,
      { 34, 1 },
      -1,
   } },

   /* ('ior', ('feq', ('fneg', 'a'), 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', ('fneg', 'a'), 'b') */
   /* search2505_0_0_0 -> 0 in the cache */
   /* search2505_0_0 -> 9 in the cache */
   /* search2505_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 9, 228 },
      -1,
   } },
   /* search2505_1_0 -> 0 in the cache */
   /* search2505_1_1 -> 0 in the cache */
   /* search2505_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 280, 99 },
      -1,
   } },

   /* replace2505_0_0 -> 0 in the cache */
   /* replace2505_0 -> 9 in the cache */
   /* replace2505_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fequ,
      0, 1,
      { 9, 1 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b(is_a_number)'), ('fneu', 'a', 'a')) => ('fequ', 'a', 'b') */
   /* search2506_0_0 -> 0 in the cache */
   /* search2506_0_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 228 },
      -1,
   } },
   /* search2506_1_0 -> 0 in the cache */
   /* search2506_1_1 -> 0 in the cache */
   /* search2506_1 -> 99 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 283, 99 },
      -1,
   } },

   /* replace2506_0 -> 0 in the cache */
   /* replace2506_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fequ,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('ior', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => ('fneo', 'a', 'b') */
   /* search2507_0_0 -> 0 in the cache */
   /* search2507_0_1 -> 1 in the cache */
   /* search2507_0 -> 192 in the cache */
   /* search2507_1_0 -> 1 in the cache */
   /* search2507_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 192, 286 },
      -1,
   } },

   /* replace2507_0 -> 0 in the cache */
   /* replace2507_1 -> 1 in the cache */
   /* replace2507 -> 273 in the cache */

   /* ('flt', 0.0, ('fabs', 'a')) => ('fneo', 0.0, 'a') */
   /* search2508_0 -> 92 in the cache */
   /* search2508_1_0 -> 91 in the cache */
   /* search2508_1 -> 96 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 92, 96 },
      -1,
   } },

   /* replace2508_0 -> 92 in the cache */
   /* replace2508_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 92, 91 },
      -1,
   } },

   /* ('ior', ('fneu', 'a@16', 'a'), ('fneu', 'b@16', 'b')) => ('funord', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2509_0_1 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 290, 290 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2509_1_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 292, 292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 291, 293 },
      -1,
   } },

   /* replace2509_0 -> 290 in the cache */
   /* replace2509_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_funord,
      0, 1,
      { 290, 292 },
      -1,
   } },

   /* ('iand', ('feq', 'a@16', 'a'), ('feq', 'b@16', 'b')) => ('ford', 'a', 'b') */
   /* search2510_0_0 -> 290 in the cache */
   /* search2510_0_1 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 290, 290 },
      -1,
   } },
   /* search2510_1_0 -> 292 in the cache */
   /* search2510_1_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 292, 292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 296, 297 },
      -1,
   } },

   /* replace2510_0 -> 290 in the cache */
   /* replace2510_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ford,
      0, 1,
      { 290, 292 },
      -1,
   } },

   /* ('ior', ('fneu', 'a@32', 'a'), ('fneu', 'b@32', 'b')) => ('funord', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2511_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 300, 300 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2511_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 302, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 301, 303 },
      -1,
   } },

   /* replace2511_0 -> 300 in the cache */
   /* replace2511_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_funord,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('iand', ('feq', 'a@32', 'a'), ('feq', 'b@32', 'b')) => ('ford', 'a', 'b') */
   /* search2512_0_0 -> 300 in the cache */
   /* search2512_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 300, 300 },
      -1,
   } },
   /* search2512_1_0 -> 302 in the cache */
   /* search2512_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 302, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 306, 307 },
      -1,
   } },

   /* replace2512_0 -> 300 in the cache */
   /* replace2512_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ford,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('ior', ('fneu', 'a@64', 'a'), ('fneu', 'b@64', 'b')) => ('funord', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2513_0_1 -> 310 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 310, 310 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2513_1_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 312, 312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 311, 313 },
      -1,
   } },

   /* replace2513_0 -> 310 in the cache */
   /* replace2513_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_funord,
      0, 1,
      { 310, 312 },
      -1,
   } },

   /* ('iand', ('feq', 'a@64', 'a'), ('feq', 'b@64', 'b')) => ('ford', 'a', 'b') */
   /* search2514_0_0 -> 310 in the cache */
   /* search2514_0_1 -> 310 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 310, 310 },
      -1,
   } },
   /* search2514_1_0 -> 312 in the cache */
   /* search2514_1_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 312, 312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 316, 317 },
      -1,
   } },

   /* replace2514_0 -> 310 in the cache */
   /* replace2514_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ford,
      0, 1,
      { 310, 312 },
      -1,
   } },

   /* ('inot', ('ford(is_used_once)', 'a', 'b')) => ('funord', 'a', 'b') */
   /* search2515_0_0 -> 0 in the cache */
   /* search2515_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ford,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 320 },
      -1,
   } },

   /* replace2515_0 -> 0 in the cache */
   /* replace2515_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_funord,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('funord(is_used_once)', 'a', 'b')) => ('ford', 'a', 'b') */
   /* search2516_0_0 -> 0 in the cache */
   /* search2516_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_funord,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 323 },
      -1,
   } },

   /* replace2516_0 -> 0 in the cache */
   /* replace2516_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ford,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search2517_0_0 -> 0 in the cache */
   /* search2517_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 326 },
      -1,
   } },

   /* replace2517_0 -> 0 in the cache */
   /* replace2517_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search2518_0_0 -> 0 in the cache */
   /* search2518_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 329 },
      -1,
   } },

   /* replace2518_0 -> 0 in the cache */
   /* replace2518_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('fequ(is_used_once)', 'a', 'b')) => ('fneo', 'a', 'b') */
   /* search2519_0_0 -> 0 in the cache */
   /* search2519_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fequ,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 332 },
      -1,
   } },

   /* replace2519_0 -> 0 in the cache */
   /* replace2519_1 -> 1 in the cache */
   /* replace2519 -> 273 in the cache */

   /* ('inot', ('fneo(is_used_once)', 'a', 'b')) => ('fequ', 'a', 'b') */
   /* search2520_0_0 -> 0 in the cache */
   /* search2520_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneo,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 334 },
      -1,
   } },

   /* replace2520_0 -> 0 in the cache */
   /* replace2520_1 -> 1 in the cache */
   /* replace2520 -> 285 in the cache */

   /* ('inot', ('flt(is_used_once)', 'a', 'b')) => ('fgeu', 'a', 'b') */
   /* search2521_0_0 -> 0 in the cache */
   /* search2521_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 336 },
      -1,
   } },

   /* replace2521_0 -> 0 in the cache */
   /* replace2521_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fgeu,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('fgeu(is_used_once)', 'a', 'b')) => ('flt', 'a', 'b') */
   /* search2522_0_0 -> 0 in the cache */
   /* search2522_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fgeu,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 339 },
      -1,
   } },

   /* replace2522_0 -> 0 in the cache */
   /* replace2522_1 -> 1 in the cache */
   /* replace2522 -> 192 in the cache */

   /* ('inot', ('fge(is_used_once)', 'a', 'b')) => ('fltu', 'a', 'b') */
   /* search2523_0_0 -> 0 in the cache */
   /* search2523_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 341 },
      -1,
   } },

   /* replace2523_0 -> 0 in the cache */
   /* replace2523_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fltu,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('inot', ('fltu(is_used_once)', 'a', 'b')) => ('fge', 'a', 'b') */
   /* search2524_0_0 -> 0 in the cache */
   /* search2524_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fltu,
      -1, 0,
      { 0, 1 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 344 },
      -1,
   } },

   /* replace2524_0 -> 0 in the cache */
   /* replace2524_1 -> 1 in the cache */
   /* replace2524 -> 194 in the cache */

   /* ('fneg', ('fneg', 'a')) => a */
   /* search2525_0_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 346 },
      -1,
   } },

   /* replace2525 -> 91 in the cache */

   /* ('iadd@32', ('imul(is_only_used_by_iadd)', 'a', 'b'), 'c') => ('imad', 'a', 'b', 'c') */
   /* search2526_0_0 -> 300 in the cache */
   /* search2526_0_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 300, 302 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 348, 349 },
      -1,
   } },

   /* replace2526_0 -> 300 in the cache */
   /* replace2526_1 -> 302 in the cache */
   /* replace2526_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imad,
      0, 1,
      { 300, 302, 349 },
      -1,
   } },

   /* ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search2527_0_0 -> 290 in the cache */
   /* search2527_0_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 290, 292 },
      2,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 352, 353 },
      -1,
   } },

   /* replace2527_0 -> 290 in the cache */
   /* replace2527_1 -> 292 in the cache */
   /* replace2527_2 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 290, 292, 353 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2528_0_0_0 -> 290 in the cache */
   /* search2528_0_0_1 -> 292 in the cache */
   /* search2528_0_0 -> 352 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 352 },
      2,
   } },
   /* search2528_1 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 356, 353 },
      -1,
   } },

   /* replace2528_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 290 },
      -1,
   } },
   /* replace2528_1 -> 292 in the cache */
   /* replace2528_2 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 358, 292, 353 },
      -1,
   } },

   /* ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2529_0_0_0 -> 290 in the cache */
   /* search2529_0_0_1 -> 292 in the cache */
   /* search2529_0_0 -> 352 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 352 },
      2,
   } },
   /* search2529_1 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 360, 353 },
      -1,
   } },

   /* replace2529_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 290 },
      -1,
   } },
   /* replace2529_1_0 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 292 },
      -1,
   } },
   /* replace2529_2 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 362, 363, 353 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2530_0_0_0_0 -> 290 in the cache */
   /* search2530_0_0_0_1 -> 292 in the cache */
   /* search2530_0_0_0 -> 352 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 365 },
      2,
   } },
   /* search2530_1 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 366, 353 },
      -1,
   } },

   /* replace2530_0_0_0 -> 290 in the cache */
   /* replace2530_0_0 -> 362 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 362 },
      -1,
   } },
   /* replace2530_1_0 -> 292 in the cache */
   /* replace2530_1 -> 363 in the cache */
   /* replace2530_2 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 368, 363, 353 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search2531_0_0 -> 300 in the cache */
   /* search2531_0_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 300, 302 },
      2,
   } },
   /* search2531_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 370, 349 },
      -1,
   } },

   /* replace2531_0 -> 300 in the cache */
   /* replace2531_1 -> 302 in the cache */
   /* replace2531_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 300, 302, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2532_0_0_0 -> 300 in the cache */
   /* search2532_0_0_1 -> 302 in the cache */
   /* search2532_0_0 -> 370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 370 },
      2,
   } },
   /* search2532_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 373, 349 },
      -1,
   } },

   /* replace2532_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 300 },
      -1,
   } },
   /* replace2532_1 -> 302 in the cache */
   /* replace2532_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 375, 302, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2533_0_0_0 -> 300 in the cache */
   /* search2533_0_0_1 -> 302 in the cache */
   /* search2533_0_0 -> 370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 370 },
      2,
   } },
   /* search2533_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 377, 349 },
      -1,
   } },

   /* replace2533_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 300 },
      -1,
   } },
   /* replace2533_1_0 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 302 },
      -1,
   } },
   /* replace2533_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 379, 380, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2534_0_0_0_0 -> 300 in the cache */
   /* search2534_0_0_0_1 -> 302 in the cache */
   /* search2534_0_0_0 -> 370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 370 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 382 },
      2,
   } },
   /* search2534_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 383, 349 },
      -1,
   } },

   /* replace2534_0_0_0 -> 300 in the cache */
   /* replace2534_0_0 -> 379 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 379 },
      -1,
   } },
   /* replace2534_1_0 -> 302 in the cache */
   /* replace2534_1 -> 380 in the cache */
   /* replace2534_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 385, 380, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search2535_0_0 -> 300 in the cache */
   /* search2535_0_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 300, 302 },
      2,
   } },
   /* search2535_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 387, 349 },
      -1,
   } },

   /* replace2535_0 -> 300 in the cache */
   /* replace2535_1 -> 302 in the cache */
   /* replace2535_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 300, 302, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c') */
   /* search2536_0_0_0 -> 300 in the cache */
   /* search2536_0_0_1 -> 302 in the cache */
   /* search2536_0_0 -> 387 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 387 },
      2,
   } },
   /* search2536_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 390, 349 },
      -1,
   } },

   /* replace2536_0_0 -> 300 in the cache */
   /* replace2536_0 -> 375 in the cache */
   /* replace2536_1 -> 302 in the cache */
   /* replace2536_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 375, 302, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2537_0_0_0 -> 300 in the cache */
   /* search2537_0_0_1 -> 302 in the cache */
   /* search2537_0_0 -> 387 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 387 },
      2,
   } },
   /* search2537_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 393, 349 },
      -1,
   } },

   /* replace2537_0_0 -> 300 in the cache */
   /* replace2537_0 -> 379 in the cache */
   /* replace2537_1_0 -> 302 in the cache */
   /* replace2537_1 -> 380 in the cache */
   /* replace2537_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 379, 380, 349 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2538_0_0_0_0 -> 300 in the cache */
   /* search2538_0_0_0_1 -> 302 in the cache */
   /* search2538_0_0_0 -> 387 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 387 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 396 },
      2,
   } },
   /* search2538_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 397, 349 },
      -1,
   } },

   /* replace2538_0_0_0 -> 300 in the cache */
   /* replace2538_0_0 -> 379 in the cache */
   /* replace2538_0 -> 385 in the cache */
   /* replace2538_1_0 -> 302 in the cache */
   /* replace2538_1 -> 380 in the cache */
   /* replace2538_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 385, 380, 349 },
      -1,
   } },

   /* ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search2539_0_0 -> 310 in the cache */
   /* search2539_0_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 310, 312 },
      2,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 400, 401 },
      -1,
   } },

   /* replace2539_0 -> 310 in the cache */
   /* replace2539_1 -> 312 in the cache */
   /* replace2539_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 310, 312, 401 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2540_0_0_0 -> 310 in the cache */
   /* search2540_0_0_1 -> 312 in the cache */
   /* search2540_0_0 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 400 },
      2,
   } },
   /* search2540_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 404, 401 },
      -1,
   } },

   /* replace2540_0_0 -> 310 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 310 },
      -1,
   } },
   /* replace2540_1 -> 312 in the cache */
   /* replace2540_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 406, 312, 401 },
      -1,
   } },

   /* ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2541_0_0_0 -> 310 in the cache */
   /* search2541_0_0_1 -> 312 in the cache */
   /* search2541_0_0 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 400 },
      2,
   } },
   /* search2541_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 408, 401 },
      -1,
   } },

   /* replace2541_0_0 -> 310 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 310 },
      -1,
   } },
   /* replace2541_1_0 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 312 },
      -1,
   } },
   /* replace2541_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 410, 411, 401 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2542_0_0_0_0 -> 310 in the cache */
   /* search2542_0_0_0_1 -> 312 in the cache */
   /* search2542_0_0_0 -> 400 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 413 },
      2,
   } },
   /* search2542_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 414, 401 },
      -1,
   } },

   /* replace2542_0_0_0 -> 310 in the cache */
   /* replace2542_0_0 -> 410 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 410 },
      -1,
   } },
   /* replace2542_1_0 -> 312 in the cache */
   /* replace2542_1 -> 411 in the cache */
   /* replace2542_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 416, 411, 401 },
      -1,
   } },

   /* ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 419 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 418, 420 },
      -1,
   } },

   /* replace2543_0 -> 418 in the cache */
   /* replace2543_1 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 418, 419 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2544_0 -> 290 in the cache */
   /* search2544_1_0 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 290, 423 },
      -1,
   } },

   /* replace2544_0 -> 290 in the cache */
   /* replace2544_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 290, 292 },
      -1,
   } },

   /* ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2545_0 -> 300 in the cache */
   /* search2545_1_0 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 300, 426 },
      -1,
   } },

   /* replace2545_0 -> 300 in the cache */
   /* replace2545_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2546_0 -> 310 in the cache */
   /* search2546_1_0 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 310, 429 },
      -1,
   } },

   /* replace2546_0 -> 310 in the cache */
   /* replace2546_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 310, 312 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search2547_0 -> 91 in the cache */
   /* search2547 -> 346 in the cache */

   /* replace2547_0 -> 91 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 91, 432 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search2548_0 -> 0 in the cache */
   /* search2548_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 434 },
      -1,
   } },

   /* replace2548_0 -> 0 in the cache */
   /* replace2548_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search2549_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 91 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   /* replace2549_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 438, 91 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search2550_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 91 },
      -1,
   } },

   /* replace2550_0 -> 91 in the cache */
   /* replace2550_1_0 -> 91 in the cache */
   /* replace2550_1 -> 437 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 91, 437 },
      -1,
   } },

   /* ('iadd@8', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 442, 443 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 444, 445 },
      -1,
   } },

   /* replace2551_0 -> 418 in the cache */
   /* replace2551_1 -> 419 in the cache */
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 418, 419, 447 },
      -1,
   } },

   /* ('iadd@8', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2552_0_1 -> 443 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 449, 443 },
      0,
   } },
   /* search2552_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 450, 445 },
      -1,
   } },

   /* replace2552_0 -> 418 in the cache */
   /* replace2552_1 -> 419 in the cache */
   /* replace2552_2 -> 447 in the cache */
   /* replace2552 -> 448 in the cache */

   /* ('iadd@8', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c') */
   /* search2553_0_0 -> 442 in the cache */
   /* search2553_0_1 -> 443 in the cache */
   /* search2553_0 -> 444 in the cache */
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 444, 452 },
      -1,
   } },

   /* replace2553_0 -> 418 in the cache */
   /* replace2553_1 -> 419 in the cache */
   /* replace2553_2 -> 447 in the cache */
   /* replace2553 -> 448 in the cache */

   /* ('iadd@8', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2554_0_0_0 -> 442 in the cache */
   /* search2554_0_0_1 -> 443 in the cache */
   /* search2554_0_0 -> 444 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 444 },
      -1,
   } },
   /* search2554_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 454, 445 },
      -1,
   } },

   /* replace2554_0_0 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 418 },
      -1,
   } },
   /* replace2554_1_0 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 419 },
      -1,
   } },
   /* replace2554_2 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 456, 457, 447 },
      -1,
   } },

   /* ('iadd@8', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2555_0_0_0 -> 449 in the cache */
   /* search2555_0_0_1 -> 443 in the cache */
   /* search2555_0_0 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 450 },
      -1,
   } },
   /* search2555_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 459, 445 },
      -1,
   } },

   /* replace2555_0_0 -> 418 in the cache */
   /* replace2555_0 -> 456 in the cache */
   /* replace2555_1_0 -> 419 in the cache */
   /* replace2555_1 -> 457 in the cache */
   /* replace2555_2 -> 447 in the cache */
   /* replace2555 -> 458 in the cache */

   /* ('iadd@8', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2556_0_0_0 -> 442 in the cache */
   /* search2556_0_0_1 -> 443 in the cache */
   /* search2556_0_0 -> 444 in the cache */
   /* search2556_0 -> 454 in the cache */
   /* search2556_1 -> 452 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 454, 452 },
      -1,
   } },

   /* replace2556_0_0 -> 418 in the cache */
   /* replace2556_0 -> 456 in the cache */
   /* replace2556_1_0 -> 419 in the cache */
   /* replace2556_1 -> 457 in the cache */
   /* replace2556_2 -> 447 in the cache */
   /* replace2556 -> 458 in the cache */

   /* ('iadd@8', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b') */
   /* search2557_0_0 -> 418 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 418, 462 },
      -1,
   } },
   /* search2557_1 -> 443 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 463, 443 },
      -1,
   } },

   /* replace2557_0 -> 418 in the cache */
   /* replace2557_1 -> 418 in the cache */
   /* replace2557_2 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 418, 418, 419 },
      -1,
   } },

   /* ('iadd@8', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b') */
   /* search2558_0_0 -> 418 in the cache */
   /* search2558_0_1 -> 462 in the cache */
   /* search2558_0 -> 463 in the cache */
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 463, 466 },
      -1,
   } },

   /* replace2558_0 -> 418 in the cache */
   /* replace2558_1 -> 418 in the cache */
   /* replace2558_2 -> 419 in the cache */
   /* replace2558 -> 465 in the cache */

   /* ('iadd@8', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2559_0_0_0 -> 418 in the cache */
   /* search2559_0_0_1 -> 462 in the cache */
   /* search2559_0_0 -> 463 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 463 },
      -1,
   } },
   /* search2559_1 -> 443 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 468, 443 },
      -1,
   } },

   /* replace2559_0_0 -> 418 in the cache */
   /* replace2559_0 -> 456 in the cache */
   /* replace2559_1_0 -> 418 in the cache */
   /* replace2559_1 -> 456 in the cache */
   /* replace2559_2 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 456, 456, 419 },
      -1,
   } },

   /* ('iadd@8', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2560_0_0_0 -> 418 in the cache */
   /* search2560_0_0_1 -> 462 in the cache */
   /* search2560_0_0 -> 463 in the cache */
   /* search2560_0 -> 468 in the cache */
   /* search2560_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 468, 466 },
      -1,
   } },

   /* replace2560_0_0 -> 418 in the cache */
   /* replace2560_0 -> 456 in the cache */
   /* replace2560_1_0 -> 418 in the cache */
   /* replace2560_1 -> 456 in the cache */
   /* replace2560_2 -> 419 in the cache */
   /* replace2560 -> 470 in the cache */

   /* ('ishl@8', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b')) */
   /* search2561_0_0 -> 418 in the cache */
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      true,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 418, 472 },
      -1,
   } },
   /* search2561_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 473, 462 },
      -1,
   } },

   /* replace2561_0 -> 418 in the cache */
   /* replace2561_1 -> 418 in the cache */
   /* replace2561_2_0 -> 419 in the cache */
   /* replace2561_2_1 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      -1, 0,
      { 419, 419 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 418, 418, 475 },
      -1,
   } },

   /* ('ishl@8', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b'))) */
   /* search2562_0_0_0 -> 418 in the cache */
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      true,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 418, 477 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 478 },
      -1,
   } },
   /* search2562_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 479, 462 },
      -1,
   } },

   /* replace2562_0_0 -> 418 in the cache */
   /* replace2562_0 -> 456 in the cache */
   /* replace2562_1_0 -> 418 in the cache */
   /* replace2562_1 -> 456 in the cache */
   /* replace2562_2_0_0 -> 419 in the cache */
   /* replace2562_2_0_1 -> 419 in the cache */
   /* replace2562_2_0 -> 475 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 456, 456, 481 },
      -1,
   } },

   /* ('iadd@16', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 483, 484 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 485, 486 },
      -1,
   } },

   /* replace2563_0 -> 290 in the cache */
   /* replace2563_1 -> 292 in the cache */
   /* replace2563_2 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 290, 292, 353 },
      -1,
   } },

   /* ('iadd@16', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2564_0_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 489, 484 },
      0,
   } },
   /* search2564_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 490, 486 },
      -1,
   } },

   /* replace2564_0 -> 290 in the cache */
   /* replace2564_1 -> 292 in the cache */
   /* replace2564_2 -> 353 in the cache */
   /* replace2564 -> 488 in the cache */

   /* ('iadd@16', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c') */
   /* search2565_0_0 -> 483 in the cache */
   /* search2565_0_1 -> 484 in the cache */
   /* search2565_0 -> 485 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 485, 492 },
      -1,
   } },

   /* replace2565_0 -> 290 in the cache */
   /* replace2565_1 -> 292 in the cache */
   /* replace2565_2 -> 353 in the cache */
   /* replace2565 -> 488 in the cache */

   /* ('iadd@16', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2566_0_0_0 -> 483 in the cache */
   /* search2566_0_0_1 -> 484 in the cache */
   /* search2566_0_0 -> 485 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 485 },
      -1,
   } },
   /* search2566_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 494, 486 },
      -1,
   } },

   /* replace2566_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 290 },
      -1,
   } },
   /* replace2566_1_0 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 292 },
      -1,
   } },
   /* replace2566_2 -> 353 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 496, 497, 353 },
      -1,
   } },

   /* ('iadd@16', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2567_0_0_0 -> 489 in the cache */
   /* search2567_0_0_1 -> 484 in the cache */
   /* search2567_0_0 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 490 },
      -1,
   } },
   /* search2567_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 499, 486 },
      -1,
   } },

   /* replace2567_0_0 -> 290 in the cache */
   /* replace2567_0 -> 496 in the cache */
   /* replace2567_1_0 -> 292 in the cache */
   /* replace2567_1 -> 497 in the cache */
   /* replace2567_2 -> 353 in the cache */
   /* replace2567 -> 498 in the cache */

   /* ('iadd@16', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2568_0_0_0 -> 483 in the cache */
   /* search2568_0_0_1 -> 484 in the cache */
   /* search2568_0_0 -> 485 in the cache */
   /* search2568_0 -> 494 in the cache */
   /* search2568_1 -> 492 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 494, 492 },
      -1,
   } },

   /* replace2568_0_0 -> 290 in the cache */
   /* replace2568_0 -> 496 in the cache */
   /* replace2568_1_0 -> 292 in the cache */
   /* replace2568_1 -> 497 in the cache */
   /* replace2568_2 -> 353 in the cache */
   /* replace2568 -> 498 in the cache */

   /* ('iadd@16', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b') */
   /* search2569_0_0 -> 290 in the cache */
   /* search2569_0_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 290, 462 },
      -1,
   } },
   /* search2569_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 502, 484 },
      -1,
   } },

   /* replace2569_0 -> 290 in the cache */
   /* replace2569_1 -> 290 in the cache */
   /* replace2569_2 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 290, 290, 292 },
      -1,
   } },

   /* ('iadd@16', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b') */
   /* search2570_0_0 -> 290 in the cache */
   /* search2570_0_1 -> 462 in the cache */
   /* search2570_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 502, 505 },
      -1,
   } },

   /* replace2570_0 -> 290 in the cache */
   /* replace2570_1 -> 290 in the cache */
   /* replace2570_2 -> 292 in the cache */
   /* replace2570 -> 504 in the cache */

   /* ('iadd@16', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2571_0_0_0 -> 290 in the cache */
   /* search2571_0_0_1 -> 462 in the cache */
   /* search2571_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search2571_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 507, 484 },
      -1,
   } },

   /* replace2571_0_0 -> 290 in the cache */
   /* replace2571_0 -> 496 in the cache */
   /* replace2571_1_0 -> 290 in the cache */
   /* replace2571_1 -> 496 in the cache */
   /* replace2571_2 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 496, 496, 292 },
      -1,
   } },

   /* ('iadd@16', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2572_0_0_0 -> 290 in the cache */
   /* search2572_0_0_1 -> 462 in the cache */
   /* search2572_0_0 -> 502 in the cache */
   /* search2572_0 -> 507 in the cache */
   /* search2572_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 507, 505 },
      -1,
   } },

   /* replace2572_0_0 -> 290 in the cache */
   /* replace2572_0 -> 496 in the cache */
   /* replace2572_1_0 -> 290 in the cache */
   /* replace2572_1 -> 496 in the cache */
   /* replace2572_2 -> 292 in the cache */
   /* replace2572 -> 509 in the cache */

   /* ('ishl@16', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b')) */
   /* search2573_0_0 -> 290 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 290, 511 },
      -1,
   } },
   /* search2573_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 512, 462 },
      -1,
   } },

   /* replace2573_0 -> 290 in the cache */
   /* replace2573_1 -> 290 in the cache */
   /* replace2573_2_0 -> 292 in the cache */
   /* replace2573_2_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      -1, 0,
      { 292, 292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 290, 290, 514 },
      -1,
   } },

   /* ('ishl@16', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b'))) */
   /* search2574_0_0_0 -> 290 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 290, 516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 517 },
      -1,
   } },
   /* search2574_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 518, 462 },
      -1,
   } },

   /* replace2574_0_0 -> 290 in the cache */
   /* replace2574_0 -> 496 in the cache */
   /* replace2574_1_0 -> 290 in the cache */
   /* replace2574_1 -> 496 in the cache */
   /* replace2574_2_0_0 -> 292 in the cache */
   /* replace2574_2_0_1 -> 292 in the cache */
   /* replace2574_2_0 -> 514 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 496, 496, 520 },
      -1,
   } },

   /* ('iadd@32', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 522, 523 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 524, 525 },
      -1,
   } },

   /* replace2575_0 -> 300 in the cache */
   /* replace2575_1 -> 302 in the cache */
   /* replace2575_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 300, 302, 349 },
      -1,
   } },

   /* ('iadd@32', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2576_0_1 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 528, 523 },
      0,
   } },
   /* search2576_1 -> 525 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 529, 525 },
      -1,
   } },

   /* replace2576_0 -> 300 in the cache */
   /* replace2576_1 -> 302 in the cache */
   /* replace2576_2 -> 349 in the cache */
   /* replace2576 -> 527 in the cache */

   /* ('iadd@32', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c') */
   /* search2577_0_0 -> 522 in the cache */
   /* search2577_0_1 -> 523 in the cache */
   /* search2577_0 -> 524 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 524, 531 },
      -1,
   } },

   /* replace2577_0 -> 300 in the cache */
   /* replace2577_1 -> 302 in the cache */
   /* replace2577_2 -> 349 in the cache */
   /* replace2577 -> 527 in the cache */

   /* ('iadd@32', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2578_0_0_0 -> 522 in the cache */
   /* search2578_0_0_1 -> 523 in the cache */
   /* search2578_0_0 -> 524 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 524 },
      -1,
   } },
   /* search2578_1 -> 525 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 533, 525 },
      -1,
   } },

   /* replace2578_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 300 },
      -1,
   } },
   /* replace2578_1_0 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 302 },
      -1,
   } },
   /* replace2578_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 535, 536, 349 },
      -1,
   } },

   /* ('iadd@32', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2579_0_0_0 -> 528 in the cache */
   /* search2579_0_0_1 -> 523 in the cache */
   /* search2579_0_0 -> 529 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 529 },
      -1,
   } },
   /* search2579_1 -> 525 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 538, 525 },
      -1,
   } },

   /* replace2579_0_0 -> 300 in the cache */
   /* replace2579_0 -> 535 in the cache */
   /* replace2579_1_0 -> 302 in the cache */
   /* replace2579_1 -> 536 in the cache */
   /* replace2579_2 -> 349 in the cache */
   /* replace2579 -> 537 in the cache */

   /* ('iadd@32', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2580_0_0_0 -> 522 in the cache */
   /* search2580_0_0_1 -> 523 in the cache */
   /* search2580_0_0 -> 524 in the cache */
   /* search2580_0 -> 533 in the cache */
   /* search2580_1 -> 531 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 533, 531 },
      -1,
   } },

   /* replace2580_0_0 -> 300 in the cache */
   /* replace2580_0 -> 535 in the cache */
   /* replace2580_1_0 -> 302 in the cache */
   /* replace2580_1 -> 536 in the cache */
   /* replace2580_2 -> 349 in the cache */
   /* replace2580 -> 537 in the cache */

   /* ('iadd@32', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b') */
   /* search2581_0_0 -> 300 in the cache */
   /* search2581_0_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 300, 462 },
      -1,
   } },
   /* search2581_1 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 541, 523 },
      -1,
   } },

   /* replace2581_0 -> 300 in the cache */
   /* replace2581_1 -> 300 in the cache */
   /* replace2581_2 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 300, 300, 302 },
      -1,
   } },

   /* ('iadd@32', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b') */
   /* search2582_0_0 -> 300 in the cache */
   /* search2582_0_1 -> 462 in the cache */
   /* search2582_0 -> 541 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 541, 544 },
      -1,
   } },

   /* replace2582_0 -> 300 in the cache */
   /* replace2582_1 -> 300 in the cache */
   /* replace2582_2 -> 302 in the cache */
   /* replace2582 -> 543 in the cache */

   /* ('iadd@32', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2583_0_0_0 -> 300 in the cache */
   /* search2583_0_0_1 -> 462 in the cache */
   /* search2583_0_0 -> 541 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 541 },
      -1,
   } },
   /* search2583_1 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 546, 523 },
      -1,
   } },

   /* replace2583_0_0 -> 300 in the cache */
   /* replace2583_0 -> 535 in the cache */
   /* replace2583_1_0 -> 300 in the cache */
   /* replace2583_1 -> 535 in the cache */
   /* replace2583_2 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 535, 535, 302 },
      -1,
   } },

   /* ('iadd@32', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2584_0_0_0 -> 300 in the cache */
   /* search2584_0_0_1 -> 462 in the cache */
   /* search2584_0_0 -> 541 in the cache */
   /* search2584_0 -> 546 in the cache */
   /* search2584_1 -> 544 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 546, 544 },
      -1,
   } },

   /* replace2584_0_0 -> 300 in the cache */
   /* replace2584_0 -> 535 in the cache */
   /* replace2584_1_0 -> 300 in the cache */
   /* replace2584_1 -> 535 in the cache */
   /* replace2584_2 -> 302 in the cache */
   /* replace2584 -> 548 in the cache */

   /* ('ishl@32', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b')) */
   /* search2585_0_0 -> 300 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 300, 550 },
      -1,
   } },
   /* search2585_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 551, 462 },
      -1,
   } },

   /* replace2585_0 -> 300 in the cache */
   /* replace2585_1 -> 300 in the cache */
   /* replace2585_2_0 -> 302 in the cache */
   /* replace2585_2_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      -1, 0,
      { 302, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 300, 300, 553 },
      -1,
   } },

   /* ('ishl@32', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b'))) */
   /* search2586_0_0_0 -> 300 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 300, 555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 556 },
      -1,
   } },
   /* search2586_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 557, 462 },
      -1,
   } },

   /* replace2586_0_0 -> 300 in the cache */
   /* replace2586_0 -> 535 in the cache */
   /* replace2586_1_0 -> 300 in the cache */
   /* replace2586_1 -> 535 in the cache */
   /* replace2586_2_0_0 -> 302 in the cache */
   /* replace2586_2_0_1 -> 302 in the cache */
   /* replace2586_2_0 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 535, 535, 559 },
      -1,
   } },

   /* ('iadd@64', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 561, 562 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 563, 564 },
      -1,
   } },

   /* replace2587_0 -> 310 in the cache */
   /* replace2587_1 -> 312 in the cache */
   /* replace2587_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 310, 312, 401 },
      -1,
   } },

   /* ('iadd@64', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2588_0_1 -> 562 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 567, 562 },
      0,
   } },
   /* search2588_1 -> 564 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 568, 564 },
      -1,
   } },

   /* replace2588_0 -> 310 in the cache */
   /* replace2588_1 -> 312 in the cache */
   /* replace2588_2 -> 401 in the cache */
   /* replace2588 -> 566 in the cache */

   /* ('iadd@64', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_16_bits)') => ('iadd3', 'a', 'b', 'c') */
   /* search2589_0_0 -> 561 in the cache */
   /* search2589_0_1 -> 562 in the cache */
   /* search2589_0 -> 563 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 563, 570 },
      -1,
   } },

   /* replace2589_0 -> 310 in the cache */
   /* replace2589_1 -> 312 in the cache */
   /* replace2589_2 -> 401 in the cache */
   /* replace2589 -> 566 in the cache */

   /* ('iadd@64', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2590_0_0_0 -> 561 in the cache */
   /* search2590_0_0_1 -> 562 in the cache */
   /* search2590_0_0 -> 563 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 563 },
      -1,
   } },
   /* search2590_1 -> 564 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 572, 564 },
      -1,
   } },

   /* replace2590_0_0 -> 310 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 310 },
      -1,
   } },
   /* replace2590_1_0 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 312 },
      -1,
   } },
   /* replace2590_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 574, 575, 401 },
      -1,
   } },

   /* ('iadd@64', ('ineg', ('iadd(is_used_once)', '#a(is_16_bits)', 'b(is_not_const)')), 'c(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2591_0_0_0 -> 567 in the cache */
   /* search2591_0_0_1 -> 562 in the cache */
   /* search2591_0_0 -> 568 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 568 },
      -1,
   } },
   /* search2591_1 -> 564 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 577, 564 },
      -1,
   } },

   /* replace2591_0_0 -> 310 in the cache */
   /* replace2591_0 -> 574 in the cache */
   /* replace2591_1_0 -> 312 in the cache */
   /* replace2591_1 -> 575 in the cache */
   /* replace2591_2 -> 401 in the cache */
   /* replace2591 -> 576 in the cache */

   /* ('iadd@64', ('ineg', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)')), '#c(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'b'), 'c') */
   /* search2592_0_0_0 -> 561 in the cache */
   /* search2592_0_0_1 -> 562 in the cache */
   /* search2592_0_0 -> 563 in the cache */
   /* search2592_0 -> 572 in the cache */
   /* search2592_1 -> 570 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 572, 570 },
      -1,
   } },

   /* replace2592_0_0 -> 310 in the cache */
   /* replace2592_0 -> 574 in the cache */
   /* replace2592_1_0 -> 312 in the cache */
   /* replace2592_1 -> 575 in the cache */
   /* replace2592_2 -> 401 in the cache */
   /* replace2592 -> 576 in the cache */

   /* ('iadd@64', ('ishl', 'a', 1), 'b(is_not_const)') => ('iadd3', 'a', 'a', 'b') */
   /* search2593_0_0 -> 310 in the cache */
   /* search2593_0_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 310, 462 },
      -1,
   } },
   /* search2593_1 -> 562 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 580, 562 },
      -1,
   } },

   /* replace2593_0 -> 310 in the cache */
   /* replace2593_1 -> 310 in the cache */
   /* replace2593_2 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 310, 310, 312 },
      -1,
   } },

   /* ('iadd@64', ('ishl', 'a', 1), '#b(is_16_bits)') => ('iadd3', 'a', 'a', 'b') */
   /* search2594_0_0 -> 310 in the cache */
   /* search2594_0_1 -> 462 in the cache */
   /* search2594_0 -> 580 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 580, 583 },
      -1,
   } },

   /* replace2594_0 -> 310 in the cache */
   /* replace2594_1 -> 310 in the cache */
   /* replace2594_2 -> 312 in the cache */
   /* replace2594 -> 582 in the cache */

   /* ('iadd@64', ('ineg', ('ishl', 'a', 1)), 'b(is_not_const)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2595_0_0_0 -> 310 in the cache */
   /* search2595_0_0_1 -> 462 in the cache */
   /* search2595_0_0 -> 580 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 580 },
      -1,
   } },
   /* search2595_1 -> 562 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 585, 562 },
      -1,
   } },

   /* replace2595_0_0 -> 310 in the cache */
   /* replace2595_0 -> 574 in the cache */
   /* replace2595_1_0 -> 310 in the cache */
   /* replace2595_1 -> 574 in the cache */
   /* replace2595_2 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 574, 574, 312 },
      -1,
   } },

   /* ('iadd@64', ('ineg', ('ishl', 'a', 1)), '#b(is_16_bits)') => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), 'b') */
   /* search2596_0_0_0 -> 310 in the cache */
   /* search2596_0_0_1 -> 462 in the cache */
   /* search2596_0_0 -> 580 in the cache */
   /* search2596_0 -> 585 in the cache */
   /* search2596_1 -> 583 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 585, 583 },
      -1,
   } },

   /* replace2596_0_0 -> 310 in the cache */
   /* replace2596_0 -> 574 in the cache */
   /* replace2596_1_0 -> 310 in the cache */
   /* replace2596_1 -> 574 in the cache */
   /* replace2596_2 -> 312 in the cache */
   /* replace2596 -> 587 in the cache */

   /* ('ishl@64', ('iadd', 'a', '#b(is_2x_16_bits)'), 1) => ('iadd3', 'a', 'a', ('iadd', 'b', 'b')) */
   /* search2597_0_0 -> 310 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 310, 589 },
      -1,
   } },
   /* search2597_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 590, 462 },
      -1,
   } },

   /* replace2597_0 -> 310 in the cache */
   /* replace2597_1 -> 310 in the cache */
   /* replace2597_2_0 -> 312 in the cache */
   /* replace2597_2_1 -> 312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      -1, 0,
      { 312, 312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 310, 310, 592 },
      -1,
   } },

   /* ('ishl@64', ('ineg', ('iadd', 'a', '#b(is_neg2x_16_bits)')), 1) => ('iadd3', ('ineg', 'a'), ('ineg', 'a'), ('ineg', ('iadd', 'b', 'b'))) */
   /* search2598_0_0_0 -> 310 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 310, 594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 595 },
      -1,
   } },
   /* search2598_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 596, 462 },
      -1,
   } },

   /* replace2598_0_0 -> 310 in the cache */
   /* replace2598_0 -> 574 in the cache */
   /* replace2598_1_0 -> 310 in the cache */
   /* replace2598_1 -> 574 in the cache */
   /* replace2598_2_0_0 -> 312 in the cache */
   /* replace2598_2_0_1 -> 312 in the cache */
   /* replace2598_2_0 -> 592 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 592 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd3,
      -1, 0,
      { 574, 574, 598 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search2599_0_0 -> 290 in the cache */
   /* search2599_0 -> 358 in the cache */
   /* search2599_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 358, 292 },
      3,
   } },

   /* replace2599_0_0 -> 290 in the cache */
   /* replace2599_0_1 -> 292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 290, 292 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 602, 603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 601, 604 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search2600_0 -> 290 in the cache */
   /* search2600_1_0 -> 292 in the cache */
   /* search2600_1 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 290, 423 },
      3,
   } },

   /* replace2600_0_0 -> 290 in the cache */
   /* replace2600_0_1 -> 292 in the cache */
   /* replace2600_0 -> 601 in the cache */
   /* replace2600_1_0 -> 603 in the cache */
   /* replace2600_1_1 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 603, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 601, 607 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 610 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 609, 611 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2601_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 613, 610 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search2602_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 615, 616 },
      -1,
   } },

   /* replace2602_0 -> 0 in the cache */
   /* replace2602_1 -> 1 in the cache */
   /* replace2602 -> 194 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search2603_0_0 -> 0 in the cache */
   /* search2603_0 -> 615 in the cache */
   /* search2603_1 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 615, 616 },
      -1,
   } },

   /* replace2603_0 -> 0 in the cache */
   /* replace2603_1 -> 1 in the cache */
   /* replace2603 -> 331 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search2604_0_0 -> 0 in the cache */
   /* search2604_0 -> 615 in the cache */
   /* search2604_1 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 615, 616 },
      -1,
   } },

   /* replace2604_0 -> 0 in the cache */
   /* replace2604_1 -> 1 in the cache */
   /* replace2604 -> 328 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search2605_0_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 91 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 620, 621 },
      -1,
   } },

   /* replace2605_0 -> 91 in the cache */
   /* replace2605_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 91, 621 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 624, 625 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 627, 628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 626, 629 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0ull /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 630, 631 },
      -1,
   } },

   /* replace2606_0_0 -> 624 in the cache */
   /* replace2606_0_1_0 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 624, 633 },
      -1,
   } },
   /* replace2606_1_0 -> 627 in the cache */
   /* replace2606_1_1_0 -> 628 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 627, 635 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 634, 636 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search2607_0_0 -> 0 in the cache */
   /* search2607_0 -> 9 in the cache */
   /* search2607_1_0 -> 1 in the cache */
   /* search2607_1 -> 5 in the cache */
   /* search2607 -> 176 in the cache */

   /* replace2607_0 -> 1 in the cache */
   /* replace2607_1 -> 0 in the cache */
   /* replace2607 -> 286 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search2608_0_0 -> 0 in the cache */
   /* search2608_0 -> 9 in the cache */
   /* search2608_1_0 -> 1 in the cache */
   /* search2608_1 -> 5 in the cache */
   /* search2608 -> 178 in the cache */

   /* replace2608_0 -> 1 in the cache */
   /* replace2608_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search2609_0_0 -> 0 in the cache */
   /* search2609_0 -> 9 in the cache */
   /* search2609_1_0 -> 1 in the cache */
   /* search2609_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2609_0 -> 1 in the cache */
   /* replace2609_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search2610_0_0 -> 0 in the cache */
   /* search2610_0 -> 9 in the cache */
   /* search2610_1_0 -> 1 in the cache */
   /* search2610_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2610_0 -> 1 in the cache */
   /* replace2610_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search2611_0_0 -> 91 in the cache */
   /* search2611_0 -> 346 in the cache */
   /* search2611_1 -> 432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 346, 432 },
      -1,
   } },

   /* replace2611_0 -> 621 in the cache */
   /* replace2611_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 621, 91 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search2612_0 -> 432 in the cache */
   /* search2612_1_0 -> 91 in the cache */
   /* search2612_1 -> 346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 432, 346 },
      -1,
   } },

   /* replace2612_0 -> 91 in the cache */
   /* replace2612_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 91, 621 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search2613_0_0 -> 91 in the cache */
   /* search2613_0 -> 346 in the cache */
   /* search2613_1 -> 432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 346, 432 },
      -1,
   } },

   /* replace2613_0 -> 621 in the cache */
   /* replace2613_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 621, 91 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search2614_0 -> 432 in the cache */
   /* search2614_1_0 -> 91 in the cache */
   /* search2614_1 -> 346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 432, 346 },
      -1,
   } },

   /* replace2614_0 -> 91 in the cache */
   /* replace2614_1 -> 621 in the cache */
   /* replace2614 -> 623 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search2615_0_0 -> 91 in the cache */
   /* search2615_0 -> 346 in the cache */
   /* search2615_1 -> 432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 346, 432 },
      -1,
   } },

   /* replace2615_0 -> 621 in the cache */
   /* replace2615_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 621, 91 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search2616_0 -> 432 in the cache */
   /* search2616_1_0 -> 91 in the cache */
   /* search2616_1 -> 346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 432, 346 },
      -1,
   } },

   /* replace2616_0 -> 91 in the cache */
   /* replace2616_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 91, 621 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search2617_0 -> 91 in the cache */
   /* search2617_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 91, 91 },
      -1,
   } },

   /* replace2617 -> 91 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search2618_0 -> 91 in the cache */
   /* search2618_1 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 91, 91 },
      -1,
   } },

   /* replace2618 -> 91 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 656 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 657 },
      0,
   } },
   /* search2619_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 658, 621 },
      -1,
   } },

   /* replace2619_0_0 -> 621 in the cache */
   /* replace2619_0_1_0 -> 91 in the cache */
   /* replace2619_0_1 -> 346 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 621, 346 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 660 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search2620_0 -> 0 in the cache */
   /* search2620_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2620_0 -> 0 in the cache */
   /* replace2620_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search2621_0 -> 0 in the cache */
   /* search2621_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2621_0 -> 0 in the cache */
   /* replace2621_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search2622_0 -> 0 in the cache */
   /* search2622_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2622_0 -> 0 in the cache */
   /* replace2622_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search2623_0 -> 0 in the cache */
   /* search2623_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace2623_0 -> 0 in the cache */
   /* replace2623_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search2624_0_0 -> 624 in the cache */
   /* search2624_0_1 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 624, 625 },
      0,
   } },
   /* search2624_1_0 -> 624 in the cache */
   /* search2624_1_1 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 624, 627 },
      0,
   } },
   /* search2624_2 -> 628 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 670, 671, 628 },
      -1,
   } },

   /* replace2624_0_0 -> 625 in the cache */
   /* replace2624_0_1 -> 627 in the cache */
   /* replace2624_0_2 -> 628 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 625, 627, 628 },
      -1,
   } },
   /* replace2624_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 673, 624 },
      -1,
   } },

   /* ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5))) */
   /* search2625_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 91 },
      -1,
   } },

   /* replace2625_0_0_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 91 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000ull /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 676, 677 },
      -1,
   } },
   /* replace2625_1_0_0_0 -> 91 in the cache */
   /* replace2625_1_0_0_1 -> 677 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 91, 677 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 679 },
      -1,
   } },
   /* replace2625_1_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 680, 621 },
      -1,
   } },
   /* replace2625_2_0_0 -> 91 in the cache */
   /* replace2625_2_0_1 -> 677 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 91, 677 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 682 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 678, 681, 683 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2626_0 -> 300 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000ull /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 300, 685, 686 },
      -1,
   } },

   /* replace2626_0 -> 686 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   /* replace2626_2 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 686, 688, 300 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2627_0 -> 300 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000ull /* -2.0 */ },
   } },
   /* search2627_2 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 300, 690, 686 },
      -1,
   } },

   /* replace2627_0 -> 686 in the cache */
   /* replace2627_1 -> 688 in the cache */
   /* replace2627_2_0 -> 300 in the cache */
   /* replace2627_2 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 686, 688, 375 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2628_0 -> 300 in the cache */
   /* search2628_1 -> 690 in the cache */
   /* search2628_2 -> 688 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 300, 690, 688 },
      -1,
   } },

   /* replace2628_0 -> 688 in the cache */
   /* replace2628_1 -> 686 in the cache */
   /* replace2628_2 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 688, 686, 300 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2629_0 -> 300 in the cache */
   /* search2629_1 -> 685 in the cache */
   /* search2629_2 -> 688 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 300, 685, 688 },
      -1,
   } },

   /* replace2629_0 -> 688 in the cache */
   /* replace2629_1 -> 686 in the cache */
   /* replace2629_2_0 -> 300 in the cache */
   /* replace2629_2 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 688, 686, 375 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2630_0_0 -> 685 in the cache */
   /* search2630_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 685, 300 },
      0,
   } },
   /* search2630_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 697, 686 },
      -1,
   } },

   /* replace2630_0 -> 686 in the cache */
   /* replace2630_1 -> 688 in the cache */
   /* replace2630_2 -> 300 in the cache */
   /* replace2630 -> 689 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2631_0_0 -> 690 in the cache */
   /* search2631_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 690, 300 },
      0,
   } },
   /* search2631_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 699, 686 },
      -1,
   } },

   /* replace2631_0 -> 686 in the cache */
   /* replace2631_1 -> 688 in the cache */
   /* replace2631_2_0 -> 300 in the cache */
   /* replace2631_2 -> 375 in the cache */
   /* replace2631 -> 692 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2632_0_0 -> 690 in the cache */
   /* search2632_0_1 -> 300 in the cache */
   /* search2632_0 -> 699 in the cache */
   /* search2632_1 -> 688 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 699, 688 },
      -1,
   } },

   /* replace2632_0 -> 688 in the cache */
   /* replace2632_1 -> 686 in the cache */
   /* replace2632_2 -> 300 in the cache */
   /* replace2632 -> 694 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2633_0_0 -> 685 in the cache */
   /* search2633_0_1 -> 300 in the cache */
   /* search2633_0 -> 697 in the cache */
   /* search2633_1 -> 688 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 697, 688 },
      -1,
   } },

   /* replace2633_0 -> 688 in the cache */
   /* replace2633_1 -> 686 in the cache */
   /* replace2633_2_0 -> 300 in the cache */
   /* replace2633_2 -> 375 in the cache */
   /* replace2633 -> 696 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 703, 705 },
      -1,
   } },
   /* search2634_1 -> 704 in the cache */
   /* search2634_2 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 706, 704, 704 },
      -1,
   } },

   /* replace2634_0 -> 704 in the cache */
   /* replace2634_1 -> 703 in the cache */
   /* replace2634_2 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 704, 703, 704 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2635_0 -> 300 in the cache */
   /* search2635_1 -> 685 in the cache */
   /* search2635_2_0_0 -> 300 in the cache */
   /* search2635_2_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 300, 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 709 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 300, 685, 710 },
      -1,
   } },

   /* replace2635_0 -> 300 in the cache */
   /* replace2635_1 -> 688 in the cache */
   /* replace2635_2 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 300, 688, 300 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2636_0 -> 300 in the cache */
   /* search2636_1 -> 685 in the cache */
   /* search2636_2_0_0 -> 300 in the cache */
   /* search2636_2_0 -> 375 in the cache */
   /* search2636_2_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 375, 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 300, 685, 713 },
      -1,
   } },

   /* replace2636_0 -> 300 in the cache */
   /* replace2636_1 -> 688 in the cache */
   /* replace2636_2 -> 300 in the cache */
   /* replace2636 -> 712 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2637_0 -> 300 in the cache */
   /* search2637_1_0 -> 300 in the cache */
   /* search2637_1 -> 375 in the cache */
   /* search2637_2_0 -> 685 in the cache */
   /* search2637_2_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 685, 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 300, 375, 715 },
      -1,
   } },

   /* replace2637_0 -> 300 in the cache */
   /* replace2637_1 -> 688 in the cache */
   /* replace2637_2 -> 300 in the cache */
   /* replace2637 -> 712 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2638_0 -> 300 in the cache */
   /* search2638_1_0 -> 685 in the cache */
   /* search2638_1_1_0 -> 300 in the cache */
   /* search2638_1_1 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 685, 375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 300, 717 },
      -1,
   } },

   /* replace2638_0 -> 300 in the cache */
   /* replace2638_1 -> 688 in the cache */
   /* replace2638_2 -> 300 in the cache */
   /* replace2638 -> 712 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 719, 720 },
      0,
   } },
   /* search2639_1_0 -> 719 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 719, 722 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 721, 723 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2639_1_0 -> 720 in the cache */
   /* replace2639_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 720, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 725, 726 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search2640_0_0 -> 719 in the cache */
   /* search2640_0_1 -> 720 in the cache */
   /* search2640_0 -> 721 in the cache */
   /* search2640_1_0 -> 719 in the cache */
   /* search2640_1_1 -> 722 in the cache */
   /* search2640_1 -> 723 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 721, 723 },
      -1,
   } },

   /* replace2640_0 -> 725 in the cache */
   /* replace2640_1_0 -> 720 in the cache */
   /* replace2640_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 720, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 725, 729 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 731 },
      -1,
   } },
   /* search2641_0_1 -> 92 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 732, 92 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000ull /* 3.4028234663852886e+38 */ },
   } },
   /* search2641_2_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 91 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 733, 734, 735 },
      -1,
   } },

   /* replace2641_0_0 -> 91 in the cache */
   /* replace2641_0 -> 735 in the cache */
   /* replace2641_1 -> 734 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 735, 734 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 742, 743 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 740, 741, 744 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 738, 739, 745 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 746, 747 },
      -1,
   } },

   /* replace2642_0 -> 738 in the cache */
   /* replace2642_1 -> 739 in the cache */
   /* replace2642_2_0 -> 740 in the cache */
   /* replace2642_2_1 -> 741 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 749, 750, 751 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 740, 741, 752 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 738, 739, 753 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 757, 758 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 755, 756, 759 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 760, 761 },
      -1,
   } },

   /* replace2643_0 -> 755 in the cache */
   /* replace2643_1 -> 756 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 763, 764, 765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 755, 756, 766 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2644_0_0_0 -> 738 in the cache */
   /* search2644_0_0_1 -> 739 in the cache */
   /* search2644_0_0_2_0 -> 740 in the cache */
   /* search2644_0_0_2_1 -> 741 in the cache */
   /* search2644_0_0_2_2_0 -> 742 in the cache */
   /* search2644_0_0_2_2_1 -> 743 in the cache */
   /* search2644_0_0_2_2 -> 744 in the cache */
   /* search2644_0_0_2 -> 745 in the cache */
   /* search2644_0_0 -> 746 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 746 },
      -1,
   } },
   /* search2644_1 -> 747 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 768, 747 },
      -1,
   } },

   /* replace2644_0_0 -> 738 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 738 },
      -1,
   } },
   /* replace2644_1 -> 739 in the cache */
   /* replace2644_2_0_0 -> 740 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 740 },
      -1,
   } },
   /* replace2644_2_1 -> 741 in the cache */
   /* replace2644_2_2_0_0 -> 749 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 749 },
      -1,
   } },
   /* replace2644_2_2_1 -> 750 in the cache */
   /* replace2644_2_2_2 -> 751 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 772, 750, 751 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 771, 741, 773 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 770, 739, 774 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2645_0_0 -> 300 in the cache */
   /* search2645_0_1 -> 302 in the cache */
   /* search2645_0_2_0 -> 349 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 777, 778 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 349, 776, 779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 300, 302, 780 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 781, 782 },
      -1,
   } },

   /* replace2645_0 -> 300 in the cache */
   /* replace2645_1 -> 302 in the cache */
   /* replace2645_2_0 -> 349 in the cache */
   /* replace2645_2_1 -> 776 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 784, 785, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 349, 776, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 300, 302, 788 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2646_0_0 -> 300 in the cache */
   /* search2646_0_1 -> 302 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 790, 791 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 300, 302, 792 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 793, 794 },
      -1,
   } },

   /* replace2646_0 -> 300 in the cache */
   /* replace2646_1 -> 302 in the cache */
   /* replace2646_2_0 -> 349 in the cache */
   /* replace2646_2_1 -> 776 in the cache */
   /* replace2646_2_2 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 349, 776, 784 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 300, 302, 796 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2647_0_0_0 -> 300 in the cache */
   /* search2647_0_0_1 -> 302 in the cache */
   /* search2647_0_0_2_0 -> 349 in the cache */
   /* search2647_0_0_2_1 -> 776 in the cache */
   /* search2647_0_0_2_2_0 -> 777 in the cache */
   /* search2647_0_0_2_2_1 -> 778 in the cache */
   /* search2647_0_0_2_2 -> 779 in the cache */
   /* search2647_0_0_2 -> 780 in the cache */
   /* search2647_0_0 -> 781 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 781 },
      -1,
   } },
   /* search2647_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 798, 782 },
      -1,
   } },

   /* replace2647_0_0 -> 300 in the cache */
   /* replace2647_0 -> 375 in the cache */
   /* replace2647_1 -> 302 in the cache */
   /* replace2647_2_0_0 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 349 },
      -1,
   } },
   /* replace2647_2_1 -> 776 in the cache */
   /* replace2647_2_2_0_0 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 784 },
      -1,
   } },
   /* replace2647_2_2_1 -> 785 in the cache */
   /* replace2647_2_2_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 801, 785, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 800, 776, 802 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 375, 302, 803 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2648_0 -> 300 in the cache */
   /* search2648_1 -> 302 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 300, 302, 805 },
      -1,
   } },

   /* replace2648 -> 805 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2649_0 -> 300 in the cache */
   /* search2649_1 -> 302 in the cache */
   /* search2649_2 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 300, 302, 805 },
      -1,
   } },

   /* replace2649 -> 805 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2650_0 -> 300 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 300, 808, 809 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffull /* 4294967295 */ },
   } },
   /* replace2650_0_1_0 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 349 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 811, 812 },
      -1,
   } },
   /* replace2650_1_0 -> 300 in the cache */
   /* replace2650_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 813, 814 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2651_0 -> 300 in the cache */
   /* search2651_1 -> 808 in the cache */
   /* search2651_2 -> 809 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 300, 808, 809 },
      -1,
   } },

   /* replace2651_0_0 -> 300 in the cache */
   /* replace2651_0_1_0_0 -> 302 in the cache */
   /* replace2651_0_1_0_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 302, 349 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 817 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 300, 818 },
      -1,
   } },
   /* replace2651_1_0 -> 349 in the cache */
   /* replace2651_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 819, 812 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2652_0 -> 91 in the cache */
   /* search2652_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 91, 805 },
      -1,
   } },

   /* replace2652 -> 91 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2653_0 -> 91 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffe0ull /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 91, 822 },
      -1,
   } },

   /* replace2653 -> 91 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2654_0 -> 91 in the cache */
   /* search2654_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 91, 805 },
      -1,
   } },

   /* replace2654 -> 91 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2655_0 -> 91 in the cache */
   /* search2655_1 -> 822 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 91, 822 },
      -1,
   } },

   /* replace2655 -> 91 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2656_0 -> 91 in the cache */
   /* search2656_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 91, 805 },
      -1,
   } },

   /* replace2656 -> 91 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2657_0_0 -> 0 in the cache */
   /* search2657_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 827, 828 },
      -1,
   } },

   /* replace2657_0 -> 0 in the cache */
   /* replace2657_1 -> 1 in the cache */
   /* replace2657 -> 827 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2658_0_0 -> 0 in the cache */
   /* search2658_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2658_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 830, 828 },
      -1,
   } },

   /* replace2658_0 -> 0 in the cache */
   /* replace2658_1 -> 1 in the cache */
   /* replace2658 -> 827 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2659_0_0 -> 0 in the cache */
   /* search2659_0_1 -> 1 in the cache */
   /* search2659_0 -> 827 in the cache */
   /* search2659_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 827, 828 },
      -1,
   } },

   /* replace2659_0 -> 0 in the cache */
   /* replace2659_1 -> 1 in the cache */
   /* replace2659 -> 830 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2660_0_0 -> 0 in the cache */
   /* search2660_0_1 -> 1 in the cache */
   /* search2660_0 -> 830 in the cache */
   /* search2660_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 830, 828 },
      -1,
   } },

   /* replace2660_0 -> 0 in the cache */
   /* replace2660_1 -> 1 in the cache */
   /* replace2660 -> 830 in the cache */

   /* ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 0) => ('bitnz', 'a', ('find_lsb', 'b')) */
   /* search2661_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 834 },
      -1,
   } },
   /* search2661_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 835, 828 },
      -1,
   } },

   /* replace2661_0 -> 0 in the cache */
   /* replace2661_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 0, 837 },
      -1,
   } },

   /* ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 0) => ('bitz', 'a', ('find_lsb', 'b')) */
   /* search2662_0_0 -> 0 in the cache */
   /* search2662_0_1 -> 834 in the cache */
   /* search2662_0 -> 835 in the cache */
   /* search2662_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 835, 828 },
      -1,
   } },

   /* replace2662_0 -> 0 in the cache */
   /* replace2662_1_0 -> 1 in the cache */
   /* replace2662_1 -> 837 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 0, 837 },
      -1,
   } },

   /* ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('bitz', 'a', ('find_lsb', 'b')) */
   /* search2663_0_0 -> 0 in the cache */
   /* search2663_0_1 -> 834 in the cache */
   /* search2663_0 -> 835 in the cache */
   /* search2663_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 835, 1 },
      -1,
   } },

   /* replace2663_0 -> 0 in the cache */
   /* replace2663_1_0 -> 1 in the cache */
   /* replace2663_1 -> 837 in the cache */
   /* replace2663 -> 840 in the cache */

   /* ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('bitnz', 'a', ('find_lsb', 'b')) */
   /* search2664_0_0 -> 0 in the cache */
   /* search2664_0_1 -> 834 in the cache */
   /* search2664_0 -> 835 in the cache */
   /* search2664_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 835, 1 },
      -1,
   } },

   /* replace2664_0 -> 0 in the cache */
   /* replace2664_1_0 -> 1 in the cache */
   /* replace2664_1 -> 837 in the cache */
   /* replace2664 -> 838 in the cache */

   /* ('ine', ('iand', 'a', ('ishl', 1, 'b')), 0) => ('bitnz', 'a', 'b') */
   /* search2665_0_0 -> 91 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1ull /* 1 */ },
   } },
   /* search2665_0_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 843, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 91, 844 },
      -1,
   } },
   /* search2665_1 -> 438 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 845, 438 },
      -1,
   } },

   /* replace2665_0 -> 91 in the cache */
   /* replace2665_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 91, 302 },
      -1,
   } },

   /* ('ieq', ('iand', 'a', ('ishl', 1, 'b')), 0) => ('bitz', 'a', 'b') */
   /* search2666_0_0 -> 91 in the cache */
   /* search2666_0_1_0 -> 843 in the cache */
   /* search2666_0_1_1 -> 302 in the cache */
   /* search2666_0_1 -> 844 in the cache */
   /* search2666_0 -> 845 in the cache */
   /* search2666_1 -> 438 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 845, 438 },
      -1,
   } },

   /* replace2666_0 -> 91 in the cache */
   /* replace2666_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 91, 302 },
      -1,
   } },

   /* ('ine', ('iand', 'a', ('ishl', 1, 'b')), ('ishl', 1, 'b')) => ('bitz', 'a', 'b') */
   /* search2667_0_0 -> 91 in the cache */
   /* search2667_0_1_0 -> 843 in the cache */
   /* search2667_0_1_1 -> 302 in the cache */
   /* search2667_0_1 -> 844 in the cache */
   /* search2667_0 -> 845 in the cache */
   /* search2667_1_0 -> 843 in the cache */
   /* search2667_1_1 -> 302 in the cache */
   /* search2667_1 -> 844 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 845, 844 },
      -1,
   } },

   /* replace2667_0 -> 91 in the cache */
   /* replace2667_1 -> 302 in the cache */
   /* replace2667 -> 849 in the cache */

   /* ('ieq', ('iand', 'a', ('ishl', 1, 'b')), ('ishl', 1, 'b')) => ('bitnz', 'a', 'b') */
   /* search2668_0_0 -> 91 in the cache */
   /* search2668_0_1_0 -> 843 in the cache */
   /* search2668_0_1_1 -> 302 in the cache */
   /* search2668_0_1 -> 844 in the cache */
   /* search2668_0 -> 845 in the cache */
   /* search2668_1_0 -> 843 in the cache */
   /* search2668_1_1 -> 302 in the cache */
   /* search2668_1 -> 844 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 845, 844 },
      -1,
   } },

   /* replace2668_0 -> 91 in the cache */
   /* replace2668_1 -> 302 in the cache */
   /* replace2668 -> 847 in the cache */

   /* ('bitz', ('ushr', 'a', 'b'), 0) => ('bitz', 'a', 'b') */
   /* search2669_0_0 -> 91 in the cache */
   /* search2669_0_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 91, 302 },
      -1,
   } },
   /* search2669_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 852, 805 },
      -1,
   } },

   /* replace2669_0 -> 91 in the cache */
   /* replace2669_1 -> 302 in the cache */
   /* replace2669 -> 849 in the cache */

   /* ('bitz', ('ishr', 'a', 'b'), 0) => ('bitz', 'a', 'b') */
   /* search2670_0_0 -> 91 in the cache */
   /* search2670_0_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 91, 302 },
      -1,
   } },
   /* search2670_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 854, 805 },
      -1,
   } },

   /* replace2670_0 -> 91 in the cache */
   /* replace2670_1 -> 302 in the cache */
   /* replace2670 -> 849 in the cache */

   /* ('bitnz', ('ushr', 'a', 'b'), 0) => ('bitnz', 'a', 'b') */
   /* search2671_0_0 -> 91 in the cache */
   /* search2671_0_1 -> 302 in the cache */
   /* search2671_0 -> 852 in the cache */
   /* search2671_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 852, 805 },
      -1,
   } },

   /* replace2671_0 -> 91 in the cache */
   /* replace2671_1 -> 302 in the cache */
   /* replace2671 -> 847 in the cache */

   /* ('bitnz', ('ishr', 'a', 'b'), 0) => ('bitnz', 'a', 'b') */
   /* search2672_0_0 -> 91 in the cache */
   /* search2672_0_1 -> 302 in the cache */
   /* search2672_0 -> 854 in the cache */
   /* search2672_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 854, 805 },
      -1,
   } },

   /* replace2672_0 -> 91 in the cache */
   /* replace2672_1 -> 302 in the cache */
   /* replace2672 -> 847 in the cache */

   /* ('ine', ('ubfe', 'a', 'b', 1), 0) => ('bitnz', 'a', 'b') */
   /* search2673_0_0 -> 300 in the cache */
   /* search2673_0_1 -> 302 in the cache */
   /* search2673_0_2 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 300, 302, 462 },
      -1,
   } },
   /* search2673_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 858, 805 },
      -1,
   } },

   /* replace2673_0 -> 300 in the cache */
   /* replace2673_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('ieq', ('ubfe', 'a', 'b', 1), 0) => ('bitz', 'a', 'b') */
   /* search2674_0_0 -> 300 in the cache */
   /* search2674_0_1 -> 302 in the cache */
   /* search2674_0_2 -> 462 in the cache */
   /* search2674_0 -> 858 in the cache */
   /* search2674_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 858, 805 },
      -1,
   } },

   /* replace2674_0 -> 300 in the cache */
   /* replace2674_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('ine', ('ubfe', 'a', 'b', 1), 1) => ('bitz', 'a', 'b') */
   /* search2675_0_0 -> 300 in the cache */
   /* search2675_0_1 -> 302 in the cache */
   /* search2675_0_2 -> 462 in the cache */
   /* search2675_0 -> 858 in the cache */
   /* search2675_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 858, 462 },
      -1,
   } },

   /* replace2675_0 -> 300 in the cache */
   /* replace2675_1 -> 302 in the cache */
   /* replace2675 -> 862 in the cache */

   /* ('ieq', ('ubfe', 'a', 'b', 1), 1) => ('bitnz', 'a', 'b') */
   /* search2676_0_0 -> 300 in the cache */
   /* search2676_0_1 -> 302 in the cache */
   /* search2676_0_2 -> 462 in the cache */
   /* search2676_0 -> 858 in the cache */
   /* search2676_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 858, 462 },
      -1,
   } },

   /* replace2676_0 -> 300 in the cache */
   /* replace2676_1 -> 302 in the cache */
   /* replace2676 -> 860 in the cache */

   /* ('ine', ('ibfe', 'a', 'b', 1), 0) => ('bitnz', 'a', 'b') */
   /* search2677_0_0 -> 300 in the cache */
   /* search2677_0_1 -> 302 in the cache */
   /* search2677_0_2 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 300, 302, 462 },
      -1,
   } },
   /* search2677_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 865, 805 },
      -1,
   } },

   /* replace2677_0 -> 300 in the cache */
   /* replace2677_1 -> 302 in the cache */
   /* replace2677 -> 860 in the cache */

   /* ('ieq', ('ibfe', 'a', 'b', 1), 0) => ('bitz', 'a', 'b') */
   /* search2678_0_0 -> 300 in the cache */
   /* search2678_0_1 -> 302 in the cache */
   /* search2678_0_2 -> 462 in the cache */
   /* search2678_0 -> 865 in the cache */
   /* search2678_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 865, 805 },
      -1,
   } },

   /* replace2678_0 -> 300 in the cache */
   /* replace2678_1 -> 302 in the cache */
   /* replace2678 -> 862 in the cache */

   /* ('ine', ('ibfe', 'a', 'b', 1), -1) => ('bitz', 'a', 'b') */
   /* search2679_0_0 -> 300 in the cache */
   /* search2679_0_1 -> 302 in the cache */
   /* search2679_0_2 -> 462 in the cache */
   /* search2679_0 -> 865 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffffull /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 865, 868 },
      -1,
   } },

   /* replace2679_0 -> 300 in the cache */
   /* replace2679_1 -> 302 in the cache */
   /* replace2679 -> 862 in the cache */

   /* ('ieq', ('ibfe', 'a', 'b', 1), -1) => ('bitnz', 'a', 'b') */
   /* search2680_0_0 -> 300 in the cache */
   /* search2680_0_1 -> 302 in the cache */
   /* search2680_0_2 -> 462 in the cache */
   /* search2680_0 -> 865 in the cache */
   /* search2680_1 -> 868 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 865, 868 },
      -1,
   } },

   /* replace2680_0 -> 300 in the cache */
   /* replace2680_1 -> 302 in the cache */
   /* replace2680 -> 860 in the cache */

   /* ('inot', ('bitnz', 'a', 'b')) => ('bitz', 'a', 'b') */
   /* search2681_0_0 -> 91 in the cache */
   /* search2681_0_1 -> 302 in the cache */
   /* search2681_0 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 847 },
      -1,
   } },

   /* replace2681_0 -> 91 in the cache */
   /* replace2681_1 -> 302 in the cache */
   /* replace2681 -> 849 in the cache */

   /* ('inot', ('bitz', 'a', 'b')) => ('bitnz', 'a', 'b') */
   /* search2682_0_0 -> 91 in the cache */
   /* search2682_0_1 -> 302 in the cache */
   /* search2682_0 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 849 },
      -1,
   } },

   /* replace2682_0 -> 91 in the cache */
   /* replace2682_1 -> 302 in the cache */
   /* replace2682 -> 847 in the cache */

   /* ('bitnz', ('inot', 'a'), 'b') => ('bitz', 'a', 'b') */
   /* search2683_0_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 91 },
      -1,
   } },
   /* search2683_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitnz,
      -1, 0,
      { 873, 302 },
      -1,
   } },

   /* replace2683_0 -> 91 in the cache */
   /* replace2683_1 -> 302 in the cache */
   /* replace2683 -> 849 in the cache */

   /* ('bitz', ('inot', 'a'), 'b') => ('bitnz', 'a', 'b') */
   /* search2684_0_0 -> 91 in the cache */
   /* search2684_0 -> 873 in the cache */
   /* search2684_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bitz,
      -1, 0,
      { 873, 302 },
      -1,
   } },

   /* replace2684_0 -> 91 in the cache */
   /* replace2684_1 -> 302 in the cache */
   /* replace2684 -> 847 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2685_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 290 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 876 },
      -1,
   } },

   /* replace2685_0 -> 290 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 290, 878 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2686_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 290 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 880 },
      -1,
   } },

   /* replace2686_0 -> 290 in the cache */
   /* replace2686_1 -> 878 in the cache */
   /* replace2686 -> 879 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2687_0_0 -> 290 in the cache */
   /* search2687_0 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 876 },
      -1,
   } },

   /* replace2687_0 -> 290 in the cache */
   /* replace2687_1 -> 878 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 290, 878 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2688_0_0 -> 290 in the cache */
   /* search2688_0 -> 880 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 880 },
      -1,
   } },

   /* replace2688_0 -> 290 in the cache */
   /* replace2688_1 -> 878 in the cache */
   /* replace2688 -> 883 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2689_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 885 },
      -1,
   } },

   /* replace2689_0 -> 300 in the cache */
   /* replace2689_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 300, 805 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2690_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 888 },
      -1,
   } },

   /* replace2690_0 -> 300 in the cache */
   /* replace2690_1 -> 805 in the cache */
   /* replace2690 -> 887 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2691_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 890 },
      -1,
   } },

   /* replace2691_0 -> 300 in the cache */
   /* replace2691_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 300, 805 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2692_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 893 },
      -1,
   } },

   /* replace2692_0 -> 300 in the cache */
   /* replace2692_1 -> 805 in the cache */
   /* replace2692 -> 892 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2693_0_0 -> 300 in the cache */
   /* search2693_0 -> 885 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 885 },
      -1,
   } },

   /* replace2693_0 -> 300 in the cache */
   /* replace2693_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 300, 805 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2694_0_0 -> 300 in the cache */
   /* search2694_0 -> 888 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 888 },
      -1,
   } },

   /* replace2694_0 -> 300 in the cache */
   /* replace2694_1 -> 805 in the cache */
   /* replace2694 -> 896 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2695_0_0 -> 300 in the cache */
   /* search2695_0 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 890 },
      -1,
   } },

   /* replace2695_0 -> 300 in the cache */
   /* replace2695_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 300, 805 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2696_0_0 -> 300 in the cache */
   /* search2696_0 -> 893 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 893 },
      -1,
   } },

   /* replace2696_0 -> 300 in the cache */
   /* replace2696_1 -> 805 in the cache */
   /* replace2696 -> 899 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2697_0_0 -> 300 in the cache */
   /* search2697_0_1 -> 805 in the cache */
   /* search2697_0 -> 887 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8ull /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 887, 901 },
      -1,
   } },

   /* replace2697_0 -> 300 in the cache */
   /* replace2697_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 300, 462 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2698_0_0 -> 300 in the cache */
   /* search2698_0_1 -> 805 in the cache */
   /* search2698_0 -> 887 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10ull /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 887, 904 },
      -1,
   } },

   /* replace2698_0 -> 300 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2ull /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 300, 906 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2699_0_0 -> 300 in the cache */
   /* search2699_0_1 -> 805 in the cache */
   /* search2699_0 -> 887 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18ull /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 887, 908 },
      -1,
   } },

   /* replace2699_0 -> 300 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ull /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 300, 910 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2700_0_0 -> 300 in the cache */
   /* search2700_0_1 -> 901 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 300, 901 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ull /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 912, 913 },
      -1,
   } },

   /* replace2700_0 -> 300 in the cache */
   /* replace2700_1 -> 462 in the cache */
   /* replace2700 -> 903 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2701_0_0 -> 300 in the cache */
   /* search2701_0_1 -> 904 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 300, 904 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000ull /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 915, 916 },
      -1,
   } },

   /* replace2701_0 -> 300 in the cache */
   /* replace2701_1 -> 906 in the cache */
   /* replace2701 -> 907 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2702_0_0 -> 300 in the cache */
   /* search2702_0_1 -> 908 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 300, 908 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000ull /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 918, 919 },
      -1,
   } },

   /* replace2702_0 -> 300 in the cache */
   /* replace2702_1 -> 910 in the cache */
   /* replace2702 -> 911 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2703_0 -> 300 in the cache */
   /* search2703_1 -> 908 in the cache */
   /* search2703 -> 918 in the cache */

   /* replace2703_0 -> 300 in the cache */
   /* replace2703_1 -> 910 in the cache */
   /* replace2703 -> 911 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2704_0 -> 300 in the cache */
   /* search2704_1 -> 904 in the cache */
   /* search2704 -> 915 in the cache */

   /* replace2704_0 -> 300 in the cache */
   /* replace2704_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 300, 462 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2705_0_0 -> 0 in the cache */
   /* search2705_0_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 828 },
      -1,
   } },
   /* search2705_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 922, 1 },
      -1,
   } },

   /* replace2705_0 -> 0 in the cache */
   /* replace2705_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2706_0_0 -> 0 in the cache */
   /* search2706_0_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 828 },
      -1,
   } },
   /* search2706_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 925, 1 },
      -1,
   } },

   /* replace2706_0 -> 0 in the cache */
   /* replace2706_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2707_0 -> 603 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2707_1_1_0 -> 292 in the cache */
   /* search2707_1_1_1 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 292, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 928, 929 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 603, 930 },
      -1,
   } },

   /* replace2707_0_0 -> 603 in the cache */
   /* replace2707_0_1_0 -> 928 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 928 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 603, 932 },
      -1,
   } },
   /* replace2707_1_0 -> 292 in the cache */
   /* replace2707_1_1 -> 928 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 292, 928 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 933, 934 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2708_1 -> 878 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 937 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 878, 939 },
      -1,
   } },

   /* replace2708_0_0_0 -> 936 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 936, 941 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 942 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 943 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2709_0 -> 688 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2709_1_1_0 -> 302 in the cache */
   /* search2709_1_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 302, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 945, 946 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 688, 947 },
      -1,
   } },

   /* replace2709_0_0 -> 688 in the cache */
   /* replace2709_0_1_0 -> 945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 688, 949 },
      -1,
   } },
   /* replace2709_1_0 -> 302 in the cache */
   /* replace2709_1_1 -> 945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 302, 945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 950, 951 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2710_0 -> 936 in the cache */
   /* search2710_1 -> 805 in the cache */
   /* search2710_2_0_0 -> 937 in the cache */
   /* search2710_2_0 -> 938 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 805, 953 },
      -1,
   } },

   /* replace2710_0_0_0 -> 936 in the cache */
   /* replace2710_0_0_1 -> 941 in the cache */
   /* replace2710_0_0 -> 942 in the cache */
   /* replace2710_0 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 943 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000ull /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2711_1_1_0 -> 312 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000ull /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 312, 958 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 957, 959 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 956, 960 },
      -1,
   } },

   /* replace2711_0_0 -> 956 in the cache */
   /* replace2711_0_1_0 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 957 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 956, 962 },
      -1,
   } },
   /* replace2711_1_0 -> 312 in the cache */
   /* replace2711_1_1 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 312, 957 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 963, 964 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2712_0 -> 936 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0ull /* 0 */ },
   } },
   /* search2712_2_0_0 -> 937 in the cache */
   /* search2712_2_0 -> 938 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 966, 967 },
      -1,
   } },

   /* replace2712_0_0_0 -> 936 in the cache */
   /* replace2712_0_0_1 -> 941 in the cache */
   /* replace2712_0_0 -> 942 in the cache */
   /* replace2712_0 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 943 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2713_0 -> 936 in the cache */
   /* search2713_1_0 -> 625 in the cache */
   /* search2713_1_1 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 625, 627 },
      0,
   } },
   /* search2713_2_0 -> 625 in the cache */
   /* search2713_2_1 -> 628 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 625, 628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 970, 971 },
      -1,
   } },

   /* replace2713_0 -> 625 in the cache */
   /* replace2713_1_0 -> 936 in the cache */
   /* replace2713_1_1 -> 627 in the cache */
   /* replace2713_1_2 -> 628 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 627, 628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 625, 973 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2714_0 -> 936 in the cache */
   /* search2714_1_0 -> 625 in the cache */
   /* search2714_1_1 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 625, 627 },
      -1,
   } },
   /* search2714_2_0 -> 625 in the cache */
   /* search2714_2_1 -> 628 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 625, 628 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 975, 976 },
      -1,
   } },

   /* replace2714_0 -> 625 in the cache */
   /* replace2714_1_0 -> 936 in the cache */
   /* replace2714_1_1 -> 627 in the cache */
   /* replace2714_1_2 -> 628 in the cache */
   /* replace2714_1 -> 973 in the cache */
   /* replace2714 -> 974 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2715_0 -> 936 in the cache */
   /* search2715_1_0 -> 756 in the cache */
   /* search2715_1_1 -> 763 in the cache */
   /* search2715_1_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 756, 763, 764 },
      0,
   } },
   /* search2715_2_0 -> 756 in the cache */
   /* search2715_2_1 -> 763 in the cache */
   /* search2715_2_2 -> 765 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 756, 763, 765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 978, 979 },
      -1,
   } },

   /* replace2715_0 -> 756 in the cache */
   /* replace2715_1 -> 763 in the cache */
   /* replace2715_2_0 -> 936 in the cache */
   /* replace2715_2_1 -> 764 in the cache */
   /* replace2715_2_2 -> 765 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 764, 765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 756, 763, 981 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2716_0 -> 936 in the cache */
   /* search2716_1_0 -> 756 in the cache */
   /* search2716_1_1 -> 763 in the cache */
   /* search2716_1_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 756, 763, 764 },
      -1,
   } },
   /* search2716_2_0 -> 756 in the cache */
   /* search2716_2_1 -> 763 in the cache */
   /* search2716_2_2 -> 765 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 756, 763, 765 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 983, 984 },
      -1,
   } },

   /* replace2716_0 -> 756 in the cache */
   /* replace2716_1 -> 763 in the cache */
   /* replace2716_2_0 -> 936 in the cache */
   /* replace2716_2_1 -> 764 in the cache */
   /* replace2716_2_2 -> 765 in the cache */
   /* replace2716_2 -> 981 in the cache */
   /* replace2716 -> 982 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2717_0 -> 936 in the cache */
   /* search2717_1_0 -> 756 in the cache */
   /* search2717_1_1 -> 763 in the cache */
   /* search2717_1_2 -> 764 in the cache */
   /* search2717_1 -> 978 in the cache */
   /* search2717_2_0 -> 756 in the cache */
   /* search2717_2_1 -> 765 in the cache */
   /* search2717_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 756, 765, 764 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 978, 986 },
      -1,
   } },

   /* replace2717_0 -> 756 in the cache */
   /* replace2717_1_0 -> 936 in the cache */
   /* replace2717_1_1 -> 763 in the cache */
   /* replace2717_1_2 -> 765 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 763, 765 },
      -1,
   } },
   /* replace2717_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 756, 988, 764 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2718_0 -> 936 in the cache */
   /* search2718_1_0 -> 756 in the cache */
   /* search2718_1_1 -> 763 in the cache */
   /* search2718_1_2 -> 764 in the cache */
   /* search2718_1 -> 983 in the cache */
   /* search2718_2_0 -> 756 in the cache */
   /* search2718_2_1 -> 765 in the cache */
   /* search2718_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 756, 765, 764 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 983, 990 },
      -1,
   } },

   /* replace2718_0 -> 756 in the cache */
   /* replace2718_1_0 -> 936 in the cache */
   /* replace2718_1_1 -> 763 in the cache */
   /* replace2718_1_2 -> 765 in the cache */
   /* replace2718_1 -> 988 in the cache */
   /* replace2718_2 -> 764 in the cache */
   /* replace2718 -> 989 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2719_0 -> 936 in the cache */
   /* search2719_1_0 -> 302 in the cache */
   /* search2719_1_1 -> 349 in the cache */
   /* search2719_1_2 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 302, 349, 776 },
      0,
   } },
   /* search2719_2_0 -> 302 in the cache */
   /* search2719_2_1 -> 349 in the cache */
   /* search2719_2_2 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 302, 349, 784 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 992, 993 },
      -1,
   } },

   /* replace2719_0 -> 302 in the cache */
   /* replace2719_1 -> 349 in the cache */
   /* replace2719_2_0 -> 936 in the cache */
   /* replace2719_2_1 -> 776 in the cache */
   /* replace2719_2_2 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 776, 784 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 302, 349, 995 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2720_0 -> 936 in the cache */
   /* search2720_1_0 -> 302 in the cache */
   /* search2720_1_1 -> 349 in the cache */
   /* search2720_1_2 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 302, 349, 776 },
      -1,
   } },
   /* search2720_2_0 -> 302 in the cache */
   /* search2720_2_1 -> 349 in the cache */
   /* search2720_2_2 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 302, 349, 784 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 997, 998 },
      -1,
   } },

   /* replace2720_0 -> 302 in the cache */
   /* replace2720_1 -> 349 in the cache */
   /* replace2720_2_0 -> 936 in the cache */
   /* replace2720_2_1 -> 776 in the cache */
   /* replace2720_2_2 -> 784 in the cache */
   /* replace2720_2 -> 995 in the cache */
   /* replace2720 -> 996 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2721_0 -> 936 in the cache */
   /* search2721_1_0 -> 302 in the cache */
   /* search2721_1_1 -> 349 in the cache */
   /* search2721_1_2 -> 776 in the cache */
   /* search2721_1 -> 992 in the cache */
   /* search2721_2_0 -> 302 in the cache */
   /* search2721_2_1 -> 784 in the cache */
   /* search2721_2_2 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 302, 784, 776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 992, 1000 },
      -1,
   } },

   /* replace2721_0 -> 302 in the cache */
   /* replace2721_1_0 -> 936 in the cache */
   /* replace2721_1_1 -> 349 in the cache */
   /* replace2721_1_2 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 936, 349, 784 },
      -1,
   } },
   /* replace2721_2 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 302, 1002, 776 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2722_0 -> 936 in the cache */
   /* search2722_1_0 -> 302 in the cache */
   /* search2722_1_1 -> 349 in the cache */
   /* search2722_1_2 -> 776 in the cache */
   /* search2722_1 -> 997 in the cache */
   /* search2722_2_0 -> 302 in the cache */
   /* search2722_2_1 -> 784 in the cache */
   /* search2722_2_2 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 302, 784, 776 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 936, 997, 1004 },
      -1,
   } },

   /* replace2722_0 -> 302 in the cache */
   /* replace2722_1_0 -> 936 in the cache */
   /* replace2722_1_1 -> 349 in the cache */
   /* replace2722_1_2 -> 784 in the cache */
   /* replace2722_1 -> 1002 in the cache */
   /* replace2722_2 -> 776 in the cache */
   /* replace2722 -> 1003 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2723_0_0_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1007 },
      -1,
   } },

   /* replace2723_0 -> 300 in the cache */
   /* replace2723 -> 379 in the cache */

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2724_0_0_0 -> 300 in the cache */
   /* search2724_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1009 },
      -1,
   } },

   /* replace2724_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2725_0_0_0 -> 300 in the cache */
   /* search2725_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1012 },
      -1,
   } },

   /* replace2725_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2726_0_0_0 -> 300 in the cache */
   /* search2726_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1015 },
      -1,
   } },

   /* replace2726_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2727_0_0_0 -> 300 in the cache */
   /* search2727_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1018 },
      -1,
   } },

   /* replace2727_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2728_0_0_0 -> 300 in the cache */
   /* search2728_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1021 },
      -1,
   } },

   /* replace2728_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2729_0_0_0 -> 300 in the cache */
   /* search2729_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1024 },
      -1,
   } },

   /* replace2729_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2730_0_0_0 -> 300 in the cache */
   /* search2730_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1027 },
      -1,
   } },

   /* replace2730_0 -> 300 in the cache */
   /* replace2730 -> 375 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2731_0_0_0 -> 300 in the cache */
   /* search2731_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1029 },
      -1,
   } },

   /* replace2731_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2732_0_0_0 -> 300 in the cache */
   /* search2732_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1032 },
      -1,
   } },

   /* replace2732_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2733_0_0_0 -> 300 in the cache */
   /* search2733_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1035 },
      -1,
   } },

   /* replace2733_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2734_0_0_0 -> 300 in the cache */
   /* search2734_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1038 },
      -1,
   } },

   /* replace2734_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2735_0_0_0 -> 300 in the cache */
   /* search2735_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1041 },
      -1,
   } },

   /* replace2735_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2736_0_0_0 -> 300 in the cache */
   /* search2736_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1044 },
      -1,
   } },

   /* replace2736_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2737_0_0_0 -> 300 in the cache */
   /* search2737_0_0 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1047 },
      -1,
   } },

   /* replace2737_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2738_0_0_0 -> 300 in the cache */
   /* search2738_0_0 -> 1006 in the cache */
   /* search2738_0_1_0 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 1051 },
      -1,
   } },

   /* replace2738_0 -> 300 in the cache */
   /* replace2738_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2739_0_0_0 -> 300 in the cache */
   /* search2739_0_0 -> 1006 in the cache */
   /* search2739_0_1_0 -> 302 in the cache */
   /* search2739_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1054 },
      -1,
   } },

   /* replace2739_0 -> 300 in the cache */
   /* replace2739_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2740_0_0_0 -> 300 in the cache */
   /* search2740_0_0 -> 1006 in the cache */
   /* search2740_0_1_0 -> 302 in the cache */
   /* search2740_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 1057 },
      -1,
   } },

   /* replace2740_0 -> 300 in the cache */
   /* replace2740_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2741_0_0_0 -> 300 in the cache */
   /* search2741_0_0 -> 1006 in the cache */
   /* search2741_0_1_0 -> 302 in the cache */
   /* search2741_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 1060 },
      -1,
   } },

   /* replace2741_0 -> 300 in the cache */
   /* replace2741_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2742_0_0_0 -> 300 in the cache */
   /* search2742_0_0 -> 1006 in the cache */
   /* search2742_0_1_0 -> 302 in the cache */
   /* search2742_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1063 },
      -1,
   } },

   /* replace2742_0 -> 300 in the cache */
   /* replace2742_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2743_0_0_0 -> 300 in the cache */
   /* search2743_0_0 -> 1006 in the cache */
   /* search2743_0_1_0 -> 302 in the cache */
   /* search2743_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 1066 },
      -1,
   } },

   /* replace2743_0 -> 300 in the cache */
   /* replace2743_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2744_0_0_0 -> 300 in the cache */
   /* search2744_0_0 -> 1006 in the cache */
   /* search2744_0_1_0 -> 302 in the cache */
   /* search2744_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1069 },
      -1,
   } },

   /* replace2744_0 -> 300 in the cache */
   /* replace2744_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2745_0_0_0 -> 300 in the cache */
   /* search2745_0_0 -> 1006 in the cache */
   /* search2745_0_1_0 -> 302 in the cache */
   /* search2745_0_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 1006, 1050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1072 },
      -1,
   } },

   /* replace2745_0 -> 300 in the cache */
   /* replace2745_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2746_0_0_0 -> 300 in the cache */
   /* search2746_0_0 -> 1006 in the cache */
   /* search2746_0_1_0 -> 302 in the cache */
   /* search2746_0_1 -> 1050 in the cache */
   /* search2746_0_2_0 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 349 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 1006, 1050, 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 1076 },
      -1,
   } },

   /* replace2746_0 -> 300 in the cache */
   /* replace2746_1 -> 302 in the cache */
   /* replace2746_2 -> 349 in the cache */
   /* replace2746 -> 372 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2747_0_0_0 -> 300 in the cache */
   /* search2747_0_0 -> 1006 in the cache */
   /* search2747_0_1_0 -> 302 in the cache */
   /* search2747_0_1 -> 1050 in the cache */
   /* search2747_0_2_0 -> 349 in the cache */
   /* search2747_0_2 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1006, 1050, 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1078 },
      -1,
   } },

   /* replace2747_0 -> 300 in the cache */
   /* replace2747_1 -> 302 in the cache */
   /* replace2747_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 300, 302, 349 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2748_0_0 -> 300 in the cache */
   /* search2748_0 -> 1006 in the cache */
   /* search2748_1_0 -> 302 in the cache */
   /* search2748_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1006, 1050 },
      -1,
   } },

   /* replace2748_0 -> 300 in the cache */
   /* replace2748_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2749_0_0 -> 300 in the cache */
   /* search2749_0 -> 1006 in the cache */
   /* search2749_1_0 -> 302 in the cache */
   /* search2749_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1006, 1050 },
      -1,
   } },

   /* replace2749_0 -> 300 in the cache */
   /* replace2749_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2750_0_0 -> 300 in the cache */
   /* search2750_0 -> 1006 in the cache */
   /* search2750_1_0 -> 302 in the cache */
   /* search2750_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1006, 1050 },
      -1,
   } },

   /* replace2750_0 -> 300 in the cache */
   /* replace2750_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 300, 302 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2751_0_0 -> 300 in the cache */
   /* search2751_0 -> 1006 in the cache */
   /* search2751_1_0 -> 302 in the cache */
   /* search2751_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1006, 1050 },
      -1,
   } },

   /* replace2751_0 -> 300 in the cache */
   /* replace2751_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 300, 302 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2752_0 -> 300 in the cache */
   /* search2752 -> 1006 in the cache */

   /* replace2752_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2753_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 300 },
      -1,
   } },

   /* replace2753_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2754_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 300 },
      -1,
   } },

   /* replace2754_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2755_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 300 },
      -1,
   } },

   /* replace2755_0 -> 300 in the cache */
   /* replace2755 -> 893 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2756_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 300 },
      -1,
   } },

   /* replace2756_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2757_0 -> 300 in the cache */
   /* search2757 -> 1094 in the cache */

   /* replace2757_0 -> 300 in the cache */
   /* replace2757 -> 890 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2758_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 300 },
      -1,
   } },

   /* replace2758_0 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 300 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2759_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 91 },
      -1,
   } },

   /* replace2759_0_0 -> 91 in the cache */
   /* replace2759_0 -> 96 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000ull /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 96, 1100 },
      -1,
   } },

   /* ('f2f16', 'a') => ('f2f16_rtz', 'a') */
   /* search2760_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 91 },
      -1,
   } },

   /* replace2760_0 -> 91 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_f2f16_rtz,
      -1, 0,
      { 91 },
      -1,
   } },

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2761_0_0 -> 805 in the cache */
   /* search2761_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 805, 300 },
      -1,
   } },
   /* search2761_1 -> 302 in the cache */
   /* search2761_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 1104, 302, 349 },
      -1,
   } },

   /* replace2761_0 -> 300 in the cache */
   /* replace2761_1 -> 302 in the cache */
   /* replace2761_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 300, 302, 349 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2762_0_0 -> 300 in the cache */
   /* search2762_0_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 300, 805 },
      -1,
   } },
   /* search2762_1 -> 302 in the cache */
   /* search2762_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 1107, 302, 349 },
      -1,
   } },

   /* replace2762_0_0 -> 300 in the cache */
   /* replace2762_0 -> 375 in the cache */
   /* replace2762_1 -> 302 in the cache */
   /* replace2762_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 375, 302, 349 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2763_0_0 -> 300 in the cache */
   /* search2763_0_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 300, 805 },
      -1,
   } },
   /* search2763_1 -> 302 in the cache */
   /* search2763_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 1110, 302, 349 },
      -1,
   } },

   /* replace2763_0 -> 300 in the cache */
   /* replace2763_1 -> 302 in the cache */
   /* replace2763_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 300, 302, 349 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2764_0_0 -> 805 in the cache */
   /* search2764_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 805, 300 },
      -1,
   } },
   /* search2764_1 -> 302 in the cache */
   /* search2764_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 1113, 302, 349 },
      -1,
   } },

   /* replace2764_0_0 -> 300 in the cache */
   /* replace2764_0 -> 375 in the cache */
   /* replace2764_1 -> 302 in the cache */
   /* replace2764_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 375, 302, 349 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search2765_0_0 -> 805 in the cache */
   /* search2765_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 805, 300 },
      -1,
   } },
   /* search2765_1 -> 302 in the cache */
   /* search2765_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 302, 349 },
      -1,
   } },

   /* replace2765_0 -> 300 in the cache */
   /* replace2765_1 -> 302 in the cache */
   /* replace2765_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 300, 302, 349 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search2766_0_0 -> 300 in the cache */
   /* search2766_0_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 300, 805 },
      -1,
   } },
   /* search2766_1 -> 302 in the cache */
   /* search2766_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1119, 302, 349 },
      -1,
   } },

   /* replace2766_0 -> 300 in the cache */
   /* replace2766_1 -> 349 in the cache */
   /* replace2766_2 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 300, 349, 302 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search2767_0_0 -> 300 in the cache */
   /* search2767_0_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 300, 805 },
      -1,
   } },
   /* search2767_1 -> 302 in the cache */
   /* search2767_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1122, 302, 349 },
      -1,
   } },

   /* replace2767_0 -> 300 in the cache */
   /* replace2767_1 -> 302 in the cache */
   /* replace2767_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 300, 302, 349 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search2768_0_0 -> 805 in the cache */
   /* search2768_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 805, 300 },
      -1,
   } },
   /* search2768_1 -> 302 in the cache */
   /* search2768_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 302, 349 },
      -1,
   } },

   /* replace2768_0 -> 300 in the cache */
   /* replace2768_1 -> 349 in the cache */
   /* replace2768_2 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 300, 349, 302 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2769_0_0 -> 805 in the cache */
   /* search2769_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 805, 300 },
      -1,
   } },
   /* search2769_1 -> 302 in the cache */
   /* search2769_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1128, 302, 349 },
      -1,
   } },

   /* replace2769_0 -> 300 in the cache */
   /* replace2769_1 -> 302 in the cache */
   /* replace2769_2 -> 349 in the cache */
   /* replace2769 -> 1106 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2770_0_0 -> 300 in the cache */
   /* search2770_0_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 300, 805 },
      -1,
   } },
   /* search2770_1 -> 302 in the cache */
   /* search2770_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1130, 302, 349 },
      -1,
   } },

   /* replace2770_0_0 -> 300 in the cache */
   /* replace2770_0 -> 375 in the cache */
   /* replace2770_1 -> 302 in the cache */
   /* replace2770_2 -> 349 in the cache */
   /* replace2770 -> 1109 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2771_0_0 -> 300 in the cache */
   /* search2771_0_1 -> 805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 300, 805 },
      -1,
   } },
   /* search2771_1 -> 302 in the cache */
   /* search2771_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1132, 302, 349 },
      -1,
   } },

   /* replace2771_0 -> 300 in the cache */
   /* replace2771_1 -> 302 in the cache */
   /* replace2771_2 -> 349 in the cache */
   /* replace2771 -> 1112 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2772_0_0 -> 805 in the cache */
   /* search2772_0_1 -> 300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 805, 300 },
      -1,
   } },
   /* search2772_1 -> 302 in the cache */
   /* search2772_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 302, 349 },
      -1,
   } },

   /* replace2772_0_0 -> 300 in the cache */
   /* replace2772_0 -> 375 in the cache */
   /* replace2772_1 -> 302 in the cache */
   /* replace2772_2 -> 349 in the cache */
   /* replace2772 -> 1115 in the cache */

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   is_used_once,
   is_only_used_by_iadd,
   is_only_used_by_fadd,
   is_only_used_as_float,
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_a_number),
   (is_not_const),
   (is_16_bits),
   (is_2x_16_bits),
   (is_neg2x_16_bits),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
   (is_pos_power_of_two),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 439, 158 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 440, 441, 159 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 821, 91, 0 },
   { 823, 91, 0 },
   { 918, 911, 167 },
   { 915, 921, 168 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 821, 91, 0 },
   { 823, 91, 0 },
   { 918, 911, 167 },
   { 915, 921, 168 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 662, 663, 163 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 664, 665, 163 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 666, 667, 163 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 668, 669, 163 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 684, 164 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 687, 689, 19 },
   { 691, 692, 19 },
   { 693, 694, 19 },
   { 695, 696, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 806, 805, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 806, 805, 0 },
   { 810, 815, 147 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 807, 805, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 807, 805, 0 },
   { 816, 820, 147 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 824, 91, 0 },
   { 825, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 826, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1006, 1089, 169 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1090, 1091, 169 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1093, 169 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1094, 893, 169 },
   { 1094, 890, 169 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 169 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1097, 1098, 169 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1101, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 273, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 236, 195, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 227, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 295, 152 },
   { 304, 305, 152 },
   { 314, 315, 152 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 337, 338, 151 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 151 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 324, 325, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 340, 192, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 872, 847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 871, 849, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1106, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1129, 1106, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1129, 1106, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1129, 1106, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1106, 171 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1129, 1106, 171 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1129, 1106, 171 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1129, 1106, 171 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1112, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1133, 1112, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1133, 1112, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1133, 1112, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1112, 171 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1133, 1112, 171 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1133, 1112, 171 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1133, 1112, 171 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1117, 1118, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1117, 1118, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1117, 1118, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1117, 1118, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1117, 1118, 172 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1117, 1118, 172 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1117, 1118, 172 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1117, 1118, 172 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1123, 1124, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1123, 1124, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1123, 1124, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1123, 1124, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1123, 1124, 172 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 972, 974, 0 },
   { 977, 974, 0 },
   { 1123, 1124, 172 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 982, 0 },
   { 985, 982, 0 },
   { 987, 989, 0 },
   { 991, 989, 0 },
   { 1123, 1124, 172 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 996, 0 },
   { 999, 996, 0 },
   { 1001, 1003, 0 },
   { 1005, 1003, 0 },
   { 1123, 1124, 172 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 645, 646, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 289, 151 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 612, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 643, 644, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1085, 1086, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 91, 0 },
   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 649, 623, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 647, 648, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 638, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 617, 194, 0 },
   { 622, 623, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1083, 1084, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 652, 653, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 618, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 639, 640, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1081, 1082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 650, 651, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 619, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 641, 642, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1087, 1088, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 724, 727, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 672, 674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 728, 730, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 698, 689, 19 },
   { 700, 692, 19 },
   { 701, 694, 19 },
   { 702, 696, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 388, 389, 35 },
   { 402, 403, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 606, 608, 162 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 600, 605, 162 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 600, 605, 162 },
   { 606, 608, 162 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 716, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 91, 0 },
   { 914, 903, 167 },
   { 917, 907, 167 },
   { 920, 911, 167 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 91, 0 },
   { 914, 903, 167 },
   { 917, 907, 167 },
   { 920, 911, 167 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 299, 152 },
   { 308, 309, 152 },
   { 318, 319, 152 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 95, 97, 0 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 841, 840, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 836, 838, 166 },
   { 841, 840, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 859, 860, 166 },
   { 863, 862, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 866, 860, 166 },
   { 869, 862, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 842, 838, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 839, 840, 166 },
   { 842, 838, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 861, 862, 166 },
   { 864, 860, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 867, 862, 166 },
   { 870, 860, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 875, 847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 855, 849, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 853, 849, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 874, 849, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 857, 847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 856, 847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 446, 448, 160 },
   { 487, 488, 160 },
   { 526, 527, 160 },
   { 565, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 446, 448, 160 },
   { 451, 448, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 464, 465, 160 },
   { 503, 504, 160 },
   { 542, 543, 160 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 446, 448, 160 },
   { 453, 448, 160 },
   { 487, 488, 160 },
   { 493, 488, 160 },
   { 526, 527, 160 },
   { 532, 527, 160 },
   { 565, 566, 161 },
   { 571, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 446, 448, 160 },
   { 451, 448, 160 },
   { 453, 448, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 493, 488, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 532, 527, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { 571, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 464, 465, 160 },
   { 467, 465, 160 },
   { 503, 504, 160 },
   { 506, 504, 160 },
   { 542, 543, 160 },
   { 545, 543, 160 },
   { 581, 582, 161 },
   { 584, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 446, 448, 160 },
   { 487, 488, 160 },
   { 526, 527, 160 },
   { 565, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 487, 488, 160 },
   { 526, 527, 160 },
   { 565, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 446, 448, 160 },
   { 464, 465, 160 },
   { 487, 488, 160 },
   { 503, 504, 160 },
   { 526, 527, 160 },
   { 542, 543, 160 },
   { 565, 566, 161 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 446, 448, 160 },
   { 451, 448, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 451, 448, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 446, 448, 160 },
   { 451, 448, 160 },
   { 464, 465, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 503, 504, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 542, 543, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 435, 436, 157 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 464, 465, 160 },
   { 503, 504, 160 },
   { 542, 543, 160 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 464, 465, 160 },
   { 503, 504, 160 },
   { 542, 543, 160 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 439, 158 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 439, 158 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 439, 158 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 474, 476, 160 },
   { 513, 515, 160 },
   { 552, 554, 160 },
   { 591, 593, 161 },
   { 821, 91, 0 },
   { 823, 91, 0 },
   { 918, 911, 167 },
   { 915, 921, 168 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 821, 91, 0 },
   { 823, 91, 0 },
   { 902, 903, 167 },
   { 905, 907, 167 },
   { 909, 911, 167 },
   { 918, 911, 167 },
   { 915, 921, 168 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 829, 827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 831, 827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 832, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 833, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 923, 924, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 877, 879, 71 },
   { 886, 887, 71 },
   { 891, 892, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 881, 879, 71 },
   { 889, 887, 71 },
   { 894, 892, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 882, 883, 71 },
   { 895, 896, 71 },
   { 898, 899, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 884, 883, 71 },
   { 897, 896, 71 },
   { 900, 899, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 926, 927, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 684, 164 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1108, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1105, 1106, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1105, 1106, 171 },
   { 1108, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1111, 1112, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1114, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1111, 1112, 171 },
   { 1114, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 236, 195, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 236, 195, 0 },
   { 249, 189, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 181, 0 },
   { 236, 195, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 181, 0 },
   { 236, 195, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 181, 0 },
   { 236, 195, 0 },
   { 249, 189, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 167, 0 },
   { 236, 195, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 167, 0 },
   { 236, 195, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 167, 0 },
   { 236, 195, 0 },
   { 249, 189, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 227, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 227, 0 },
   { 257, 223, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 219, 0 },
   { 244, 227, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 219, 0 },
   { 244, 227, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 219, 0 },
   { 244, 227, 0 },
   { 257, 223, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 211, 0 },
   { 244, 227, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 211, 0 },
   { 244, 227, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 211, 0 },
   { 244, 227, 0 },
   { 257, 223, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { 281, 282, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { 278, 279, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 278, 279, 151 },
   { 281, 282, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 181, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 177, 179, 0 },
   { 180, 181, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 175, 0 },
   { 180, 181, 0 },
   { 187, 189, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 167, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 161, 163, 0 },
   { 165, 167, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { 165, 167, 0 },
   { 187, 189, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 222, 223, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 0 },
   { 218, 219, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 214, 215, 0 },
   { 218, 219, 0 },
   { 222, 223, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 210, 211, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 209, 0 },
   { 210, 211, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 207, 0 },
   { 210, 211, 0 },
   { 222, 223, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 120, 121, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 123, 124, 0 },
   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 118, 0 },
   { 120, 121, 0 },
   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 115, 0 },
   { 120, 121, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 645, 646, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 645, 646, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 643, 644, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 643, 644, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 649, 623, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 649, 623, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 638, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 647, 648, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 647, 648, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 638, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 178, 638, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 632, 637, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 652, 653, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 639, 640, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 639, 640, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 650, 651, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 641, 642, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 641, 642, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 659, 661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 931, 935, 16 },
   { 948, 952, 18 },
   { 961, 965, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 698, 689, 19 },
   { 700, 692, 19 },
   { 701, 694, 19 },
   { 702, 696, 19 },
   { 931, 935, 16 },
   { 948, 952, 18 },
   { 961, 965, 20 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 357, 359, 34 },
   { 371, 372, 35 },
   { 374, 376, 35 },
   { 402, 403, 36 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 391, 392, 35 },
   { 402, 403, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 361, 364, 34 },
   { 371, 372, 35 },
   { 378, 381, 35 },
   { 402, 403, 36 },
   { 409, 412, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 394, 395, 35 },
   { 402, 403, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 388, 389, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 388, 389, 35 },
   { 409, 412, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 394, 395, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 391, 392, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 361, 364, 34 },
   { 374, 376, 35 },
   { 378, 381, 35 },
   { 405, 407, 36 },
   { 409, 412, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 394, 395, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 391, 392, 35 },
   { 409, 412, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 394, 395, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 762, 767, 165 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 394, 395, 35 },
   { 409, 412, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 711, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 714, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 708, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 708, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 708, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 714, 712, 19 },
   { 716, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 687, 689, 19 },
   { 691, 692, 19 },
   { 693, 694, 19 },
   { 695, 696, 19 },
   { 707, 708, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 708, 19 },
   { 711, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 708, 19 },
   { 714, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 708, 19 },
   { 716, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1028, 375, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1061, 1062, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1080, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1067, 1068, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1059, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1052, 1053, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1077, 372, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1008, 379, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1039, 1040, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1033, 1034, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1049, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1036, 1037, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1010, 1011, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1013, 1014, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1016, 1017, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1019, 1020, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1022, 1023, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1025, 1026, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1030, 1031, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1045, 1046, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1064, 1065, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1070, 1071, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1074, 0 },
   { 1102, 1103, 170 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1129, 1106, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1129, 1106, 171 },
   { 1131, 1109, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1133, 1112, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1133, 1112, 171 },
   { 1135, 1115, 171 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1117, 1118, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1117, 1118, 172 },
   { 1120, 1121, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1123, 1124, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 940, 944, 0 },
   { 954, 955, 0 },
   { 968, 969, 0 },
   { 1123, 1124, 172 },
   { 1126, 1127, 172 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 736, 737, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 266, 267, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 95, 97, 0 },
   { 269, 270, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 95, 97, 0 },
   { 266, 267, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 266, 267, 151 },
   { 269, 270, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 80, 0 },
   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 67, 70, 0 },
   { 72, 75, 0 },
   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 65, 0 },
   { 72, 75, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 718, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 718, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 718, 712, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 846, 847, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 836, 838, 166 },
   { 841, 840, 166 },
   { 846, 847, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 850, 849, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 841, 840, 166 },
   { 850, 849, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 848, 849, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 839, 840, 166 },
   { 842, 838, 166 },
   { 848, 849, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 851, 847, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 842, 838, 166 },
   { 851, 847, 166 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 495, 498, 160 },
   { 534, 537, 160 },
   { 573, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 469, 470, 160 },
   { 508, 509, 160 },
   { 547, 548, 160 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 461, 458, 160 },
   { 495, 498, 160 },
   { 501, 498, 160 },
   { 534, 537, 160 },
   { 540, 537, 160 },
   { 573, 576, 161 },
   { 579, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 461, 458, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 501, 498, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 540, 537, 160 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { 579, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 469, 470, 160 },
   { 471, 470, 160 },
   { 508, 509, 160 },
   { 510, 509, 160 },
   { 547, 548, 160 },
   { 549, 548, 160 },
   { 586, 587, 161 },
   { 588, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 455, 458, 160 },
   { 487, 488, 160 },
   { 495, 498, 160 },
   { 526, 527, 160 },
   { 534, 537, 160 },
   { 565, 566, 161 },
   { 573, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 487, 488, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 526, 527, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 565, 566, 161 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 469, 470, 160 },
   { 487, 488, 160 },
   { 508, 509, 160 },
   { 526, 527, 160 },
   { 547, 548, 160 },
   { 565, 566, 161 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 451, 448, 160 },
   { 455, 458, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 495, 498, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 534, 537, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { 573, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 451, 448, 160 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 446, 448, 160 },
   { 451, 448, 160 },
   { 469, 470, 160 },
   { 487, 488, 160 },
   { 491, 488, 160 },
   { 508, 509, 160 },
   { 526, 527, 160 },
   { 530, 527, 160 },
   { 547, 548, 160 },
   { 565, 566, 161 },
   { 569, 566, 161 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 435, 436, 157 },
   { 455, 458, 160 },
   { 495, 498, 160 },
   { 534, 537, 160 },
   { 573, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 435, 436, 157 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 350, 351, 153 },
   { 435, 436, 157 },
   { 469, 470, 160 },
   { 508, 509, 160 },
   { 547, 548, 160 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 464, 465, 160 },
   { 495, 498, 160 },
   { 503, 504, 160 },
   { 534, 537, 160 },
   { 542, 543, 160 },
   { 573, 576, 161 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 464, 465, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 503, 504, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 542, 543, 160 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { 581, 582, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 464, 465, 160 },
   { 469, 470, 160 },
   { 503, 504, 160 },
   { 508, 509, 160 },
   { 542, 543, 160 },
   { 547, 548, 160 },
   { 581, 582, 161 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 469, 470, 160 },
   { 495, 498, 160 },
   { 508, 509, 160 },
   { 534, 537, 160 },
   { 547, 548, 160 },
   { 573, 576, 161 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 157 },
   { 455, 458, 160 },
   { 460, 458, 160 },
   { 469, 470, 160 },
   { 495, 498, 160 },
   { 500, 498, 160 },
   { 508, 509, 160 },
   { 534, 537, 160 },
   { 539, 537, 160 },
   { 547, 548, 160 },
   { 573, 576, 161 },
   { 578, 576, 161 },
   { 586, 587, 161 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 480, 482, 160 },
   { 519, 521, 160 },
   { 558, 560, 160 },
   { 597, 599, 161 },
   { 821, 91, 0 },
   { 823, 91, 0 },
   { 918, 911, 167 },
   { 915, 921, 168 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 236, 195, 0 },
   { 247, 185, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 181, 0 },
   { 236, 195, 0 },
   { 247, 185, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 167, 0 },
   { 236, 195, 0 },
   { 247, 185, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 151, 0 },
   { 234, 181, 0 },
   { 236, 195, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 151, 0 },
   { 234, 181, 0 },
   { 236, 195, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 151, 0 },
   { 234, 181, 0 },
   { 236, 195, 0 },
   { 249, 189, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 151, 0 },
   { 234, 181, 0 },
   { 236, 195, 0 },
   { 247, 185, 0 },
   { 251, 191, 0 },
   { 253, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 227, 0 },
   { 255, 221, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 219, 0 },
   { 244, 227, 0 },
   { 255, 221, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 211, 0 },
   { 244, 227, 0 },
   { 255, 221, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 203, 0 },
   { 242, 219, 0 },
   { 244, 227, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 203, 0 },
   { 242, 219, 0 },
   { 244, 227, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 203, 0 },
   { 242, 219, 0 },
   { 244, 227, 0 },
   { 257, 223, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 203, 0 },
   { 242, 219, 0 },
   { 244, 227, 0 },
   { 255, 221, 0 },
   { 259, 225, 0 },
   { 261, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 151 },
   { 281, 282, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { 275, 276, 151 },
   { 281, 282, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 151 },
   { 278, 279, 151 },
   { 281, 282, 151 },
   { 284, 285, 151 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 183, 185, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 171, 0 },
   { 177, 179, 0 },
   { 180, 181, 0 },
   { 183, 185, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 161, 163, 0 },
   { 165, 167, 0 },
   { 183, 185, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 151, 0 },
   { 180, 181, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 149, 151, 0 },
   { 177, 179, 0 },
   { 180, 181, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 149, 151, 0 },
   { 173, 175, 0 },
   { 180, 181, 0 },
   { 187, 189, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 139, 0 },
   { 145, 147, 0 },
   { 149, 151, 0 },
   { 169, 171, 0 },
   { 177, 179, 0 },
   { 180, 181, 0 },
   { 183, 185, 0 },
   { 190, 191, 0 },
   { 193, 195, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 220, 221, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 212, 213, 0 },
   { 216, 217, 0 },
   { 218, 219, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 205, 0 },
   { 208, 209, 0 },
   { 210, 211, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 203, 0 },
   { 218, 219, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 200, 201, 0 },
   { 202, 203, 0 },
   { 216, 217, 0 },
   { 218, 219, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 199, 0 },
   { 202, 203, 0 },
   { 214, 215, 0 },
   { 218, 219, 0 },
   { 222, 223, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 197, 0 },
   { 200, 201, 0 },
   { 202, 203, 0 },
   { 212, 213, 0 },
   { 216, 217, 0 },
   { 218, 219, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 226, 227, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 0 },
   { 111, 112, 0 },
   { 123, 124, 0 },
   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 0 },
   { 111, 112, 0 },
   { 117, 118, 0 },
   { 120, 121, 0 },
   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 108, 109, 0 },
   { 111, 112, 0 },
   { 123, 124, 0 },
   { 126, 127, 0 },
   { 129, 130, 0 },
   { 654, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 151 },
   { 269, 270, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 95, 97, 0 },
   { 263, 264, 151 },
   { 269, 270, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 151 },
   { 266, 267, 151 },
   { 269, 270, 151 },
   { 272, 273, 151 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 60, 0 },
   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 55, 0 },
   { 57, 60, 0 },
   { 77, 80, 0 },
   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 47, 50, 0 },
   { 57, 60, 0 },
   { 67, 70, 0 },
   { 72, 75, 0 },
   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 42, 45, 0 },
   { 52, 55, 0 },
   { 57, 60, 0 },
   { 77, 80, 0 },
   { 82, 85, 0 },
   { 87, 90, 0 },
   { 655, 91, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 367, 369, 34 },
   { 371, 372, 35 },
   { 384, 386, 35 },
   { 402, 403, 36 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 398, 399, 35 },
   { 402, 403, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 388, 389, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 367, 369, 34 },
   { 374, 376, 35 },
   { 384, 386, 35 },
   { 405, 407, 36 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 398, 399, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 391, 392, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 754, 165 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 762, 767, 165 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 367, 369, 34 },
   { 378, 381, 35 },
   { 384, 386, 35 },
   { 409, 412, 36 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 398, 399, 35 },
   { 409, 412, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 394, 395, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 754, 165 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 783, 789, 165 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 754, 165 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 398, 399, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 433, 156 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 354, 355, 34 },
   { 371, 372, 35 },
   { 402, 403, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 357, 359, 34 },
   { 374, 376, 35 },
   { 405, 407, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 762, 767, 165 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 361, 364, 34 },
   { 378, 381, 35 },
   { 409, 412, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { 795, 797, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 795, 797, 165 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 748, 754, 165 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 367, 369, 34 },
   { 384, 386, 35 },
   { 415, 417, 36 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 398, 399, 35 },
   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { 783, 789, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 783, 789, 165 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 422, 154 },
   { 424, 425, 154 },
   { 427, 428, 154 },
   { 430, 431, 155 },
   { 769, 775, 165 },
   { 799, 804, 165 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         3,
         8,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         155,
         156,
         2,
         2,
         155,
         373,
         4,
         5,
         157,
         158,
         159,
         160,
         4,
         374,
         375,
         2,
         161,
         2,
         155,
         156,
         2,
         2,
         155,
         373,
         162,
         163,
         162,
         164,
         165,
         162,
         162,
         164,
         376,
         166,
         167,
         166,
         168,
         169,
         166,
         166,
         168,
         377,
         2,
         3,
         2,
         155,
         156,
         2,
         2,
         155,
         373,
         2,
         3,
         2,
         155,
         156,
         2,
         170,
         155,
         373,
         162,
         378,
         162,
         164,
         165,
         162,
         162,
         164,
         376,
         379,
         380,
         379,
         381,
         382,
         379,
         379,
         381,
         383,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         7,
         8,
         9,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         3,
         11,
         4,
         10,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         12,
         0,
         12,
         16,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         6,
         7,
         228,
         229,
         229,
         230,
         6,
         406,
         407,
         228,
         229,
         229,
         408,
         409,
         410,
         411,
         590,
         591,
         592,
         593,
         640,
         641,
         7,
         7,
         231,
         232,
         233,
         234,
         7,
         412,
         413,
         414,
         415,
         416,
         417,
         418,
         419,
         420,
         594,
         595,
         596,
         597,
         642,
         643,
         228,
         231,
         228,
         235,
         235,
         236,
         228,
         406,
         407,
         228,
         235,
         235,
         421,
         422,
         423,
         424,
         598,
         591,
         592,
         599,
         640,
         641,
         229,
         232,
         235,
         229,
         229,
         237,
         229,
         425,
         426,
         235,
         229,
         229,
         427,
         428,
         429,
         430,
         600,
         601,
         602,
         603,
         644,
         645,
         229,
         233,
         235,
         229,
         229,
         237,
         229,
         425,
         426,
         235,
         229,
         229,
         427,
         428,
         429,
         430,
         600,
         601,
         602,
         603,
         644,
         645,
         230,
         234,
         236,
         237,
         237,
         230,
         230,
         431,
         432,
         236,
         237,
         237,
         433,
         434,
         435,
         436,
         604,
         605,
         606,
         607,
         646,
         647,
         6,
         7,
         228,
         229,
         229,
         230,
         238,
         406,
         407,
         228,
         229,
         229,
         408,
         409,
         410,
         411,
         590,
         591,
         592,
         593,
         640,
         641,
         406,
         412,
         406,
         425,
         425,
         431,
         406,
         406,
         437,
         406,
         425,
         425,
         438,
         439,
         440,
         441,
         608,
         609,
         610,
         611,
         648,
         649,
         407,
         413,
         407,
         426,
         426,
         432,
         407,
         437,
         407,
         407,
         426,
         426,
         442,
         443,
         444,
         445,
         612,
         613,
         614,
         615,
         650,
         651,
         228,
         414,
         228,
         235,
         235,
         236,
         228,
         406,
         407,
         228,
         235,
         235,
         421,
         422,
         423,
         424,
         598,
         591,
         592,
         599,
         640,
         641,
         229,
         415,
         235,
         229,
         229,
         237,
         229,
         425,
         426,
         235,
         229,
         229,
         427,
         428,
         429,
         430,
         600,
         601,
         602,
         603,
         644,
         645,
         229,
         416,
         235,
         229,
         229,
         237,
         229,
         425,
         426,
         235,
         229,
         229,
         427,
         428,
         429,
         430,
         600,
         601,
         602,
         603,
         644,
         645,
         408,
         417,
         421,
         427,
         427,
         433,
         408,
         438,
         442,
         421,
         427,
         427,
         408,
         446,
         447,
         448,
         616,
         617,
         618,
         619,
         652,
         653,
         409,
         418,
         422,
         428,
         428,
         434,
         409,
         439,
         443,
         422,
         428,
         428,
         446,
         409,
         449,
         450,
         620,
         621,
         622,
         623,
         654,
         655,
         410,
         419,
         423,
         429,
         429,
         435,
         410,
         440,
         444,
         423,
         429,
         429,
         447,
         449,
         410,
         451,
         624,
         625,
         626,
         627,
         656,
         657,
         411,
         420,
         424,
         430,
         430,
         436,
         411,
         441,
         445,
         424,
         430,
         430,
         448,
         450,
         451,
         411,
         628,
         629,
         630,
         631,
         658,
         659,
         590,
         594,
         598,
         600,
         600,
         604,
         590,
         608,
         612,
         598,
         600,
         600,
         616,
         620,
         624,
         628,
         590,
         632,
         633,
         634,
         660,
         661,
         591,
         595,
         591,
         601,
         601,
         605,
         591,
         609,
         613,
         591,
         601,
         601,
         617,
         621,
         625,
         629,
         632,
         591,
         635,
         636,
         662,
         663,
         592,
         596,
         592,
         602,
         602,
         606,
         592,
         610,
         614,
         592,
         602,
         602,
         618,
         622,
         626,
         630,
         633,
         635,
         592,
         637,
         664,
         665,
         593,
         597,
         599,
         603,
         603,
         607,
         593,
         611,
         615,
         599,
         603,
         603,
         619,
         623,
         627,
         631,
         634,
         636,
         637,
         593,
         666,
         667,
         640,
         642,
         640,
         644,
         644,
         646,
         640,
         648,
         650,
         640,
         644,
         644,
         652,
         654,
         656,
         658,
         660,
         662,
         664,
         666,
         640,
         668,
         641,
         643,
         641,
         645,
         645,
         647,
         641,
         649,
         651,
         641,
         645,
         645,
         653,
         655,
         657,
         659,
         661,
         663,
         665,
         667,
         668,
         641,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         10,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         8,
         171,
         172,
         173,
         174,
         175,
         176,
         177,
         545,
         546,
         638,
         639,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         3,
         8,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         9,
         10,
         9,
         178,
         179,
         9,
         9,
         178,
         384,
         9,
         11,
         12,
         180,
         181,
         182,
         11,
         11,
         385,
         386,
         11,
         9,
         183,
         9,
         178,
         179,
         9,
         9,
         178,
         384,
         9,
         184,
         185,
         184,
         186,
         187,
         184,
         184,
         186,
         387,
         184,
         188,
         189,
         188,
         190,
         191,
         188,
         188,
         190,
         388,
         188,
         9,
         192,
         9,
         178,
         179,
         9,
         9,
         178,
         384,
         9,
         9,
         10,
         9,
         178,
         179,
         9,
         193,
         178,
         384,
         9,
         184,
         389,
         184,
         186,
         187,
         184,
         184,
         186,
         387,
         184,
         390,
         391,
         390,
         392,
         393,
         390,
         390,
         392,
         394,
         390,
         9,
         395,
         9,
         178,
         179,
         9,
         9,
         178,
         384,
         9,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         8,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         13,
         14,
         13,
         194,
         195,
         13,
         13,
         13,
         396,
         14,
         14,
         196,
         197,
         198,
         199,
         200,
         14,
         397,
         13,
         196,
         13,
         194,
         195,
         13,
         13,
         13,
         396,
         194,
         197,
         194,
         201,
         202,
         194,
         194,
         194,
         398,
         195,
         198,
         195,
         202,
         203,
         195,
         195,
         195,
         399,
         13,
         199,
         13,
         194,
         195,
         13,
         13,
         13,
         396,
         13,
         200,
         13,
         194,
         195,
         13,
         13,
         13,
         396,
         13,
         14,
         13,
         194,
         195,
         13,
         13,
         204,
         396,
         396,
         397,
         396,
         398,
         399,
         396,
         396,
         396,
         400,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         7,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         15,
         16,
         15,
         205,
         206,
         15,
         15,
         401,
         16,
         16,
         207,
         208,
         209,
         210,
         16,
         402,
         15,
         207,
         15,
         205,
         206,
         15,
         15,
         401,
         205,
         208,
         205,
         211,
         212,
         205,
         205,
         403,
         206,
         209,
         206,
         212,
         213,
         206,
         206,
         404,
         15,
         210,
         15,
         205,
         206,
         15,
         15,
         401,
         15,
         16,
         15,
         205,
         206,
         15,
         214,
         401,
         401,
         402,
         401,
         403,
         404,
         401,
         401,
         405,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         8,
         9,
         4,
         10,
         11,
         4,
         12,
         13,
         14,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         16,
         17,
         18,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         17,
         18,
         17,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         18,
         18,
         18,
         18,
         246,
         247,
         248,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         17,
         18,
         249,
         250,
         251,
         17,
         245,
         245,
         502,
         503,
         504,
         505,
         502,
         506,
         503,
         17,
         583,
         584,
         583,
         585,
         583,
         17,
         18,
         250,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         507,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         251,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         507,
         17,
         17,
         17,
         17,
         17,
         17,
         246,
         17,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         245,
         247,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         248,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         245,
         17,
         18,
         502,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         508,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         503,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         509,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         504,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         508,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         505,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         509,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         502,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         510,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         506,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         511,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         503,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         512,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         17,
         507,
         507,
         17,
         245,
         245,
         508,
         509,
         508,
         509,
         510,
         511,
         512,
         17,
         586,
         586,
         587,
         588,
         589,
         17,
         18,
         583,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         586,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         584,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         586,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         583,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         587,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         585,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         588,
         17,
         17,
         17,
         17,
         17,
         17,
         18,
         583,
         17,
         17,
         17,
         245,
         245,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         589,
         17,
         17,
         17,
         17,
         17,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         291,
         292,
         293,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         1,
         7,
         8,
         1,
         1,
         9,
         9,
         10,
         11,
         12,
         12,
         13,
         14,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         2,
         15,
         16,
         2,
         17,
         17,
         18,
         19,
         20,
         20,
         21,
         22,
         2,
         2,
         23,
         24,
         4,
         25,
         26,
         4,
         4,
         27,
         28,
         29,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         7,
         30,
         31,
         32,
         9,
         33,
         33,
         34,
         35,
         36,
         37,
         15,
         37,
         38,
         39,
         17,
         40,
         40,
         41,
         42,
         43,
         2,
         44,
         45,
         46,
         47,
         48,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 49,
      .table = (const uint16_t []) {
      
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         87,
         328,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         88,
         329,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         89,
         330,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         90,
         330,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         87,
         88,
         89,
         90,
         91,
         20,
         331,
         332,
         333,
         334,
         335,
         336,
         337,
         338,
         339,
         340,
         341,
         342,
         343,
         344,
         345,
         346,
         347,
         348,
         349,
         350,
         347,
         351,
         348,
         548,
         549,
         550,
         551,
         552,
         553,
         554,
         555,
         556,
         557,
         558,
         559,
         560,
         561,
         562,
         563,
         562,
         564,
         562,
         20,
         328,
         329,
         330,
         330,
         20,
         20,
         352,
         353,
         354,
         355,
         356,
         357,
         358,
         359,
         360,
         361,
         362,
         363,
         364,
         365,
         366,
         367,
         368,
         369,
         368,
         369,
         370,
         371,
         372,
         565,
         566,
         567,
         568,
         569,
         570,
         571,
         572,
         573,
         574,
         575,
         576,
         577,
         578,
         579,
         579,
         580,
         581,
         582,
         20,
         86,
         20,
         20,
         20,
         331,
         352,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         332,
         353,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         333,
         354,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         334,
         355,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         335,
         356,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         336,
         357,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         337,
         358,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         338,
         359,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         339,
         360,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         340,
         361,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         341,
         362,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         342,
         363,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         343,
         364,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         344,
         365,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         345,
         366,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         346,
         367,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         347,
         368,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         348,
         369,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         349,
         368,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         350,
         369,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         347,
         370,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         351,
         371,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         348,
         372,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         548,
         565,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         549,
         566,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         550,
         567,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         551,
         568,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         552,
         569,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         553,
         570,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         20,
         20,
         20,
         554,
         571,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         86,
         86,
         86,
         86,
         86,
         86,
         86,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         555,
         572,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         556,
         573,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         557,
         574,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         558,
         575,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         559,
         576,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         560,
         577,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         561,
         578,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         562,
         579,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         563,
         579,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         562,
         580,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         564,
         581,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         562,
         582,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         21,
         92,
         93,
         94,
         95,
         96,
         97,
         98,
         99,
         100,
         101,
         102,
         103,
      },
   },
   [nir_op_ford] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_funord] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         23,
      },
   },
   [nir_op_fequ] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         24,
      },
   },
   [nir_op_fneo] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         25,
      },
   },
   [nir_op_fgeu] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         26,
      },
   },
   [nir_op_fltu] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         27,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         5,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         7,
         8,
         9,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         28,
         29,
         267,
         268,
         269,
         270,
         271,
         524,
         525,
         526,
         29,
         29,
         272,
         273,
         274,
         275,
         276,
         527,
         528,
         529,
         267,
         272,
         267,
         268,
         277,
         278,
         279,
         530,
         531,
         532,
         268,
         273,
         268,
         268,
         280,
         281,
         282,
         533,
         534,
         535,
         269,
         274,
         277,
         280,
         269,
         283,
         284,
         536,
         537,
         538,
         270,
         275,
         278,
         281,
         283,
         270,
         285,
         524,
         525,
         526,
         271,
         276,
         279,
         282,
         284,
         285,
         271,
         539,
         540,
         541,
         524,
         527,
         530,
         533,
         536,
         524,
         539,
         524,
         525,
         542,
         525,
         528,
         531,
         534,
         537,
         525,
         540,
         525,
         525,
         543,
         526,
         529,
         532,
         535,
         538,
         526,
         541,
         542,
         543,
         526,
      },
   },
   [nir_op_imul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         30,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         31,
         32,
         220,
         221,
         31,
         513,
         32,
         32,
         222,
         223,
         32,
         514,
         220,
         222,
         220,
         224,
         220,
         513,
         221,
         223,
         224,
         221,
         221,
         515,
         31,
         32,
         220,
         221,
         225,
         513,
         513,
         514,
         513,
         515,
         513,
         513,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         33,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         34,
         286,
         287,
         288,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         35,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         0,
         36,
         0,
         0,
         0,
         37,
         38,
         37,
         37,
         37,
         0,
         289,
         0,
         0,
         0,
         0,
         290,
         0,
         0,
         0,
         0,
         544,
         0,
         0,
         0,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         239,
         240,
         241,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         39,
         305,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         215,
         215,
         0,
         0,
         215,
         216,
         0,
         0,
         0,
         0,
         217,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         40,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         41,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         42,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         43,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         218,
         218,
         218,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         219,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         44,
         306,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         6,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         46,
         45,
         242,
         243,
         45,
         453,
         454,
         458,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         46,
         45,
         242,
         243,
         45,
         453,
         454,
         458,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         455,
         459,
         455,
         456,
         456,
         455,
         460,
         461,
         461,
         455,
         457,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         46,
         45,
         242,
         243,
         45,
         453,
         454,
         458,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         455,
         455,
         455,
         456,
         462,
         455,
         455,
         456,
         462,
         455,
         457,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         244,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         46,
         45,
         242,
         243,
         45,
         453,
         454,
         458,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         455,
         455,
         455,
         456,
         462,
         455,
         455,
         456,
         462,
         455,
         457,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         459,
         455,
         456,
         456,
         455,
         460,
         461,
         461,
         455,
         457,
         455,
         455,
         455,
         456,
         462,
         455,
         455,
         456,
         462,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         455,
         455,
         456,
         462,
         455,
         455,
         456,
         462,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         46,
         45,
         242,
         242,
         45,
         453,
         454,
         454,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         243,
         45,
         45,
         242,
         243,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
         455,
         455,
         455,
         456,
         456,
         455,
         455,
         456,
         456,
         455,
         457,
         45,
         45,
         45,
         242,
         242,
         45,
         45,
         242,
         242,
         45,
         452,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         0,
         227,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         5,
         5,
         0,
         0,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         6,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         489,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         108,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         109,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         110,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         107,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         490,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         112,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         113,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         114,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         111,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         491,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         116,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         117,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         118,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         115,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         492,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         120,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         121,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         122,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         493,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         124,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         125,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         126,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         494,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         128,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         129,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         130,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         495,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         132,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         133,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         134,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         131,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         496,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         136,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         137,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         138,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         135,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         497,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         140,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         141,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         142,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         139,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         498,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         144,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         145,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         146,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         143,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         499,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         148,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         149,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         150,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         147,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         500,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         152,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         153,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         154,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         151,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         501,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         488,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         104,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         105,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         106,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         47,
         307,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         48,
         308,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
         49,
         294,
         547,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         50,
         0,
         51,
         0,
         50,
         0,
         51,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         52,
         0,
         53,
         0,
         52,
         0,
         53,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         54,
         55,
         54,
         55,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         56,
         57,
         56,
         57,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         295,
         58,
         58,
         58,
         296,
         58,
         58,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         59,
         60,
         59,
         59,
         59,
         60,
         59,
         59,
         59,
         297,
         59,
         59,
         59,
         298,
         59,
         59,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         2,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         252,
         0,
         0,
         0,
         0,
         252,
         0,
         0,
         253,
         0,
         254,
         255,
         516,
         517,
         252,
         253,
         252,
         252,
         252,
         252,
         252,
         252,
         0,
         0,
         252,
         0,
         0,
         0,
         518,
         519,
         0,
         254,
         252,
         0,
         0,
         0,
         0,
         252,
         0,
         255,
         252,
         0,
         0,
         0,
         0,
         252,
         0,
         516,
         252,
         518,
         0,
         0,
         0,
         252,
         252,
         517,
         252,
         519,
         252,
         252,
         252,
         252,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         2,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         256,
         0,
         0,
         0,
         0,
         256,
         0,
         0,
         257,
         0,
         258,
         259,
         520,
         521,
         256,
         257,
         256,
         256,
         256,
         256,
         256,
         256,
         0,
         0,
         256,
         0,
         0,
         0,
         522,
         523,
         0,
         258,
         256,
         0,
         0,
         0,
         0,
         256,
         0,
         259,
         256,
         0,
         0,
         0,
         0,
         256,
         0,
         520,
         256,
         522,
         0,
         0,
         0,
         256,
         256,
         521,
         256,
         523,
         256,
         256,
         256,
         256,
      },
   },
   [nir_op_bitz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         61,
         61,
         61,
         61,
         61,
         61,
         61,
         61,
         61,
         61,
         260,
         260,
         260,
         260,
         260,
         61,
         261,
         61,
         61,
         61,
         61,
         262,
         61,
         61,
         61,
      },
   },
   [nir_op_bitnz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         62,
         263,
         263,
         263,
         263,
         263,
         62,
         264,
         62,
         62,
         62,
         62,
         265,
         62,
         62,
         62,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         63,
         300,
         301,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         64,
         302,
         303,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         299,
         299,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         304,
         304,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         65,
         0,
         65,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         266,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 26,
      .table = (const uint16_t []) {
      
         66,
         463,
         464,
         465,
         466,
         467,
         468,
         469,
         470,
         471,
         472,
         473,
         474,
         475,
         476,
         477,
         478,
         479,
         480,
         481,
         482,
         483,
         484,
         485,
         486,
         487,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         67,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         309,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         310,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         311,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         312,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         313,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         314,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         315,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         316,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         317,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         318,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         319,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         320,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         321,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         68,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         69,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         70,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         71,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         72,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         73,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         322,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         323,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         324,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         325,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         326,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
         327,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         74,
         75,
         76,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         77,
         78,
         79,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         80,
         81,
         82,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         83,
         84,
         85,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   7,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   9,
   11,
   13,
   0,
   18,
   0,
   23,
   25,
   27,
   29,
   31,
   0,
   33,
   0,
   0,
   0,
   38,
   40,
   43,
   45,
   0,
   48,
   0,
   51,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   53,
   55,
   57,
   59,
   61,
   64,
   66,
   68,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   70,
   73,
   77,
   81,
   84,
   88,
   93,
   95,
   97,
   99,
   101,
   103,
   105,
   107,
   109,
   111,
   113,
   115,
   117,
   120,
   125,
   130,
   132,
   136,
   142,
   148,
   150,
   154,
   160,
   166,
   169,
   174,
   181,
   188,
   190,
   194,
   200,
   206,
   208,
   212,
   218,
   224,
   227,
   232,
   239,
   246,
   248,
   252,
   258,
   264,
   266,
   270,
   276,
   282,
   285,
   290,
   297,
   304,
   306,
   310,
   316,
   322,
   324,
   328,
   334,
   340,
   343,
   348,
   355,
   0,
   0,
   362,
   364,
   366,
   368,
   370,
   0,
   372,
   374,
   0,
   0,
   0,
   0,
   0,
   376,
   378,
   380,
   383,
   385,
   387,
   389,
   391,
   0,
   0,
   393,
   396,
   0,
   398,
   0,
   401,
   403,
   0,
   0,
   0,
   0,
   0,
   405,
   408,
   0,
   0,
   410,
   413,
   0,
   415,
   0,
   417,
   0,
   0,
   419,
   0,
   0,
   421,
   424,
   0,
   426,
   428,
   0,
   0,
   430,
   0,
   432,
   0,
   434,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   436,
   0,
   438,
   443,
   447,
   449,
   454,
   458,
   466,
   468,
   476,
   482,
   0,
   487,
   489,
   491,
   0,
   494,
   0,
   496,
   498,
   503,
   505,
   510,
   515,
   518,
   522,
   524,
   527,
   530,
   533,
   535,
   538,
   541,
   544,
   546,
   548,
   550,
   552,
   554,
   0,
   556,
   561,
   570,
   572,
   574,
   579,
   588,
   601,
   603,
   605,
   614,
   620,
   626,
   635,
   645,
   655,
   668,
   671,
   677,
   683,
   685,
   687,
   689,
   698,
   0,
   0,
   0,
   0,
   706,
   708,
   710,
   712,
   714,
   716,
   720,
   724,
   728,
   732,
   0,
   734,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   736,
   738,
   740,
   743,
   745,
   747,
   750,
   753,
   756,
   759,
   764,
   769,
   774,
   780,
   786,
   791,
   797,
   803,
   808,
   813,
   818,
   824,
   830,
   835,
   841,
   847,
   851,
   855,
   860,
   865,
   870,
   874,
   878,
   882,
   888,
   894,
   898,
   904,
   910,
   914,
   918,
   922,
   928,
   934,
   938,
   944,
   950,
   954,
   958,
   963,
   969,
   0,
   974,
   977,
   979,
   0,
   981,
   0,
   984,
   986,
   0,
   988,
   0,
   990,
   994,
   996,
   0,
   998,
   0,
   1002,
   1004,
   0,
   1006,
   1008,
   0,
   1010,
   1012,
   0,
   1014,
   0,
   1016,
   1018,
   0,
   1020,
   1022,
   1030,
   1036,
   1038,
   1042,
   1044,
   1046,
   1054,
   1060,
   1066,
   1073,
   1084,
   1086,
   1090,
   1092,
   1094,
   1100,
   1108,
   1114,
   1120,
   1131,
   1140,
   1145,
   1152,
   1157,
   1162,
   1171,
   1178,
   1181,
   1186,
   1189,
   1192,
   1201,
   1210,
   1221,
   1230,
   1239,
   1246,
   1255,
   1262,
   1269,
   1274,
   1277,
   1280,
   1285,
   1290,
   0,
   1293,
   1295,
   1297,
   1299,
   1301,
   1303,
   1306,
   1312,
   1315,
   1318,
   1321,
   1324,
   1327,
   1330,
   1333,
   1336,
   1339,
   1342,
   1345,
   1348,
   1351,
   1354,
   1357,
   1360,
   1363,
   1366,
   1369,
   1372,
   1375,
   1378,
   1381,
   1384,
   1387,
   1390,
   1393,
   1396,
   1400,
   1405,
   1410,
   1416,
   1421,
   1426,
   1432,
   1437,
   1442,
   1448,
   1453,
   1458,
   1464,
   1466,
   1470,
   1474,
   1479,
   1484,
   1489,
   1492,
   1496,
   1500,
   1505,
   1511,
   1516,
   1518,
   1520,
   1522,
   1524,
   1528,
   1530,
   1533,
   1535,
   1539,
   1541,
   1544,
   1550,
   1560,
   1566,
   1576,
   1590,
   1600,
   1610,
   1624,
   1634,
   1648,
   1666,
   1680,
   1687,
   1698,
   1705,
   1715,
   1729,
   1739,
   1749,
   1763,
   1772,
   1774,
   0,
   1776,
   1782,
   1789,
   1796,
   1802,
   1809,
   1816,
   1824,
   1830,
   1837,
   1844,
   1850,
   1857,
   1864,
   1872,
   1877,
   1883,
   1889,
   1894,
   1902,
   1910,
   1915,
   1923,
   1931,
   1942,
   1947,
   1955,
   1963,
   1968,
   1976,
   1984,
   1995,
   2000,
   2007,
   2015,
   2023,
   2028,
   2034,
   2040,
   2045,
   2052,
   2060,
   2068,
   2070,
   2078,
   2084,
   2086,
   2088,
   2096,
   2102,
   2104,
   2110,
   2116,
   2121,
   2132,
   2141,
   2146,
   2149,
   2158,
   2165,
   2168,
   2177,
   2188,
   2197,
   2206,
   2213,
   2222,
   2229,
   2236,
   2239,
   2248,
   2255,
   2258,
   2263,
   2274,
   2283,
   2288,
   2291,
   2300,
   2307,
   2310,
   2313,
   2322,
   2329,
   2332,
   2341,
   2348,
   2351,
   2360,
   2369,
   2376,
   2378,
   2380,
   2386,
   2392,
   2398,
   2404,
   2413,
   2422,
   2429,
   2436,
   2445,
   2454,
   2461,
   2468,
   2475,
   2482,
   2491,
   2500,
   2507,
   2514,
   2521,
   2528,
   2535,
   2542,
   2551,
   2560,
   2567,
   2574,
   2581,
   2588,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(
   nir_shader *shader
) {
   bool progress = false;
   bool condition_flags[173];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(1136 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !options->lower_ftrunc || options->lower_ffloor;
   condition_flags[6] = !options->lower_iadd_sat;
   condition_flags[7] = !options->lower_uadd_sat;
   condition_flags[8] = (options->has_fmulz ||               (options->has_fmulz_no_denorms &&                !nir_is_denorm_preserve(info->float_controls_execution_mode, 32)));
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = !options->has_udot_4x8_sat;
   condition_flags[14] = !options->has_sdot_4x8_sat;
   condition_flags[15] = !options->has_sudot_4x8_sat;
   condition_flags[16] = options->lower_flrp16;
   condition_flags[17] = !options->lower_flrp16;
   condition_flags[18] = options->lower_flrp32;
   condition_flags[19] = !options->lower_flrp32;
   condition_flags[20] = options->lower_flrp64;
   condition_flags[21] = !options->lower_flrp64;
   condition_flags[22] = options->lower_ftrunc;
   condition_flags[23] = (options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[24] = options->lower_ffloor;
   condition_flags[25] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[26] = !options->lower_ffloor;
   condition_flags[27] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[28] = options->lower_ffract;
   condition_flags[29] = (options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[30] = options->lower_fceil;
   condition_flags[31] = options->lower_ffma16;
   condition_flags[32] = options->lower_ffma32;
   condition_flags[33] = options->lower_ffma64;
   condition_flags[34] = options->fuse_ffma16;
   condition_flags[35] = options->fuse_ffma32;
   condition_flags[36] = options->fuse_ffma64;
   condition_flags[37] = options->lower_fdph;
   condition_flags[38] = !options->lower_fdph;
   condition_flags[39] = options->lower_fdot;
   condition_flags[40] = !options->lower_fsat;
   condition_flags[41] = !options->lower_iabs;
   condition_flags[42] = options->lower_fsat;
   condition_flags[43] = !options->lower_fsign;
   condition_flags[44] = !options->lower_fsign & !(options->lower_doubles_options & nir_lower_dsign);
   condition_flags[45] = options->lower_umax && !options->lower_bitops;
   condition_flags[46] = options->lower_umin && !options->lower_bitops;
   condition_flags[47] = !options->lower_umax;
   condition_flags[48] = !options->lower_umin;
   condition_flags[49] = !false;
   condition_flags[50] = (options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[51] = (options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[52] = !(options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[53] = !(options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[54] = !((options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[55] = options->lower_scmp;
   condition_flags[56] = options->lower_vector_cmp;
   condition_flags[57] = !options->lower_pack_64_2x32_split;
   condition_flags[58] = options->has_rotate16;
   condition_flags[59] = options->has_rotate32;
   condition_flags[60] = !options->has_rotate8;
   condition_flags[61] = !options->has_rotate16;
   condition_flags[62] = !options->has_rotate32;
   condition_flags[63] = options->has_shfr32;
   condition_flags[64] = options->lower_fpow;
   condition_flags[65] = !options->lower_fpow;
   condition_flags[66] = options->lower_fdiv;
   condition_flags[67] = options->lower_fsqrt;
   condition_flags[68] = !options->lower_fsqrt;
   condition_flags[69] = options->lower_sincos;
   condition_flags[70] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[71] = !options->lower_extract_byte;
   condition_flags[72] = !options->lower_extract_word;
   condition_flags[73] = options->has_pack_32_4x8;
   condition_flags[74] = options->lower_pack_64_2x32_split;
   condition_flags[75] = options->lower_pack_32_2x16_split || options->lower_pack_split;
   condition_flags[76] = options->has_pack_half_2x16_rtz;
   condition_flags[77] = options->lower_unpack_64_2x32_split;
   condition_flags[78] = options->lower_unpack_32_2x16_split || options->lower_pack_split;
   condition_flags[79] = !options->lower_unpack_64_2x32_split;
   condition_flags[80] = options->has_find_msb_rev;
   condition_flags[81] = !options->lower_ifind_msb;
   condition_flags[82] = !options->lower_ufind_msb;
   condition_flags[83] = !options->lower_find_lsb;
   condition_flags[84] = options->lower_fmod;
   condition_flags[85] = options->lower_uadd_carry;
   condition_flags[86] = options->lower_usub_borrow;
   condition_flags[87] = options->lower_bitfield_insert && options->has_bfm && options->has_bfi;
   condition_flags[88] = options->lower_hadd;
   condition_flags[89] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[90] = options->lower_mul_32x16;
   condition_flags[91] = options->lower_uadd_sat || (options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64)) != 0;
   condition_flags[92] = options->lower_uadd_sat;
   condition_flags[93] = options->lower_usub_sat;
   condition_flags[94] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[95] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[96] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[97] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[98] = options->lower_bitfield_insert && (!options->has_bfm || (!options->has_bfi && !options->has_bitfield_select));
   condition_flags[99] = options->lower_bitfield_insert && options->has_bfm && options->has_bitfield_select;
   condition_flags[100] = options->lower_bitfield_extract && options->has_bfe;
   condition_flags[101] = options->has_bfm;
   condition_flags[102] = options->lower_bitfield_extract && !options->has_bfe;
   condition_flags[103] = options->lower_ifind_msb && !options->has_find_msb_rev && !options->has_uclz;
   condition_flags[104] = options->lower_ifind_msb && options->has_find_msb_rev;
   condition_flags[105] = options->lower_ifind_msb && options->has_uclz;
   condition_flags[106] = options->lower_ufind_msb && options->has_find_msb_rev;
   condition_flags[107] = options->lower_ufind_msb && options->has_uclz;
   condition_flags[108] = !options->has_uclz && options->has_find_msb_rev;
   condition_flags[109] = options->lower_find_lsb;
   condition_flags[110] = options->lower_extract_byte;
   condition_flags[111] = options->lower_extract_word;
   condition_flags[112] = options->lower_pack_unorm_2x16;
   condition_flags[113] = options->lower_pack_unorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[114] = options->lower_pack_unorm_4x8 && options->has_pack_32_4x8;
   condition_flags[115] = options->lower_pack_snorm_2x16;
   condition_flags[116] = options->lower_pack_snorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[117] = options->lower_pack_snorm_4x8 && options->has_pack_32_4x8;
   condition_flags[118] = options->lower_unpack_unorm_2x16;
   condition_flags[119] = options->lower_unpack_unorm_4x8;
   condition_flags[120] = options->lower_unpack_snorm_2x16;
   condition_flags[121] = options->lower_unpack_snorm_4x8;
   condition_flags[122] = options->lower_pack_split;
   condition_flags[123] = options->lower_pack_split && !nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[124] = options->lower_pack_split && nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[125] = options->lower_isign;
   condition_flags[126] = !options->lower_isign;
   condition_flags[127] = options->lower_fsign;
   condition_flags[128] = options->lower_doubles_options & nir_lower_dsign;
   condition_flags[129] = !options->has_imul24;
   condition_flags[130] = !options->has_umul24;
   condition_flags[131] = !options->has_umad24;
   condition_flags[132] = options->has_imul24;
   condition_flags[133] = options->has_umad24;
   condition_flags[134] = options->has_umul24;
   condition_flags[135] = !options->lower_uadd_sat && !(options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64));
   condition_flags[136] = !options->lower_usub_sat;
   condition_flags[137] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[138] = options->lower_iadd_sat;
   condition_flags[139] = options->support_8bit_alu;
   condition_flags[140] = options->support_16bit_alu;
   condition_flags[141] = options->lower_ldexp;
   condition_flags[142] = !options->lower_bitfield_reverse;
   condition_flags[143] = options->has_msad;
   condition_flags[144] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[145] = options->lower_fisnormal;
   condition_flags[146] = options->lower_fquantize2f16;
   condition_flags[147] = options->avoid_ternary_with_two_constants;
   condition_flags[148] = !options->vectorize_vec2_16bit;
   condition_flags[149] = (options->lower_int64_options & nir_lower_shift64) != 0;
   condition_flags[150] = (options->lower_int64_options & nir_lower_ineg64) != 0;
   condition_flags[151] = options->has_fneo_fcmpu;
   condition_flags[152] = options->has_ford_funord;
   condition_flags[153] = options->has_imad32;
   condition_flags[154] = options->has_fsub;
   condition_flags[155] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[156] = options->lower_fneg;
   condition_flags[157] = options->has_isub || options->lower_ineg;
   condition_flags[158] = options->lower_ineg;
   condition_flags[159] = options->lower_iabs;
   condition_flags[160] = options->has_iadd3;
   condition_flags[161] = options->has_iadd3 && !(options->lower_int64_options & nir_lower_iadd3_64);
   condition_flags[162] = options->vectorize_vec2_16bit;
   condition_flags[163] = options->fdot_replicates;
   condition_flags[164] = options->lower_fround_even;
   condition_flags[165] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[166] = options->has_bit_test;
   condition_flags[167] = !options->lower_insert_byte;
   condition_flags[168] = !options->lower_insert_word;
   condition_flags[169] = !options->preserve_mediump;
   condition_flags[170] = options->force_f2f16_rtz && !nir_is_rounding_mode_rtne(info->float_controls_execution_mode, 16);
   condition_flags[171] = options->has_fused_comp_and_csel;
   condition_flags[172] = options->has_fused_comp_and_csel && !options->no_integers;

   nir_foreach_function_impl(impl, shader) {
     progress |= nir_algebraic_impl(impl, condition_flags, &nir_opt_algebraic_late_table);
   }

   return progress;
}

#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2773_0 -> 0 in the cache */
   /* replace2773_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2774_0 -> 6 in the cache */
   /* replace2774_1 -> 8 in the cache */
   /* replace2774_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2775_0_0 -> 0 in the cache */
   /* search2775_0 -> 1 in the cache */
   /* search2775_1_0 -> 2 in the cache */
   /* search2775_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2775_0 -> 0 in the cache */
   /* replace2775_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2776_0_0 -> 0 in the cache */
   /* search2776_0 -> 1 in the cache */
   /* search2776_1_0 -> 2 in the cache */
   /* search2776_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2776_0 -> 0 in the cache */
   /* replace2776_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2777_0_0 -> 0 in the cache */
   /* search2777_0 -> 1 in the cache */
   /* search2777_1_0 -> 2 in the cache */
   /* search2777_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2777_0 -> 0 in the cache */
   /* replace2777_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2778 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2779_0_0 -> 0 in the cache */
   /* search2779_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2779_0_0 -> 0 in the cache */
   /* replace2779_0 -> 1 in the cache */
   /* replace2779_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2780_0_0 -> 0 in the cache */
   /* search2780_0_1 -> 2 in the cache */
   /* search2780_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2780_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2780_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2781_0_0 -> 6 in the cache */
   /* search2781_0_1 -> 8 in the cache */
   /* search2781_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2781_0_0 -> 6 in the cache */
   /* replace2781_0 -> 7 in the cache */
   /* replace2781_1 -> 8 in the cache */
   /* replace2781_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2782_0_0 -> 6 in the cache */
   /* search2782_0_1 -> 8 in the cache */
   /* search2782_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2782_0_0 -> 6 in the cache */
   /* replace2782_0 -> 7 in the cache */
   /* replace2782_1_0 -> 8 in the cache */
   /* replace2782_1 -> 9 in the cache */
   /* replace2782_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2783_0_0 -> 0 in the cache */
   /* search2783_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2783_0_0 -> 0 in the cache */
   /* replace2783_0 -> 1 in the cache */
   /* replace2783_1_0 -> 2 in the cache */
   /* replace2783_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2784_0_0 -> 0 in the cache */
   /* search2784_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2784_0_0 -> 0 in the cache */
   /* replace2784_0 -> 1 in the cache */
   /* replace2784_1_0 -> 2 in the cache */
   /* replace2784_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2785_0_0 -> 0 in the cache */
   /* search2785_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2785_0_0 -> 0 in the cache */
   /* replace2785_0 -> 1 in the cache */
   /* replace2785_1_0 -> 2 in the cache */
   /* replace2785_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2786_0_0 -> 0 in the cache */
   /* search2786_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2786_0_0 -> 0 in the cache */
   /* replace2786_0 -> 1 in the cache */
   /* replace2786_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2787_0_0 -> 0 in the cache */
   /* search2787_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2787_0_0 -> 0 in the cache */
   /* replace2787_0 -> 1 in the cache */
   /* replace2787_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2788_0_0 -> 0 in the cache */
   /* search2788_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2788_0_0 -> 0 in the cache */
   /* replace2788_0 -> 1 in the cache */
   /* replace2788_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2789_0_0 -> 0 in the cache */
   /* search2789_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2789_0 -> 0 in the cache */
   /* replace2789_1_0 -> 2 in the cache */
   /* replace2789_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2790_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2790_0_0 -> 19 in the cache */
   /* replace2790_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2791_0_0 -> 19 in the cache */
   /* search2791_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2791_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   is_used_once,
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(
   nir_shader *shader
) {
   bool progress = false;
   bool condition_flags[173];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !options->lower_ftrunc || options->lower_ffloor;
   condition_flags[6] = !options->lower_iadd_sat;
   condition_flags[7] = !options->lower_uadd_sat;
   condition_flags[8] = (options->has_fmulz ||               (options->has_fmulz_no_denorms &&                !nir_is_denorm_preserve(info->float_controls_execution_mode, 32)));
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = !options->has_udot_4x8_sat;
   condition_flags[14] = !options->has_sdot_4x8_sat;
   condition_flags[15] = !options->has_sudot_4x8_sat;
   condition_flags[16] = options->lower_flrp16;
   condition_flags[17] = !options->lower_flrp16;
   condition_flags[18] = options->lower_flrp32;
   condition_flags[19] = !options->lower_flrp32;
   condition_flags[20] = options->lower_flrp64;
   condition_flags[21] = !options->lower_flrp64;
   condition_flags[22] = options->lower_ftrunc;
   condition_flags[23] = (options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[24] = options->lower_ffloor;
   condition_flags[25] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[26] = !options->lower_ffloor;
   condition_flags[27] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[28] = options->lower_ffract;
   condition_flags[29] = (options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract)) && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[30] = options->lower_fceil;
   condition_flags[31] = options->lower_ffma16;
   condition_flags[32] = options->lower_ffma32;
   condition_flags[33] = options->lower_ffma64;
   condition_flags[34] = options->fuse_ffma16;
   condition_flags[35] = options->fuse_ffma32;
   condition_flags[36] = options->fuse_ffma64;
   condition_flags[37] = options->lower_fdph;
   condition_flags[38] = !options->lower_fdph;
   condition_flags[39] = options->lower_fdot;
   condition_flags[40] = !options->lower_fsat;
   condition_flags[41] = !options->lower_iabs;
   condition_flags[42] = options->lower_fsat;
   condition_flags[43] = !options->lower_fsign;
   condition_flags[44] = !options->lower_fsign & !(options->lower_doubles_options & nir_lower_dsign);
   condition_flags[45] = options->lower_umax && !options->lower_bitops;
   condition_flags[46] = options->lower_umin && !options->lower_bitops;
   condition_flags[47] = !options->lower_umax;
   condition_flags[48] = !options->lower_umin;
   condition_flags[49] = !false;
   condition_flags[50] = (options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[51] = (options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0) && !(options->lower_bitops || (options->lower_int64_options & nir_lower_logic64) != 0);
   condition_flags[52] = !(options->lower_umax || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[53] = !(options->lower_umin || (options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[54] = !((options->lower_int64_options & nir_lower_minmax64) != 0);
   condition_flags[55] = options->lower_scmp;
   condition_flags[56] = options->lower_vector_cmp;
   condition_flags[57] = !options->lower_pack_64_2x32_split;
   condition_flags[58] = options->has_rotate16;
   condition_flags[59] = options->has_rotate32;
   condition_flags[60] = !options->has_rotate8;
   condition_flags[61] = !options->has_rotate16;
   condition_flags[62] = !options->has_rotate32;
   condition_flags[63] = options->has_shfr32;
   condition_flags[64] = options->lower_fpow;
   condition_flags[65] = !options->lower_fpow;
   condition_flags[66] = options->lower_fdiv;
   condition_flags[67] = options->lower_fsqrt;
   condition_flags[68] = !options->lower_fsqrt;
   condition_flags[69] = options->lower_sincos;
   condition_flags[70] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[71] = !options->lower_extract_byte;
   condition_flags[72] = !options->lower_extract_word;
   condition_flags[73] = options->has_pack_32_4x8;
   condition_flags[74] = options->lower_pack_64_2x32_split;
   condition_flags[75] = options->lower_pack_32_2x16_split || options->lower_pack_split;
   condition_flags[76] = options->has_pack_half_2x16_rtz;
   condition_flags[77] = options->lower_unpack_64_2x32_split;
   condition_flags[78] = options->lower_unpack_32_2x16_split || options->lower_pack_split;
   condition_flags[79] = !options->lower_unpack_64_2x32_split;
   condition_flags[80] = options->has_find_msb_rev;
   condition_flags[81] = !options->lower_ifind_msb;
   condition_flags[82] = !options->lower_ufind_msb;
   condition_flags[83] = !options->lower_find_lsb;
   condition_flags[84] = options->lower_fmod;
   condition_flags[85] = options->lower_uadd_carry;
   condition_flags[86] = options->lower_usub_borrow;
   condition_flags[87] = options->lower_bitfield_insert && options->has_bfm && options->has_bfi;
   condition_flags[88] = options->lower_hadd;
   condition_flags[89] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[90] = options->lower_mul_32x16;
   condition_flags[91] = options->lower_uadd_sat || (options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64)) != 0;
   condition_flags[92] = options->lower_uadd_sat;
   condition_flags[93] = options->lower_usub_sat;
   condition_flags[94] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[95] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[96] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[97] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[98] = options->lower_bitfield_insert && (!options->has_bfm || (!options->has_bfi && !options->has_bitfield_select));
   condition_flags[99] = options->lower_bitfield_insert && options->has_bfm && options->has_bitfield_select;
   condition_flags[100] = options->lower_bitfield_extract && options->has_bfe;
   condition_flags[101] = options->has_bfm;
   condition_flags[102] = options->lower_bitfield_extract && !options->has_bfe;
   condition_flags[103] = options->lower_ifind_msb && !options->has_find_msb_rev && !options->has_uclz;
   condition_flags[104] = options->lower_ifind_msb && options->has_find_msb_rev;
   condition_flags[105] = options->lower_ifind_msb && options->has_uclz;
   condition_flags[106] = options->lower_ufind_msb && options->has_find_msb_rev;
   condition_flags[107] = options->lower_ufind_msb && options->has_uclz;
   condition_flags[108] = !options->has_uclz && options->has_find_msb_rev;
   condition_flags[109] = options->lower_find_lsb;
   condition_flags[110] = options->lower_extract_byte;
   condition_flags[111] = options->lower_extract_word;
   condition_flags[112] = options->lower_pack_unorm_2x16;
   condition_flags[113] = options->lower_pack_unorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[114] = options->lower_pack_unorm_4x8 && options->has_pack_32_4x8;
   condition_flags[115] = options->lower_pack_snorm_2x16;
   condition_flags[116] = options->lower_pack_snorm_4x8 && !options->has_pack_32_4x8;
   condition_flags[117] = options->lower_pack_snorm_4x8 && options->has_pack_32_4x8;
   condition_flags[118] = options->lower_unpack_unorm_2x16;
   condition_flags[119] = options->lower_unpack_unorm_4x8;
   condition_flags[120] = options->lower_unpack_snorm_2x16;
   condition_flags[121] = options->lower_unpack_snorm_4x8;
   condition_flags[122] = options->lower_pack_split;
   condition_flags[123] = options->lower_pack_split && !nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[124] = options->lower_pack_split && nir_is_denorm_flush_to_zero(info->float_controls_execution_mode, 16);
   condition_flags[125] = options->lower_isign;
   condition_flags[126] = !options->lower_isign;
   condition_flags[127] = options->lower_fsign;
   condition_flags[128] = options->lower_doubles_options & nir_lower_dsign;
   condition_flags[129] = !options->has_imul24;
   condition_flags[130] = !options->has_umul24;
   condition_flags[131] = !options->has_umad24;
   condition_flags[132] = options->has_imul24;
   condition_flags[133] = options->has_umad24;
   condition_flags[134] = options->has_umul24;
   condition_flags[135] = !options->lower_uadd_sat && !(options->lower_int64_options & (nir_lower_iadd64 | nir_lower_uadd_sat64));
   condition_flags[136] = !options->lower_usub_sat;
   condition_flags[137] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[138] = options->lower_iadd_sat;
   condition_flags[139] = options->support_8bit_alu;
   condition_flags[140] = options->support_16bit_alu;
   condition_flags[141] = options->lower_ldexp;
   condition_flags[142] = !options->lower_bitfield_reverse;
   condition_flags[143] = options->has_msad;
   condition_flags[144] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[145] = options->lower_fisnormal;
   condition_flags[146] = options->lower_fquantize2f16;
   condition_flags[147] = options->avoid_ternary_with_two_constants;
   condition_flags[148] = !options->vectorize_vec2_16bit;
   condition_flags[149] = (options->lower_int64_options & nir_lower_shift64) != 0;
   condition_flags[150] = (options->lower_int64_options & nir_lower_ineg64) != 0;
   condition_flags[151] = options->has_fneo_fcmpu;
   condition_flags[152] = options->has_ford_funord;
   condition_flags[153] = options->has_imad32;
   condition_flags[154] = options->has_fsub;
   condition_flags[155] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[156] = options->lower_fneg;
   condition_flags[157] = options->has_isub || options->lower_ineg;
   condition_flags[158] = options->lower_ineg;
   condition_flags[159] = options->lower_iabs;
   condition_flags[160] = options->has_iadd3;
   condition_flags[161] = options->has_iadd3 && !(options->lower_int64_options & nir_lower_iadd3_64);
   condition_flags[162] = options->vectorize_vec2_16bit;
   condition_flags[163] = options->fdot_replicates;
   condition_flags[164] = options->lower_fround_even;
   condition_flags[165] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[166] = options->has_bit_test;
   condition_flags[167] = !options->lower_insert_byte;
   condition_flags[168] = !options->lower_insert_word;
   condition_flags[169] = !options->preserve_mediump;
   condition_flags[170] = options->force_f2f16_rtz && !nir_is_rounding_mode_rtne(info->float_controls_execution_mode, 16);
   condition_flags[171] = options->has_fused_comp_and_csel;
   condition_flags[172] = options->has_fused_comp_and_csel && !options->no_integers;

   nir_foreach_function_impl(impl, shader) {
     progress |= nir_algebraic_impl(impl, condition_flags, &nir_opt_algebraic_distribute_src_mods_table);
   }

   return progress;
}
